@@ -11,34 +11,29 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "irisnetplugin.h"
+#include "qdnssd.h"
 
 #include <QtCore>
 #include <QtNetwork>
-#include "qdnssd.h"
-
-// for ntohl
-#ifdef Q_OS_WIN
-# include <windows.h>
+#ifdef Q_OS_WIN // for ntohl
+#include <windows.h>
 #else
-# include <netinet/in.h>
+#include <netinet/in.h>
 #endif
 
 static QByteArray nameToDottedString(const QByteArray &in)
 {
     QByteArray out;
-    int at = 0;
-    while(at < in.size())
-    {
+    int        at = 0;
+    while (at < in.size()) {
         int len = in[at++];
-        if(len > 0)
+        if (len > 0)
             out += in.mid(at, len);
         out += '.';
         at += len;
@@ -46,21 +41,17 @@ static QByteArray nameToDottedString(const QByteArray &in)
     return out;
 }
 
-static QMap<QString,QByteArray> textsToAttribs(const QList<QByteArray> &texts)
+static QMap<QString, QByteArray> textsToAttribs(const QList<QByteArray> &texts)
 {
-    QMap<QString,QByteArray> out;
-    foreach(const QByteArray &a, texts)
-    {
-        QString key;
+    QMap<QString, QByteArray> out;
+    for (const QByteArray &a : texts) {
+        QString    key;
         QByteArray value;
-        int x = a.indexOf('=');
-        if(x != -1)
-        {
-            key = QString::fromLatin1(a.mid(0, x));
+        int        x = a.indexOf('=');
+        if (x != -1) {
+            key   = QString::fromLatin1(a.mid(0, x));
             value = a.mid(x + 1);
-        }
-        else
-        {
+        } else {
             key = QString::fromLatin1(a);
         }
 
@@ -69,12 +60,11 @@ static QMap<QString,QByteArray> textsToAttribs(const QList<QByteArray> &texts)
     return out;
 }
 
-static QByteArray attribsToTxtRecord(const QMap<QString,QByteArray> &attribs)
+static QByteArray attribsToTxtRecord(const QMap<QString, QByteArray> &attribs)
 {
-    QList<QByteArray> texts;
-    QMapIterator<QString,QByteArray> it(attribs);
-    while(it.hasNext())
-    {
+    QList<QByteArray>                 texts;
+    QMapIterator<QString, QByteArray> it(attribs);
+    while (it.hasNext()) {
         it.next();
         QByteArray line = it.key().toLatin1() + '=' + it.value();
         texts += line;
@@ -86,14 +76,14 @@ static QByteArray attribsToTxtRecord(const QMap<QString,QByteArray> &attribs)
 static QList<QByteArray> nameToInstanceParts(const QByteArray &name)
 {
     // FIXME: improve this parsing...  (what about escaping??)
-    int at = name.indexOf('.');
+    int        at    = name.indexOf('.');
     QByteArray sname = name.mid(0, at);
     ++at;
     int next = name.indexOf('.', at);
     ++next;
-    next = name.indexOf('.', next);
-    QByteArray stype = name.mid(at, next - at);
-    at = next + 1;
+    next               = name.indexOf('.', next);
+    QByteArray stype   = name.mid(at, next - at);
+    at                 = next + 1;
     QByteArray sdomain = name.mid(at);
 
     QList<QByteArray> out;
@@ -106,46 +96,40 @@ static QList<QByteArray> nameToInstanceParts(const QByteArray &name)
 static XMPP::NameRecord importQDnsSdRecord(const QDnsSd::Record &in)
 {
     XMPP::NameRecord out;
-    switch(in.rrtype)
+    switch (in.rrtype) {
+    case 1: // A
     {
-        case 1: // A
-        {
-            quint32 *p = (quint32 *)in.rdata.data();
-            out.setAddress(QHostAddress(ntohl(*p)));
-        }
-        break;
+        quint32 *p = (quint32 *)in.rdata.data();
+        out.setAddress(QHostAddress(ntohl(*p)));
+    } break;
 
-        case 28: // AAAA
-        {
-            out.setAddress(QHostAddress((quint8 *)in.rdata.data()));
-        }
-        break;
+    case 28: // AAAA
+    {
+        out.setAddress(QHostAddress((quint8 *)in.rdata.data()));
+    } break;
 
-        case 12: // PTR
-        {
-            out.setPtr(nameToDottedString(in.rdata));
-        }
-        break;
+    case 12: // PTR
+    {
+        out.setPtr(nameToDottedString(in.rdata));
+    } break;
 
-        case 10: // NULL
-        {
-            out.setNull(in.rdata);
-        }
-        break;
+    case 10: // NULL
+    {
+        out.setNull(in.rdata);
+    } break;
 
-        case 16: // TXT
-        {
-            QList<QByteArray> txtEntries = QDnsSd::parseTxtRecord(in.rdata);
-            if(txtEntries.isEmpty())
-                return out;
-            out.setTxt(txtEntries);
-        }
-        break;
-
-        default: // unsupported
-        {
+    case 16: // TXT
+    {
+        QList<QByteArray> txtEntries = QDnsSd::parseTxtRecord(in.rdata);
+        if (txtEntries.isEmpty())
             return out;
-        }
+        out.setTxt(txtEntries);
+    } break;
+
+    default: // unsupported
+    {
+        return out;
+    }
     }
 
     out.setOwner(in.name);
@@ -154,13 +138,9 @@ static XMPP::NameRecord importQDnsSdRecord(const QDnsSd::Record &in)
 }
 
 namespace {
-
-class QDnsSdDelegate
-{
+class QDnsSdDelegate {
 public:
-    virtual ~QDnsSdDelegate()
-    {
-    }
+    virtual ~QDnsSdDelegate() { }
 
     virtual void dns_queryResult(int id, const QDnsSd::QueryResult &result)
     {
@@ -187,32 +167,26 @@ public:
     }
 };
 
-class IdManager
-{
+class IdManager {
 private:
     QSet<int> set;
-    int at;
+    int       at;
 
     inline void bump_at()
     {
-        if(at == 0x7fffffff)
+        if (at == 0x7fffffff)
             at = 0;
         else
             ++at;
     }
 
 public:
-    IdManager() :
-        at(0)
-    {
-    }
+    IdManager() : at(0) { }
 
     int reserveId()
     {
-        while(1)
-        {
-            if(!set.contains(at))
-            {
+        while (1) {
+            if (!set.contains(at)) {
                 int id = at;
                 set.insert(id);
                 bump_at();
@@ -223,62 +197,62 @@ public:
         }
     }
 
-    void releaseId(int id)
-    {
-        set.remove(id);
-    }
+    void releaseId(int id) { set.remove(id); }
 };
 
-}
+} // namespace
 
 //----------------------------------------------------------------------------
 // AppleProvider
 //----------------------------------------------------------------------------
-class AppleProvider : public XMPP::IrisNetProvider
-{
+class AppleProvider : public XMPP::IrisNetProvider {
     Q_OBJECT
     Q_INTERFACES(XMPP::IrisNetProvider);
-public:
-    QDnsSd dns;
-    QHash<int,QDnsSdDelegate*> delegateById;
 
-    AppleProvider() :
-        dns(this)
+public:
+    QDnsSd                       dns;
+    QHash<int, QDnsSdDelegate *> delegateById;
+
+    AppleProvider() : dns(this)
     {
-        connect(&dns, SIGNAL(queryResult(int,QDnsSd::QueryResult)), SLOT(dns_queryResult(int,QDnsSd::QueryResult)));
-        connect(&dns, SIGNAL(browseResult(int,QDnsSd::BrowseResult)), SLOT(dns_browseResult(int,QDnsSd::BrowseResult)));
-        connect(&dns, SIGNAL(resolveResult(int,QDnsSd::ResolveResult)), SLOT(dns_resolveResult(int,QDnsSd::ResolveResult)));
-        connect(&dns, SIGNAL(regResult(int,QDnsSd::RegResult)), SLOT(dns_regResult(int,QDnsSd::RegResult)));
+        connect(&dns, SIGNAL(queryResult(int, QDnsSd::QueryResult)), SLOT(dns_queryResult(int, QDnsSd::QueryResult)));
+        connect(&dns, SIGNAL(browseResult(int, QDnsSd::BrowseResult)),
+                SLOT(dns_browseResult(int, QDnsSd::BrowseResult)));
+        connect(&dns, SIGNAL(resolveResult(int, QDnsSd::ResolveResult)),
+                SLOT(dns_resolveResult(int, QDnsSd::ResolveResult)));
+        connect(&dns, SIGNAL(regResult(int, QDnsSd::RegResult)), SLOT(dns_regResult(int, QDnsSd::RegResult)));
     }
 
-    virtual XMPP::NameProvider *createNameProviderInternet();
-    virtual XMPP::NameProvider *createNameProviderLocal();
+    virtual XMPP::NameProvider *   createNameProviderInternet();
+    virtual XMPP::NameProvider *   createNameProviderLocal();
     virtual XMPP::ServiceProvider *createServiceProvider();
 
     int query(QDnsSdDelegate *p, const QByteArray &name, int qType)
     {
-        int id = dns.query(name, qType);
+        int id           = dns.query(name, qType);
         delegateById[id] = p;
         return id;
     }
 
     int browse(QDnsSdDelegate *p, const QByteArray &serviceType, const QByteArray &domain)
     {
-        int id = dns.browse(serviceType, domain);
+        int id           = dns.browse(serviceType, domain);
         delegateById[id] = p;
         return id;
     }
 
-    int resolve(QDnsSdDelegate *p, const QByteArray &serviceName, const QByteArray &serviceType, const QByteArray &domain)
+    int resolve(QDnsSdDelegate *p, const QByteArray &serviceName, const QByteArray &serviceType,
+                const QByteArray &domain)
     {
-        int id = dns.resolve(serviceName, serviceType, domain);
+        int id           = dns.resolve(serviceName, serviceType, domain);
         delegateById[id] = p;
         return id;
     }
 
-    int reg(QDnsSdDelegate *p, const QByteArray &serviceName, const QByteArray &serviceType, const QByteArray &domain, int port, const QByteArray &txtRecord)
+    int reg(QDnsSdDelegate *p, const QByteArray &serviceName, const QByteArray &serviceType, const QByteArray &domain,
+            int port, const QByteArray &txtRecord)
     {
-        int id = dns.reg(serviceName, serviceType, domain, port, txtRecord);
+        int id           = dns.reg(serviceName, serviceType, domain, port, txtRecord);
         delegateById[id] = p;
         return id;
     }
@@ -291,23 +265,19 @@ public:
 
     void stop_all(QDnsSdDelegate *p)
     {
-        QList<int> ids;
-        QHashIterator<int,QDnsSdDelegate*> it(delegateById);
-        while(it.hasNext())
-        {
+        QList<int>                           ids;
+        QHashIterator<int, QDnsSdDelegate *> it(delegateById);
+        while (it.hasNext()) {
             it.next();
-            if(it.value() == p)
+            if (it.value() == p)
                 ids += it.key();
         }
-        foreach(int id, ids)
+        for (int id : ids)
             stop(id);
     }
 
 private slots:
-    void dns_queryResult(int id, const QDnsSd::QueryResult &result)
-    {
-        delegateById[id]->dns_queryResult(id, result);
-    }
+    void dns_queryResult(int id, const QDnsSd::QueryResult &result) { delegateById[id]->dns_queryResult(id, result); }
 
     void dns_browseResult(int id, const QDnsSd::BrowseResult &result)
     {
@@ -319,10 +289,7 @@ private slots:
         delegateById[id]->dns_resolveResult(id, result);
     }
 
-    void dns_regResult(int id, const QDnsSd::RegResult &result)
-    {
-        delegateById[id]->dns_regResult(id, result);
-    }
+    void dns_regResult(int id, const QDnsSd::RegResult &result) { delegateById[id]->dns_regResult(id, result); }
 };
 
 //----------------------------------------------------------------------------
@@ -330,27 +297,20 @@ private slots:
 //----------------------------------------------------------------------------
 // only use this class for a single browse.  if you want to browse again,
 //   create a new object.
-class AppleBrowse : public QObject, public QDnsSdDelegate
-{
+class AppleBrowse : public QObject, public QDnsSdDelegate {
     Q_OBJECT
 public:
-    AppleProvider *global;
-    int browse_id;
+    AppleProvider *              global;
+    int                          browse_id;
     QList<XMPP::ServiceInstance> instances;
-    QHash<int,QByteArray> pendingByQueryId; // waiting for TXT
+    QHash<int, QByteArray>       pendingByQueryId; // waiting for TXT
 
-    AppleBrowse(AppleProvider *_global, QObject *parent = 0) :
-        QObject(parent),
-        global(_global),
-        browse_id(-1)
+    AppleBrowse(AppleProvider *_global, QObject *parent = 0) : QObject(parent), global(_global), browse_id(-1)
     {
         connect(this, SIGNAL(unavailable_p(XMPP::ServiceInstance)), SIGNAL(unavailable(XMPP::ServiceInstance)));
     }
 
-    ~AppleBrowse()
-    {
-        global->stop_all(this);
-    }
+    ~AppleBrowse() { global->stop_all(this); }
 
     void browse(const QString &type, const QString &domain)
     {
@@ -370,30 +330,24 @@ protected:
     {
         Q_UNUSED(id);
 
-        if(!result.success)
-        {
+        if (!result.success) {
             emit error();
             return;
         }
 
-        foreach(const QDnsSd::BrowseEntry &e, result.entries)
-        {
-            XMPP::ServiceInstance si(e.serviceName, e.serviceType, e.replyDomain, QMap<QString,QByteArray>());
+        for (const QDnsSd::BrowseEntry &e : result.entries) {
+            XMPP::ServiceInstance si(e.serviceName, e.serviceType, e.replyDomain, QMap<QString, QByteArray>());
 
-            if(e.added)
-            {
-                int query_id = global->query(this, si.name(), 16); // 16 == TXT
+            if (e.added) {
+                int query_id               = global->query(this, si.name(), 16); // 16 == TXT
                 pendingByQueryId[query_id] = si.name();
-            }
-            else // removed
+            } else // removed
             {
                 // emit these queued for SS.  no worry of SR since
                 //   the browse operation is not cancellable.
-                for(int n = 0; n < instances.count(); ++n)
-                {
+                for (int n = 0; n < instances.count(); ++n) {
                     const XMPP::ServiceInstance &i = instances[n];
-                    if(i.name() == si.name())
-                    {
+                    if (i.name() == si.name()) {
                         emit unavailable_p(i);
                         instances.removeAt(n);
                         --n; // adjust position
@@ -405,8 +359,7 @@ protected:
 
     virtual void dns_queryResult(int id, const QDnsSd::QueryResult &result)
     {
-        if(!result.success)
-        {
+        if (!result.success) {
             // if we get here, then it means we received a browse
             //   entry, but could not fetch its TXT record.  if
             //   that happens, cancel the query and drop the
@@ -420,14 +373,13 @@ protected:
         Q_ASSERT(!result.records.isEmpty());
 
         // only the first entry matters, and it must be an added TXT
-        if(!result.records[0].added || result.records[0].rrtype != 16)
+        if (!result.records[0].added || result.records[0].rrtype != 16)
             return;
 
         // we only care about one answer
-        QByteArray name = pendingByQueryId[id];
+        QByteArray        name  = pendingByQueryId[id];
         QList<QByteArray> parts = nameToInstanceParts(name);
-        if(parts.isEmpty())
-        {
+        if (parts.isEmpty()) {
             // TODO: error
             Q_ASSERT(0);
         }
@@ -438,19 +390,18 @@ protected:
         XMPP::NameRecord rec = importQDnsSdRecord(result.records[0]);
 
         // bad answer?
-        if(rec.isNull())
+        if (rec.isNull())
             return;
 
-        QMap<QString,QByteArray> attribs = textsToAttribs(rec.texts());
+        QMap<QString, QByteArray> attribs = textsToAttribs(rec.texts());
         // FIXME: conversion/escaping?
-        XMPP::ServiceInstance si(QString::fromUtf8(parts[0]), QString::fromUtf8(parts[1]), QString::fromUtf8(parts[2]), attribs);
+        XMPP::ServiceInstance si(QString::fromUtf8(parts[0]), QString::fromUtf8(parts[1]), QString::fromUtf8(parts[2]),
+                                 attribs);
 
         // does qdnssd guarantee we won't receive dups?
         bool found = false;
-        foreach(const XMPP::ServiceInstance &i, instances)
-        {
-            if(i.name() == si.name())
-            {
+        for (const XMPP::ServiceInstance &i : instances) {
+            if (i.name() == si.name()) {
                 found = true;
                 break;
             }
@@ -467,50 +418,39 @@ protected:
 //----------------------------------------------------------------------------
 // only use this class for a single lookup.  if you want to lookup again,
 //   create a new object.
-class AppleBrowseLookup : public QObject, public QDnsSdDelegate
-{
+class AppleBrowseLookup : public QObject, public QDnsSdDelegate {
     Q_OBJECT
 public:
-    AppleProvider *global;
-    int resolve_id;
+    AppleProvider *    global;
+    int                resolve_id;
     XMPP::NameResolver nameResolverAaaa;
     XMPP::NameResolver nameResolverA;
-    bool activeAaaa;
-    bool activeA;
-    QTimer waitTimer;
-    QByteArray host;
-    QHostAddress addr4;
-    QHostAddress addr6;
-    int port;
+    bool               activeAaaa;
+    bool               activeA;
+    QTimer             waitTimer;
+    QByteArray         host;
+    QHostAddress       addr4;
+    QHostAddress       addr6;
+    int                port;
 
     AppleBrowseLookup(AppleProvider *_global, QObject *parent = 0) :
-        QObject(parent),
-        global(_global),
-        resolve_id(-1),
-        nameResolverAaaa(this),
-        nameResolverA(this),
-        activeAaaa(false),
-        activeA(false),
-        waitTimer(this)
+        QObject(parent), global(_global), resolve_id(-1), nameResolverAaaa(this), nameResolverA(this),
+        activeAaaa(false), activeA(false), waitTimer(this)
     {
         connect(&nameResolverAaaa, SIGNAL(resultsReady(QList<XMPP::NameRecord>)),
-            SLOT(nameAaaa_resultsReady(QList<XMPP::NameRecord>)));
+                SLOT(nameAaaa_resultsReady(QList<XMPP::NameRecord>)));
         connect(&nameResolverAaaa, SIGNAL(error(XMPP::NameResolver::Error)),
-            SLOT(nameAaaa_error(XMPP::NameResolver::Error)));
+                SLOT(nameAaaa_error(XMPP::NameResolver::Error)));
 
         connect(&nameResolverA, SIGNAL(resultsReady(QList<XMPP::NameRecord>)),
-            SLOT(nameA_resultsReady(QList<XMPP::NameRecord>)));
-        connect(&nameResolverA, SIGNAL(error(XMPP::NameResolver::Error)),
-            SLOT(nameA_error(XMPP::NameResolver::Error)));
+                SLOT(nameA_resultsReady(QList<XMPP::NameRecord>)));
+        connect(&nameResolverA, SIGNAL(error(XMPP::NameResolver::Error)), SLOT(nameA_error(XMPP::NameResolver::Error)));
 
         connect(&waitTimer, SIGNAL(timeout()), SLOT(waitTimer_timeout()));
         waitTimer.setSingleShot(true);
     }
 
-    ~AppleBrowseLookup()
-    {
-        global->stop_all(this);
-    }
+    ~AppleBrowseLookup() { global->stop_all(this); }
 
     void resolve(const QByteArray &instance, const QByteArray &type, const QByteArray &domain)
     {
@@ -528,8 +468,7 @@ protected:
         // there is only one response, so deregister
         global->stop(id);
 
-        if(!result.success)
-        {
+        if (!result.success) {
             emit error();
             return;
         }
@@ -538,7 +477,7 @@ protected:
         port = result.port;
 
         activeAaaa = true;
-        activeA = true;
+        activeA    = true;
         nameResolverAaaa.start(host, XMPP::NameRecord::Aaaa);
         nameResolverA.start(host, XMPP::NameRecord::A);
         waitTimer.start(500); // 500ms cut-off time, take what we have and run
@@ -549,7 +488,7 @@ private slots:
     {
         // nameresolver guarantees at least one result, and we only
         //   care about the first
-        addr6 = results[0].address();
+        addr6      = results[0].address();
         activeAaaa = false;
         tryDone();
     }
@@ -565,7 +504,7 @@ private slots:
     {
         // nameresolver guarantees at least one result, and we only
         //   care about the first
-        addr4 = results[0].address();
+        addr4   = results[0].address();
         activeA = false;
         tryDone();
     }
@@ -577,10 +516,7 @@ private slots:
         tryDone();
     }
 
-    void waitTimer_timeout()
-    {
-        tryDone();
-    }
+    void waitTimer_timeout() { tryDone(); }
 
 private:
     void tryDone()
@@ -589,8 +525,7 @@ private:
         //   results, or if the wait timer ends and we have at least
         //   one result
 
-        if(!activeAaaa && !activeA && addr6.isNull() && addr4.isNull())
-        {
+        if (!activeAaaa && !activeA && addr6.isNull() && addr4.isNull()) {
             nameResolverAaaa.stop();
             nameResolverA.stop();
             waitTimer.stop();
@@ -599,15 +534,14 @@ private:
             return;
         }
 
-        if(!waitTimer.isActive() && (!addr6.isNull() || !addr4.isNull()))
-        {
+        if (!waitTimer.isActive() && (!addr6.isNull() || !addr4.isNull())) {
             nameResolverAaaa.stop();
             nameResolverA.stop();
 
             QList<QHostAddress> out;
-            if(!addr4.isNull())
+            if (!addr4.isNull())
                 out += addr4;
-            if(!addr6.isNull())
+            if (!addr6.isNull())
                 out += addr6;
             emit finished(out, port);
         }
@@ -617,27 +551,16 @@ private:
 //----------------------------------------------------------------------------
 // AppleNameProvider
 //----------------------------------------------------------------------------
-class AppleNameProvider : public XMPP::NameProvider, public QDnsSdDelegate
-{
+class AppleNameProvider : public XMPP::NameProvider, public QDnsSdDelegate {
     Q_OBJECT
 public:
     AppleProvider *global;
 
-    AppleNameProvider(AppleProvider *parent) :
-        NameProvider(parent),
-        global(parent)
-    {
-    }
+    AppleNameProvider(AppleProvider *parent) : NameProvider(parent), global(parent) { }
 
-    ~AppleNameProvider()
-    {
-        global->stop_all(this);
-    }
+    ~AppleNameProvider() { global->stop_all(this); }
 
-    virtual bool supportsLongLived() const
-    {
-        return true;
-    }
+    virtual bool supportsLongLived() const { return true; }
 
     virtual bool supportsRecordType(int type) const
     {
@@ -652,31 +575,26 @@ public:
         return global->query(this, name, qType);
     }
 
-    virtual void resolve_stop(int id)
-    {
-        global->stop(id);
-    }
+    virtual void resolve_stop(int id) { global->stop(id); }
 
 protected:
     virtual void dns_queryResult(int id, const QDnsSd::QueryResult &result)
     {
-        if(!result.success)
-        {
+        if (!result.success) {
             emit resolve_error(id, XMPP::NameResolver::ErrorGeneric);
             return;
         }
 
         QList<XMPP::NameRecord> results;
-        foreach(const QDnsSd::Record &rec, result.records)
-        {
+        for (const QDnsSd::Record &rec : result.records) {
             XMPP::NameRecord nr = importQDnsSdRecord(rec);
 
             // unsupported type
-            if(nr.isNull())
+            if (nr.isNull())
                 continue;
 
             // if removed, ensure ttl is 0
-            if(!rec.added)
+            if (!rec.added)
                 nr.setTtl(0);
 
             results += nr;
@@ -689,23 +607,16 @@ protected:
 //----------------------------------------------------------------------------
 // AppleServiceProvider
 //----------------------------------------------------------------------------
-class AppleServiceProvider : public XMPP::ServiceProvider, public QDnsSdDelegate
-{
+class AppleServiceProvider : public XMPP::ServiceProvider, public QDnsSdDelegate {
     Q_OBJECT
 public:
-    class Browse
-    {
+    class Browse {
     public:
         AppleServiceProvider *parent;
-        int id;
-        AppleBrowse *browse;
+        int                   id;
+        AppleBrowse *         browse;
 
-        Browse(AppleServiceProvider *_parent) :
-            parent(_parent),
-            id(-1),
-            browse(0)
-        {
-        }
+        Browse(AppleServiceProvider *_parent) : parent(_parent), id(-1), browse(0) { }
 
         ~Browse()
         {
@@ -714,19 +625,13 @@ public:
         }
     };
 
-    class Resolve
-    {
+    class Resolve {
     public:
         AppleServiceProvider *parent;
-        int id;
-        AppleBrowseLookup *resolve;
+        int                   id;
+        AppleBrowseLookup *   resolve;
 
-        Resolve(AppleServiceProvider *_parent) :
-            parent(_parent),
-            id(-1),
-            resolve(0)
-        {
-        }
+        Resolve(AppleServiceProvider *_parent) : parent(_parent), id(-1), resolve(0) { }
 
         ~Resolve()
         {
@@ -735,16 +640,12 @@ public:
         }
     };
 
-    AppleProvider *global;
-    QList<Browse*> browseList;
-    QList<Resolve*> resolveList;
-    IdManager idManager;
+    AppleProvider *  global;
+    QList<Browse *>  browseList;
+    QList<Resolve *> resolveList;
+    IdManager        idManager;
 
-    AppleServiceProvider(AppleProvider *parent) :
-        ServiceProvider(parent),
-        global(parent)
-    {
-    }
+    AppleServiceProvider(AppleProvider *parent) : ServiceProvider(parent), global(parent) { }
 
     ~AppleServiceProvider()
     {
@@ -755,9 +656,8 @@ public:
 
     int indexOfBrowseByBrowse(AppleBrowse *browse) const
     {
-        for(int n = 0; n < browseList.count(); ++n)
-        {
-            if(browseList[n]->browse == browse)
+        for (int n = 0; n < browseList.count(); ++n) {
+            if (browseList[n]->browse == browse)
                 return n;
         }
         return -1;
@@ -765,9 +665,8 @@ public:
 
     int indexOfBrowseById(int id) const
     {
-        for(int n = 0; n < browseList.count(); ++n)
-        {
-            if(browseList[n]->id == id)
+        for (int n = 0; n < browseList.count(); ++n) {
+            if (browseList[n]->id == id)
                 return n;
         }
         return -1;
@@ -775,9 +674,8 @@ public:
 
     int indexOfResolveByResolve(AppleBrowseLookup *resolve) const
     {
-        for(int n = 0; n < resolveList.count(); ++n)
-        {
-            if(resolveList[n]->resolve == resolve)
+        for (int n = 0; n < resolveList.count(); ++n) {
+            if (resolveList[n]->resolve == resolve)
                 return n;
         }
         return -1;
@@ -785,9 +683,8 @@ public:
 
     int indexOfResolveById(int id) const
     {
-        for(int n = 0; n < resolveList.count(); ++n)
-        {
-            if(resolveList[n]->id == id)
+        for (int n = 0; n < resolveList.count(); ++n) {
+            if (resolveList[n]->id == id)
                 return n;
         }
         return -1;
@@ -796,7 +693,7 @@ public:
     virtual int browse_start(const QString &type, const QString &domain)
     {
         Browse *b = new Browse(this);
-        b->id = idManager.reserveId();
+        b->id     = idManager.reserveId();
         b->browse = new AppleBrowse(global, this);
         connect(b->browse, SIGNAL(available(XMPP::ServiceInstance)), SLOT(browse_available(XMPP::ServiceInstance)));
         connect(b->browse, SIGNAL(unavailable(XMPP::ServiceInstance)), SLOT(browse_unavailable(XMPP::ServiceInstance)));
@@ -809,7 +706,7 @@ public:
     virtual void browse_stop(int id)
     {
         int at = indexOfBrowseById(id);
-        if(at == -1)
+        if (at == -1)
             return;
 
         Browse *b = browseList[at];
@@ -820,14 +717,13 @@ public:
     virtual int resolve_start(const QByteArray &name)
     {
         QList<QByteArray> parts = nameToInstanceParts(name);
-        if(parts.isEmpty())
-        {
+        if (parts.isEmpty()) {
             // TODO: signal error rather than die
             Q_ASSERT(0);
         }
 
         Resolve *r = new Resolve(this);
-        r->id = idManager.reserveId();
+        r->id      = idManager.reserveId();
         r->resolve = new AppleBrowseLookup(global, this);
         connect(r->resolve, SIGNAL(finished(QList<QHostAddress>)), SLOT(resolve_finished(QList<QHostAddress>)));
         connect(r->resolve, SIGNAL(error()), SLOT(resolve_error()));
@@ -839,7 +735,7 @@ public:
     virtual void resolve_stop(int id)
     {
         int at = indexOfResolveById(id);
-        if(at == -1)
+        if (at == -1)
             return;
 
         Resolve *r = resolveList[at];
@@ -847,11 +743,11 @@ public:
         delete r;
     }
 
-    virtual int publish_start(const QString &instance, const QString &type, int port, const QMap<QString,QByteArray> &attributes)
+    virtual int publish_start(const QString &instance, const QString &type, int port,
+                              const QMap<QString, QByteArray> &attributes)
     {
         QByteArray txtRecord = attribsToTxtRecord(attributes);
-        if(txtRecord.isEmpty())
-        {
+        if (txtRecord.isEmpty()) {
             // TODO: signal error rather than die
             Q_ASSERT(0);
         }
@@ -862,37 +758,30 @@ public:
         return global->reg(this, instance.toUtf8(), type.toUtf8(), domain.toUtf8(), port, txtRecord);
     }
 
-    virtual void publish_update(int id, const QMap<QString,QByteArray> &attributes)
+    virtual void publish_update(int id, const QMap<QString, QByteArray> &attributes)
     {
         // TODO: verify 'id' is valid.  if not valid, then assert/return (don't do anything or signal error)
 
         QByteArray txtRecord = attribsToTxtRecord(attributes);
-        if(txtRecord.isEmpty())
-        {
+        if (txtRecord.isEmpty()) {
             // TODO: signal error rather than die
             Q_ASSERT(0);
         }
 
-        if(global->dns.recordUpdateTxt(id, txtRecord, 4500))
-        {
+        if (global->dns.recordUpdateTxt(id, txtRecord, 4500)) {
             // FIXME: SR
             QMetaObject::invokeMethod(this, "publish_published", Qt::QueuedConnection, Q_ARG(int, id));
-        }
-        else
-        {
+        } else {
             // TODO: unpublish
 
             // FIXME: register meta type, SR
-            QMetaObject::invokeMethod(this, "publish_error", Qt::QueuedConnection,
-                Q_ARG(int, id),
+            QMetaObject::invokeMethod(
+                this, "publish_error", Qt::QueuedConnection, Q_ARG(int, id),
                 Q_ARG(XMPP::ServiceLocalPublisher::Error, XMPP::ServiceLocalPublisher::ErrorGeneric));
         }
     }
 
-    virtual void publish_stop(int id)
-    {
-        global->stop(id);
-    }
+    virtual void publish_stop(int id) { global->stop(id); }
 
     virtual int publish_extra_start(int pub_id, const XMPP::NameRecord &name)
     {
@@ -967,11 +856,10 @@ private slots:
         delete r;
 
         QList<ResolveResult> results;
-        foreach(const QHostAddress &addr, addrs)
-        {
+        for (const QHostAddress &addr : addrs) {
             ResolveResult r;
             r.address = addr;
-            r.port = port;
+            r.port    = port;
             results += r;
         }
 
@@ -995,26 +883,14 @@ private slots:
 };
 
 // AppleProvider
-XMPP::NameProvider *AppleProvider::createNameProviderInternet()
-{
-    return new AppleNameProvider(this);
-}
+XMPP::NameProvider *AppleProvider::createNameProviderInternet() { return new AppleNameProvider(this); }
 
-XMPP::NameProvider *AppleProvider::createNameProviderLocal()
-{
-    return new AppleNameProvider(this);
-}
+XMPP::NameProvider *AppleProvider::createNameProviderLocal() { return new AppleNameProvider(this); }
 
-XMPP::ServiceProvider *AppleProvider::createServiceProvider()
-{
-    return new AppleServiceProvider(this);
-}
+XMPP::ServiceProvider *AppleProvider::createServiceProvider() { return new AppleServiceProvider(this); }
 
 #ifdef APPLEDNS_STATIC
-XMPP::IrisNetProvider *irisnet_createAppleProvider()
-{
-        return new AppleProvider;
-}
+XMPP::IrisNetProvider *irisnet_createAppleProvider() { return new AppleProvider; }
 #else
 Q_EXPORT_PLUGIN2(appledns, AppleProvider)
 #endif
