@@ -11,32 +11,26 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef ADDRESSRESOLVER_H
 #define ADDRESSRESOLVER_H
 
-#include <QObject>
 #include <QHostAddress>
+#include <QObject>
 
 namespace XMPP {
-
 // resolve both AAAA and A for a hostname
-class AddressResolver : public QObject
-{
+class AddressResolver : public QObject {
     Q_OBJECT
 
 public:
-    enum Error
-    {
-        ErrorGeneric
-    };
+    enum Error { ErrorGeneric };
 
-    AddressResolver(QObject *parent = 0);
+    AddressResolver(QObject *parent = nullptr);
     ~AddressResolver();
 
     void start(const QByteArray &hostName);
@@ -51,7 +45,6 @@ private:
     friend class Private;
     Private *d;
 };
+} // namespace XMPP
 
-}
-
-#endif
+#endif // ADDRESSRESOLVER_H
