@@ -11,10 +11,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -24,13 +22,11 @@
 #include "irisnetglobal.h"
 
 namespace XMPP {
-
-class NetAvailability : public QObject
-{
+class NetAvailability : public QObject {
     Q_OBJECT
 
 public:
-    NetAvailability(QObject *parent = 0);
+    NetAvailability(QObject *parent = nullptr);
     ~NetAvailability();
 
     bool isAvailable() const;
@@ -43,7 +39,6 @@ private:
     friend class Private;
     Private *d;
 };
+} // namespace XMPP
 
-}
-
-#endif
+#endif // NETAVAILABILITY_H
