@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006,2008  Justin Karneges
+ * Copyright (C) 2006-2008  Justin Karneges
  * Copyright (C) 2009-2010  Dennis Schridde
  *
  * This library is free software; you can redistribute it and/or
@@ -12,34 +12,29 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef NETNAMES_H
 #define NETNAMES_H
 
+#include "irisnetglobal.h"
+
 #include <QtCore>
 #include <QtNetwork>
-
 #include <limits>
 
-#include "irisnetglobal.h"
-
 // it seems visual studio defines it somewhere
 #ifdef max
-# undef max
+#undef max
 #endif
 
 namespace XMPP {
-
 class NameManager;
 
-class IRISNET_EXPORT NetNames
-{
+class IRISNET_EXPORT NetNames {
 public:
     // free any shared data, shutdown internal dns sessions if necessary.
     static void cleanup();
@@ -49,7 +44,7 @@ public:
 
     // convert idn names
     static QByteArray idnaFromString(const QString &in);
-    static QString idnaToString(const QByteArray &in);
+    static QString    idnaToString(const QByteArray &in);
 
     // dns escaping
     static QByteArray escapeDomain(const QByteArray &in);
@@ -62,9 +57,13 @@ private:
 /**
    \brief Provides a DNS record
 
-   NameRecord provides a DNS (Domain Name System) record, which is information assicated with a domain name.  For most purposes, the information is an IP address.  However, DNS records are capable of holding a variety of data types, such as named pointers to other domain names and even arbitrary text strings.  The results of a NameResolver operation are a list of NameRecords.
+   NameRecord provides a DNS (Domain Name System) record, which is information assicated with a domain name.  For most
+purposes, the information is an IP address.  However, DNS records are capable of holding a variety of data types, such
+as named pointers to other domain names and even arbitrary text strings.  The results of a NameResolver operation are a
+list of NameRecords.
 
-   The most common type is the address record, "A", which contains an IPv4 address.  Here is an example of how to get the IP address out of an address record:
+   The most common type is the address record, "A", which contains an IPv4 address.  Here is an example of how to get
+the IP address out of an address record:
 
 \code
 NameRecord record = ... // obtain a record from somewhere
@@ -75,9 +74,13 @@ if(record.type() == NameRecord::A)
 }
 \endcode
 
-   Getting the data out of a NameRecord involves calling the right retrieval functions, depending on the type.  Many types share retrieval functions.  For example, the "AAAA" type holds an IPv6 address, which is accessed the same way as the "A" type, by calling address().  See the NameRecord::Type enum for further information about which retrieval functions should be called for each type.
+   Getting the data out of a NameRecord involves calling the right retrieval functions, depending on the type.  Many
+types share retrieval functions.  For example, the "AAAA" type holds an IPv6 address, which is accessed the same way as
+the "A" type, by calling address().  See the NameRecord::Type enum for further information about which retrieval
+functions should be called for each type.
 
-   To create a NameRecord, use setOwner() and setTtl() as necessary, and then call one of the set<em>X</em> functions (where <em>X</em> is the desired type).  For example, to set an A or AAAA record, use setAddress() like this:
+   To create a NameRecord, use setOwner() and setTtl() as necessary, and then call one of the set<em>X</em> functions
+(where <em>X</em> is the desired type).  For example, to set an A or AAAA record, use setAddress() like this:
 
 \code
 // make example.com the owner, with 1 hour TTL
@@ -85,20 +88,19 @@ NameRecord record("example.com", 3600);
 record.setAddress(QHostAddress("1.2.3.4"));
 \endcode
 
-   Note that in the case of setAddress(), the record type need not be specified.  NameRecord will determine the type to use based on the given QHostAddress.
+   Note that in the case of setAddress(), the record type need not be specified.  NameRecord will determine the type to
+use based on the given QHostAddress.
 
    \sa NameResolver
 */
-class IRISNET_EXPORT NameRecord
-{
+class IRISNET_EXPORT NameRecord {
 public:
     /**
         \brief The type of DNS record
 
         The retrieval functions are shown for each type.
     */
-    enum Type
-    {
+    enum Type {
         A,     ///< IPv4 address.  Use address().
         Aaaa,  ///< IPv6 address.  Use address().
         Mx,    ///< Mail server.  Use name() and priority().
@@ -109,7 +111,7 @@ public:
         Hinfo, ///< Host information.  Use cpu() and os().
         Ns,    ///< Name server.  Use name().
         Null,  ///< Null type.  Use rawData().
-        Any    ///< "Any record", for use with NameResolver::start() only.  A NameRecord object will never be of this type.
+        Any ///< "Any record", for use with NameResolver::start() only.  A NameRecord object will never be of this type.
     };
 
     /**
@@ -122,7 +124,8 @@ public:
     /**
        \brief Constructs a partially initialized record object, with the given \a owner and \a ttl
 
-       For the record to be usable, call an appropriate set<em>X</em> function (where <em>X</em> is the desired type) afterwards.
+       For the record to be usable, call an appropriate set<em>X</em> function (where <em>X</em> is the desired type)
+       afterwards.
     */
     NameRecord(const QByteArray &owner, int ttl);
 
@@ -139,7 +142,7 @@ public:
     /**
        \brief Assigns \a from to this object and returns a reference to this object
     */
-    NameRecord & operator=(const NameRecord &from);
+    NameRecord &operator=(const NameRecord &from);
 
     /**
        \brief Compares \a other with this object
@@ -149,14 +152,17 @@ public:
     /**
        \brief Returns true if this record object is null, otherwise returns false
 
-       Be sure not to confuse a null object with the NULL type (NameRecord::Null).  Don't ask why DNS has a type called NULL that contains valid data.
+       Be sure not to confuse a null object with the NULL type (NameRecord::Null).  Don't ask why DNS has a type called
+       NULL that contains valid data.
     */
     bool isNull() const; // don't confuse with Null type
 
     /**
        \brief Returns the owner of this record
 
-       The owner is usually not a useful attribute, since it will be the same as the name searched for with NameResolver.  For example, if the A record of "example.com" is looked up, then the resulting records will all have "example.com" as the owner.
+       The owner is usually not a useful attribute, since it will be the same as the name searched for with
+       NameResolver.  For example, if the A record of "example.com" is looked up, then the resulting records will all
+       have "example.com" as the owner.
 
        \sa setOwner
     */
@@ -165,9 +171,11 @@ public:
     /**
        \brief Returns the TTL (time-to-live) of this record
 
-       This is the number of seconds the record should be considered valid, which is useful information when performing caching.
+       This is the number of seconds the record should be considered valid, which is useful information when performing
+       caching.
 
-       As a special exception, a TTL of 0 when performing a long-lived lookup indicates that a record is no longer available.
+       As a special exception, a TTL of 0 when performing a long-lived lookup indicates that a record is no longer
+       available.
 
        \sa setTtl
     */
@@ -310,21 +318,20 @@ private:
 IRISNET_EXPORT QDebug operator<<(QDebug, XMPP::NameRecord::Type);
 IRISNET_EXPORT QDebug operator<<(QDebug, const XMPP::NameRecord &);
 
-
-class IRISNET_EXPORT ServiceInstance
-{
+class IRISNET_EXPORT ServiceInstance {
 public:
     ServiceInstance();
-    ServiceInstance(const QString &instance, const QString &type, const QString &domain, const QMap<QString,QByteArray> &attributes);
+    ServiceInstance(const QString &instance, const QString &type, const QString &domain,
+                    const QMap<QString, QByteArray> &attributes);
     ServiceInstance(const ServiceInstance &from);
     ~ServiceInstance();
-    ServiceInstance & operator=(const ServiceInstance &from);
+    ServiceInstance &operator=(const ServiceInstance &from);
 
-    QString instance() const;
-    QString type() const;
-    QString domain() const;
-    QMap<QString,QByteArray> attributes() const;
-    QByteArray name() const; // full dns label
+    QString                   instance() const;
+    QString                   type() const;
+    QString                   domain() const;
+    QMap<QString, QByteArray> attributes() const;
+    QByteArray                name() const; // full dns label
 
 private:
     class Private;
@@ -336,9 +343,11 @@ private:
 /**
    \brief Represents a DNS query/lookup
 
-   NameResolver performs an asynchronous DNS lookup for a given domain name and record type.  Call start() to begin.  The resultsReady() signal is emitted on success, otherwise error() is emitted.  To cancel a lookup, call stop().
+   NameResolver performs an asynchronous DNS lookup for a given domain name and record type.  Call start() to begin. The
+resultsReady() signal is emitted on success, otherwise error() is emitted.  To cancel a lookup, call stop().
 
-   Each NameResolver object can only perform one DNS lookup at a time.  If start() is called while a lookup is already in progress, then the existing lookup is stopped before starting the new lookup.
+   Each NameResolver object can only perform one DNS lookup at a time.  If start() is called while a lookup is already
+in progress, then the existing lookup is stopped before starting the new lookup.
 
    Each NameResolver object should be used for just one DNS query and then be deleted.
    Otherwise ambiguity might arise when receiving multiple answers to future queries.
@@ -373,57 +382,62 @@ void dns_error(XMPP::NameResolver::Error error)
 }
 \endcode
 
-   Yes, a domain name can have multiple IP addresses.  Many applications ignore this fact, and use only one of the answers.  A proper network application should try connecting to each IP address until one succeeds.
+   Yes, a domain name can have multiple IP addresses.  Many applications ignore this fact, and use only one of the
+answers.  A proper network application should try connecting to each IP address until one succeeds.
 
-   To lookup other types, pass the desired type to start().  For example, suppose you want to look up the MX record of a domain name:
+   To lookup other types, pass the desired type to start().  For example, suppose you want to look up the MX record of a
+domain name:
 
 \code
 // look up the MX record for affinix.com
 resolver->start("affinix.com", NameRecord::Mx);
 \endcode
 
-   It is also possible to perform long-lived queries.  This is generally useful for DNS Service Discovery.  Long-lived queries are continuous, and resultsReady() may be emitted multiple times.  Unlike a normal lookup, which stops once the results are returned, a long-lived query will keep going until stop() is called.
+   It is also possible to perform long-lived queries.  This is generally useful for DNS Service Discovery.  Long-lived
+queries are continuous, and resultsReady() may be emitted multiple times.  Unlike a normal lookup, which stops once the
+results are returned, a long-lived query will keep going until stop() is called.
 
-   For example, suppose you want to scan the local network for SSH services.  According to the DNS-SD protocol, this is done by querying for the name "_ssh._tcp.local." of type PTR.
+   For example, suppose you want to scan the local network for SSH services.  According to the DNS-SD protocol, this is
+done by querying for the name "_ssh._tcp.local." of type PTR.
 
 \code
 // monitor for SSH services on the local network
 resolver->start("_ssh._tcp.local.", NameRecord::Ptr, NameResolver::LongLived);
 \endcode
 
-   Don't be alarmed by the trailing dot (".") character in this last example.  It is not well known, but all valid DNS domain names end with a dot.  However, NameResolver, like most DNS programming interfaces, allows the dot to be left out.  What this means is that if a trailing dot is missing in the input to start(), NameResolver will internally append one before performing the query.
+   Don't be alarmed by the trailing dot (".") character in this last example.  It is not well known, but all valid DNS
+domain names end with a dot.  However, NameResolver, like most DNS programming interfaces, allows the dot to be left
+out.  What this means is that if a trailing dot is missing in the input to start(), NameResolver will internally append
+one before performing the query.
 
    \sa NameRecord
 */
-class IRISNET_EXPORT NameResolver : public QObject
-{
+class IRISNET_EXPORT NameResolver : public QObject {
     Q_OBJECT
 public:
     /**
        \brief Resolve mode
     */
-    enum Mode
-    {
-        Single,       ///< A normal DNS query with a single result set.
-        LongLived     ///< An endless query, with multiple result sets allowed.
+    enum Mode {
+        Single,   ///< A normal DNS query with a single result set.
+        LongLived ///< An endless query, with multiple result sets allowed.
     };
 
     /**
        \brief Resolve error
     */
-    enum Error
-    {
-        ErrorGeneric,     ///< General failure during lookup, no further details.
-        ErrorNoName,      ///< Name does not exist.
-        ErrorTimeout,     ///< The operation timed out.
-        ErrorNoLocal,     ///< The query is to the local network, but no mechanism for Multicast DNS is available.
-        ErrorNoLongLived  ///< The query requires long-lived capability, but no mechanism for doing so is available.
+    enum Error {
+        ErrorGeneric,    ///< General failure during lookup, no further details.
+        ErrorNoName,     ///< Name does not exist.
+        ErrorTimeout,    ///< The operation timed out.
+        ErrorNoLocal,    ///< The query is to the local network, but no mechanism for Multicast DNS is available.
+        ErrorNoLongLived ///< The query requires long-lived capability, but no mechanism for doing so is available.
     };
 
     /**
        \brief Constructs a new resolver object with the given \a parent
     */
-    NameResolver(QObject *parent = 0);
+    NameResolver(QObject *parent = nullptr);
 
     /**
        \brief Destroys the resolver object
@@ -435,7 +449,8 @@ public:
     /**
        \brief Starts a lookup
 
-       A lookup for \a name of \a type is started.  For normal queries, \a mode should be NameResolver::Single (this is the default).  For long-lived queries, use NameResolver::LongLived.
+       A lookup for \a name of \a type is started.  For normal queries, \a mode should be NameResolver::Single (this is
+       the default).  For long-lived queries, use NameResolver::LongLived.
 
        If a lookup is already in progress, it is stopped before starting the new lookup.
 
@@ -446,7 +461,8 @@ public:
     /**
        \brief Stops a lookup
 
-       Use this function if you want to stop the current lookup, such that the resolver object may be reused again later.  If you don't plan to reuse the object, then destroying the object is enough.
+       Use this function if you want to stop the current lookup, such that the resolver object may be reused again
+       later.  If you don't plan to reuse the object, then destroying the object is enough.
 
        \sa start
     */
@@ -456,16 +472,21 @@ signals:
     /**
        \brief Notification of result records
 
-       This signal is emitted when results of the lookup operation have arrived.  The \a results parameter is a list of NameRecords.  All records will be of the type queried for with start(), unless the NameRecord::Any type was specified, in which case the records may be of any type
+       This signal is emitted when results of the lookup operation have arrived.  The \a results parameter is a list of
+       NameRecords.  All records will be of the type queried for with start(), unless the NameRecord::Any type was
+       specified, in which case the records may be of any type
 
-       When using the NameResolver::Single mode, the lookup is stopped once results are ready.  However, with the NameResolver::LongLived mode, the lookup stays active, and in that case this signal may be emitted multiple times.
+       When using the NameResolver::Single mode, the lookup is stopped once results are ready.  However, with the
+       NameResolver::LongLived mode, the lookup stays active, and in that case this signal may be emitted multiple
+       times.
     */
     void resultsReady(const QList<XMPP::NameRecord> &results);
 
     /**
        \brief Notification of error
 
-       This signal is emitted if an error has occurred while performing a lookup.  The reason for error can be found in \a e.  Regardless of the mode used, the lookup is stopped when an error occurs.
+       This signal is emitted if an error has occurred while performing a lookup.  The reason for error can be found in
+       \a e.  Regardless of the mode used, the lookup is stopped when an error occurs.
     */
     void error(XMPP::NameResolver::Error e);
 
@@ -479,53 +500,44 @@ private:
 
 IRISNET_EXPORT QDebug operator<<(QDebug, XMPP::NameResolver::Error);
 
-
-class IRISNET_EXPORT WeightedNameRecordList
-{
-    friend QDebug operator<<(QDebug, const WeightedNameRecordList&);
+class IRISNET_EXPORT WeightedNameRecordList {
+    friend QDebug operator<<(QDebug, const WeightedNameRecordList &);
 
 public:
     WeightedNameRecordList();
     WeightedNameRecordList(const QList<NameRecord> &list);
     WeightedNameRecordList(const WeightedNameRecordList &other);
-    WeightedNameRecordList& operator=(const WeightedNameRecordList &other);
+    WeightedNameRecordList &operator=(const WeightedNameRecordList &other);
     ~WeightedNameRecordList();
-    bool isEmpty() const; //!< Returns true if the list contains no items; otherwise returns false.
-    NameRecord takeNext(); //!< Removes the next host to try from the list and returns it.
+    bool       isEmpty() const; //!< Returns true if the list contains no items; otherwise returns false.
+    NameRecord takeNext();      //!< Removes the next host to try from the list and returns it.
 
     void clear(); //!< Removes all items from the list.
-    void append(const WeightedNameRecordList&);
-    void append(const QList<NameRecord>&);
-    void append(const NameRecord&);
+    void append(const WeightedNameRecordList &);
+    void append(const QList<NameRecord> &);
+    void append(const NameRecord &);
     void append(const QString &hostname, quint16 port);
 
-    WeightedNameRecordList& operator<<(const WeightedNameRecordList&);
-    WeightedNameRecordList& operator<<(const QList<NameRecord>&);
-    WeightedNameRecordList& operator<<(const NameRecord&);
+    WeightedNameRecordList &operator<<(const WeightedNameRecordList &);
+    WeightedNameRecordList &operator<<(const QList<NameRecord> &);
+    WeightedNameRecordList &operator<<(const NameRecord &);
 
 private:
-    typedef QMultiMap<int /* weight */, NameRecord> WeightedNameRecordPriorityGroup;
+    typedef QMultiMap<int /* weight */, NameRecord>                   WeightedNameRecordPriorityGroup;
     typedef QMap<int /* priority */, WeightedNameRecordPriorityGroup> WNRL;
 
-    WNRL priorityGroups;
+    WNRL           priorityGroups;
     WNRL::iterator currentPriorityGroup;
 };
 
-QDebug operator<<(QDebug, const XMPP::WeightedNameRecordList&);
+QDebug operator<<(QDebug, const XMPP::WeightedNameRecordList &);
 
-
-class IRISNET_EXPORT ServiceBrowser : public QObject
-{
+class IRISNET_EXPORT ServiceBrowser : public QObject {
     Q_OBJECT
 public:
-    enum Error
-    {
-        ErrorGeneric,
-        ErrorNoLocal,
-        ErrorNoWide
-    };
+    enum Error { ErrorGeneric, ErrorNoLocal, ErrorNoWide };
 
-    ServiceBrowser(QObject *parent = 0);
+    ServiceBrowser(QObject *parent = nullptr);
     ~ServiceBrowser();
 
     void start(const QString &type, const QString &domain = "local");
@@ -544,7 +556,6 @@ private:
     friend class NameManager;
 };
 
-
 /*! DNS resolver with DNS-SD/mDNS and recursive lookup support */
 /*
 Flow:
@@ -568,12 +579,10 @@ Flow:
     8) host[] empty -> (9)
 9) Try servername directly
 */
-class IRISNET_EXPORT ServiceResolver : public QObject
-{
+class IRISNET_EXPORT ServiceResolver : public QObject {
     Q_OBJECT
 public:
-    struct ProtoSplit
-    {
+    struct ProtoSplit {
         ServiceResolver *ipv4;
         ServiceResolver *ipv6;
     };
@@ -581,8 +590,10 @@ public:
     /*! Error codes for (SRV) lookups */
     enum Error {
         ServiceNotFound, //!< There is no service with the specified parameters
-        NoHostLeft, //!< we did all we could, none of the found host seemed to suffice the users needs
-        ErrorGeneric, ErrorTimeout, ErrorNoLocal // Stuff that netnames_jdns.cpp needs ...
+        NoHostLeft,      //!< we did all we could, none of the found host seemed to suffice the users needs
+        ErrorGeneric,
+        ErrorTimeout,
+        ErrorNoLocal // Stuff that netnames_jdns.cpp needs ...
     };
     /*! Order of lookup / IP protocols to try */
     enum Protocol { IPv6_IPv4, IPv4_IPv6, HappyEyeballs, IPv6, IPv4 };
@@ -591,11 +602,11 @@ public:
      * Create a new ServiceResolver.
      * This resolver can be used for multiple lookups in a row, but not concurrently!
      */
-    ServiceResolver(QObject *parent = 0);
+    ServiceResolver(QObject *parent = nullptr);
     ~ServiceResolver();
 
-    Protocol protocol() const; //!< IP protocol to use, defaults to IPv6_IPv4
-    void setProtocol(Protocol); //!< Set IP protocol to use, \sa protocol
+    Protocol protocol() const;      //!< IP protocol to use, defaults to IPv6_IPv4
+    void     setProtocol(Protocol); //!< Set IP protocol to use, \sa protocol
 
     /*!
      * Start a DNS-SD lookup
@@ -616,7 +627,8 @@ public:
      * \param domain Domainname to lookup
      * \param port Specify a valid port number to make ServiceResolver fallback to domain:port
      */
-    void start(const QString &service, const QString &transport, const QString &domain, int port = std::numeric_limits<int>::max());
+    void start(const QString &service, const QString &transport, const QString &domain,
+               int port = std::numeric_limits<int>::max());
 
     /*! Announce the next resolved host, \sa resultReady */
     void tryNext();
@@ -645,15 +657,15 @@ signals:
     void srvFailed();
 
 private slots:
-    void handle_srv_ready(const QList<XMPP::NameRecord>&);
+    void handle_srv_ready(const QList<XMPP::NameRecord> &);
     void handle_srv_error(XMPP::NameResolver::Error);
-    void handle_host_ready(const QList<XMPP::NameRecord>&);
+    void handle_host_ready(const QList<XMPP::NameRecord> &);
     void handle_host_error(XMPP::NameResolver::Error);
     void handle_host_fallback_error(XMPP::NameResolver::Error);
 
 private:
     void clear_resolvers();
-    void cleanup_resolver(XMPP::NameResolver*);
+    void cleanup_resolver(XMPP::NameResolver *);
     bool check_protocol_fallback();
     bool lookup_host_fallback();
     bool try_next_host();
@@ -666,22 +678,20 @@ private:
     friend class NameManager;
 };
 
-class IRISNET_EXPORT ServiceLocalPublisher : public QObject
-{
+class IRISNET_EXPORT ServiceLocalPublisher : public QObject {
     Q_OBJECT
 public:
-    enum Error
-    {
+    enum Error {
         ErrorGeneric,  // generic error
         ErrorConflict, // name in use
         ErrorNoLocal   // unable to setup multicast dns
     };
 
-    ServiceLocalPublisher(QObject *parent = 0);
+    ServiceLocalPublisher(QObject *parent = nullptr);
     ~ServiceLocalPublisher();
 
-    void publish(const QString &instance, const QString &type, int port, const QMap<QString,QByteArray> &attributes);
-    void updateAttributes(const QMap<QString,QByteArray> &attributes);
+    void publish(const QString &instance, const QString &type, int port, const QMap<QString, QByteArray> &attributes);
+    void updateAttributes(const QMap<QString, QByteArray> &attributes);
     void addRecord(const NameRecord &rec);
     void cancel();
 
@@ -697,10 +707,8 @@ private:
     friend class NameManager;
 };
 
-}
-
+} // namespace XMPP
 
 Q_DECLARE_METATYPE(XMPP::NameResolver::Error)
 
-
-#endif
+#endif // NETNAMES_H
