@@ -13,37 +13,30 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
-#include <QTcpSocket>
-#include <QHostAddress>
-#include <QMetaType>
-
-#include <limits>
-
 #include "bsocket.h"
 
+#include <QHostAddress>
+#include <QMetaType>
+#include <QTcpSocket>
+#include <limits>
+
 //#define BS_DEBUG
-
 #ifdef BS_DEBUG
-# define BSDEBUG (qDebug() << this << "#" << __FUNCTION__ << ":")
+#define BSDEBUG (qDebug() << this << "#" << __FUNCTION__ << ":")
 #endif
 
-
 #define READBUFSIZE 65536
 
 // CS_NAMESPACE_BEGIN
-
-class QTcpSocketSignalRelay : public QObject
-{
+class QTcpSocketSignalRelay : public QObject {
     Q_OBJECT
 public:
-    QTcpSocketSignalRelay(QTcpSocket *sock, QObject *parent = 0)
-    :QObject(parent)
+    QTcpSocketSignalRelay(QTcpSocket *sock, QObject *parent = nullptr) : QObject(parent)
     {
         qRegisterMetaType<QAbstractSocket::SocketError>("QAbstractSocket::SocketError");
         connect(sock, SIGNAL(hostFound()), SLOT(sock_hostFound()), Qt::QueuedConnection);
@@ -51,7 +44,8 @@ public:
         connect(sock, SIGNAL(disconnected()), SLOT(sock_disconnected()), Qt::QueuedConnection);
         connect(sock, SIGNAL(readyRead()), SLOT(sock_readyRead()), Qt::QueuedConnection);
         connect(sock, SIGNAL(bytesWritten(qint64)), SLOT(sock_bytesWritten(qint64)), Qt::QueuedConnection);
-        connect(sock, SIGNAL(error(QAbstractSocket::SocketError)), SLOT(sock_error(QAbstractSocket::SocketError)), Qt::QueuedConnection);
+        connect(sock, SIGNAL(error(QAbstractSocket::SocketError)), SLOT(sock_error(QAbstractSocket::SocketError)),
+                Qt::QueuedConnection);
     }
 
 signals:
@@ -63,89 +57,63 @@ signals:
     void error(QAbstractSocket::SocketError);
 
 public slots:
-    void sock_hostFound()
-    {
-        emit hostFound();
-    }
+    void sock_hostFound() { emit hostFound(); }
 
-    void sock_connected()
-    {
-        emit connected();
-    }
+    void sock_connected() { emit connected(); }
 
-    void sock_disconnected()
-    {
-        emit disconnected();
-    }
+    void sock_disconnected() { emit disconnected(); }
 
-    void sock_readyRead()
-    {
-        emit readyRead();
-    }
+    void sock_readyRead() { emit readyRead(); }
 
-    void sock_bytesWritten(qint64 x)
-    {
-        emit bytesWritten(x);
-    }
+    void sock_bytesWritten(qint64 x) { emit bytesWritten(x); }
 
-    void sock_error(QAbstractSocket::SocketError x)
-    {
-        emit error(x);
-    }
+    void sock_error(QAbstractSocket::SocketError x) { emit error(x); }
 };
 
-
-class HappyEyeballsConnector : public QObject
-{
+class HappyEyeballsConnector : public QObject {
     Q_OBJECT
 public:
-    enum State {
-        Failure,
-        Created,
-        Resolve,
-        Connecting,
-        Connected
-    };
+    enum State { Failure, Created, Resolve, Connecting, Connected };
 
     struct SockData {
-        QTcpSocket *sock;
+        QTcpSocket *           sock;
         QTcpSocketSignalRelay *relay;
-        State state;
+        State                  state;
         XMPP::ServiceResolver *resolver;
     };
 
     /*! source data */
-    QString service;
-    QString transport;
-    QString domain;
-    quint16 port = 0;
-    QHostAddress address;
+    QString                               service;
+    QString                               transport;
+    QString                               domain;
+    quint16                               port = 0;
+    QHostAddress                          address;
     QAbstractSocket::NetworkLayerProtocol fallbackProtocol = QAbstractSocket::IPv4Protocol;
 
     /*! runtime data */
-    QString lastError;
-    int lastIndex;
+    QString         lastError;
+    int             lastIndex;
     QList<SockData> sockets;
-    QTimer fallbackTimer;
+    QTimer          fallbackTimer;
 
-    HappyEyeballsConnector(QObject *parent) :
-        QObject(parent)
+    HappyEyeballsConnector(QObject *parent) : QObject(parent)
     {
         fallbackTimer.setSingleShot(true);
         fallbackTimer.setInterval(250); /* rfc recommends 150-250ms */
         connect(&fallbackTimer, SIGNAL(timeout()), SLOT(startFallback()));
     }
 
-    SockData& addSocket()
+    SockData &addSocket()
     {
         SockData sd;
         sd.state = Created;
-        sd.sock = new QTcpSocket(this);
+        sd.sock  = new QTcpSocket(this);
+        sd.sock->setProxy(QNetworkProxy::NoProxy);
         sd.sock->setReadBufferSize(READBUFSIZE);
-        sd.relay = new QTcpSocketSignalRelay(sd.sock, this);
-        sd.resolver = 0;
-        connect(sd.relay, SIGNAL(connected()), SLOT(qs_connected()));
-        connect(sd.relay, SIGNAL(error(QAbstractSocket::SocketError)), SLOT(qs_error(QAbstractSocket::SocketError)));
+        sd.relay    = new QTcpSocketSignalRelay(sd.sock, this);
+        sd.resolver = nullptr;
+        connect(sd.relay, &QTcpSocketSignalRelay::connected, this, &HappyEyeballsConnector::qs_connected);
+        connect(sd.relay, &QTcpSocketSignalRelay::error, this, &HappyEyeballsConnector::qs_error);
         sockets.append(sd);
         return sockets[sockets.count() - 1];
     }
@@ -158,15 +126,14 @@ public:
         fallbackTimer.stop();
     }
 
-
     void connectToHost(const QHostAddress &address, quint16 port)
     {
 #ifdef BS_DEBUG
         BSDEBUG << "a:" << address << "p:" << port;
 #endif
         this->address = address;
-        SockData &sd = addSocket();
-        sd.state = Connecting;
+        SockData &sd  = addSocket();
+        sd.state      = Connecting;
         sd.sock->connectToHost(address, port);
     }
 
@@ -177,16 +144,19 @@ public:
         BSDEBUG << "h:" << host << "p:" << port << "pr:" << protocol;
 #endif
         this->domain = host;
-        this->port = port;
+        this->port   = port;
         SockData &sd = addSocket();
 
         QHostAddress addr(host);
         if (addr.isNull()) {
             sd.resolver = new XMPP::ServiceResolver;
             initResolver(sd.resolver);
-            sd.resolver->setProtocol(protocol == QAbstractSocket::UnknownNetworkLayerProtocol?
-                (fallbackProtocol == QAbstractSocket::IPv4Protocol? XMPP::ServiceResolver::IPv6 : XMPP::ServiceResolver::IPv4) :
-                (protocol== QAbstractSocket::IPv4Protocol? XMPP::ServiceResolver::IPv4 : XMPP::ServiceResolver::IPv6));
+            sd.resolver->setProtocol(protocol == QAbstractSocket::UnknownNetworkLayerProtocol
+                                         ? (fallbackProtocol == QAbstractSocket::IPv4Protocol
+                                                ? XMPP::ServiceResolver::IPv6
+                                                : XMPP::ServiceResolver::IPv4)
+                                         : (protocol == QAbstractSocket::IPv4Protocol ? XMPP::ServiceResolver::IPv4
+                                                                                      : XMPP::ServiceResolver::IPv6));
             if (protocol == QAbstractSocket::UnknownNetworkLayerProtocol) {
                 addSocket();
                 fallbackTimer.start();
@@ -196,7 +166,7 @@ public:
         } else {
             // connecting by IP.
             lastIndex = sockets.count() - 1;
-            sd.state = Connecting;
+            sd.state  = Connecting;
             sd.sock->connectToHost(addr, port);
         }
     }
@@ -206,12 +176,12 @@ public:
 #ifdef BS_DEBUG
         BSDEBUG << "s:" << service << "t:" << transport << "d:" << domain;
 #endif
-        this->service = service;
+        this->service   = service;
         this->transport = transport;
-        this->domain = domain;
-        this->port = port;
-        SockData &sd = addSocket();
-        sd.resolver = new XMPP::ServiceResolver(this);
+        this->domain    = domain;
+        this->port      = port;
+        SockData &sd    = addSocket();
+        sd.resolver     = new XMPP::ServiceResolver(this);
         sd.resolver->setProtocol(XMPP::ServiceResolver::HappyEyeballs);
         connect(sd.resolver, SIGNAL(srvReady()), SLOT(splitSrvResolvers()));
         // we don't care about special handling of fail. we have fallback host there anyway
@@ -223,11 +193,12 @@ public:
     SockData takeCurrent(QObject *parent)
     {
         SockData csd = sockets.takeAt(lastIndex);
-        lastIndex = -1;
+        lastIndex    = -1;
         disconnect(csd.relay);
         csd.relay->setParent(parent);
         csd.sock->setParent(parent);
-        delete csd.resolver; // FIME ensure it's accessible only from connected signal. we don't delete resolver from its slot
+        delete csd
+            .resolver; // FIME ensure it's accessible only from connected signal. we don't delete resolver from its slot
         csd.resolver = nullptr;
         return csd;
     }
@@ -251,8 +222,10 @@ private:
     void initResolver(XMPP::ServiceResolver *resolver)
     {
         resolver->setParent(this);
-        connect(resolver, SIGNAL(resultReady(QHostAddress,quint16)), this, SLOT(handleDnsReady(QHostAddress,quint16)));
-        connect(resolver, SIGNAL(error(XMPP::ServiceResolver::Error)), this, SLOT(handleDnsError(XMPP::ServiceResolver::Error)));
+        connect(resolver, SIGNAL(resultReady(QHostAddress, quint16)), this,
+                SLOT(handleDnsReady(QHostAddress, quint16)));
+        connect(resolver, SIGNAL(error(XMPP::ServiceResolver::Error)), this,
+                SLOT(handleDnsError(XMPP::ServiceResolver::Error)));
     }
 
     void setCurrentByResolver(XMPP::ServiceResolver *resolver)
@@ -286,7 +259,8 @@ private slots:
 #ifdef BS_DEBUG
         BSDEBUG;
 #endif
-        setCurrentByRelay(static_cast<QTcpSocketSignalRelay*>(sender()));
+        QPointer<HappyEyeballsConnector> valid(this);
+        setCurrentByRelay(static_cast<QTcpSocketSignalRelay *>(sender()));
         for (int i = 0; i < sockets.count(); i++) {
             if (i != lastIndex) {
                 abortSocket(sockets[i]);
@@ -295,12 +269,14 @@ private slots:
                 sockets[i].state = Connected;
             }
             emit connected();
+            if (!valid)
+                return;
         }
     }
 
     void qs_error(QAbstractSocket::SocketError errorCode)
     {
-        setCurrentByRelay(static_cast<QTcpSocketSignalRelay*>(sender()));
+        setCurrentByRelay(static_cast<QTcpSocketSignalRelay *>(sender()));
         // TODO remember error code
         lastError = sockets[lastIndex].sock->errorString();
 #ifdef BS_DEBUG
@@ -321,10 +297,10 @@ private slots:
 #ifdef BS_DEBUG
         BSDEBUG << "splitting resolvers";
 #endif
-        setCurrentByResolver(static_cast<XMPP::ServiceResolver*>(sender()));
-        SockData &sdv4 = sockets[lastIndex];
-        SockData &sdv6 = addSocket();
-        XMPP::ServiceResolver::ProtoSplit ps = sdv4.resolver->happySplit();
+        setCurrentByResolver(static_cast<XMPP::ServiceResolver *>(sender()));
+        SockData &                        sdv4 = sockets[lastIndex];
+        SockData &                        sdv6 = addSocket();
+        XMPP::ServiceResolver::ProtoSplit ps   = sdv4.resolver->happySplit();
         initResolver(ps.ipv4);
         initResolver(ps.ipv6);
 
@@ -332,7 +308,7 @@ private slots:
         sdv4.resolver->deleteLater();
 
         sdv4.resolver = ps.ipv4;
-        sdv4.state = Created;
+        sdv4.state    = Created;
         sdv6.resolver = ps.ipv6;
 
         if (fallbackProtocol == QAbstractSocket::IPv4Protocol) {
@@ -351,13 +327,14 @@ private slots:
 #ifdef BS_DEBUG
         BSDEBUG << "a:" << address << "p:" << port;
 #endif
-        setCurrentByResolver(static_cast<XMPP::ServiceResolver*>(sender()));
+        setCurrentByResolver(static_cast<XMPP::ServiceResolver *>(sender()));
         sockets[lastIndex].state = Connecting;
         sockets[lastIndex].sock->connectToHost(address, port);
     }
 
     /* resolver failed the dns lookup */
-    void handleDnsError(XMPP::ServiceResolver::Error e) {
+    void handleDnsError(XMPP::ServiceResolver::Error e)
+    {
 #ifdef BS_DEBUG
         BSDEBUG << "e:" << e;
 #else
@@ -373,7 +350,7 @@ private slots:
 #ifdef BS_DEBUG
         BSDEBUG;
 #endif
-        for(int i = 0; i < sockets.count(); i++) {
+        for (int i = 0; i < sockets.count(); i++) {
             SockData &sd = sockets[i];
             if (sd.state == Created) {
                 sd.state = Resolve;
@@ -382,8 +359,9 @@ private slots:
                 } else {
                     sd.resolver = new XMPP::ServiceResolver;
                     initResolver(sd.resolver);
-                    sd.resolver->setProtocol(fallbackProtocol == QAbstractSocket::IPv4Protocol?
-                                                 XMPP::ServiceResolver::IPv4 : XMPP::ServiceResolver::IPv6);
+                    sd.resolver->setProtocol(fallbackProtocol == QAbstractSocket::IPv4Protocol
+                                                 ? XMPP::ServiceResolver::IPv4
+                                                 : XMPP::ServiceResolver::IPv6);
                     sd.resolver->start(domain, port);
                 }
             }
@@ -395,29 +373,27 @@ signals:
     void error(QAbstractSocket::SocketError);
 };
 
-class BSocket::Private
-{
+class BSocket::Private {
 public:
     Private()
     {
-        qsock = nullptr;
+        qsock       = nullptr;
         qsock_relay = nullptr;
     }
 
-    QTcpSocket *qsock;
+    QTcpSocket *           qsock;
     QTcpSocketSignalRelay *qsock_relay;
-    int state;
+    int                    state;
 
-    QString domain; //!< Domain we are currently connected to
-    QString host; //!< Hostname we are currently connected to
+    QString      domain;  //!< Domain we are currently connected to
+    QString      host;    //!< Hostname we are currently connected to
     QHostAddress address; //!< IP address we are currently connected to
-    quint16 port; //!< Port we are currently connected to
+    quint16      port;    //!< Port we are currently connected to
 
     QPointer<HappyEyeballsConnector> connector;
 };
 
-BSocket::BSocket(QObject *parent)
-:ByteStream(parent)
+BSocket::BSocket(QObject *parent) : ByteStream(parent)
 {
     d = new Private;
     resetConnection();
@@ -429,23 +405,25 @@ BSocket::~BSocket()
     delete d;
 }
 
-
 void BSocket::resetConnection(bool clear)
 {
 #ifdef BS_DEBUG
     BSDEBUG << clear;
 #endif
     if (d->connector) {
-        delete d->connector; // fixme: deleteLater?
+        d->connector->deleteLater();
+        disconnect(d->connector);
+        d->connector = nullptr;
     }
 
-    if(d->qsock) {
+    if (d->qsock) {
         delete d->qsock_relay;
         d->qsock_relay = nullptr;
 
         // move remaining into the local queue
         if (d->qsock->isOpen()) {
-            QByteArray block(int(d->qsock->bytesAvailable()), 0); // memory won't never be cheap enough to have gigabytes for socket buffer
+            QByteArray block(int(d->qsock->bytesAvailable()),
+                             0); // memory won't never be cheap enough to have gigabytes for socket buffer
             if (block.size()) {
                 d->qsock->read(block.data(), block.size());
                 appendRead(block);
@@ -453,29 +431,28 @@ void BSocket::resetConnection(bool clear)
             d->qsock->close();
         }
 
-        //d->sd.deleteLater(d->qsock);
+        // d->sd.deleteLater(d->qsock);
         d->qsock->deleteLater();
         d->qsock = nullptr;
-    }
-    else {
-        if(clear)
+    } else {
+        if (clear)
             clearReadBuffer();
     }
 
-    d->state = Idle;
-    d->domain = "";
-    d->host = "";
+    d->state   = Idle;
+    d->domain  = "";
+    d->host    = "";
     d->address = QHostAddress();
-    d->port = 0;
+    d->port    = 0;
     setOpenMode(QIODevice::NotOpen);
 }
 
 void BSocket::ensureConnector()
 {
-    if(!d->connector) {
+    if (!d->connector) {
         d->connector = new HappyEyeballsConnector(this);
-        connect(d->connector, SIGNAL(connected()), SLOT(qs_connected()));
-        connect(d->connector, SIGNAL(error(QAbstractSocket::SocketError)), SLOT(qs_error(QAbstractSocket::SocketError)));
+        connect(d->connector, &HappyEyeballsConnector::connected, this, &BSocket::qs_connected);
+        connect(d->connector, &HappyEyeballsConnector::error, this, &BSocket::qs_error);
     }
 }
 
@@ -484,8 +461,8 @@ void BSocket::connectToHost(const QHostAddress &address, quint16 port)
 {
     resetConnection(true);
     d->address = address;
-    d->port = port;
-    d->state = Connecting;
+    d->port    = port;
+    d->state   = Connecting;
 
     ensureConnector();
     d->connector->connectToHost(address, port);
@@ -495,8 +472,8 @@ void BSocket::connectToHost(const QHostAddress &address, quint16 port)
 void BSocket::connectToHost(const QString &host, quint16 port, QAbstractSocket::NetworkLayerProtocol protocol)
 {
     resetConnection(true);
-    d->host = host;
-    d->port = port;
+    d->host  = host;
+    d->port  = port;
     d->state = Connecting;
 
     ensureConnector();
@@ -508,42 +485,36 @@ void BSocket::connectToHost(const QString &service, const QString &transport, co
 {
     resetConnection(true);
     d->domain = domain;
-    d->state = Connecting;
+    d->state  = Connecting;
 
     ensureConnector();
     d->connector->connectToHost(service, transport, domain, port);
 }
 
-QAbstractSocket* BSocket::abstractSocket() const
-{
-    return d->qsock;
-}
+QAbstractSocket *BSocket::abstractSocket() const { return d->qsock; }
 
 qintptr BSocket::socket() const
 {
-    if(d->qsock)
+    if (d->qsock)
         return d->qsock->socketDescriptor();
     else
         return -1;
 }
 
-void BSocket::setSocket(qintptr s)
+void BSocket::setSocket(QTcpSocket *s)
 {
     resetConnection(true);
-    d->qsock = new QTcpSocket(this);
-    d->qsock->setSocketDescriptor(s);
+    s->setParent(this);
+    d->qsock       = s;
     d->qsock_relay = new QTcpSocketSignalRelay(d->qsock, this);
     qs_connected_step2(false); // we have desriptor already. so it's already known to be connected
 }
 
-int BSocket::state() const
-{
-    return d->state;
-}
+int BSocket::state() const { return d->state; }
 
 bool BSocket::isOpen() const
 {
-    if(d->state == Connected)
+    if (d->state == Connected)
         return true;
     else
         return false;
@@ -551,10 +522,10 @@ bool BSocket::isOpen() const
 
 void BSocket::close()
 {
-    if(d->state == Idle)
+    if (d->state == Idle)
         return;
 
-    if(d->qsock) {
+    if (d->qsock) {
         d->state = Closing;
         d->qsock->close();
         if (d->qsock->state() == QAbstractSocket::ClosingState) {
@@ -562,15 +533,14 @@ void BSocket::close()
         } else {
             resetConnection();
         }
-    }
-    else {
+    } else {
         resetConnection();
     }
 }
 
 qint64 BSocket::writeData(const char *data, qint64 maxSize)
 {
-    if(d->state != Connected)
+    if (d->state != Connected)
         return 0;
 #ifdef BS_DEBUG_EXTRA
     BSDEBUG << "- [" << maxSize << "]: {" << QByteArray::fromRawData(data, maxSize) << "}";
@@ -580,13 +550,13 @@ qint64 BSocket::writeData(const char *data, qint64 maxSize)
 
 qint64 BSocket::readData(char *data, qint64 maxSize)
 {
-    if(!maxSize) {
+    if (!maxSize) {
         return 0;
     }
     qint64 readSize;
-    if(d->qsock) {
+    if (d->qsock) {
         qint64 max = bytesAvailable();
-        if(maxSize <= 0 || maxSize > max) {
+        if (maxSize <= 0 || maxSize > max) {
             maxSize = max;
         }
         readSize = d->qsock->read(data, maxSize);
@@ -602,7 +572,7 @@ qint64 BSocket::readData(char *data, qint64 maxSize)
 
 qint64 BSocket::bytesAvailable() const
 {
-    if(d->qsock)
+    if (d->qsock)
         return d->qsock->bytesAvailable();
     else
         return ByteStream::bytesAvailable();
@@ -610,14 +580,14 @@ qint64 BSocket::bytesAvailable() const
 
 qint64 BSocket::bytesToWrite() const
 {
-    if(!d->qsock)
+    if (!d->qsock)
         return 0;
     return d->qsock->bytesToWrite();
 }
 
 QHostAddress BSocket::address() const
 {
-    if(d->qsock)
+    if (d->qsock)
         return d->qsock->localAddress();
     else
         return QHostAddress();
@@ -625,7 +595,7 @@ QHostAddress BSocket::address() const
 
 quint16 BSocket::port() const
 {
-    if(d->qsock)
+    if (d->qsock)
         return d->qsock->localPort();
     else
         return 0;
@@ -633,7 +603,7 @@ quint16 BSocket::port() const
 
 QHostAddress BSocket::peerAddress() const
 {
-    if(d->qsock)
+    if (d->qsock)
         return d->qsock->peerAddress();
     else
         return QHostAddress();
@@ -641,7 +611,7 @@ QHostAddress BSocket::peerAddress() const
 
 quint16 BSocket::peerPort() const
 {
-    if(d->qsock)
+    if (d->qsock)
         return d->qsock->peerPort();
     else
         return 0;
@@ -650,8 +620,8 @@ quint16 BSocket::peerPort() const
 void BSocket::qs_connected()
 {
     HappyEyeballsConnector::SockData sd = d->connector->takeCurrent(this);
-    d->qsock = sd.sock;
-    d->qsock_relay = sd.relay;
+    d->qsock                            = sd.sock;
+    d->qsock_relay                      = sd.relay;
     d->connector->deleteLater();
     qs_connected_step2(true);
 }
@@ -668,19 +638,19 @@ void BSocket::qs_connected_step2(bool signalConnected)
 #ifdef BS_DEBUG
     BSDEBUG << "Connected";
 #endif
+    QPointer<BSocket> valid(this);
     if (signalConnected) {
         emit connected();
     }
 
-    if (d->qsock->bytesAvailable()) {
+    if (valid && d->qsock->bytesAvailable()) {
         qs_readyRead();
     }
 }
 
 void BSocket::qs_closed()
 {
-    if(d->state == Closing)
-    {
+    if (d->state == Closing) {
 #ifdef BS_DEBUG
         BSDEBUG << "Delayed Close Finished";
 #endif
@@ -689,10 +659,7 @@ void BSocket::qs_closed()
     }
 }
 
-void BSocket::qs_readyRead()
-{
-    emit readyRead();
-}
+void BSocket::qs_readyRead() { emit readyRead(); }
 
 void BSocket::qs_bytesWritten(qint64 x64)
 {
@@ -705,7 +672,7 @@ void BSocket::qs_bytesWritten(qint64 x64)
 
 void BSocket::qs_error(QAbstractSocket::SocketError x)
 {
-    if(x == QTcpSocket::RemoteHostClosedError) {
+    if (x == QTcpSocket::RemoteHostClosedError) {
 #ifdef BS_DEBUG
         BSDEBUG << "Connection Closed";
 #endif
@@ -718,9 +685,9 @@ void BSocket::qs_error(QAbstractSocket::SocketError x)
     BSDEBUG << "Error";
 #endif
     resetConnection();
-    if(x == QTcpSocket::ConnectionRefusedError)
+    if (x == QTcpSocket::ConnectionRefusedError)
         emit error(ErrConnectionRefused);
-    else if(x == QTcpSocket::HostNotFoundError)
+    else if (x == QTcpSocket::HostNotFoundError)
         emit error(ErrHostNotFound);
     else
         emit error(ErrRead);
