@@ -13,50 +13,48 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef CS_BSOCKET_H
 #define CS_BSOCKET_H
 
-#include <QAbstractSocket>
-#include <limits>
-
 #include "bytestream.h"
 #include "netnames.h"
 
-class QString;
-class QObject;
+#include <QAbstractSocket>
+#include <limits>
+
 class QByteArray;
+class QObject;
+class QString;
 
 // CS_NAMESPACE_BEGIN
-
-
 /*!
     Socket with automatic hostname lookups, using SRV, AAAA and A DNS queries.
 */
-class BSocket : public ByteStream
-{
+class BSocket : public ByteStream {
     Q_OBJECT
 public:
     enum Error { ErrConnectionRefused = ErrCustom, ErrHostNotFound };
     enum State { Idle, HostLookup, Connecting, Connected, Closing };
-    BSocket(QObject *parent=0);
+    BSocket(QObject *parent = nullptr);
     ~BSocket();
 
     /*! Connect to an already resolved host */
     void connectToHost(const QHostAddress &address, quint16 port);
     /*! Connect to a host via the specified protocol, or the default protocols if not specified */
-    void connectToHost(const QString &host, quint16 port, QAbstractSocket::NetworkLayerProtocol protocol = QAbstractSocket::UnknownNetworkLayerProtocol);
+    void connectToHost(const QString &host, quint16 port,
+                       QAbstractSocket::NetworkLayerProtocol protocol = QAbstractSocket::UnknownNetworkLayerProtocol);
     /*! Connect to the hosts for the specified service */
-    void connectToHost(const QString &service, const QString &transport, const QString &domain, quint16 port = std::numeric_limits<quint16>::max());
-    virtual QAbstractSocket* abstractSocket() const;
-    qintptr socket() const;
-    void setSocket(qintptr);
-    int state() const;
+    void                     connectToHost(const QString &service, const QString &transport, const QString &domain,
+                                           quint16 port = std::numeric_limits<quint16>::max());
+    virtual QAbstractSocket *abstractSocket() const;
+    qintptr                  socket() const;
+    void                     setSocket(QTcpSocket *);
+    int                      state() const;
 
     // from ByteStream
     bool isOpen() const;
@@ -67,11 +65,11 @@ public:
 
     // local
     QHostAddress address() const;
-    quint16 port() const;
+    quint16      port() const;
 
     // remote
     QHostAddress peerAddress() const;
-    quint16 peerPort() const;
+    quint16      peerPort() const;
 
 protected:
     qint64 writeData(const char *data, qint64 maxSize);
@@ -92,15 +90,13 @@ private:
     class Private;
     Private *d;
 
-    void resetConnection(bool clear=false);
+    void resetConnection(bool clear = false);
     void ensureConnector();
     void recreate_resolver();
     bool check_protocol_fallback();
     void dns_srv_try_next();
     bool connect_host_try_next();
     void qs_connected_step2(bool signalConnected = true);
-};
+}; // CS_NAMESPACE_END
 
-// CS_NAMESPACE_END
-
-#endif
+#endif // CS_BSOCKET_H
