@@ -12,41 +12,39 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef CS_BYTESTREAM_H
 #define CS_BYTESTREAM_H
 
-#include <QObject>
 #include <QByteArray>
 #include <QIODevice>
+#include <QObject>
 
 class QAbstractSocket;
-// CS_NAMESPACE_BEGIN
 
+// CS_NAMESPACE_BEGIN
 // CS_EXPORT_BEGIN
-class ByteStream : public QIODevice
-{
+class ByteStream : public QIODevice {
     Q_OBJECT
 public:
     enum Error { ErrOk, ErrRead, ErrWrite, ErrCustom = 10 };
-    ByteStream(QObject *parent=nullptr);
-    ~ByteStream()=0;
+    ByteStream(QObject *parent = nullptr);
+    ~ByteStream() = 0;
 
-    bool isSequential() const { return true; }
+    bool   isSequential() const { return true; }
     qint64 bytesAvailable() const;
     qint64 bytesToWrite() const;
 
-    static QByteArray takeArray(QByteArray &from, int size=0, bool del=true);
+    static QByteArray takeArray(QByteArray &from, int size = 0, bool del = true);
 
-    int errorCode() const;
+    int      errorCode() const;
     QString &errorText() const;
 
-    virtual QAbstractSocket* abstractSocket() const { return nullptr; }
+    virtual QAbstractSocket *abstractSocket() const { return nullptr; }
 
 signals:
     void connectionClosed();
@@ -57,25 +55,24 @@ protected:
     qint64 writeData(const char *data, qint64 maxSize);
     qint64 readData(char *data, qint64 maxSize);
 
-    void setError(int code = ErrOk, const QString &text = QString());
-    void clearReadBuffer();
-    void clearWriteBuffer();
-    void appendRead(const QByteArray &);
-    void appendWrite(const QByteArray &);
-    QByteArray takeRead(int size=0, bool del=true);
-    QByteArray takeWrite(int size=0, bool del=true);
-    QByteArray & readBuf();
-    QByteArray & writeBuf();
+    void        setError(int code = ErrOk, const QString &text = QString());
+    void        clearReadBuffer();
+    void        clearWriteBuffer();
+    void        appendRead(const QByteArray &);
+    void        appendWrite(const QByteArray &);
+    QByteArray  takeRead(int size = 0, bool del = true);
+    QByteArray  takeWrite(int size = 0, bool del = true);
+    QByteArray &readBuf();
+    QByteArray &writeBuf();
     virtual int tryWrite();
 
 private:
-//! \if _hide_doc_
+    //! \if _hide_doc_
     class Private;
     Private *d;
-//! \endif
+    //! \endif
 };
 // CS_EXPORT_END
-
 // CS_NAMESPACE_END
 
-#endif
+#endif // CS_BYTESTREAM_H
