@@ -12,37 +12,35 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "httppoll.h"
 
-#include <QUrl>
-#include <qstringlist.h>
-#include <qtimer.h>
-#include <qpointer.h>
-#include <QtCrypto>
-#include <QByteArray>
-#include <stdlib.h>
 #include "bsocket.h"
 
+#include <QByteArray>
+#include <QUrl>
+#include <QtCrypto>
+#include <qpointer.h>
+#include <qstringlist.h>
+#include <qtimer.h>
 #ifdef PROX_DEBUG
 #include <stdio.h>
 #endif
+#include <stdlib.h>
 
 #define POLL_KEYS 64
 
 // CS_NAMESPACE_BEGIN
-
 static QByteArray randomArray(int size)
 {
     QByteArray a;
-  a.resize(size);
-    for(int n = 0; n < size; ++n)
-        a[n] = (char)(256.0*rand()/(RAND_MAX+1.0));
+    a.resize(size);
+    for (int n = 0; n < size; ++n)
+        a[n] = (char)(256.0 * rand() / (RAND_MAX + 1.0));
     return a;
 }
 
@@ -51,48 +49,43 @@ static QByteArray randomArray(int size)
 //----------------------------------------------------------------------------
 static QString hpk(int n, const QString &s)
 {
-    if(n == 0)
+    if (n == 0)
         return s;
     else
-        return QCA::Base64().arrayToString( QCA::Hash("sha1").hash( hpk(n - 1, s).toLatin1() ).toByteArray() );
+        return QCA::Base64().arrayToString(QCA::Hash("sha1").hash(hpk(n - 1, s).toLatin1()).toByteArray());
 }
 
-class HttpPoll::Private
-{
+class HttpPoll::Private {
 public:
-    Private(HttpPoll *_q) :
-        http(_q)
-    {
-    }
+    Private(HttpPoll *_q) : http(_q) { }
 
     HttpProxyPost http;
-    QString host;
-    int port;
-    QString user, pass;
-    QUrl url;
-    bool use_proxy;
+    QString       host;
+    int           port;
+    QString       user, pass;
+    QUrl          url;
+    bool          use_proxy;
 
     QByteArray out;
 
-    int state;
-    bool closing;
+    int     state;
+    bool    closing;
     QString ident;
 
     QTimer *t;
 
     QString key[POLL_KEYS];
-    int key_n;
+    int     key_n;
 
     int polltime;
 };
 
-HttpPoll::HttpPoll(QObject *parent)
-:ByteStream(parent)
+HttpPoll::HttpPoll(QObject *parent) : ByteStream(parent)
 {
     d = new Private(this);
 
     d->polltime = 30;
-    d->t = new QTimer(this);
+    d->t        = new QTimer(this);
     d->t->setSingleShot(true);
     connect(d->t, SIGNAL(timeout()), SLOT(do_sync()));
 
@@ -109,20 +102,17 @@ HttpPoll::~HttpPoll()
     delete d;
 }
 
-QAbstractSocket* HttpPoll::abstractSocket() const
-{
-    return d->http.abstractSocket();
-}
+QAbstractSocket *HttpPoll::abstractSocket() const { return d->http.abstractSocket(); }
 
 void HttpPoll::resetConnection(bool clear)
 {
-    if(d->http.isActive())
+    if (d->http.isActive())
         d->http.stop();
-    if(clear)
+    if (clear)
         clearReadBuffer();
     clearWriteBuffer();
     d->out.resize(0);
-    d->state = 0;
+    d->state   = 0;
     d->closing = false;
     d->t->stop();
 }
@@ -133,50 +123,46 @@ void HttpPoll::setAuth(const QString &user, const QString &pass)
     d->pass = pass;
 }
 
-void HttpPoll::connectToUrl(const QUrl &url)
-{
-    connectToHost("", 0, url);
-}
+void HttpPoll::connectToUrl(const QUrl &url) { connectToHost("", 0, url); }
 
 void HttpPoll::connectToHost(const QString &proxyHost, int proxyPort, const QUrl &url)
 {
     resetConnection(true);
 
     bool useSsl = false;
-    d->port = 80;
+    d->port     = 80;
     // using proxy?
-    if(!proxyHost.isEmpty()) {
-        d->host = proxyHost;
-        d->port = proxyPort;
-        d->url = url;
+    if (!proxyHost.isEmpty()) {
+        d->host      = proxyHost;
+        d->port      = proxyPort;
+        d->url       = url;
         d->use_proxy = true;
-    }
-    else {
+    } else {
         d->host = url.host();
-        if(url.port() != -1)
+        if (url.port() != -1)
             d->port = url.port();
         else if (url.scheme() == "https") {
             d->port = 443;
-            useSsl = true;
+            useSsl  = true;
         }
         d->url.setUrl(url.path() + "?" + url.query(QUrl::FullyEncoded), QUrl::StrictMode);
         d->use_proxy = false;
     }
 
     resetKey();
-    bool last;
+    bool    last;
     QString key = getKey(&last);
 
 #ifdef PROX_DEBUG
     fprintf(stderr, "HttpPoll: Connecting to %s:%d [%s]", d->host.latin1(), d->port, d->url.latin1());
-    if(d->user.isEmpty())
+    if (d->user.isEmpty())
         fprintf(stderr, "\n");
     else
         fprintf(stderr, ", auth {%s,%s}\n", d->user.latin1(), d->pass.latin1());
 #endif
     QPointer<QObject> self = this;
     syncStarted();
-    if(!self)
+    if (!self)
         return;
 
     d->state = 1;
@@ -185,49 +171,41 @@ void HttpPoll::connectToHost(const QString &proxyHost, int proxyPort, const QUrl
     d->http.post(d->host, d->port, d->url, makePacket("0", key, "", QByteArray()), d->use_proxy);
 }
 
-QByteArray HttpPoll::makePacket(const QString &ident, const QString &key, const QString &newkey, const QByteArray &block)
+QByteArray HttpPoll::makePacket(const QString &ident, const QString &key, const QString &newkey,
+                                const QByteArray &block)
 {
     QString str = ident;
-    if(!key.isEmpty()) {
+    if (!key.isEmpty()) {
         str += ';';
         str += key;
     }
-    if(!newkey.isEmpty()) {
+    if (!newkey.isEmpty()) {
         str += ';';
         str += newkey;
     }
     str += ',';
-    QByteArray cs = str.toLatin1();
-    int len = cs.length();
+    QByteArray cs  = str.toLatin1();
+    int        len = cs.length();
 
     QByteArray a;
-  a.resize(len + block.size());
+    a.resize(len + block.size());
     memcpy(a.data(), cs.data(), len);
     memcpy(a.data() + len, block.data(), block.size());
     return a;
 }
 
-int HttpPoll::pollInterval() const
-{
-    return d->polltime;
-}
+int HttpPoll::pollInterval() const { return d->polltime; }
 
-void HttpPoll::setPollInterval(int seconds)
-{
-    d->polltime = seconds;
-}
+void HttpPoll::setPollInterval(int seconds) { d->polltime = seconds; }
 
-bool HttpPoll::isOpen() const
-{
-    return (d->state == 2 ? true: false);
-}
+bool HttpPoll::isOpen() const { return (d->state == 2 ? true : false); }
 
 void HttpPoll::close()
 {
-    if(d->state == 0 || d->closing)
+    if (d->state == 0 || d->closing)
         return;
 
-    if(bytesToWrite() == 0)
+    if (bytesToWrite() == 0)
         resetConnection();
     else
         d->closing = true;
@@ -238,58 +216,56 @@ void HttpPoll::http_result()
     // check for death :)
     QPointer<QObject> self = this;
     syncFinished();
-    if(!self)
+    if (!self)
         return;
 
     // get id and packet
     QString id;
     QString cookie = d->http.getHeader("Set-Cookie");
-    int n = cookie.indexOf("ID=");
-    if(n == -1) {
+    int     n      = cookie.indexOf("ID=");
+    if (n == -1) {
         resetConnection();
         setError(ErrRead);
         return;
     }
     n += 3;
     int n2 = cookie.indexOf(';', n);
-    if(n2 != -1)
-        id = cookie.mid(n, n2-n);
+    if (n2 != -1)
+        id = cookie.mid(n, n2 - n);
     else
         id = cookie.mid(n);
     QByteArray block = d->http.body();
 
     // session error?
-    if(id.right(2) == ":0") {
-        if(id == "0:0" && d->state == 2) {
+    if (id.right(2) == ":0") {
+        if (id == "0:0" && d->state == 2) {
             resetConnection();
             connectionClosed();
             return;
-        }
-        else {
+        } else {
             resetConnection();
             setError(ErrRead);
             return;
         }
     }
 
-    d->ident = id;
+    d->ident              = id;
     bool justNowConnected = false;
-    if(d->state == 1) {
-        d->state = 2;
+    if (d->state == 1) {
+        d->state         = 2;
         justNowConnected = true;
     }
 
     // sync up again soon
-    if(bytesToWrite() > 0 || !d->closing) {
+    if (bytesToWrite() > 0 || !d->closing) {
         d->t->start(d->polltime * 1000);
-  }
+    }
 
     // connecting
-    if(justNowConnected) {
+    if (justNowConnected) {
         connected();
-    }
-    else {
-        if(!d->out.isEmpty()) {
+    } else {
+        if (!d->out.isEmpty()) {
             int x = d->out.size();
             d->out.resize(0);
             takeWrite(x);
@@ -297,22 +273,21 @@ void HttpPoll::http_result()
         }
     }
 
-    if(!self)
+    if (!self)
         return;
 
-    if(!block.isEmpty()) {
+    if (!block.isEmpty()) {
         appendRead(block);
         readyRead();
     }
 
-    if(!self)
+    if (!self)
         return;
 
-    if(bytesToWrite() > 0) {
+    if (bytesToWrite() > 0) {
         do_sync();
-    }
-    else {
-        if(d->closing) {
+    } else {
+        if (d->closing) {
             resetConnection();
             delayedCloseFinished();
             return;
@@ -323,46 +298,46 @@ void HttpPoll::http_result()
 void HttpPoll::http_error(int x)
 {
     resetConnection();
-    if(x == HttpProxyPost::ErrConnectionRefused)
+    if (x == HttpProxyPost::ErrConnectionRefused)
         setError(ErrConnectionRefused);
-    else if(x == HttpProxyPost::ErrHostNotFound)
+    else if (x == HttpProxyPost::ErrHostNotFound)
         setError(ErrHostNotFound);
-    else if(x == HttpProxyPost::ErrSocket)
+    else if (x == HttpProxyPost::ErrSocket)
         setError(ErrRead);
-    else if(x == HttpProxyPost::ErrProxyConnect)
+    else if (x == HttpProxyPost::ErrProxyConnect)
         setError(ErrProxyConnect);
-    else if(x == HttpProxyPost::ErrProxyNeg)
+    else if (x == HttpProxyPost::ErrProxyNeg)
         setError(ErrProxyNeg);
-    else if(x == HttpProxyPost::ErrProxyAuth)
+    else if (x == HttpProxyPost::ErrProxyAuth)
         setError(ErrProxyAuth);
 }
 
 int HttpPoll::tryWrite()
 {
-    if(!d->http.isActive())
+    if (!d->http.isActive())
         do_sync();
     return 0;
 }
 
 void HttpPoll::do_sync()
 {
-    if(d->http.isActive())
+    if (d->http.isActive())
         return;
 
     d->t->stop();
     d->out = takeWrite(0, false);
 
-    bool last;
+    bool    last;
     QString key = getKey(&last);
     QString newkey;
-    if(last) {
+    if (last) {
         resetKey();
         newkey = getKey(&last);
     }
 
     QPointer<QObject> self = this;
     syncStarted();
-    if(!self)
+    if (!self)
         return;
 
     d->http.post(d->host, d->port, d->url, makePacket(d->ident, key, newkey, d->out), d->use_proxy);
@@ -373,24 +348,23 @@ void HttpPoll::resetKey()
 #ifdef PROX_DEBUG
     fprintf(stderr, "HttpPoll: reset key!\n");
 #endif
-    QByteArray a = randomArray(64);
-    QString str = QString::fromLatin1(a.data(), a.size());
+    QByteArray a   = randomArray(64);
+    QString    str = QString::fromLatin1(a.data(), a.size());
 
     d->key_n = POLL_KEYS;
-    for(int n = 0; n < POLL_KEYS; ++n)
-        d->key[n] = hpk(n+1, str);
+    for (int n = 0; n < POLL_KEYS; ++n)
+        d->key[n] = hpk(n + 1, str);
 }
 
-const QString & HttpPoll::getKey(bool *last)
+const QString &HttpPoll::getKey(bool *last)
 {
     *last = false;
     --(d->key_n);
-    if(d->key_n == 0)
+    if (d->key_n == 0)
         *last = true;
     return d->key[d->key_n];
 }
 
-
 //----------------------------------------------------------------------------
 // HttpProxyPost
 //----------------------------------------------------------------------------
@@ -398,8 +372,8 @@ static QString extractLine(QByteArray *buf, bool *found)
 {
     // scan for newline
     int n;
-    for(n = 0; n < (int)buf->size()-1; ++n) {
-        if(buf->at(n) == '\r' && buf->at(n+1) == '\n') {
+    for (n = 0; n < (int)buf->size() - 1; ++n) {
+        if (buf->at(n) == '\r' && buf->at(n + 1) == '\n') {
             QByteArray cstr;
             cstr.resize(n);
             memcpy(cstr.data(), buf->data(), n);
@@ -409,13 +383,13 @@ static QString extractLine(QByteArray *buf, bool *found)
             buf->resize(buf->size() - n);
             QString s = QString::fromUtf8(cstr);
 
-            if(found)
+            if (found)
                 *found = true;
             return s;
         }
     }
 
-    if(found)
+    if (found)
         *found = false;
     return "";
 }
@@ -423,51 +397,42 @@ static QString extractLine(QByteArray *buf, bool *found)
 static bool extractMainHeader(const QString &line, QString *proto, int *code, QString *msg)
 {
     int n = line.indexOf(' ');
-    if(n == -1)
+    if (n == -1)
         return false;
-    if(proto)
+    if (proto)
         *proto = line.mid(0, n);
     ++n;
     int n2 = line.indexOf(' ', n);
-    if(n2 == -1)
+    if (n2 == -1)
         return false;
-    if(code)
-        *code = line.mid(n, n2-n).toInt();
-    n = n2+1;
-    if(msg)
+    if (code)
+        *code = line.mid(n, n2 - n).toInt();
+    n = n2 + 1;
+    if (msg)
         *msg = line.mid(n);
     return true;
 }
 
-class HttpProxyPost::Private
-{
+class HttpProxyPost::Private {
 public:
-    Private(HttpProxyPost *_q) :
-        sock(_q),
-        tls(0)
-    {
-    }
+    Private(HttpProxyPost *_q) : sock(_q), tls(nullptr) { }
 
-    ~Private()
-    {
-        delete tls;
-    }
+    ~Private() { delete tls; }
 
-    BSocket sock;
+    BSocket      sock;
     QHostAddress lastAddress;
-    QByteArray postdata, recvBuf, body;
-    QUrl url;
-    QString user, pass;
-    bool inHeader;
-    QStringList headerLines;
-    bool asProxy;
-    bool useSsl;
-    QString host;
-    QCA::TLS *tls;
+    QByteArray   postdata, recvBuf, body;
+    QUrl         url;
+    QString      user, pass;
+    bool         inHeader;
+    QStringList  headerLines;
+    bool         asProxy;
+    bool         useSsl;
+    QString      host;
+    QCA::TLS *   tls;
 };
 
-HttpProxyPost::HttpProxyPost(QObject *parent)
-:QObject(parent)
+HttpProxyPost::HttpProxyPost(QObject *parent) : QObject(parent)
 {
     d = new Private(this);
     connect(&d->sock, SIGNAL(connected()), SLOT(sock_connected()));
@@ -483,22 +448,16 @@ HttpProxyPost::~HttpProxyPost()
     delete d;
 }
 
-void HttpProxyPost::setUseSsl(bool state)
-{
-    d->useSsl = state;
-}
+void HttpProxyPost::setUseSsl(bool state) { d->useSsl = state; }
 
-QAbstractSocket* HttpProxyPost::abstractSocket() const
-{
-    return d->sock.abstractSocket();
-}
+QAbstractSocket *HttpProxyPost::abstractSocket() const { return d->sock.abstractSocket(); }
 
 void HttpProxyPost::resetConnection(bool clear)
 {
-    if(d->sock.state() != BSocket::Idle)
+    if (d->sock.state() != BSocket::Idle)
         d->sock.close();
     d->recvBuf.resize(0);
-    if(clear)
+    if (clear)
         d->body.resize(0);
 }
 
@@ -508,23 +467,20 @@ void HttpProxyPost::setAuth(const QString &user, const QString &pass)
     d->pass = pass;
 }
 
-bool HttpProxyPost::isActive() const
-{
-    return (d->sock.state() == BSocket::Idle ? false: true);
-}
+bool HttpProxyPost::isActive() const { return (d->sock.state() == BSocket::Idle ? false : true); }
 
 void HttpProxyPost::post(const QString &proxyHost, int proxyPort, const QUrl &url, const QByteArray &data, bool asProxy)
 {
     resetConnection(true);
 
-    d->host = proxyHost;
-    d->url = url;
+    d->host     = proxyHost;
+    d->url      = url;
     d->postdata = data;
-    d->asProxy = asProxy;
+    d->asProxy  = asProxy;
 
 #ifdef PROX_DEBUG
     fprintf(stderr, "HttpProxyPost: Connecting to %s:%d", proxyHost.latin1(), proxyPort);
-    if(d->user.isEmpty())
+    if (d->user.isEmpty())
         fprintf(stderr, "\n");
     else
         fprintf(stderr, ", auth {%s,%s}\n", d->user.latin1(), d->pass.latin1());
@@ -538,25 +494,19 @@ void HttpProxyPost::post(const QString &proxyHost, int proxyPort, const QUrl &ur
     }
 }
 
-void HttpProxyPost::stop()
-{
-    resetConnection();
-}
+void HttpProxyPost::stop() { resetConnection(); }
 
-QByteArray HttpProxyPost::body() const
-{
-    return d->body;
-}
+QByteArray HttpProxyPost::body() const { return d->body; }
 
 QString HttpProxyPost::getHeader(const QString &var) const
 {
-    foreach (const QString &s, d->headerLines) {
+    for (const QString &s : d->headerLines) {
         int n = s.indexOf(": ");
-        if(n == -1)
+        if (n == -1)
             continue;
         QString v = s.mid(0, n);
-        if(v.toLower() == var.toLower())
-            return s.mid(n+2);
+        if (v.toLower() == var.toLower())
+            return s.mid(n + 2);
     }
     return "";
 }
@@ -566,7 +516,7 @@ void HttpProxyPost::sock_connected()
 #ifdef PROX_DEBUG
     fprintf(stderr, "HttpProxyPost: Connected\n");
 #endif
-    if(d->useSsl) {
+    if (d->useSsl) {
         d->tls = new QCA::TLS(this);
         connect(d->tls, SIGNAL(readyRead()), SLOT(tls_readyRead()));
         connect(d->tls, SIGNAL(readyReadOutgoing()), SLOT(tls_readyReadOutgoing()));
@@ -575,7 +525,7 @@ void HttpProxyPost::sock_connected()
     }
 
     d->lastAddress = d->sock.peerAddress();
-    d->inHeader = true;
+    d->inHeader    = true;
     d->headerLines.clear();
 
     QUrl u = d->url;
@@ -583,22 +533,21 @@ void HttpProxyPost::sock_connected()
     // connected, now send the request
     QByteArray s;
     s += QByteArray("POST ") + d->url.toEncoded() + " HTTP/1.1\r\n";
-    if(d->asProxy) {
-        if(!d->user.isEmpty()) {
+    if (d->asProxy) {
+        if (!d->user.isEmpty()) {
             QByteArray str = d->user.toUtf8() + ':' + d->pass.toUtf8();
             s += QByteArray("Proxy-Authorization: Basic ") + str.toBase64() + "\r\n";
         }
         s += "Pragma: no-cache\r\n";
         s += QByteArray("Host: ") + u.host().toUtf8() + "\r\n";
-    }
-    else {
+    } else {
         s += QByteArray("Host: ") + d->host.toUtf8() + "\r\n";
     }
     s += "Content-Type: application/x-www-form-urlencoded\r\n";
     s += QByteArray("Content-Length: ") + QByteArray::number(d->postdata.size()) + "\r\n";
     s += "\r\n";
 
-    if(d->useSsl) {
+    if (d->useSsl) {
         // write request
         d->tls->write(s);
 
@@ -622,13 +571,13 @@ void HttpProxyPost::sock_connectionClosed()
 
 void HttpProxyPost::tls_readyRead()
 {
-    //printf("tls_readyRead\n");
+    // printf("tls_readyRead\n");
     processData(d->tls->read());
 }
 
 void HttpProxyPost::tls_readyReadOutgoing()
 {
-    //printf("tls_readyReadOutgoing\n");
+    // printf("tls_readyReadOutgoing\n");
     d->sock.write(d->tls->readOutgoing());
 }
 
@@ -644,7 +593,7 @@ void HttpProxyPost::tls_error()
 void HttpProxyPost::sock_readyRead()
 {
     QByteArray block = d->sock.readAll();
-    if(d->useSsl)
+    if (d->useSsl)
         d->tls->writeIncoming(block);
     else
         processData(block);
@@ -654,14 +603,14 @@ void HttpProxyPost::processData(const QByteArray &block)
 {
     d->recvBuf += block;
 
-    if(d->inHeader) {
+    if (d->inHeader) {
         // grab available lines
-        while(1) {
-            bool found;
+        while (1) {
+            bool    found;
             QString line = extractLine(&d->recvBuf, &found);
-            if(!found)
+            if (!found)
                 break;
-            if(line.isEmpty()) {
+            if (line.isEmpty()) {
                 d->inHeader = false;
                 break;
             }
@@ -669,55 +618,50 @@ void HttpProxyPost::processData(const QByteArray &block)
         }
 
         // done with grabbing the header?
-        if(!d->inHeader) {
+        if (!d->inHeader) {
             QString str = d->headerLines.first();
             d->headerLines.takeFirst();
 
             QString proto;
-            int code;
+            int     code;
             QString msg;
-            if(!extractMainHeader(str, &proto, &code, &msg)) {
+            if (!extractMainHeader(str, &proto, &code, &msg)) {
 #ifdef PROX_DEBUG
                 fprintf(stderr, "HttpProxyPost: invalid header!\n");
 #endif
                 resetConnection(true);
                 error(ErrProxyNeg);
                 return;
-            }
-            else {
+            } else {
 #ifdef PROX_DEBUG
-                fprintf(stderr, "HttpProxyPost: header proto=[%s] code=[%d] msg=[%s]\n", proto.latin1(), code, msg.latin1());
-                foreach (const QString &s, d->headerLines)
+                fprintf(stderr, "HttpProxyPost: header proto=[%s] code=[%d] msg=[%s]\n", proto.latin1(), code,
+                        msg.latin1());
+                for (const QString &s : d->headerLines)
                     fprintf(stderr, "HttpProxyPost: * [%s]\n", qPrintable(s));
 #endif
             }
 
-            if(code == 200) { // OK
+            if (code == 200) { // OK
 #ifdef PROX_DEBUG
                 fprintf(stderr, "HttpProxyPost: << Success >>\n");
 #endif
-            }
-            else {
-                int err;
+            } else {
+                int     err;
                 QString errStr;
-                if(code == 407) { // Authentication failed
-                    err = ErrProxyAuth;
+                if (code == 407) { // Authentication failed
+                    err    = ErrProxyAuth;
                     errStr = tr("Authentication failed");
-                }
-                else if(code == 404) { // Host not found
-                    err = ErrHostNotFound;
+                } else if (code == 404) { // Host not found
+                    err    = ErrHostNotFound;
                     errStr = tr("Host not found");
-                }
-                else if(code == 403) { // Access denied
-                    err = ErrProxyNeg;
+                } else if (code == 403) { // Access denied
+                    err    = ErrProxyNeg;
                     errStr = tr("Access denied");
-                }
-                else if(code == 503) { // Connection refused
-                    err = ErrConnectionRefused;
+                } else if (code == 503) { // Connection refused
+                    err    = ErrConnectionRefused;
                     errStr = tr("Connection refused");
-                }
-                else { // invalid reply
-                    err = ErrProxyNeg;
+                } else { // invalid reply
+                    err    = ErrProxyNeg;
                     errStr = tr("Invalid reply");
                 }
 
@@ -738,44 +682,39 @@ void HttpProxyPost::sock_error(int x)
     fprintf(stderr, "HttpProxyPost: socket error: %d\n", x);
 #endif
     resetConnection(true);
-    if(x == BSocket::ErrHostNotFound)
+    if (x == BSocket::ErrHostNotFound)
         error(ErrProxyConnect);
-    else if(x == BSocket::ErrConnectionRefused)
+    else if (x == BSocket::ErrConnectionRefused)
         error(ErrProxyConnect);
-    else if(x == BSocket::ErrRead)
+    else if (x == BSocket::ErrRead)
         error(ErrProxyNeg);
 }
 
 //----------------------------------------------------------------------------
 // HttpProxyGetStream
 //----------------------------------------------------------------------------
-class HttpProxyGetStream::Private
-{
+class HttpProxyGetStream::Private {
 public:
-    Private(HttpProxyGetStream *_q) :
-        sock(_q)
-    {
-    }
+    Private(HttpProxyGetStream *_q) : sock(_q) { }
 
-    BSocket sock;
-    QByteArray recvBuf;
-    QString url;
-    QString user, pass;
-    bool inHeader;
+    BSocket     sock;
+    QByteArray  recvBuf;
+    QString     url;
+    QString     user, pass;
+    bool        inHeader;
     QStringList headerLines;
-    bool use_ssl;
-    bool asProxy;
-    QString host;
-    int length;
+    bool        use_ssl;
+    bool        asProxy;
+    QString     host;
+    int         length;
 
     QCA::TLS *tls;
 };
 
-HttpProxyGetStream::HttpProxyGetStream(QObject *parent)
-:QObject(parent)
+HttpProxyGetStream::HttpProxyGetStream(QObject *parent) : QObject(parent)
 {
-    d = new Private(this);
-    d->tls = 0;
+    d      = new Private(this);
+    d->tls = nullptr;
     connect(&d->sock, SIGNAL(connected()), SLOT(sock_connected()));
     connect(&d->sock, SIGNAL(connectionClosed()), SLOT(sock_connectionClosed()));
     connect(&d->sock, SIGNAL(readyRead()), SLOT(sock_readyRead()));
@@ -791,14 +730,14 @@ HttpProxyGetStream::~HttpProxyGetStream()
 
 void HttpProxyGetStream::resetConnection(bool /*clear*/)
 {
-    if(d->tls) {
+    if (d->tls) {
         delete d->tls;
-        d->tls = 0;
+        d->tls = nullptr;
     }
-    if(d->sock.state() != BSocket::Idle)
+    if (d->sock.state() != BSocket::Idle)
         d->sock.close();
     d->recvBuf.resize(0);
-    //if(clear)
+    // if(clear)
     //    d->body.resize(0);
     d->length = -1;
 }
@@ -809,23 +748,20 @@ void HttpProxyGetStream::setAuth(const QString &user, const QString &pass)
     d->pass = pass;
 }
 
-bool HttpProxyGetStream::isActive() const
-{
-    return (d->sock.state() == BSocket::Idle ? false: true);
-}
+bool HttpProxyGetStream::isActive() const { return (d->sock.state() == BSocket::Idle ? false : true); }
 
 void HttpProxyGetStream::get(const QString &proxyHost, int proxyPort, const QString &url, bool ssl, bool asProxy)
 {
     resetConnection(true);
 
-    d->host = proxyHost;
-    d->url = url;
+    d->host    = proxyHost;
+    d->url     = url;
     d->use_ssl = ssl;
     d->asProxy = asProxy;
 
 #ifdef PROX_DEBUG
     fprintf(stderr, "HttpProxyGetStream: Connecting to %s:%d", proxyHost.latin1(), proxyPort);
-    if(d->user.isEmpty())
+    if (d->user.isEmpty())
         fprintf(stderr, "\n");
     else
         fprintf(stderr, ", auth {%s,%s}\n", d->user.latin1(), d->pass.latin1());
@@ -833,35 +769,29 @@ void HttpProxyGetStream::get(const QString &proxyHost, int proxyPort, const QStr
     d->sock.connectToHost(proxyHost, proxyPort);
 }
 
-void HttpProxyGetStream::stop()
-{
-    resetConnection();
-}
+void HttpProxyGetStream::stop() { resetConnection(); }
 
 QString HttpProxyGetStream::getHeader(const QString &var) const
 {
-    foreach (const QString &s, d->headerLines) {
+    for (const QString &s : d->headerLines) {
         int n = s.indexOf(": ");
-        if(n == -1)
+        if (n == -1)
             continue;
         QString v = s.mid(0, n);
-        if(v.toLower() == var.toLower())
-            return s.mid(n+2);
+        if (v.toLower() == var.toLower())
+            return s.mid(n + 2);
     }
     return "";
 }
 
-int HttpProxyGetStream::length() const
-{
-    return d->length;
-}
+int HttpProxyGetStream::length() const { return d->length; }
 
 void HttpProxyGetStream::sock_connected()
 {
 #ifdef PROX_DEBUG
     fprintf(stderr, "HttpProxyGetStream: Connected\n");
 #endif
-    if(d->use_ssl) {
+    if (d->use_ssl) {
         d->tls = new QCA::TLS(this);
         connect(d->tls, SIGNAL(readyRead()), SLOT(tls_readyRead()));
         connect(d->tls, SIGNAL(readyReadOutgoing()), SLOT(tls_readyReadOutgoing()));
@@ -877,21 +807,20 @@ void HttpProxyGetStream::sock_connected()
     // connected, now send the request
     QString s;
     s += QString("GET ") + d->url + " HTTP/1.0\r\n";
-    if(d->asProxy) {
-        if(!d->user.isEmpty()) {
+    if (d->asProxy) {
+        if (!d->user.isEmpty()) {
             QString str = d->user + ':' + d->pass;
             s += QString("Proxy-Authorization: Basic ") + QCA::Base64().encodeString(str) + "\r\n";
         }
         s += "Pragma: no-cache\r\n";
         s += QString("Host: ") + u.host() + "\r\n";
-    }
-    else {
+    } else {
         s += QString("Host: ") + d->host + "\r\n";
     }
     s += "\r\n";
 
     // write request
-    if(d->use_ssl)
+    if (d->use_ssl)
         d->tls->write(s.toUtf8());
     else
         d->sock.write(s.toUtf8());
@@ -899,7 +828,7 @@ void HttpProxyGetStream::sock_connected()
 
 void HttpProxyGetStream::sock_connectionClosed()
 {
-    //d->body = d->recvBuf;
+    // d->body = d->recvBuf;
     resetConnection();
     emit finished();
 }
@@ -908,7 +837,7 @@ void HttpProxyGetStream::sock_readyRead()
 {
     QByteArray block = d->sock.readAll();
 
-    if(d->use_ssl)
+    if (d->use_ssl)
         d->tls->writeIncoming(block);
     else
         processData(block);
@@ -917,21 +846,21 @@ void HttpProxyGetStream::sock_readyRead()
 void HttpProxyGetStream::processData(const QByteArray &block)
 {
     printf("processData: %d bytes\n", block.size());
-    if(!d->inHeader) {
+    if (!d->inHeader) {
         emit dataReady(block);
         return;
     }
 
     d->recvBuf += block;
 
-    if(d->inHeader) {
+    if (d->inHeader) {
         // grab available lines
-        while(1) {
-            bool found;
+        while (1) {
+            bool    found;
             QString line = extractLine(&d->recvBuf, &found);
-            if(!found)
+            if (!found)
                 break;
-            if(line.isEmpty()) {
+            if (line.isEmpty()) {
                 printf("empty line\n");
                 d->inHeader = false;
                 break;
@@ -941,65 +870,60 @@ void HttpProxyGetStream::processData(const QByteArray &block)
         }
 
         // done with grabbing the header?
-        if(!d->inHeader) {
+        if (!d->inHeader) {
             QString str = d->headerLines.first();
             d->headerLines.takeFirst();
 
             QString proto;
-            int code;
+            int     code;
             QString msg;
-            if(!extractMainHeader(str, &proto, &code, &msg)) {
+            if (!extractMainHeader(str, &proto, &code, &msg)) {
 #ifdef PROX_DEBUG
                 fprintf(stderr, "HttpProxyGetStream: invalid header!\n");
 #endif
                 resetConnection(true);
                 error(ErrProxyNeg);
                 return;
-            }
-            else {
+            } else {
 #ifdef PROX_DEBUG
-                fprintf(stderr, "HttpProxyGetStream: header proto=[%s] code=[%d] msg=[%s]\n", proto.latin1(), code, msg.latin1());
-                foreach (const QString &s, d->headerLines)
+                fprintf(stderr, "HttpProxyGetStream: header proto=[%s] code=[%d] msg=[%s]\n", proto.latin1(), code,
+                        msg.latin1());
+                for (const QString &s : d->headerLines)
                     fprintf(stderr, "HttpProxyGetStream: * [%s]\n", qPrintable(s));
 #endif
             }
 
-            if(code == 200) { // OK
+            if (code == 200) { // OK
 #ifdef PROX_DEBUG
                 fprintf(stderr, "HttpProxyGetStream: << Success >>\n");
 #endif
 
                 bool ok;
-                int x = getHeader("Content-Length").toInt(&ok);
-                if(ok)
+                int  x = getHeader("Content-Length").toInt(&ok);
+                if (ok)
                     d->length = x;
 
                 QPointer<QObject> self = this;
-                emit handshaken();
-                if(!self)
+                emit              handshaken();
+                if (!self)
                     return;
-            }
-            else {
-                int err;
+            } else {
+                int     err;
                 QString errStr;
-                if(code == 407) { // Authentication failed
-                    err = ErrProxyAuth;
+                if (code == 407) { // Authentication failed
+                    err    = ErrProxyAuth;
                     errStr = tr("Authentication failed");
-                }
-                else if(code == 404) { // Host not found
-                    err = ErrHostNotFound;
+                } else if (code == 404) { // Host not found
+                    err    = ErrHostNotFound;
                     errStr = tr("Host not found");
-                }
-                else if(code == 403) { // Access denied
-                    err = ErrProxyNeg;
+                } else if (code == 403) { // Access denied
+                    err    = ErrProxyNeg;
                     errStr = tr("Access denied");
-                }
-                else if(code == 503) { // Connection refused
-                    err = ErrConnectionRefused;
+                } else if (code == 503) { // Connection refused
+                    err    = ErrConnectionRefused;
                     errStr = tr("Connection refused");
-                }
-                else { // invalid reply
-                    err = ErrProxyNeg;
+                } else { // invalid reply
+                    err    = ErrProxyNeg;
                     errStr = tr("Invalid reply");
                 }
 
@@ -1011,7 +935,7 @@ void HttpProxyGetStream::processData(const QByteArray &block)
                 return;
             }
 
-            if(!d->recvBuf.isEmpty()) {
+            if (!d->recvBuf.isEmpty()) {
                 QByteArray a = d->recvBuf;
                 d->recvBuf.clear();
                 emit dataReady(a);
@@ -1026,23 +950,23 @@ void HttpProxyGetStream::sock_error(int x)
     fprintf(stderr, "HttpProxyGetStream: socket error: %d\n", x);
 #endif
     resetConnection(true);
-    if(x == BSocket::ErrHostNotFound)
+    if (x == BSocket::ErrHostNotFound)
         error(ErrProxyConnect);
-    else if(x == BSocket::ErrConnectionRefused)
+    else if (x == BSocket::ErrConnectionRefused)
         error(ErrProxyConnect);
-    else if(x == BSocket::ErrRead)
+    else if (x == BSocket::ErrRead)
         error(ErrProxyNeg);
 }
 
 void HttpProxyGetStream::tls_readyRead()
 {
-    //printf("tls_readyRead\n");
+    // printf("tls_readyRead\n");
     processData(d->tls->read());
 }
 
 void HttpProxyGetStream::tls_readyReadOutgoing()
 {
-    //printf("tls_readyReadOutgoing\n");
+    // printf("tls_readyReadOutgoing\n");
     d->sock.write(d->tls->readOutgoing());
 }
 
