@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009,2010  Barracuda Networks, Inc.
+ * Copyright (C) 2009-2010  Barracuda Networks, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -11,54 +11,44 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "icelocaltransport.h"
 
+#include "objectsession.h"
+#include "stunallocate.h"
+#include "stunbinding.h"
+#include "stunmessage.h"
+#include "stuntransaction.h"
+#include "turnclient.h"
+
 #include <QHostAddress>
 #include <QUdpSocket>
 #include <QtCrypto>
-#include "objectsession.h"
-#include "stunmessage.h"
-#include "stuntransaction.h"
-#include "stunbinding.h"
-#include "stunallocate.h"
-#include "turnclient.h"
 
 // don't queue more incoming packets than this per transmit path
 #define MAX_PACKET_QUEUE 64
 
 namespace XMPP {
-
-enum
-{
-    Direct,
-    Relayed
-};
+enum { Direct, Relayed };
 
 //----------------------------------------------------------------------------
 // SafeUdpSocket
 //----------------------------------------------------------------------------
 // DOR-safe wrapper for QUdpSocket
-class SafeUdpSocket : public QObject
-{
+class SafeUdpSocket : public QObject {
     Q_OBJECT
 
 private:
     ObjectSession sess;
-    QUdpSocket *sock;
-    int writtenCount;
+    QUdpSocket *  sock;
+    int           writtenCount;
 
 public:
-    SafeUdpSocket(QUdpSocket *_sock, QObject *parent = 0) :
-        QObject(parent),
-        sess(this),
-        sock(_sock)
+    SafeUdpSocket(QUdpSocket *_sock, QObject *parent = nullptr) : QObject(parent), sess(this), sock(_sock)
     {
         sock->setParent(this);
         connect(sock, SIGNAL(readyRead()), SLOT(sock_readyRead()));
@@ -69,8 +59,7 @@ public:
 
     ~SafeUdpSocket()
     {
-        if(sock)
-        {
+        if (sock) {
             QUdpSocket *out = release();
             out->deleteLater();
         }
@@ -79,30 +68,21 @@ public:
     QUdpSocket *release()
     {
         sock->disconnect(this);
-        sock->setParent(0);
+        sock->setParent(nullptr);
         QUdpSocket *out = sock;
-        sock = 0;
+        sock            = nullptr;
         return out;
     }
 
-    QHostAddress localAddress() const
-    {
-        return sock->localAddress();
-    }
+    QHostAddress localAddress() const { return sock->localAddress(); }
 
-    quint16 localPort() const
-    {
-        return sock->localPort();
-    }
+    quint16 localPort() const { return sock->localPort(); }
 
-    bool hasPendingDatagrams() const
-    {
-        return sock->hasPendingDatagrams();
-    }
+    bool hasPendingDatagrams() const { return sock->hasPendingDatagrams(); }
 
-    QByteArray readDatagram(QHostAddress *address = 0, quint16 *port = 0)
+    QByteArray readDatagram(QHostAddress *address = nullptr, quint16 *port = nullptr)
     {
-        if(!sock->hasPendingDatagrams())
+        if (!sock->hasPendingDatagrams())
             return QByteArray();
 
         QByteArray buf;
@@ -121,10 +101,7 @@ signals:
     void datagramsWritten(int count);
 
 private slots:
-    void sock_readyRead()
-    {
-        emit readyRead();
-    }
+    void sock_readyRead() { emit readyRead(); }
 
     void sock_bytesWritten(qint64 bytes)
     {
@@ -136,7 +113,7 @@ private slots:
 
     void processWritten()
     {
-        int count = writtenCount;
+        int count    = writtenCount;
         writtenCount = 0;
 
         emit datagramsWritten(count);
@@ -146,122 +123,98 @@ private slots:
 //----------------------------------------------------------------------------
 // IceLocalTransport
 //----------------------------------------------------------------------------
-class IceLocalTransport::Private : public QObject
-{
+class IceLocalTransport::Private : public QObject {
     Q_OBJECT
 
 public:
-    class WriteItem
-    {
+    class WriteItem {
     public:
-        enum Type
-        {
-            Direct,
-            Pool,
-            Turn
-        };
+        enum Type { Direct, Pool, Turn };
 
-        Type type;
+        Type         type;
         QHostAddress addr;
-        int port;
+        int          port;
     };
 
-    class Written
-    {
+    class Written {
     public:
         QHostAddress addr;
-        int port;
-        int count;
+        int          port;
+        int          count;
     };
 
-    class Datagram
-    {
+    class Datagram {
     public:
         QHostAddress addr;
-        int port;
-        QByteArray buf;
+        int          port;
+        QByteArray   buf;
     };
 
-    IceLocalTransport *q;
-    ObjectSession sess;
-    QUdpSocket *extSock;
-    SafeUdpSocket *sock;
-    StunTransactionPool *pool;
-    StunBinding *stunBinding;
-    TurnClient *turn;
-    bool turnActivated;
-    QHostAddress addr;
-    int port;
-    QHostAddress refAddr;
-    int refPort;
-    QHostAddress relAddr;
-    int relPort;
-    QHostAddress stunBindAddr;
-    int stunBindPort;
-    QHostAddress stunRelayAddr;
-    int stunRelayPort;
-    QString stunUser;
-    QCA::SecureArray stunPass;
-    QString clientSoftware;
-    QList<Datagram> in;
-    QList<Datagram> inRelayed;
-    QList<WriteItem> pendingWrites;
-    int retryCount;
-    bool stopping;
-    int debugLevel;
+    IceLocalTransport *      q;
+    ObjectSession            sess;
+    QUdpSocket *             extSock;
+    SafeUdpSocket *          sock;
+    StunTransactionPool::Ptr pool;
+    StunBinding *            stunBinding;
+    TurnClient *             turn;
+    bool                     turnActivated;
+    QHostAddress             addr;
+    int                      port;
+    QHostAddress             refAddr;
+    int                      refPort;
+    QHostAddress             refAddrSource;
+    QHostAddress             relAddr;
+    int                      relPort;
+    QHostAddress             stunBindAddr;
+    int                      stunBindPort;
+    QHostAddress             stunRelayAddr;
+    int                      stunRelayPort;
+    QString                  stunUser;
+    QCA::SecureArray         stunPass;
+    QString                  clientSoftware;
+    QList<Datagram>          in;
+    QList<Datagram>          inRelayed;
+    QList<WriteItem>         pendingWrites;
+    int                      retryCount;
+    bool                     stopping;
+    int                      debugLevel;
 
     Private(IceLocalTransport *_q) :
-        QObject(_q),
-        q(_q),
-        sess(this),
-        extSock(0),
-        sock(0),
-        pool(0),
-        stunBinding(0),
-        turn(0),
-        turnActivated(false),
-        port(-1),
-        refPort(-1),
-        relPort(-1),
-        retryCount(0),
-        stopping(false),
+        QObject(_q), q(_q), sess(this), extSock(nullptr), sock(nullptr), pool(nullptr), stunBinding(nullptr),
+        turn(nullptr), turnActivated(false), port(-1), refPort(-1), relPort(-1), retryCount(0), stopping(false),
         debugLevel(IceTransport::DL_None)
     {
     }
 
-    ~Private()
-    {
-        reset();
-    }
+    ~Private() { reset(); }
 
     void reset()
     {
         sess.reset();
 
         delete stunBinding;
-        stunBinding = 0;
+        stunBinding = nullptr;
 
         delete turn;
-        turn = 0;
+        turn          = nullptr;
         turnActivated = false;
 
-        if(sock)
-        {
-            if(extSock)
-            {
-                sock->release();
-                extSock = 0;
+        if (sock) { // if started
+            if (extSock) {
+                sock->release(); // detaches the socket but doesn't destroy
+                extSock = nullptr;
             }
 
             delete sock;
-            sock = 0;
+            sock = nullptr;
         }
 
         addr = QHostAddress();
         port = -1;
 
-        refAddr = QHostAddress();
-        refPort = -1;
+        refAddr       = QHostAddress();
+        refPort       = -1;
+        refAddrSource = QHostAddress();
 
         relAddr = QHostAddress();
         relPort = -1;
@@ -271,7 +224,7 @@ public:
         pendingWrites.clear();
 
         retryCount = 0;
-        stopping = false;
+        stopping   = false;
     }
 
     void start()
@@ -284,12 +237,19 @@ public:
     void stop()
     {
         Q_ASSERT(sock);
-        Q_ASSERT(!stopping);
+        if (stopping) {
+            auto as = QString("%1:%2").arg(addr.toString(), QString::number(port));
+            emit q->debugLine(QString("local transport %1 is already stopping. just wait...").arg(as));
+            return;
+        } else {
+            auto as = QString("%1:%2").arg(addr.toString(), QString::number(port));
+            emit q->debugLine(QString("stopping local transport %1.").arg(as));
+        }
 
         stopping = true;
 
-        if(turn)
-            turn->close();
+        if (turn)
+            turn->close(); // will emit stopped() eventually calling postStop()
         else
             sess.defer(this, "postStop");
     }
@@ -298,49 +258,66 @@ public:
     {
         Q_ASSERT(!pool);
 
-        pool = new StunTransactionPool(StunTransaction::Udp, this);
+        pool = StunTransactionPool::Ptr::create(StunTransaction::Udp);
         pool->setDebugLevel((StunTransactionPool::DebugLevel)debugLevel);
-        connect(pool, SIGNAL(outgoingMessage(QByteArray,QHostAddress,int)), SLOT(pool_outgoingMessage(QByteArray,QHostAddress,int)));
-        connect(pool, SIGNAL(needAuthParams()), SLOT(pool_needAuthParams()));
-        connect(pool, SIGNAL(debugLine(QString)), SLOT(pool_debugLine(QString)));
+        connect(pool.data(), SIGNAL(outgoingMessage(QByteArray, QHostAddress, int)),
+                SLOT(pool_outgoingMessage(QByteArray, QHostAddress, int)));
+        connect(pool.data(), SIGNAL(needAuthParams()), SLOT(pool_needAuthParams()));
+        connect(pool.data(), SIGNAL(debugLine(QString)), SLOT(pool_debugLine(QString)));
 
         pool->setLongTermAuthEnabled(true);
-        if(!stunUser.isEmpty())
-        {
+        if (!stunUser.isEmpty()) {
             pool->setUsername(stunUser);
             pool->setPassword(stunPass);
         }
 
-        if(!stunBindAddr.isNull())
-        {
-            stunBinding = new StunBinding(pool);
-            connect(stunBinding, SIGNAL(success()), SLOT(binding_success()));
-            connect(stunBinding, SIGNAL(error(XMPP::StunBinding::Error)), SLOT(binding_error(XMPP::StunBinding::Error)));
-            stunBinding->start(stunBindAddr, stunBindPort);
-        }
+        do_stun();
+        do_turn();
+    }
 
-        if(!stunRelayAddr.isNull())
-        {
-            do_turn();
+    void do_stun()
+    {
+        if (stunBindAddr.isNull()) {
+            return;
         }
+        stunBinding = new StunBinding(pool.data());
+        connect(stunBinding, &StunBinding::success, this, [&]() {
+            refAddr       = stunBinding->reflexiveAddress();
+            refPort       = stunBinding->reflexivePort();
+            refAddrSource = stunBindAddr;
+
+            delete stunBinding;
+            stunBinding = nullptr;
+
+            emit q->addressesChanged();
+        });
+        connect(stunBinding, &StunBinding::error, this, [&](XMPP::StunBinding::Error) {
+            delete stunBinding;
+            stunBinding = nullptr;
+        });
+        stunBinding->start(stunBindAddr, stunBindPort);
     }
 
     void do_turn()
     {
+        if (stunRelayAddr.isNull()) {
+            return;
+        }
         turn = new TurnClient(this);
         turn->setDebugLevel((TurnClient::DebugLevel)debugLevel);
         connect(turn, SIGNAL(connected()), SLOT(turn_connected()));
         connect(turn, SIGNAL(tlsHandshaken()), SLOT(turn_tlsHandshaken()));
         connect(turn, SIGNAL(closed()), SLOT(turn_closed()));
         connect(turn, SIGNAL(activated()), SLOT(turn_activated()));
-        connect(turn, SIGNAL(packetsWritten(int,QHostAddress,int)), SLOT(turn_packetsWritten(int,QHostAddress,int)));
+        connect(turn, SIGNAL(packetsWritten(int, QHostAddress, int)),
+                SLOT(turn_packetsWritten(int, QHostAddress, int)));
         connect(turn, SIGNAL(error(XMPP::TurnClient::Error)), SLOT(turn_error(XMPP::TurnClient::Error)));
         connect(turn, SIGNAL(outgoingDatagram(QByteArray)), SLOT(turn_outgoingDatagram(QByteArray)));
         connect(turn, SIGNAL(debugLine(QString)), SLOT(turn_debugLine(QString)));
 
         turn->setClientSoftwareNameAndVersion(clientSoftware);
 
-        turn->connectToHost(pool, stunRelayAddr, stunRelayPort);
+        turn->connectToHost(pool.data(), stunRelayAddr, stunRelayPort);
     }
 
 private:
@@ -348,11 +325,10 @@ private:
     QUdpSocket *createSocket()
     {
         QUdpSocket *qsock = new QUdpSocket(this);
-        if(!qsock->bind(addr, 0))
-        {
+        if (!qsock->bind(addr, 0)) {
             delete qsock;
             emit q->error(IceLocalTransport::ErrorBind);
-            return 0;
+            return nullptr;
         }
 
         return qsock;
@@ -371,25 +347,23 @@ private:
     bool handleRetry()
     {
         // don't allow retrying if activated or stopping)
-        if(turnActivated || stopping)
+        if (turnActivated || stopping)
             return false;
 
         ++retryCount;
-        if(retryCount < 3)
-        {
-            if(debugLevel >= IceTransport::DL_Info)
+        if (retryCount < 3) {
+            if (debugLevel >= IceTransport::DL_Info)
                 emit q->debugLine("retrying...");
 
             delete sock;
-            sock = 0;
+            sock = nullptr;
 
             // to receive this error, it is a Relay, so change
             //   the mode
-            //stunType = IceLocalTransport::Relay;
+            // stunType = IceLocalTransport::Relay;
 
             QUdpSocket *qsock = createSocket();
-            if(!qsock)
-            {
+            if (!qsock) {
                 // signal emitted in this case.  bail.
                 //   (return true so caller takes no action)
                 return true;
@@ -399,8 +373,9 @@ private:
 
             prepareSocket();
 
-            refAddr = QHostAddress();
-            refPort = -1;
+            refAddr       = QHostAddress();
+            refPort       = -1;
+            refAddrSource = QHostAddress();
 
             relAddr = QHostAddress();
             relPort = -1;
@@ -419,25 +394,22 @@ private:
     // return true if data packet, false if pool or nothing
     bool processIncomingStun(const QByteArray &buf, const QHostAddress &fromAddr, int fromPort, Datagram *dg)
     {
-        QByteArray data;
+        QByteArray   data;
         QHostAddress dataAddr;
-        int dataPort;
+        int          dataPort;
 
         bool notStun;
-        if(!pool->writeIncomingMessage(buf, &notStun, fromAddr, fromPort) && turn)
-        {
+        if (!pool->writeIncomingMessage(buf, &notStun, fromAddr, fromPort) && turn) {
             data = turn->processIncomingDatagram(buf, notStun, &dataAddr, &dataPort);
-            if(!data.isNull())
-            {
+            if (!data.isNull()) {
                 dg->addr = dataAddr;
                 dg->port = dataPort;
-                dg->buf = data;
+                dg->buf  = data;
                 return true;
-            }
-            else
-            {
-                if(debugLevel >= IceTransport::DL_Packet)
-                    emit q->debugLine("Warning: server responded with what doesn't seem to be a STUN or data packet, skipping.");
+            } else {
+                if (debugLevel >= IceTransport::DL_Packet)
+                    emit q->debugLine(
+                        "Warning: server responded with what doesn't seem to be a STUN or data packet, skipping.");
             }
         }
 
@@ -447,18 +419,14 @@ private:
 private slots:
     void postStart()
     {
-        if(stopping)
+        if (stopping)
             return;
 
-        if(extSock)
-        {
+        if (extSock) {
             sock = new SafeUdpSocket(extSock, this);
-        }
-        else
-        {
+        } else {
             QUdpSocket *qsock = createSocket();
-            if(!qsock)
-            {
+            if (!qsock) {
                 // signal emitted in this case.  bail
                 return;
             }
@@ -481,48 +449,43 @@ private slots:
     {
         ObjectSessionWatcher watch(&sess);
 
-        QList<Datagram> dreads;
-        QList<Datagram> rreads;
+        QList<Datagram> dreads; // direct
+        QList<Datagram> rreads; // relayed
 
-        while(sock->hasPendingDatagrams())
-        {
+        while (sock->hasPendingDatagrams()) {
             QHostAddress from;
-            quint16 fromPort;
+            quint16      fromPort;
 
             Datagram dg;
 
             QByteArray buf = sock->readDatagram(&from, &fromPort);
-            if((from == stunBindAddr && fromPort == stunBindPort) || (from == stunRelayAddr && fromPort == stunRelayPort))
-            {
+            if ((from == stunBindAddr && fromPort == stunBindPort)
+                || (from == stunRelayAddr && fromPort == stunRelayPort)) {
                 bool haveData = processIncomingStun(buf, from, fromPort, &dg);
 
                 // processIncomingStun could cause signals to
                 //   emit.  for example, stopped()
-                if(!watch.isValid())
+                if (!watch.isValid())
                     return;
 
-                if(haveData)
+                if (haveData)
                     rreads += dg;
-            }
-            else
-            {
+            } else {
                 dg.addr = from;
                 dg.port = fromPort;
-                dg.buf = buf;
+                dg.buf  = buf;
                 dreads += dg;
             }
         }
 
-        if(dreads.count() > 0)
-        {
+        if (dreads.count() > 0) {
             in += dreads;
             emit q->readyRead(Direct);
-            if(!watch.isValid())
+            if (!watch.isValid())
                 return;
         }
 
-        if(rreads.count() > 0)
-        {
+        if (rreads.count() > 0) {
             inRelayed += rreads;
             emit q->readyRead(Relayed);
         }
@@ -531,60 +494,49 @@ private slots:
     void sock_datagramsWritten(int count)
     {
         QList<Written> dwrites;
-        int twrites = 0;
+        int            twrites = 0;
 
-        while(count > 0)
-        {
+        while (count > 0) {
             Q_ASSERT(!pendingWrites.isEmpty());
             WriteItem wi = pendingWrites.takeFirst();
             --count;
 
-            if(wi.type == WriteItem::Direct)
-            {
+            if (wi.type == WriteItem::Direct) {
                 int at = -1;
-                for(int n = 0; n < dwrites.count(); ++n)
-                {
-                    if(dwrites[n].addr == wi.addr && dwrites[n].port == wi.port)
-                    {
+                for (int n = 0; n < dwrites.count(); ++n) {
+                    if (dwrites[n].addr == wi.addr && dwrites[n].port == wi.port) {
                         at = n;
                         break;
                     }
                 }
 
-                if(at != -1)
-                {
+                if (at != -1) {
                     ++dwrites[at].count;
-                }
-                else
-                {
+                } else {
                     Written wr;
-                    wr.addr = wi.addr;
-                    wr.port = wi.port;
+                    wr.addr  = wi.addr;
+                    wr.port  = wi.port;
                     wr.count = 1;
                     dwrites += wr;
                 }
-            }
-            else if(wi.type == WriteItem::Turn)
+            } else if (wi.type == WriteItem::Turn)
                 ++twrites;
         }
 
-        if(dwrites.isEmpty() && twrites == 0)
+        if (dwrites.isEmpty() && twrites == 0)
             return;
 
         ObjectSessionWatcher watch(&sess);
 
-        if(!dwrites.isEmpty())
-        {
-            foreach(const Written &wr, dwrites)
-            {
+        if (!dwrites.isEmpty()) {
+            for (const Written &wr : dwrites) {
                 emit q->datagramsWritten(Direct, wr.count, wr.addr, wr.port);
-                if(!watch.isValid())
+                if (!watch.isValid())
                     return;
             }
         }
 
-        if(twrites > 0)
-        {
+        if (twrites > 0) {
             // note: this will invoke turn_packetsWritten()
             turn->outgoingDatagramsWritten(twrites);
         }
@@ -598,6 +550,12 @@ private slots:
         WriteItem wi;
         wi.type = WriteItem::Pool;
         pendingWrites += wi;
+        // emit q->debugLine(QString("Sending udp packet from: %1:%2 to: %3:%4")
+        //                      .arg(sock->localAddress().toString())
+        //                      .arg(sock->localPort())
+        //                      .arg(toAddress.toString())
+        //                      .arg(toPort));
+
         sock->writeDatagram(packet, toAddress, toPort);
     }
 
@@ -610,53 +568,27 @@ private slots:
         pool->continueAfterParams();
     }
 
-    void pool_debugLine(const QString &line)
-    {
-        emit q->debugLine(line);
-    }
-
-    void binding_success()
-    {
-        refAddr = stunBinding->reflexiveAddress();
-        refPort = stunBinding->reflexivePort();
-
-        delete stunBinding;
-        stunBinding = 0;
-
-        emit q->addressesChanged();
-    }
-
-    void binding_error(XMPP::StunBinding::Error e)
-    {
-        Q_UNUSED(e);
-
-        delete stunBinding;
-        stunBinding = 0;
-
-        // don't report any error
-        //if(stunType == IceLocalTransport::Basic || (stunType == IceLocalTransport::Auto && !turn))
-        //    emit q->addressesChanged();
-    }
+    void pool_debugLine(const QString &line) { emit q->debugLine(line); }
 
     void turn_connected()
     {
-        if(debugLevel >= IceTransport::DL_Info)
+        if (debugLevel >= IceTransport::DL_Info)
             emit q->debugLine("turn_connected");
     }
 
     void turn_tlsHandshaken()
     {
-        if(debugLevel >= IceTransport::DL_Info)
+        if (debugLevel >= IceTransport::DL_Info)
             emit q->debugLine("turn_tlsHandshaken");
     }
 
     void turn_closed()
     {
-        if(debugLevel >= IceTransport::DL_Info)
+        if (debugLevel >= IceTransport::DL_Info)
             emit q->debugLine("turn_closed");
 
         delete turn;
-        turn = 0;
+        turn          = nullptr;
         turnActivated = false;
 
         postStop();
@@ -668,18 +600,19 @@ private slots:
 
         // take reflexive address from TURN only if we are not using a
         //   separate STUN server
-        if(stunBindAddr.isNull() || stunBindAddr == stunRelayAddr)
-        {
-            refAddr = allocate->reflexiveAddress();
-            refPort = allocate->reflexivePort();
+        if (stunBindAddr.isNull() || stunBindAddr == stunRelayAddr) {
+            refAddr       = allocate->reflexiveAddress();
+            refPort       = allocate->reflexivePort();
+            refAddrSource = stunRelayAddr;
         }
 
-        if(debugLevel >= IceTransport::DL_Info)
-            emit q->debugLine(QString("Server says we are ") + allocate->reflexiveAddress().toString() + ';' + QString::number(allocate->reflexivePort()));
+        if (debugLevel >= IceTransport::DL_Info)
+            emit q->debugLine(QString("Server says we are ") + allocate->reflexiveAddress().toString() + ';'
+                              + QString::number(allocate->reflexivePort()));
 
         relAddr = allocate->relayedAddress();
         relPort = allocate->relayedPort();
-        if(debugLevel >= IceTransport::DL_Info)
+        if (debugLevel >= IceTransport::DL_Info)
             emit q->debugLine(QString("Server relays via ") + relAddr.toString() + ';' + QString::number(relPort));
 
         turnActivated = true;
@@ -694,27 +627,26 @@ private slots:
 
     void turn_error(XMPP::TurnClient::Error e)
     {
-        if(debugLevel >= IceTransport::DL_Info)
+        if (debugLevel >= IceTransport::DL_Info)
             emit q->debugLine(QString("turn_error: ") + turn->errorString());
 
         delete turn;
-        turn = 0;
+        turn              = nullptr;
         bool wasActivated = turnActivated;
-        turnActivated = false;
+        turnActivated     = false;
 
-        if(e == TurnClient::ErrorMismatch)
-        {
-            if(!extSock && handleRetry())
+        if (e == TurnClient::ErrorMismatch) {
+            if (!extSock && handleRetry())
                 return;
         }
 
         // this means our relay died on us.  in the future we might
         //   consider reporting this
-        if(wasActivated)
+        if (wasActivated)
             return;
 
         // don't report any error
-        //if(stunType == IceLocalTransport::Relay || (stunType == IceLocalTransport::Auto && !stunBinding))
+        // if(stunType == IceLocalTransport::Relay || (stunType == IceLocalTransport::Auto && !stunBinding))
         //    emit q->addressesChanged();
     }
 
@@ -726,27 +658,14 @@ private slots:
         sock->writeDatagram(buf, stunRelayAddr, stunRelayPort);
     }
 
-    void turn_debugLine(const QString &line)
-    {
-        emit q->debugLine(line);
-    }
+    void turn_debugLine(const QString &line) { emit q->debugLine(line); }
 };
 
-IceLocalTransport::IceLocalTransport(QObject *parent) :
-    IceTransport(parent)
-{
-    d = new Private(this);
-}
+IceLocalTransport::IceLocalTransport(QObject *parent) : IceTransport(parent) { d = new Private(this); }
 
-IceLocalTransport::~IceLocalTransport()
-{
-    delete d;
-}
+IceLocalTransport::~IceLocalTransport() { delete d; }
 
-void IceLocalTransport::setClientSoftwareNameAndVersion(const QString &str)
-{
-    d->clientSoftware = str;
-}
+void IceLocalTransport::setClientSoftwareNameAndVersion(const QString &str) { d->clientSoftware = str; }
 
 void IceLocalTransport::start(QUdpSocket *sock)
 {
@@ -760,10 +679,7 @@ void IceLocalTransport::start(const QHostAddress &addr)
     d->start();
 }
 
-void IceLocalTransport::stop()
-{
-    d->stop();
-}
+void IceLocalTransport::stop() { d->stop(); }
 
 void IceLocalTransport::setStunBindService(const QHostAddress &addr, int port)
 {
@@ -771,63 +687,48 @@ void IceLocalTransport::setStunBindService(const QHostAddress &addr, int port)
     d->stunBindPort = port;
 }
 
-void IceLocalTransport::setStunRelayService(const QHostAddress &addr, int port, const QString &user, const QCA::SecureArray &pass)
+void IceLocalTransport::setStunRelayService(const QHostAddress &addr, int port, const QString &user,
+                                            const QCA::SecureArray &pass)
 {
     d->stunRelayAddr = addr;
     d->stunRelayPort = port;
-    d->stunUser = user;
-    d->stunPass = pass;
+    d->stunUser      = user;
+    d->stunPass      = pass;
 }
 
-void IceLocalTransport::stunStart()
-{
-    d->stunStart();
-}
+QHostAddress IceLocalTransport::stunBindServiceAddress() const { return d->stunBindAddr; }
 
-QHostAddress IceLocalTransport::localAddress() const
-{
-    return d->addr;
-}
+QHostAddress IceLocalTransport::stunRelayServiceAddress() const { return d->stunRelayAddr; }
 
-int IceLocalTransport::localPort() const
-{
-    return d->port;
-}
+void IceLocalTransport::stunStart() { d->stunStart(); }
 
-QHostAddress IceLocalTransport::serverReflexiveAddress() const
-{
-    return d->refAddr;
-}
+QHostAddress IceLocalTransport::localAddress() const { return d->addr; }
 
-int IceLocalTransport::serverReflexivePort() const
-{
-    return d->refPort;
-}
+int IceLocalTransport::localPort() const { return d->port; }
 
-QHostAddress IceLocalTransport::relayedAddress() const
-{
-    return d->relAddr;
-}
+QHostAddress IceLocalTransport::serverReflexiveAddress() const { return d->refAddr; }
 
-int IceLocalTransport::relayedPort() const
-{
-    return d->relPort;
-}
+int IceLocalTransport::serverReflexivePort() const { return d->refPort; }
+
+QHostAddress IceLocalTransport::reflexiveAddressSource() const { return d->refAddrSource; }
+
+QHostAddress IceLocalTransport::relayedAddress() const { return d->relAddr; }
+
+int IceLocalTransport::relayedPort() const { return d->relPort; }
 
 void IceLocalTransport::addChannelPeer(const QHostAddress &addr, int port)
 {
-    if(d->turn)
+    if (d->turn)
         d->turn->addChannelPeer(addr, port);
 }
 
 bool IceLocalTransport::hasPendingDatagrams(int path) const
 {
-    if(path == Direct)
+    if (path == Direct)
         return !d->in.isEmpty();
-    else if(path == Relayed)
+    else if (path == Relayed)
         return !d->inRelayed.isEmpty();
-    else
-    {
+    else {
         Q_ASSERT(0);
         return false;
     }
@@ -835,54 +736,55 @@ bool IceLocalTransport::hasPendingDatagrams(int path) const
 
 QByteArray IceLocalTransport::readDatagram(int path, QHostAddress *addr, int *port)
 {
-    QList<Private::Datagram> *in = 0;
-    if(path == Direct)
+    QList<Private::Datagram> *in = nullptr;
+    if (path == Direct)
         in = &d->in;
-    else if(path == Relayed)
+    else if (path == Relayed)
         in = &d->inRelayed;
     else
         Q_ASSERT(0);
 
-    if(!in->isEmpty())
-    {
+    if (!in->isEmpty()) {
         Private::Datagram datagram = in->takeFirst();
-        *addr = datagram.addr;
-        *port = datagram.port;
+        *addr                      = datagram.addr;
+        *port                      = datagram.port;
         return datagram.buf;
-    }
-    else
+    } else
         return QByteArray();
 }
 
 void IceLocalTransport::writeDatagram(int path, const QByteArray &buf, const QHostAddress &addr, int port)
 {
-    if(path == Direct)
-    {
+    if (path == Direct) {
         Private::WriteItem wi;
         wi.type = Private::WriteItem::Direct;
         wi.addr = addr;
         wi.port = port;
         d->pendingWrites += wi;
         d->sock->writeDatagram(buf, addr, port);
-    }
-    else if(path == Relayed)
-    {
-        if(d->turn && d->turnActivated)
+    } else if (path == Relayed) {
+        if (d->turn && d->turnActivated)
             d->turn->write(buf, addr, port);
-    }
-    else
+    } else
         Q_ASSERT(0);
 }
 
 void IceLocalTransport::setDebugLevel(DebugLevel level)
 {
     d->debugLevel = level;
-    if(d->pool)
+    if (d->pool)
         d->pool->setDebugLevel((StunTransactionPool::DebugLevel)level);
-    if(d->turn)
+    if (d->turn)
         d->turn->setDebugLevel((TurnClient::DebugLevel)level);
 }
 
+void IceLocalTransport::changeThread(QThread *thread)
+{
+    if (d->pool)
+        d->pool->moveToThread(thread);
+    moveToThread(thread);
 }
 
+} // namespace XMPP
+
 #include "icelocaltransport.moc"
