@@ -11,31 +11,28 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef STUNTRANSACTION_H
 #define STUNTRANSACTION_H
 
-#include <QObject>
 #include <QByteArray>
+#include <QEnableSharedFromThis>
 #include <QHostAddress>
+#include <QObject>
 
 namespace QCA {
-    class SecureArray;
+class SecureArray;
 }
 
 namespace XMPP {
-
 class StunMessage;
-
-class StunTransactionPrivate;
 class StunTransactionPool;
 class StunTransactionPoolPrivate;
+class StunTransactionPrivate;
 
 // Notes:
 //
@@ -61,24 +58,18 @@ class StunTransactionPoolPrivate;
 // - if short term or long term auth is used, then the request is authenticated
 //   and the response is required to be authenticated.
 
-class StunTransaction : public QObject
-{
+class StunTransaction : public QObject {
     Q_OBJECT
 
 public:
-    enum Mode
-    {
+    enum Mode {
         Udp, // handle retransmissions
         Tcp  // send once
     };
 
-    enum Error
-    {
-        ErrorGeneric,
-        ErrorTimeout
-    };
+    enum Error { ErrorGeneric, ErrorTimeout };
 
-    StunTransaction(QObject *parent = 0);
+    StunTransaction(QObject *parent = nullptr);
     ~StunTransaction();
 
     // toAddress/toPort are optional, to associate this request to a
@@ -86,6 +77,7 @@ public:
     // note: not DOR-DS safe.  this function will cause the pool's
     //   outgoingMessage() signal to be emitted.
     void start(StunTransactionPool *pool, const QHostAddress &toAddress = QHostAddress(), int toPort = -1);
+    void cancel();
 
     // pass message with class unset.  use transaction id from the
     //   createMessage signal.
@@ -130,19 +122,15 @@ private:
 //   emitted as a direct result of calling certain member functions of this
 //   class as well as any other class that might use it (such as StunBinding).
 //   so, be careful with what you do in your retransmit slot.
-class StunTransactionPool : public QObject
-{
+class StunTransactionPool : public QObject, public QEnableSharedFromThis<StunTransactionPool> {
     Q_OBJECT
 
 public:
-    enum DebugLevel
-    {
-        DL_None,
-        DL_Info,
-        DL_Packet
-    };
+    using Ptr = QSharedPointer<StunTransactionPool>;
 
-    StunTransactionPool(StunTransaction::Mode mode, QObject *parent = 0);
+    enum DebugLevel { DL_None, DL_Info, DL_Packet };
+
+    StunTransactionPool(StunTransaction::Mode mode);
     ~StunTransactionPool();
 
     StunTransaction::Mode mode() const;
@@ -159,15 +147,16 @@ public:
     //   not be a STUN message.  *notStun will be set to true if the packet
     //   is surely not STUN, or set to false if it is unclear whether the
     //   packet is STUN or not.
-    bool writeIncomingMessage(const QByteArray &packet, bool *notStun = 0, const QHostAddress &addr = QHostAddress(), int port = -1);
+    bool writeIncomingMessage(const QByteArray &packet, bool *notStun = nullptr,
+                              const QHostAddress &addr = QHostAddress(), int port = -1);
 
     void setLongTermAuthEnabled(bool enabled);
 
     QString realm() const;
-    void setUsername(const QString &username);
-    void setPassword(const QCA::SecureArray &password);
-    void setRealm(const QString &realm);
-    void continueAfterParams();
+    void    setUsername(const QString &username);
+    void    setPassword(const QCA::SecureArray &password);
+    void    setRealm(const QString &realm);
+    void    continueAfterParams();
 
     // for use with stun indications
     QByteArray generateId() const;
@@ -201,7 +190,6 @@ private:
     friend class StunTransactionPoolPrivate;
     StunTransactionPoolPrivate *d;
 };
+} // namespace XMPP
 
-}
-
-#endif
+#endif // STUNTRANSACTION_H
