@@ -11,10 +11,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -23,22 +21,18 @@
 
 #include <QtCrypto>
 
-namespace XMPP {
+namespace XMPP { namespace StunUtil {
+    quint16 read16(const quint8 *in);
+    quint32 read32(const quint8 *in);
+    quint64 read64(const quint8 *in);
 
-namespace StunUtil {
+    void write16(quint8 *out, quint16 i);
+    void write32(quint8 *out, quint32 i);
+    void write64(quint8 *out, quint64 i);
 
-quint16 read16(const quint8 *in);
-quint32 read32(const quint8 *in);
-quint64 read64(const quint8 *in);
+    QCA::SecureArray saslPrep(const QCA::SecureArray &in);
 
-void write16(quint8 *out, quint16 i);
-void write32(quint8 *out, quint32 i);
-void write64(quint8 *out, quint64 i);
+} // namespace StunUtil
+} // namespace XMPP
 
-QCA::SecureArray saslPrep(const QCA::SecureArray &in);
-
-}
-
-}
-
-#endif
+#endif // STUNUTIL_H
