@@ -113,17 +113,16 @@ read /etc/hosts manually:
 
 #include "jdns_p.h"
 
+#ifdef JDNS_OS_UNIX
+# include <arpa/nameser.h>
+# include <dlfcn.h>
+# include <netinet/in.h>
+# include <resolv.h>
+#endif
 #ifdef JDNS_OS_WIN
 # include <windows.h>
 #endif
 
-#ifdef JDNS_OS_UNIX
-# include <netinet/in.h>
-# include <arpa/nameser.h>
-# include <resolv.h>
-# include <dlfcn.h>
-#endif
-
 #define string_indexOf jdns_string_indexOf
 #define string_split jdns_string_split
 
@@ -727,7 +726,7 @@ static int my_res_init()
 //   specify the platforms that have __res_state_ext
 //#ifdef __res_state_ext
 #if defined(JDNS_OS_MAC) || defined(JDNS_OS_FREEBSD) || \
-    defined(JDNS_OS_NETBSD) || defined (JDNS_OS_SOLARIS)
+    defined(JDNS_OS_NETBSD) || defined (JDNS_OS_SOLARIS) || defined (JDNS_OS_HAIKU)
 # define USE_EXTEXT
 #endif
 #if defined(JDNS_OS_OPENBSD)
