@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2008    Justin Karneges
+ * Copyright (C) 2006-2008  Justin Karneges
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the
@@ -100,10 +100,12 @@ static bool matchRecordExceptTtl(const QJDns::Record &a, const QJDns::Record &b)
 
 static void getHex(unsigned char in, char *hi, char *lo)
 {
-    QString str;
-    str.sprintf("%02x", in);
-    *hi = str[0].toLatin1();
-    *lo = str[1].toLatin1();
+    auto str = QString::asprintf("%02x", in);
+    if (!str.isEmpty())
+    {
+        *hi = str[0].toLatin1();
+        *lo = str[1].toLatin1();
+    }
 }
 
 static QByteArray getDec(int in)
@@ -120,7 +122,7 @@ static QByteArray makeReverseName(const QHostAddress &addr)
         Q_IPV6ADDR raw = addr.toIPv6Address();
         for(int n = 0; n < 32; ++n)
         {
-            char hi, lo;
+            char hi = '0', lo = '0';
             getHex(raw.c[31 - n], &hi, &lo);
             out += lo;
             out += '.';
@@ -156,7 +158,6 @@ static inline uint qHash(const Handle &key)
     return ((h1 << 16) | (h1 >> 16)) ^ h2;
 }
 
-
 //----------------------------------------------------------------------------
 // JDnsShutdown
 //----------------------------------------------------------------------------
@@ -176,7 +177,7 @@ JDnsShutdownWorker::JDnsShutdownWorker(const QList<QJDnsShared*> &_list) : QObje
 
 void JDnsShutdownWorker::jdns_shutdownFinished()
 {
-    QJDnsShared *i = (QJDnsShared *)sender();
+    QJDnsShared *i = static_cast<QJDnsShared *>(sender());
     list.removeAll(i);
     delete i;
     if(list.isEmpty())
@@ -1010,7 +1011,7 @@ void QJDnsSharedPrivate::publishCancel(QJDnsSharedRequest *obj)
 
 void QJDnsSharedPrivate::jdns_resultsReady(int id, const QJDns::Response &results)
 {
-    QJDns *jdns = (QJDns *)sender();
+    QJDns *jdns = static_cast<QJDns *>(sender());
     QJDnsSharedRequest *obj = findRequest(jdns, id);
     Q_ASSERT(obj);
 
@@ -1091,7 +1092,7 @@ void QJDnsSharedPrivate::jdns_resultsReady(int id, const QJDns::Response &result
 
 void QJDnsSharedPrivate::jdns_published(int id)
 {
-    QJDns *jdns = (QJDns *)sender();
+    QJDns *jdns = static_cast<QJDns *>(sender());
     QJDnsSharedRequest *obj = findRequest(jdns, id);
     Q_ASSERT(obj);
 
@@ -1125,7 +1126,7 @@ void QJDnsSharedPrivate::jdns_published(int id)
 
 void QJDnsSharedPrivate::jdns_error(int id, QJDns::Error e)
 {
-    QJDns *jdns = (QJDns *)sender();
+    QJDns *jdns = static_cast<QJDns *>(sender());
     QJDnsSharedRequest *obj = findRequest(jdns, id);
     Q_ASSERT(obj);
 
@@ -1186,7 +1187,7 @@ void QJDnsSharedPrivate::jdns_error(int id, QJDns::Error e)
 
 void QJDnsSharedPrivate::jdns_shutdownFinished()
 {
-    QJDns *jdns = (QJDns *)sender();
+    QJDns *jdns = static_cast<QJDns *>(sender());
 
     addDebug(instanceForQJDns.value(jdns)->index, "jdns_shutdownFinished, removing interface");
 
@@ -1202,7 +1203,7 @@ void QJDnsSharedPrivate::jdns_shutdownFinished()
 
 void QJDnsSharedPrivate::jdns_debugLinesReady()
 {
-    QJDns *jdns = (QJDns *)sender();
+    QJDns *jdns = static_cast<QJDns *>(sender());
 
     doDebug(jdns, instanceForQJDns.value(jdns)->index);
 }
