@@ -11,9 +11,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -22,15 +21,11 @@
 #include <cassert>
 
 namespace XMPP {
-
-RandomNumberGenerator::~RandomNumberGenerator()
-{
-}
+RandomNumberGenerator::~RandomNumberGenerator() { }
 
 double RandomNumberGenerator::generateNumberBetween(double a, double b) const
 {
     assert(b > a);
-    return a + (generateNumber()/getMaximumGeneratedNumber())*(b-a);
-}
-
+    return a + (generateNumber() / getMaximumGeneratedNumber()) * (b - a);
 }
+} // namespace XMPP
