@@ -11,9 +11,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -21,17 +20,16 @@
 #define RANDOMNUMBERGENERATOR_H
 
 namespace XMPP {
-    class RandomNumberGenerator
-    {
-        public:
-            virtual ~RandomNumberGenerator();
+class RandomNumberGenerator {
+public:
+    virtual ~RandomNumberGenerator();
 
-            double generateNumberBetween(double a, double b) const;
+    double generateNumberBetween(double a, double b) const;
 
-        protected:
-            virtual double generateNumber() const = 0;
-            virtual double getMaximumGeneratedNumber() const = 0;
-    };
-}
+protected:
+    virtual double generateNumber() const            = 0;
+    virtual double getMaximumGeneratedNumber() const = 0;
+};
+} // namespace XMPP
 
-#endif
+#endif // RANDOMNUMBERGENERATOR_H
