@@ -11,9 +11,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -22,20 +21,17 @@
 
 #include "xmpp/base/randomnumbergenerator.h"
 
+#include <cstdlib>
+
 namespace XMPP {
-    class RandRandomNumberGenerator : public RandomNumberGenerator
-    {
-        public:
-            RandRandomNumberGenerator() {}
+class RandRandomNumberGenerator : public RandomNumberGenerator {
+public:
+    RandRandomNumberGenerator() { }
 
-            virtual double generateNumber() const {
-                return rand();
-            }
+    virtual double generateNumber() const { return rand(); }
 
-            virtual double getMaximumGeneratedNumber() const {
-                return RAND_MAX;
-            }
-    };
-}
+    virtual double getMaximumGeneratedNumber() const { return RAND_MAX; }
+};
+} // namespace XMPP
 
-#endif
+#endif // RANDRANDOMNUMBERGENERATOR_H
