@@ -11,9 +11,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -22,12 +21,11 @@
 
 #include <QObject>
 
-class TimeZone
-{
+class TimeZone {
 public:
-    static int offsetFromUtc(); // in minutes
+    static int     offsetFromUtc(); // in minutes
     static QString abbreviation();
-    static int tzdToInt(const QString &tzd);
+    static int     tzdToInt(const QString &tzd);
 };
 
 #endif // IRIS_TIMEZONE_H
