@@ -11,34 +11,33 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
+#include "xmpp/base/randrandomnumbergenerator.h"
+#include "qttestutil/qttestutil.h"
+
 #include <QObject>
 #include <QtTest/QtTest>
 
-#include "qttestutil/qttestutil.h"
-#include "xmpp/base/randrandomnumbergenerator.h"
-
 using namespace XMPP;
 
-class RandRandomNumberGeneratorTest : public QObject
-{
-        Q_OBJECT
+class RandRandomNumberGeneratorTest : public QObject {
+    Q_OBJECT
 
-    private slots:
-        void testGenerateNumber() {
-            RandRandomNumberGenerator testling;
+private slots:
+    void testGenerateNumber()
+    {
+        RandRandomNumberGenerator testling;
 
-            double a = testling.generateNumberBetween(0.0,100.0);
-            double b = testling.generateNumberBetween(0.0,100.0);
+        double a = testling.generateNumberBetween(0.0, 100.0);
+        double b = testling.generateNumberBetween(0.0, 100.0);
 
-            QVERIFY(a != b);
-        }
- };
+        QVERIFY(a != b);
+    }
+};
 
 QTTESTUTIL_REGISTER_TEST(RandRandomNumberGeneratorTest);
 #include "randrandomnumbergeneratortest.moc"
