@@ -11,34 +11,33 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 // FIXME: Complete this
 
-#include <QtTest/QtTest>
-#include <QObject>
-
-#include "qttestutil/qttestutil.h"
 #include "xmpp/jid/jid.h"
+#include "qttestutil/qttestutil.h"
+
+#include <QObject>
+#include <QtTest/QtTest>
 
 using namespace XMPP;
 
-class JidTest : public QObject
-{
-        Q_OBJECT
+class JidTest : public QObject {
+    Q_OBJECT
 
-    private slots:
-        void testConstructorWithString() {
-            Jid testling("foo@bar/baz");
+private slots:
+    void testConstructorWithString()
+    {
+        Jid testling("foo@bar/baz");
 
-            QCOMPARE(testling.node(), QString("foo"));
-            QCOMPARE(testling.domain(), QString("bar"));
-            QCOMPARE(testling.resource(), QString("baz"));
-        }
+        QCOMPARE(testling.node(), QString("foo"));
+        QCOMPARE(testling.domain(), QString("bar"));
+        QCOMPARE(testling.resource(), QString("baz"));
+    }
 };
 
 QTTESTUTIL_REGISTER_TEST(JidTest);
