@@ -11,9 +11,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -36,7 +35,6 @@
  *
  *        QTTESTUTIL_REGISTER_TEST(MyTest)
  */
-#define QTTESTUTIL_REGISTER_TEST(TestClass) \
-    static QtTestUtil::TestRegistration<TestClass> TestClass##Registration
+#define QTTESTUTIL_REGISTER_TEST(TestClass) static QtTestUtil::TestRegistration<TestClass> TestClass##Registration
 
-#endif
+#endif // QTTESTUTIL_H
