@@ -11,9 +11,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -22,25 +21,20 @@
 #include <QtTest/QtTest>
 
 namespace QtTestUtil {
-
-TestRegistry* TestRegistry::getInstance()
+TestRegistry *TestRegistry::getInstance()
 {
     static TestRegistry registry;
     return &registry;
 }
 
-void TestRegistry::registerTest(QObject* test)
-{
-    tests_ += test;
-}
+void TestRegistry::registerTest(QObject *test) { tests_ += test; }
 
-int TestRegistry::runTests(int argc, char* argv[])
+int TestRegistry::runTests(int argc, char *argv[])
 {
     int result = 0;
-    foreach(QObject* test, tests_) {
+    foreach (QObject *test, tests_) {
         result |= QTest::qExec(test, argc, argv);
     }
     return result;
 }
-
-}
+} // namespace QtTestUtil
