@@ -11,32 +11,29 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
+#include "qttestutil/qttestutil.h"
+
 #include <QObject>
 #include <QtTest/QtTest>
 
-#include "qttestutil/qttestutil.h"
+class MyClassTest : public QObject {
+    Q_OBJECT
 
-class MyClassTest : public QObject
-{
-     Q_OBJECT
+private slots:
+    void initTestCase() { }
 
-    private slots:
-        void initTestCase() {
-        }
+    void cleanupTestCase() { }
 
-        void cleanupTestCase() {
-        }
-
-        void testMyMethod() {
-            //QCOMPARE(foo, bar);
-            //QVERIFY(baz);
-        }
+    void testMyMethod()
+    {
+        // QCOMPARE(foo, bar);
+        // QVERIFY(baz);
+    }
 };
 
 QTTESTUTIL_REGISTER_TEST(MyClassTest);
