@@ -11,9 +11,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -24,18 +23,15 @@
 #include <QString>
 
 namespace XMPP {
-    class PLAINMessage
-    {
-        public:
-            PLAINMessage(const QString& authzid, const QString& authcid, const QByteArray& password);
+class PLAINMessage {
+public:
+    PLAINMessage(const QString &authzid, const QString &authcid, const QByteArray &password);
 
-            const QByteArray& getValue() {
-                return value_;
-            }
+    const QByteArray &getValue() { return value_; }
 
-        private:
-            QByteArray value_;
-    };
-}
+private:
+    QByteArray value_;
+};
+} // namespace XMPP
 
-#endif
+#endif // PLAINMESSAGE_H
