@@ -11,38 +11,33 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef SCRAMSHA1MESSAGE_H
 #define SCRAMSHA1MESSAGE_H
 
+#include "xmpp/base/randomnumbergenerator.h"
+
 #include <QByteArray>
 #include <QString>
 
-#include "xmpp/base/randomnumbergenerator.h"
-
 namespace XMPP {
-    class SCRAMSHA1Message
-    {
-        public:
-            SCRAMSHA1Message(const QString& authzid, const QString& authcid, const QByteArray& cnonce, const RandomNumberGenerator& rand);
+class SCRAMSHA1Message {
+public:
+    SCRAMSHA1Message(const QString &authzid, const QString &authcid, const QByteArray &cnonce,
+                     const RandomNumberGenerator &rand);
 
-            const QByteArray& getValue() {
-                return value_;
-            }
+    const QByteArray &getValue() { return value_; }
 
-            bool isValid() const {
-                return isValid_;
-            }
+    bool isValid() const { return isValid_; }
 
-        private:
-            QByteArray value_;
-            bool isValid_;
-    };
-}
+private:
+    QByteArray value_;
+    bool       isValid_;
+};
+} // namespace XMPP
 
-#endif
+#endif // SCRAMSHA1MESSAGE_H
