@@ -11,43 +11,45 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "xmpp/sasl/scramsha1response.h"
 
+#include "xmpp/base/randomnumbergenerator.h"
+#include "xmpp/jid/jid.h"
+
 #include <QByteArray>
+#include <QRegExp>
 #include <QString>
 #include <QTextStream>
 #include <QtCrypto>
 #include <QtDebug>
-#include <QRegExp>
-
-#include "xmpp/base/randomnumbergenerator.h"
-#include "xmpp/jid/jid.h"
 
 namespace XMPP {
-    QCA::SecureArray HMAC_SHA_1(const QCA::SecureArray &key, const QCA::SecureArray &str) {
-        QCA::SecureArray result = QCA::MessageAuthenticationCode("hmac(sha1)", key).process(str);
-        return result;
-    }
+QCA::SecureArray HMAC_SHA_1(const QCA::SecureArray &key, const QCA::SecureArray &str)
+{
+    QCA::SecureArray result = QCA::MessageAuthenticationCode("hmac(sha1)", key).process(str);
+    return result;
+}
 
-    SCRAMSHA1Response::SCRAMSHA1Response(const QByteArray& server_first_message, const QByteArray& password_in, const QByteArray& client_first_message, const QString &salted_password_base64, const RandomNumberGenerator& rand)
+SCRAMSHA1Response::SCRAMSHA1Response(const QByteArray &server_first_message, const QByteArray &password_in,
+                                     const QByteArray &client_first_message, const QString &salted_password_base64,
+                                     const RandomNumberGenerator &rand)
 {
     Q_UNUSED(rand);
     QString pass_in = QString::fromUtf8(password_in);
     QString pass_out;
 
     QRegExp pattern("r=(.*),s=(.+),i=(\\d+)");
-    int pos = pattern.indexIn(QString(server_first_message));
-    isValid_ = true;
+    int     pos = pattern.indexIn(QString(server_first_message));
+    isValid_    = true;
     if (pos > -1) {
         QString clientservernonce = pattern.cap(1);
-        QString salt = pattern.cap(2);
-        QString icount = pattern.cap(3);
+        QString salt              = pattern.cap(2);
+        QString icount            = pattern.cap(3);
 
         unsigned int dkLen;
 
@@ -61,7 +63,8 @@ namespace XMPP {
 
         // SaltedPassword  := Hi(Normalize(password), salt, i)
         if (salted_password_base64.size() > 0)
-            salted_password_ = QCA::SymmetricKey(QCA::SecureArray(QCA::Base64().stringToArray(salted_password_base64.toUtf8())));
+            salted_password_
+                = QCA::SymmetricKey(QCA::SecureArray(QCA::Base64().stringToArray(salted_password_base64.toUtf8())));
         if (salted_password_.size() == 0) {
             if (!StringPrepCache::saslprep(pass_in, 1023, pass_out)) {
                 isValid_ = false;
@@ -69,7 +72,9 @@ namespace XMPP {
             }
 
             password = pass_out.toUtf8();
-            salted_password_ = hi.makeKey(QCA::SecureArray(password), QCA::InitializationVector(QCA::Base64().stringToArray(salt)), dkLen, icount.toULong());
+            salted_password_
+                = hi.makeKey(QCA::SecureArray(password), QCA::InitializationVector(QCA::Base64().stringToArray(salt)),
+                             dkLen, icount.toULong());
         }
 
         // ClientKey       := HMAC(SaltedPassword, "Client Key")
@@ -87,12 +92,13 @@ namespace XMPP {
             gs2_header = pattern.cap(1);
         }
 
-        QString client_final_message;
+        QString     client_final_message;
         QTextStream final_message_stream(&client_final_message);
         final_message_stream << "c=" << QCA::Base64().arrayToString((gs2_header.toUtf8()));
         final_message_stream << ",r=" << clientservernonce;
 
-        // AuthMessage     := client-first-message-bare + "," + server-first-message + "," + client-final-message-without-proof
+        // AuthMessage     := client-first-message-bare + "," + server-first-message + "," +
+        // client-final-message-without-proof
         QRegExp extract_cfmb_pattern("(n=.+)");
         if (extract_cfmb_pattern.indexIn(QString(client_first_message)) < 0) {
             isValid_ = false;
@@ -110,7 +116,7 @@ namespace XMPP {
 
         // ClientProof     := ClientKey XOR ClientSignature
         QCA::SecureArray client_proof(client_key.size());
-        for(int i = 0; i < client_proof.size(); ++i) {
+        for (int i = 0; i < client_proof.size(); ++i) {
             client_proof[i] = client_key[i] ^ client_signature[i];
         }
 
@@ -128,8 +134,5 @@ namespace XMPP {
     }
 }
 
-const QString SCRAMSHA1Response::getSaltedPassword() {
-    return QCA::Base64().arrayToString(salted_password_);
-}
-
-}
+const QString SCRAMSHA1Response::getSaltedPassword() { return QCA::Base64().arrayToString(salted_password_); }
+} // namespace XMPP
