@@ -11,9 +11,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -25,18 +24,15 @@
 #include <QtCrypto>
 
 namespace XMPP {
-    class SCRAMSHA1Signature
-    {
-        public:
-            SCRAMSHA1Signature(const QByteArray &server_final_message, const QCA::SecureArray &server_signature_should);
+class SCRAMSHA1Signature {
+public:
+    SCRAMSHA1Signature(const QByteArray &server_final_message, const QCA::SecureArray &server_signature_should);
 
-            bool isValid() const {
-                return isValid_;
-            }
+    bool isValid() const { return isValid_; }
 
-        private:
-            bool isValid_;
-    };
-}
+private:
+    bool isValid_;
+};
+} // namespace XMPP
 
-#endif
+#endif // SCRAMSHA1SIGNATURE_H
