@@ -12,9 +12,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -22,12 +21,11 @@
 #define SIMPLESASL_H
 
 namespace QCA {
-    class Provider;
+class Provider;
 }
 
-namespace XMPP
-{
-    QCA::Provider* createProviderSimpleSASL();
+namespace XMPP {
+QCA::Provider *createProviderSimpleSASL();
 }
 
-#endif
+#endif // SIMPLESASL_H
