@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001, 2002  Justin Karneges
+ * Copyright (C) 2001-2002  Justin Karneges
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -11,96 +11,75 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
+#include "xmpp_discoinfotask.h"
+
+#include "xmpp/jid/jid.h"
+#include "xmpp_caps.h"
+#include "xmpp_client.h"
+#include "xmpp_discoitem.h"
+#include "xmpp_task.h"
+#include "xmpp_xmlcommon.h"
+
 #include <QDomElement>
 #include <QString>
 #include <QTimer>
 
-#include "xmpp_task.h"
-#include "xmpp/jid/jid.h"
-#include "xmpp_discoitem.h"
-#include "xmpp_discoinfotask.h"
-#include "xmpp_xmlcommon.h"
-#include "xmpp_client.h"
-#include "xmpp_caps.h"
-
 using namespace XMPP;
 
-class DiscoInfoTask::Private
-{
+class DiscoInfoTask::Private {
 public:
-    bool allowCache = true;
-    Jid jid;
-    QString node;
+    bool                allowCache = true;
+    Jid                 jid;
+    QString             node;
     DiscoItem::Identity ident;
-    DiscoItem item;
+    DiscoItem           item;
 };
 
-DiscoInfoTask::DiscoInfoTask(Task *parent)
-: Task(parent)
-{
-    d = new Private;
-}
+DiscoInfoTask::DiscoInfoTask(Task *parent) : Task(parent) { d = new Private; }
 
-DiscoInfoTask::~DiscoInfoTask()
-{
-    delete d;
-}
+DiscoInfoTask::~DiscoInfoTask() { delete d; }
 
-void DiscoInfoTask::setAllowCache(bool allow)
-{
-    d->allowCache = allow;
-}
+void DiscoInfoTask::setAllowCache(bool allow) { d->allowCache = allow; }
 
 void DiscoInfoTask::get(const DiscoItem &item)
 {
     DiscoItem::Identity id;
-    if ( item.identities().count() == 1 )
+    if (item.identities().count() == 1)
         id = item.identities().first();
     get(item.jid(), item.node(), id);
 }
 
-void DiscoInfoTask::get (const Jid &j, const QString &node, DiscoItem::Identity ident)
+void DiscoInfoTask::get(const Jid &j, const QString &node, DiscoItem::Identity ident)
 {
     d->item = DiscoItem(); // clear item
 
-    d->jid = j;
-    d->node = node;
+    d->jid   = j;
+    d->node  = node;
     d->ident = ident;
 }
 
-
 /**
  * Original requested jid.
  * Is here because sometimes the responder does not include this information
  * in the reply.
  */
-const Jid& DiscoInfoTask::jid() const
-{
-    return d->jid;
-}
+const Jid &DiscoInfoTask::jid() const { return d->jid; }
 
 /**
  * Original requested node.
  * Is here because sometimes the responder does not include this information
  * in the reply.
  */
-const QString& DiscoInfoTask::node() const
-{
-    return d->node;
-}
+const QString &DiscoInfoTask::node() const { return d->node; }
 
-const DiscoItem &DiscoInfoTask::item() const
-{
-    return d->item;
-}
+const DiscoItem &DiscoInfoTask::item() const { return d->item; }
 
-void DiscoInfoTask::onGo ()
+void DiscoInfoTask::onGo()
 {
     if (d->allowCache && client()->capsManager()->isEnabled()) {
         d->item = client()->capsManager()->disco(d->jid);
@@ -110,10 +89,9 @@ void DiscoInfoTask::onGo ()
         }
     }
 
-    QDomElement iq = createIQ(doc(), "get", d->jid.full(), id());
-    QDomElement query = doc()->createElement("query");
-    query.setAttribute("xmlns", "http://jabber.org/protocol/disco#info");
-    if ( !d->node.isEmpty() )
+    QDomElement iq    = createIQ(doc(), "get", d->jid.full(), id());
+    QDomElement query = doc()->createElementNS("http://jabber.org/protocol/disco#info", "query");
+    if (!d->node.isEmpty())
         query.setAttribute("node", d->node);
 
 #if 0 // seems like disco#info get request was misinterpreted. xep-0030 says it has to be an EMPTY query.
@@ -135,29 +113,26 @@ void DiscoInfoTask::onGo ()
 
 void DiscoInfoTask::cachedReady()
 {
-    d->item.setJid( d->jid );
+    d->item.setJid(d->jid);
     setSuccess();
 }
 
 bool DiscoInfoTask::take(const QDomElement &x)
 {
-    if(!iqVerify(x, d->jid, id()))
+    if (!iqVerify(x, d->jid, id()))
         return false;
 
-    if(x.attribute("type") == "result") {
+    if (x.attribute("type") == "result") {
         d->item = DiscoItem::fromDiscoInfoResult(queryTag(x));
-        d->item.setJid( d->jid );
+        d->item.setJid(d->jid);
         if (d->allowCache && client()->capsManager()->isEnabled()) {
             client()->capsManager()->updateDisco(d->jid, d->item);
         }
 
         setSuccess();
-    }
-    else {
+    } else {
         setError(x);
     }
 
     return true;
 }
-
-
