@@ -12,9 +12,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -23,14 +22,12 @@
 
 class QDomElement;
 
-namespace XMPP
-{
-    class EncryptionHandler
-    {
-    public:
-        virtual bool decryptMessageElement(QDomElement &) = 0;
-        virtual bool encryptMessageElement(QDomElement &) = 0;
-    };
-}
+namespace XMPP {
+class EncryptionHandler {
+public:
+    virtual bool decryptMessageElement(QDomElement &) = 0;
+    virtual bool encryptMessageElement(QDomElement &) = 0;
+};
+} // namespace XMPP
 
-#endif //PSI_XMPP_ENCRYPTIONHANDLER_H
+#endif // PSI_XMPP_ENCRYPTIONHANDLER_H
