@@ -11,32 +11,29 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef XMPP_PUBSUBITEM_H
 #define XMPP_PUBSUBITEM_H
 
-#include <QString>
 #include <QDomElement>
+#include <QString>
 
-namespace XMPP
-{
-    class PubSubItem
-    {
-    public:
-        PubSubItem();
-        PubSubItem(const QString& id, const QDomElement& payload);
-        const QString& id() const;
-        const QDomElement& payload() const;
+namespace XMPP {
+class PubSubItem {
+public:
+    PubSubItem();
+    PubSubItem(const QString &id, const QDomElement &payload);
+    const QString &    id() const;
+    const QDomElement &payload() const;
 
-    private:
-        QString id_;
-        QDomElement payload_;
-    };
-}
+private:
+    QString     id_;
+    QDomElement payload_;
+};
+} // namespace XMPP
 
-#endif
+#endif // XMPP_PUBSUBITEM_H
