@@ -11,31 +11,27 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef XMPP_PUBSUBRETRACTION_H
 #define XMPP_PUBSUBRETRACTION_H
 
-#include <QString>
 #include <QDomElement>
+#include <QString>
 
-namespace XMPP
-{
+namespace XMPP {
+class PubSubRetraction {
+public:
+    PubSubRetraction();
+    PubSubRetraction(const QString &id);
+    const QString &id() const;
 
-    class PubSubRetraction
-    {
-    public:
-        PubSubRetraction();
-        PubSubRetraction(const QString& id);
-        const QString& id() const;
+private:
+    QString id_;
+};
+} // namespace XMPP
 
-    private:
-        QString id_;
-    };
-}
-
-#endif
+#endif // XMPP_PUBSUBRETRACTION_H
