@@ -12,10 +12,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -23,11 +21,7 @@
 #define XMPP_RECEIPTS_H
 
 namespace XMPP {
-    typedef enum {
-        ReceiptNone,
-        ReceiptRequest,
-        ReceiptReceived
-    } MessageReceipt;
-}
+typedef enum { ReceiptNone, ReceiptRequest, ReceiptReceived } MessageReceipt;
+} // namespace XMPP
 
-#endif
+#endif // XMPP_RECEIPTS_H
