@@ -11,37 +11,34 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef XMPP_RESOURCE_H
 #define XMPP_RESOURCE_H
 
-#include <QString>
-
 #include "xmpp_status.h"
 
-namespace XMPP
-{
-    class Resource
-    {
-    public:
-        Resource(const QString &name="", const Status &s=Status());
+#include <QString>
 
-        const QString & name() const;
-        int priority() const;
-        const Status & status() const;
+namespace XMPP {
+class Resource {
+public:
+    Resource(const QString &name = "", const Status &s = Status());
 
-        void setName(const QString &);
-        void setStatus(const Status &);
+    const QString &name() const;
+    int            priority() const;
+    const Status & status() const;
 
-    private:
-        QString v_name;
-        Status v_status;
-    };
-}
+    void setName(const QString &);
+    void setStatus(const Status &);
 
-#endif
+private:
+    QString v_name;
+    Status  v_status;
+};
+} // namespace XMPP
+
+#endif // XMPP_RESOURCE_H
