@@ -11,35 +11,32 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef XMPP_RESOURCELIST_H
 #define XMPP_RESOURCELIST_H
 
-#include <QList>
-
 #include "xmpp_resource.h"
 
+#include <QList>
+
 class QString;
 
-namespace XMPP
-{
-    class ResourceList : public QList<Resource>
-    {
-    public:
-        ResourceList();
-        ~ResourceList();
+namespace XMPP {
+class ResourceList : public QList<Resource> {
+public:
+    ResourceList();
+    ~ResourceList();
 
-        ResourceList::Iterator find(const QString &);
-        ResourceList::Iterator priority();
+    ResourceList::Iterator find(const QString &);
+    ResourceList::Iterator priority();
 
-        ResourceList::ConstIterator find(const QString &) const;
-        ResourceList::ConstIterator priority() const;
-    };
-}
+    ResourceList::ConstIterator find(const QString &) const;
+    ResourceList::ConstIterator priority() const;
+};
+} // namespace XMPP
 
-#endif
+#endif // XMPP_RESOURCELIST_H
