@@ -11,44 +11,42 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef XMPP_ROSTER_H
 #define XMPP_ROSTER_H
 
-#include <QList>
-
 #include "xmpp_rosteritem.h"
 
+#include <QList>
+
 class QDomDocument;
 class QDomElement;
 
-namespace XMPP
-{
-    class Jid;
-    class Roster : public QList<RosterItem>
-    {
-    public:
-        Roster();
-        ~Roster();
+namespace XMPP {
+class Jid;
 
-        Roster(const Roster &other);
-        Roster &operator=(const Roster &other);
+class Roster : public QList<RosterItem> {
+public:
+    Roster();
+    Roster(const Roster &other);
+    ~Roster();
 
-        Roster::Iterator find(const Jid &);
-        Roster::ConstIterator find(const Jid &) const;
+    Roster &operator=(const Roster &other);
 
-        void setGroupsDelimiter(const QString &groupsDelimiter);
-        QString groupsDelimiter() const;
+    Roster::Iterator      find(const Jid &);
+    Roster::ConstIterator find(const Jid &) const;
 
-    private:
-        class Private;
-        Private *d;
-    };
-}
+    void    setGroupsDelimiter(const QString &groupsDelimiter);
+    QString groupsDelimiter() const;
 
-#endif
+private:
+    class Private;
+    Private *d = nullptr;
+};
+} // namespace XMPP
+
+#endif // XMPP_ROSTER_H
