@@ -11,50 +11,45 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include <QCoreApplication>
+#include <QNetworkAddressEntry>
+#include <QNetworkInterface>
 #include <QTimer>
 #include <QUdpSocket>
-#include <QNetworkInterface>
-#include <QNetworkAddressEntry>
 #include <QtCrypto>
-#include <iris/netnames.h>
+#include <iris/ice176.h>
 #include <iris/netinterface.h>
+#include <iris/netnames.h>
 #include <iris/processquit.h>
 #include <iris/udpportreserver.h>
-#include <iris/ice176.h>
 #include <stdio.h>
 
 // scope values: 0 = local, 1 = link-local, 2 = private, 3 = public
 static int getAddressScope(const QHostAddress &a)
 {
-    if(a.protocol() == QAbstractSocket::IPv6Protocol)
-    {
-        if(a == QHostAddress(QHostAddress::LocalHostIPv6))
+    if (a.protocol() == QAbstractSocket::IPv6Protocol) {
+        if (a == QHostAddress(QHostAddress::LocalHostIPv6))
             return 0;
-        else if(XMPP::Ice176::isIPv6LinkLocalAddress(a))
+        else if (XMPP::Ice176::isIPv6LinkLocalAddress(a))
             return 1;
-    }
-    else if(a.protocol() == QAbstractSocket::IPv4Protocol)
-    {
+    } else if (a.protocol() == QAbstractSocket::IPv4Protocol) {
         quint32 v4 = a.toIPv4Address();
-        quint8 a0 = v4 >> 24;
-        quint8 a1 = (v4 >> 16) & 0xff;
-        if(a0 == 127)
+        quint8  a0 = v4 >> 24;
+        quint8  a1 = (v4 >> 16) & 0xff;
+        if (a0 == 127)
             return 0;
-        else if(a0 == 169 && a1 == 254)
+        else if (a0 == 169 && a1 == 254)
             return 1;
-        else if(a0 == 10)
+        else if (a0 == 10)
             return 2;
-        else if(a0 == 172 && a1 >= 16 && a1 <= 31)
+        else if (a0 == 172 && a1 >= 16 && a1 <= 31)
             return 2;
-        else if(a0 == 192 && a1 == 168)
+        else if (a0 == 192 && a1 == 168)
             return 2;
     }
 
@@ -67,15 +62,15 @@ static int comparePriority(const QHostAddress &a, const QHostAddress &b)
     // prefer closer scope
     int a_scope = getAddressScope(a);
     int b_scope = getAddressScope(b);
-    if(a_scope < b_scope)
+    if (a_scope < b_scope)
         return -1;
-    else if(a_scope > b_scope)
+    else if (a_scope > b_scope)
         return 1;
 
     // prefer ipv6
-    if(a.protocol() == QAbstractSocket::IPv6Protocol && b.protocol() != QAbstractSocket::IPv6Protocol)
+    if (a.protocol() == QAbstractSocket::IPv6Protocol && b.protocol() != QAbstractSocket::IPv6Protocol)
         return -1;
-    else if(b.protocol() == QAbstractSocket::IPv6Protocol && a.protocol() != QAbstractSocket::IPv6Protocol)
+    else if (b.protocol() == QAbstractSocket::IPv6Protocol && a.protocol() != QAbstractSocket::IPv6Protocol)
         return 1;
 
     return 0;
@@ -85,12 +80,10 @@ static QList<QHostAddress> sortAddrs(const QList<QHostAddress> &in)
 {
     QList<QHostAddress> out;
 
-    foreach(const QHostAddress &a, in)
-    {
+    for (const QHostAddress &a : in) {
         int at;
-        for(at = 0; at < out.count(); ++at)
-        {
-            if(comparePriority(a, out[at]) < 0)
+        for (at = 0; at < out.count(); ++at) {
+            if (comparePriority(a, out[at]) < 0)
                 break;
         }
 
@@ -104,14 +97,11 @@ static QList<QHostAddress> sortAddrs(const QList<QHostAddress> &in)
 static QString urlishEncode(const QString &in)
 {
     QString out;
-    for(int n = 0; n < in.length(); ++n)
-    {
-        if(in[n] == '%' || in[n] == ',' || in[n] == ';' || in[n] == ' ' || in[n] == '\n')
-        {
+    for (int n = 0; n < in.length(); ++n) {
+        if (in[n] == '%' || in[n] == ',' || in[n] == ';' || in[n] == ' ' || in[n] == '\n') {
             unsigned char c = (unsigned char)in[n].toLatin1();
-            out += QString().sprintf("%%%02x", c);
-        }
-        else
+            out += QString::asprintf("%%%02x", c);
+        } else
             out += in[n];
     }
     return out;
@@ -120,23 +110,19 @@ static QString urlishEncode(const QString &in)
 static QString urlishDecode(const QString &in, bool *ok = 0)
 {
     QString out;
-    for(int n = 0; n < in.length(); ++n)
-    {
-        if(in[n] == '%')
-        {
-            if(n + 2 >= in.length())
-            {
-                if(ok)
+    for (int n = 0; n < in.length(); ++n) {
+        if (in[n] == '%') {
+            if (n + 2 >= in.length()) {
+                if (ok)
                     *ok = false;
                 return QString();
             }
 
             QString hex = in.mid(n + 1, 2);
-            bool b;
-            int x = hex.toInt(&b, 16);
-            if(!b)
-            {
-                if(ok)
+            bool    b;
+            int     x = hex.toInt(&b, 16);
+            if (!b) {
+                if (ok)
                     *ok = false;
                 return QString();
             }
@@ -144,12 +130,11 @@ static QString urlishDecode(const QString &in, bool *ok = 0)
             unsigned char c = (unsigned char)x;
             out += c;
             n += 2;
-        }
-        else
+        } else
             out += in[n];
     }
 
-    if(ok)
+    if (ok)
         *ok = true;
     return out;
 }
@@ -172,7 +157,7 @@ static QString candidate_to_line(const XMPP::Ice176::Candidate &in)
     list += QString::number(in.rem_port);
     list += in.type;
 
-    for(int n = 0; n < list.count(); ++n)
+    for (int n = 0; n < list.count(); ++n)
         list[n] = urlishEncode(list[n]);
     return list.join(",");
 }
@@ -180,40 +165,38 @@ static QString candidate_to_line(const XMPP::Ice176::Candidate &in)
 static XMPP::Ice176::Candidate line_to_candidate(const QString &in)
 {
     QStringList list = in.split(',');
-    if(list.count() < 14)
+    if (list.count() < 14)
         return XMPP::Ice176::Candidate();
 
-    for(int n = 0; n < list.count(); ++n)
-    {
-        bool ok;
+    for (int n = 0; n < list.count(); ++n) {
+        bool    ok;
         QString str = urlishDecode(list[n], &ok);
-        if(!ok)
+        if (!ok)
             return XMPP::Ice176::Candidate();
         list[n] = str;
     }
 
     XMPP::Ice176::Candidate out;
-    out.component = list[0].toInt();
+    out.component  = list[0].toInt();
     out.foundation = list[1];
     out.generation = list[2].toInt();
-    out.id = list[3];
-    out.ip = QHostAddress(list[4]);
-    out.network = list[5].toInt();
-    out.port = list[6].toInt();
-    out.priority = list[7].toInt();
-    out.protocol = list[8];
-    out.rel_addr = QHostAddress(list[9]);
-    out.rel_port = list[10].toInt();
-    out.rem_addr = QHostAddress(list[11]);
-    out.rem_port = list[12].toInt();
-    out.type = list[13];
+    out.id         = list[3];
+    out.ip         = QHostAddress(list[4]);
+    out.network    = list[5].toInt();
+    out.port       = list[6].toInt();
+    out.priority   = list[7].toInt();
+    out.protocol   = list[8];
+    out.rel_addr   = QHostAddress(list[9]);
+    out.rel_port   = list[10].toInt();
+    out.rem_addr   = QHostAddress(list[11]);
+    out.rem_port   = list[12].toInt();
+    out.type       = list[13];
     return out;
 }
 
-class IceOffer
-{
+class IceOffer {
 public:
-    QString user, pass;
+    QString                        user, pass;
     QList<XMPP::Ice176::Candidate> candidates;
 };
 
@@ -222,9 +205,8 @@ static QStringList line_wrap(const QString &in, int maxlen)
     Q_ASSERT(maxlen >= 1);
 
     QStringList out;
-    int at = 0;
-    while(at < in.length())
-    {
+    int         at = 0;
+    while (at < in.length()) {
         int takeAmount = qMin(maxlen, in.length() - at);
         out += in.mid(at, takeAmount);
         at += takeAmount;
@@ -232,10 +214,7 @@ static QStringList line_wrap(const QString &in, int maxlen)
     return out;
 }
 
-static QString lines_unwrap(const QStringList &in)
-{
-    return in.join(QString());
-}
+static QString lines_unwrap(const QStringList &in) { return in.join(QString()); }
 
 static QStringList iceblock_create(const IceOffer &in)
 {
@@ -247,7 +226,7 @@ static QStringList iceblock_create(const IceOffer &in)
         userpass += urlishEncode(in.user);
         userpass += urlishEncode(in.pass);
         body += userpass.join(",");
-        foreach(const XMPP::Ice176::Candidate &c, in.candidates)
+        for (const XMPP::Ice176::Candidate &c : in.candidates)
             body += candidate_to_line(c);
         out += line_wrap(body.join(";"), 78);
     }
@@ -258,44 +237,41 @@ static QStringList iceblock_create(const IceOffer &in)
 static IceOffer iceblock_parse(const QStringList &in)
 {
     IceOffer out;
-    if(in.count() < 3 || in[0] != "-----BEGIN ICE-----" || in[in.count()-1] != "-----END ICE-----")
+    if (in.count() < 3 || in[0] != "-----BEGIN ICE-----" || in[in.count() - 1] != "-----END ICE-----")
         return IceOffer();
 
     QStringList body = lines_unwrap(in.mid(1, in.count() - 2)).split(';');
-    if(body.count() < 2)
+    if (body.count() < 2)
         return IceOffer();
 
     QStringList parts = body[0].split(',');
-    if(parts.count() != 2)
+    if (parts.count() != 2)
         return IceOffer();
     bool ok;
     out.user = urlishDecode(parts[0], &ok);
-    if(!ok || out.user.isEmpty())
+    if (!ok || out.user.isEmpty())
         return IceOffer();
     out.pass = urlishDecode(parts[1], &ok);
-    if(!ok || out.pass.isEmpty())
+    if (!ok || out.pass.isEmpty())
         return IceOffer();
 
-    for(int n = 1; n < body.count(); ++n)
-    {
+    for (int n = 1; n < body.count(); ++n) {
         XMPP::Ice176::Candidate c = line_to_candidate(body[n]);
-        if(c.type.isEmpty())
+        if (c.type.isEmpty())
             return IceOffer();
         out.candidates += c;
     }
     return out;
 }
 
-class IceBlockReader : public QObject
-{
+class IceBlockReader : public QObject {
     Q_OBJECT
 
 public:
     QCA::ConsoleReference *con;
-    QByteArray in;
+    QByteArray             in;
 
-    IceBlockReader(QObject *parent = 0) :
-        QObject(parent)
+    IceBlockReader(QObject *parent = 0) : QObject(parent)
     {
         bool ok;
 
@@ -314,16 +290,15 @@ private slots:
     void con_readyRead()
     {
         in += con->read();
-        if(in.contains("-----END ICE-----"))
-        {
+        if (in.contains("-----END ICE-----")) {
             delete con;
             con = 0;
 
             QStringList out;
-            QBuffer buf(&in);
+            QBuffer     buf(&in);
             buf.open(QIODevice::ReadOnly | QIODevice::Text);
             QTextStream ts(&buf);
-            while(!ts.atEnd())
+            while (!ts.atEnd())
                 out += ts.readLine();
             emit finished(out);
         }
@@ -338,15 +313,13 @@ private slots:
     }
 };
 
-class EnterPrompt : public QObject
-{
+class EnterPrompt : public QObject {
     Q_OBJECT
 
 public:
     QCA::ConsoleReference *con;
 
-    EnterPrompt(QObject *parent = 0) :
-        QObject(parent)
+    EnterPrompt(QObject *parent = 0) : QObject(parent)
     {
         bool ok;
 
@@ -364,8 +337,7 @@ signals:
 private slots:
     void con_readyRead()
     {
-        if(con->read().contains('\n'))
-        {
+        if (con->read().contains('\n')) {
             delete con;
             con = 0;
 
@@ -414,52 +386,44 @@ private slots:
         return;
 }*/
 
-class App : public QObject
-{
+class App : public QObject {
     Q_OBJECT
 
 public:
-    class Channel
-    {
+    class Channel {
     public:
         QUdpSocket *sock6, *sock4;
-        bool ready;
+        bool        ready;
     };
 
-    enum StunServiceType
-    {
-        Auto,
-        Basic,
-        Relay
-    };
+    enum StunServiceType { Auto, Basic, Relay };
 
-    int opt_mode = 0;
-    int opt_localBase = 0;
-    int opt_iceBase = 0;
-    int opt_channels = 0;
-    QString opt_stunHost;
-    int opt_stunPort = 0;
+    int             opt_mode      = 0;
+    int             opt_localBase = 0;
+    int             opt_iceBase   = 0;
+    int             opt_channels  = 0;
+    QString         opt_stunHost;
+    int             opt_stunPort = 0;
     StunServiceType opt_stunType = Auto;
-    QString opt_user;
-    QString opt_pass;
-    bool opt_ipv6_only = false;
-    bool opt_relay_udp_only = false;
-    bool opt_relay_tcp_only = false;
+    QString         opt_user;
+    QString         opt_pass;
+    bool            opt_ipv6_only      = false;
+    bool            opt_relay_udp_only = false;
+    bool            opt_relay_tcp_only = false;
 
-    XMPP::NameResolver dns;
-    QHostAddress stunAddr;
-    XMPP::UdpPortReserver portReserver;
-    XMPP::Ice176 *ice = nullptr;
+    XMPP::NameResolver                dns;
+    QHostAddress                      stunAddr;
+    XMPP::UdpPortReserver             portReserver;
+    XMPP::Ice176 *                    ice = nullptr;
+    QList<XMPP::Ice176::Candidate>    localCandidates;
     QList<XMPP::Ice176::LocalAddress> localAddrs;
-    QList<Channel> channels;
-    QCA::Console *console = nullptr;
-    IceBlockReader *reader = nullptr;
-    EnterPrompt *prompt = nullptr;
-    IceOffer inOffer;
+    QList<Channel>                    channels;
+    QCA::Console *                    console = nullptr;
+    IceBlockReader *                  reader  = nullptr;
+    EnterPrompt *                     prompt  = nullptr;
+    IceOffer                          inOffer;
 
-    App() : portReserver(this)
-    {
-    }
+    App() : portReserver(this) { }
 
     ~App()
     {
@@ -469,18 +433,15 @@ public:
 
         delete ice;
 
-        for(int n = 0; n < channels.count(); ++n)
-        {
-            if(channels[n].sock6)
-            {
+        for (int n = 0; n < channels.count(); ++n) {
+            if (channels[n].sock6) {
                 channels[n].sock6->disconnect(this);
                 channels[n].sock6->setParent(0);
                 channels[n].sock6->deleteLater();
                 channels[n].sock6 = 0;
             }
 
-            if(channels[n].sock4)
-            {
+            if (channels[n].sock4) {
                 channels[n].sock4->disconnect(this);
                 channels[n].sock4->setParent(0);
                 channels[n].sock4->deleteLater();
@@ -494,10 +455,17 @@ public slots:
     {
         connect(XMPP::ProcessQuit::instance(), SIGNAL(quit()), SLOT(do_quit()));
 
-        connect(&dns, SIGNAL(resultsReady(const QList<XMPP::NameRecord> &)), SLOT(dns_resultsReady(const QList<XMPP::NameRecord> &)));
-        connect(&dns, SIGNAL(error(XMPP::NameResolver::Error)), SLOT(dns_error(XMPP::NameResolver::Error)));
+        connect(&dns, &XMPP::NameResolver::resultsReady, this, [this](const QList<XMPP::NameRecord> &results) {
+            stunAddr = results.first().address();
+            start_ice();
+        });
+        connect(&dns, &XMPP::NameResolver::error, this, [this](XMPP::NameResolver::Error e) {
+            Q_UNUSED(e);
+            printf("Unable to resolve stun host.\n");
+            emit quit();
+        });
 
-        if(!opt_stunHost.isEmpty())
+        if (!opt_stunHost.isEmpty())
             dns.start(opt_stunHost.toLatin1(), XMPP::NameRecord::A);
         else
             start_ice();
@@ -510,22 +478,29 @@ public:
         connect(ice, SIGNAL(started()), SLOT(ice_started()));
         connect(ice, SIGNAL(stopped()), SLOT(ice_stopped()));
         connect(ice, SIGNAL(error(XMPP::Ice176::Error)), SLOT(ice_error(XMPP::Ice176::Error)));
-        connect(ice, SIGNAL(localCandidatesReady(const QList<XMPP::Ice176::Candidate> &)), SLOT(ice_localCandidatesReady(const QList<XMPP::Ice176::Candidate> &)));
-        connect(ice, SIGNAL(componentReady(int)), SLOT(ice_componentReady(int)));
+        connect(ice, &XMPP::Ice176::localCandidatesReady, this,
+                [this](const QList<XMPP::Ice176::Candidate> &cs) { localCandidates += cs; });
+        connect(ice, &XMPP::Ice176::localGatheringComplete, this, &App::ice_localGatheringComplete);
+        connect(ice, &XMPP::Ice176::componentReady, this, [this](int componentIndex) {
+            printf("Channel %d ready.\n", componentIndex);
+            channels[componentIndex].ready = true;
+        });
+
         connect(ice, SIGNAL(readyRead(int)), SLOT(ice_readyRead(int)));
         connect(ice, SIGNAL(datagramsWritten(int, int)), SLOT(ice_datagramsWritten(int, int)));
+        connect(ice, &XMPP::Ice176::readyToSendMedia, this, []() { printf("ICE ready to send media.\n"); });
+        connect(ice, &XMPP::Ice176::iceFinished, this,
+                []() { printf("ICE negotiation has finished and media stream is active now!\n"); });
 
         // set up local ports for forwarding
-        for(int n = 0; n < opt_channels; ++n)
-        {
+        for (int n = 0; n < opt_channels; ++n) {
             Channel chan;
 
-            int port = opt_localBase + 32 + n;
+            int port   = opt_localBase + 32 + n;
             chan.sock6 = setupSocket(QHostAddress::LocalHostIPv6, port);
             chan.sock4 = setupSocket(QHostAddress::LocalHost, port);
 
-            if(!chan.sock6 && !chan.sock4)
-            {
+            if (!chan.sock6 && !chan.sock4) {
                 printf("Unable to bind to port %d.\n", port);
                 emit quit();
                 return;
@@ -537,8 +512,7 @@ public:
         }
 
         QList<QHostAddress> listenAddrs;
-        if(!opt_relay_tcp_only)
-        {
+        if (!opt_relay_tcp_only) {
             /*XMPP::NetInterfaceManager netman;
             foreach(const QString &id, netman.interfaces())
             {
@@ -562,18 +536,19 @@ public:
                     strList += addr.addr.toString();
                 }
             }*/
-            foreach(const QNetworkInterface &ni, QNetworkInterface::allInterfaces())
-            {
+            auto const interfaces = QNetworkInterface::allInterfaces();
+            for (const QNetworkInterface &ni : interfaces) {
+                if (!(ni.flags() & QNetworkInterface::IsUp))
+                    continue;
                 QList<QNetworkAddressEntry> entries = ni.addressEntries();
-                foreach(const QNetworkAddressEntry &na, entries)
-                {
+                for (const QNetworkAddressEntry &na : entries) {
                     QHostAddress h = na.ip();
 
-                    if(opt_ipv6_only && h.protocol() != QAbstractSocket::IPv6Protocol)
+                    if (opt_ipv6_only && h.protocol() != QAbstractSocket::IPv6Protocol)
                         continue;
 
                     // skip localhost
-                    if(getAddressScope(h) == 0)
+                    if (getAddressScope(h) == 0)
                         continue;
 
                     // don't put the same address in twice.
@@ -581,9 +556,8 @@ public:
                     //   two link-local ipv6 interfaces
                     //   with the exact same address, we
                     //   only use the first one
-                    if(!listenAddrs.contains(h))
-                    {
-                        if(h.protocol() == QAbstractSocket::IPv6Protocol && XMPP::Ice176::isIPv6LinkLocalAddress(h))
+                    if (!listenAddrs.contains(h)) {
+                        if (h.protocol() == QAbstractSocket::IPv6Protocol && XMPP::Ice176::isIPv6LinkLocalAddress(h))
                             h.setScopeId(ni.name());
                         listenAddrs += h;
                     }
@@ -600,7 +574,7 @@ public:
         listenAddrs = sortAddrs(listenAddrs);
 
         QStringList strList;
-        foreach(const QHostAddress &h, listenAddrs) //QNetworkInterface::allAddresses())
+        for (const QHostAddress &h : listenAddrs) // QNetworkInterface::allAddresses())
         {
             XMPP::Ice176::LocalAddress addr;
             addr.addr = h;
@@ -608,8 +582,7 @@ public:
             strList += h.toString();
         }
 
-        if(opt_iceBase > 0)
-        {
+        if (opt_iceBase > 0) {
             portReserver.setAddresses(listenAddrs);
             portReserver.setPorts(opt_iceBase, opt_channels);
 
@@ -618,22 +591,19 @@ public:
 
         ice->setLocalAddresses(localAddrs);
 
-        if(!strList.isEmpty())
-        {
+        if (!strList.isEmpty()) {
             printf("Host addresses:\n");
-            foreach(const QString &s, strList)
+            for (const QString &s : strList)
                 printf("  %s\n", qPrintable(s));
         }
 
         ice->setComponentCount(opt_channels);
-        ice->setLocalCandidateTrickle(false);
+        ice->setLocalFeatures(XMPP::Ice176::Trickle | XMPP::Ice176::NotNominatedData);
 
-        if(!stunAddr.isNull())
-        {
-            if(opt_stunType == Basic || opt_stunType == Auto)
+        if (!stunAddr.isNull()) {
+            if (opt_stunType == Basic || opt_stunType == Auto)
                 ice->setStunBindService(stunAddr, opt_stunPort);
-            if((opt_stunType == Relay || opt_stunType == Auto) && !opt_user.isEmpty())
-            {
+            if ((opt_stunType == Relay || opt_stunType == Auto) && !opt_user.isEmpty()) {
                 ice->setStunRelayUdpService(stunAddr, opt_stunPort, opt_user, opt_pass.toUtf8());
                 ice->setStunRelayTcpService(stunAddr, opt_stunPort, opt_user, opt_pass.toUtf8());
             }
@@ -641,14 +611,13 @@ public:
             printf("STUN service: %s\n", qPrintable(stunAddr.toString()));
         }
 
-        if(opt_relay_udp_only)
-        {
+        if (opt_relay_udp_only) {
             ice->setUseLocal(false);
             ice->setUseStunBind(false);
             ice->setUseStunRelayTcp(false);
         }
 
-        if(opt_mode == 0)
+        if (opt_mode == 0)
             ice->start(XMPP::Ice176::Initiator);
         else
             ice->start(XMPP::Ice176::Responder);
@@ -663,8 +632,7 @@ private:
         QUdpSocket *sock = new QUdpSocket(this);
         connect(sock, SIGNAL(readyRead()), SLOT(sock_readyRead()));
         connect(sock, SIGNAL(bytesWritten(qint64)), SLOT(sock_bytesWritten(qint64)));
-        if(!sock->bind(addr, port))
-        {
+        if (!sock->bind(addr, port)) {
             delete sock;
             return 0;
         }
@@ -678,47 +646,25 @@ private slots:
         // a good idea
         XMPP::ProcessQuit::cleanup();
 
-        if(ice)
-        {
+        if (ice) {
             printf("Stopping ICE.\n");
             ice->stop();
-        }
-        else
+        } else
             emit quit();
     }
 
-    void dns_resultsReady(const QList<XMPP::NameRecord> &results)
-    {
-        stunAddr = results.first().address();
-
-        start_ice();
-    }
-
-    void dns_error(XMPP::NameResolver::Error e)
-    {
-        Q_UNUSED(e);
-        printf("Unable to resolve stun host.\n");
-        emit quit();
-    }
-
     void ice_started()
     {
-        if(channels.count() > 1)
-        {
+        if (channels.count() > 1) {
             printf("Local ports: %d-%d\n", opt_localBase, opt_localBase + channels.count() - 1);
             printf("Tunnel ports: %d-%d\n", opt_localBase + 32, opt_localBase + 32 + channels.count() - 1);
-        }
-        else
-        {
+        } else {
             printf("Local port: %d\n", opt_localBase);
             printf("Tunnel port: %d\n", opt_localBase + 32);
         }
     }
 
-    void ice_stopped()
-    {
-        emit quit();
-    }
+    void ice_stopped() { emit quit(); }
 
     void ice_error(XMPP::Ice176::Error e)
     {
@@ -726,14 +672,14 @@ private slots:
         emit quit();
     }
 
-    void ice_localCandidatesReady(const QList<XMPP::Ice176::Candidate> &list)
+    void ice_localGatheringComplete()
     {
         IceOffer out;
-        out.user = ice->localUfrag();
-        out.pass = ice->localPassword();
-        out.candidates = list;
+        out.user          = ice->localUfrag();
+        out.pass          = ice->localPassword();
+        out.candidates    = localCandidates;
         QStringList block = iceblock_create(out);
-        foreach(const QString &s, block)
+        for (const QString &s : block)
             printf("%s\n", qPrintable(s));
 
         printf("Give above ICE block to peer.  Obtain peer ICE block and paste below...\n");
@@ -745,36 +691,16 @@ private slots:
         connect(reader, SIGNAL(error()), SLOT(reader_error()));
     }
 
-    void ice_componentReady(int index)
-    {
-        printf("Channel %d ready.\n", index);
-        channels[index].ready = true;
-
-        bool allReady = true;
-        for(int n = 0; n < channels.count(); ++n)
-        {
-            if(!channels[n].ready)
-            {
-                allReady = false;
-                break;
-            }
-        }
-
-        if(allReady)
-        {
-            printf("Tunnel established!\n");
-        }
-    }
-
     void ice_readyRead(int componentIndex)
     {
-        while(ice->hasPendingDatagrams(componentIndex))
-        {
+        while (ice->hasPendingDatagrams(componentIndex)) {
             QByteArray buf = ice->readDatagram(componentIndex);
-            if(channels[componentIndex].sock6)
-                channels[componentIndex].sock6->writeDatagram(buf, QHostAddress::LocalHostIPv6, opt_localBase + componentIndex);
-            if(channels[componentIndex].sock4)
-                channels[componentIndex].sock4->writeDatagram(buf, QHostAddress::LocalHost, opt_localBase + componentIndex);
+            if (channels[componentIndex].sock6)
+                channels[componentIndex].sock6->writeDatagram(buf, QHostAddress::LocalHostIPv6,
+                                                              opt_localBase + componentIndex);
+            if (channels[componentIndex].sock4)
+                channels[componentIndex].sock4->writeDatagram(buf, QHostAddress::LocalHost,
+                                                              opt_localBase + componentIndex);
         }
     }
 
@@ -792,8 +718,7 @@ private slots:
         reader = 0;
 
         inOffer = iceblock_parse(lines);
-        if(inOffer.user.isEmpty())
-        {
+        if (inOffer.user.isEmpty()) {
             printf("Error parsing ICE block.\n");
             emit quit();
             return;
@@ -822,6 +747,7 @@ private slots:
         ice->setPeerUfrag(inOffer.user);
         ice->setPeerPassword(inOffer.pass);
         ice->addRemoteCandidates(inOffer.candidates);
+        ice->startChecks();
     }
 
     void prompt_error()
@@ -836,26 +762,23 @@ private slots:
     void sock_readyRead()
     {
         QUdpSocket *sock = static_cast<QUdpSocket *>(sender());
-        int at = -1;
-        for(int n = 0; n < channels.count(); ++n)
-        {
-            if(channels[n].sock6 == sock || channels[n].sock4 == sock)
-            {
+        int         at   = -1;
+        for (int n = 0; n < channels.count(); ++n) {
+            if (channels[n].sock6 == sock || channels[n].sock4 == sock) {
                 at = n;
                 break;
             }
         }
         Q_ASSERT(at != -1);
 
-        while(sock->hasPendingDatagrams())
-        {
+        while (sock->hasPendingDatagrams()) {
             QByteArray buf;
             buf.resize(sock->pendingDatagramSize());
 
             // note: we don't care who sent it
             sock->readDatagram(buf.data(), buf.size());
 
-            if(channels[at].ready)
+            if (channels[at].ready)
                 ice->writeDatagram(at, buf);
         }
     }
@@ -896,83 +819,72 @@ int main(int argc, char **argv)
     QStringList args = qapp.arguments();
     args.removeFirst();
 
-    int localBase = 60000;
-    int iceBase = 0;
-    int channels = 1;
-    QString stunHost;
-    int stunPort = 3478;
+    int                  localBase = 60000;
+    int                  iceBase   = 0;
+    int                  channels  = 1;
+    QString              stunHost;
+    int                  stunPort = 3478;
     App::StunServiceType stunType = App::Auto;
-    QString user, pass;
-    bool ipv6_only = false;
-    bool relay_udp_only = false;
-    bool relay_tcp_only = false;
+    QString              user, pass;
+    bool                 ipv6_only      = false;
+    bool                 relay_udp_only = false;
+    bool                 relay_tcp_only = false;
 
-    for(int n = 0; n < args.count(); ++n)
-    {
+    for (int n = 0; n < args.count(); ++n) {
         QString s = args[n];
-        if(!s.startsWith("--"))
+        if (!s.startsWith("--"))
             continue;
         QString var;
         QString val;
-        int x = s.indexOf('=');
-        if(x != -1)
-        {
+        int     x = s.indexOf('=');
+        if (x != -1) {
             var = s.mid(2, x - 2);
             val = s.mid(x + 1);
-        }
-        else
-        {
+        } else {
             var = s.mid(2);
         }
 
         bool known = true;
 
-        if(var == "localbase")
+        if (var == "localbase")
             localBase = val.toInt();
-        else if(var == "icebase")
+        else if (var == "icebase")
             iceBase = val.toInt();
-        else if(var == "channels")
-        {
+        else if (var == "channels") {
             channels = val.toInt();
-            if(channels < 1 || channels > 32)
-            {
+            if (channels < 1 || channels > 32) {
                 fprintf(stderr, "Number of channels must be between 1-32.\n");
                 return 1;
             }
-        }
-        else if(var == "stunhost")
+        } else if (var == "stunhost")
             stunHost = val;
-        else if(var == "stunport")
+        else if (var == "stunport")
             stunPort = val.toInt();
-        else if(var == "stuntype")
-        {
-            if(val == "auto")
+        else if (var == "stuntype") {
+            if (val == "auto")
                 stunType = App::Auto;
-            else if(val == "basic")
+            else if (val == "basic")
                 stunType = App::Basic;
-            else if(val == "relay")
+            else if (val == "relay")
                 stunType = App::Relay;
-            else
-            {
+            else {
                 usage();
                 return 1;
             }
-        }
-        else if(var == "user")
+        } else if (var == "user")
             user = val;
-        else if(var == "pass")
+        else if (var == "pass")
             pass = val;
-        else if(var == "ipv6-only")
+        else if (var == "ipv6-only")
             ipv6_only = true;
-        else if(var == "relay-udp-only")
+        else if (var == "relay-udp-only")
             relay_udp_only = true;
-        else if(var == "relay-tcp-only")
+        else if (var == "relay-tcp-only")
             relay_tcp_only = true;
         else
             known = false;
 
-        if(!known)
-        {
+        if (!known) {
             fprintf(stderr, "Unknown option '%s'.\n", qPrintable(var));
             return 1;
         }
@@ -981,47 +893,43 @@ int main(int argc, char **argv)
         --n; // adjust position
     }
 
-    if(args.isEmpty())
-    {
+    if (args.isEmpty()) {
         usage();
         return 1;
     }
 
-    if(relay_udp_only && relay_tcp_only)
-    {
+    if (relay_udp_only && relay_tcp_only) {
         fprintf(stderr, "Cannot use both --relay-udp-only and --relay-tcp-only.\n");
         return 1;
     }
 
     int mode = -1;
-    if(args[0] == "initiator")
+    if (args[0] == "initiator")
         mode = 0;
-    else if(args[0] == "responder")
+    else if (args[0] == "responder")
         mode = 1;
 
-    if(mode == -1)
-    {
+    if (mode == -1) {
         usage();
         return 1;
     }
 
-    if(!QCA::isSupported("hmac(sha1)"))
-    {
+    if (!QCA::isSupported("hmac(sha1)")) {
         printf("Error: Need hmac(sha1) support.\n");
         return 1;
     }
 
     App app;
-    app.opt_mode = mode;
-    app.opt_localBase = localBase;
-    app.opt_iceBase = iceBase;
-    app.opt_channels = channels;
-    app.opt_stunHost = stunHost;
-    app.opt_stunPort = stunPort;
-    app.opt_stunType = stunType;
-    app.opt_user = user;
-    app.opt_pass = pass;
-    app.opt_ipv6_only = ipv6_only;
+    app.opt_mode           = mode;
+    app.opt_localBase      = localBase;
+    app.opt_iceBase        = iceBase;
+    app.opt_channels       = channels;
+    app.opt_stunHost       = stunHost;
+    app.opt_stunPort       = stunPort;
+    app.opt_stunType       = stunType;
+    app.opt_user           = user;
+    app.opt_pass           = pass;
+    app.opt_ipv6_only      = ipv6_only;
     app.opt_relay_udp_only = relay_udp_only;
     app.opt_relay_tcp_only = relay_tcp_only;
 
