@@ -1,10 +1,8 @@
 /*
- * Copyright (C) 2008 Remko Troncon
+ * Copyright (C) 2008  Remko Troncon
  * See COPYING file for the detailed license.
  */
 
 #include "AutoUpdater.h"
 
-AutoUpdater::~AutoUpdater()
-{
-}
+AutoUpdater::~AutoUpdater() = default;
