@@ -12,8 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -23,17 +22,16 @@
 
 class AbstractTreeItem;
 
-class AbstractTreeModel : public QAbstractItemModel
-{
+class AbstractTreeModel : public QAbstractItemModel {
     Q_OBJECT
 
 public:
-    explicit AbstractTreeModel(AbstractTreeItem *root, QObject *parent = 0);
+    explicit AbstractTreeModel(AbstractTreeItem *root, QObject *parent = nullptr);
     ~AbstractTreeModel() override;
 
     QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override;
     QModelIndex parent(const QModelIndex &index) const override;
-    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    int         rowCount(const QModelIndex &parent = QModelIndex()) const override;
 
 protected:
     AbstractTreeItem *root() const;
