@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -26,25 +25,24 @@
 
 class PsiAccount;
 
-class AccountLabel : public QLabel
-{
+class AccountLabel : public QLabel {
     Q_OBJECT
     Q_PROPERTY(bool showJid READ showJid WRITE setShowJid)
 public:
-    AccountLabel(QWidget* parent);
+    AccountLabel(QWidget *parent);
     ~AccountLabel();
 
-    PsiAccount* account() const;
-    bool showJid() const;
-    void setAccount(PsiAccount* account);
-    void setShowJid(bool showJid);
+    PsiAccount *account() const;
+    bool        showJid() const;
+    void        setAccount(PsiAccount *account);
+    void        setShowJid(bool showJid);
 
 private slots:
     void updateName();
 
 private:
     QPointer<PsiAccount> account_;
-    bool showJid_;
+    bool                 showJid_;
 };
 
-#endif
+#endif // ACCOUNTLABEL_H
