@@ -13,58 +13,47 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "activecontactsmenu.h"
+
 #include "psiaccount.h"
+#include "psicon.h"
 #include "psicontact.h"
 #include "psiiconset.h"
-#include "psicon.h"
 
-
-class ActiveContactAction : public QAction
-{
+class ActiveContactAction : public QAction {
     Q_OBJECT
 public:
-    ActiveContactAction(const QString& jid, const QString& nick, const QIcon& icon, PsiAccount* pa, QMenu* parent)
-        : QAction(icon, nick, parent)
-        , pa_(pa)
-        , jid_(jid)
+    ActiveContactAction(const QString &jid, const QString &nick, const QIcon &icon, PsiAccount *pa, QMenu *parent) :
+        QAction(icon, nick, parent), pa_(pa), jid_(jid)
     {
         parent->addAction(this);
         connect(this, SIGNAL(triggered()), SLOT(actionActivated()));
     }
 
 private slots:
-    void actionActivated()
-    {
-        pa_->actionDefault(Jid(jid_));
-    }
+    void actionActivated() { pa_->actionDefault(Jid(jid_)); }
 
 private:
-    PsiAccount* pa_;
-    QString jid_;
+    PsiAccount *pa_;
+    QString     jid_;
 };
 
-
-
-ActiveContactsMenu::ActiveContactsMenu(PsiCon *psi, QWidget *parent)
-    : QMenu(parent)
-    , psi_(psi)
+ActiveContactsMenu::ActiveContactsMenu(PsiCon *psi, QWidget *parent) : QMenu(parent), psi_(psi)
 {
-    foreach(PsiAccount *pa, psi_->contactList()->accounts()) {
-        if(!pa->enabled())
+    for (PsiAccount *pa : psi_->contactList()->accounts()) {
+        if (!pa->enabled())
             continue;
 
-        QList<PsiContact*> list = pa->activeContacts();
-        foreach(PsiContact* pc, list) {
-            new ActiveContactAction(pc->jid().full(), pc->name(), PsiIconset::instance()->statusPtr(pc->jid(), pc->status())->icon(), pa, this);
+        const QList<PsiContact *> list = pa->activeContacts();
+        for (PsiContact *pc : list) {
+            new ActiveContactAction(pc->jid().full(), pc->name(),
+                                    PsiIconset::instance()->statusPtr(pc->jid(), pc->status())->icon(), pa, this);
         }
     }
 }
 
-
 #include "activecontactsmenu.moc"
