@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -25,14 +24,13 @@
 
 class PsiCon;
 
-class ActiveContactsMenu : public QMenu
-{
+class ActiveContactsMenu : public QMenu {
     Q_OBJECT
 public:
-    ActiveContactsMenu(PsiCon* psi, QWidget* parent);
+    ActiveContactsMenu(PsiCon *psi, QWidget *parent);
 
 private:
-    PsiCon* psi_;
+    PsiCon *psi_;
 };
 
-#endif
+#endif // ACTIVECONTACTSMENU_H
