@@ -13,32 +13,23 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "activeprofiles.h"
-
-#include <QCoreApplication>
-#include <QString>
-#include <QStringList>
-#include <QByteArray>
-#include <QDBusConnection>
-#include <QDBusConnectionInterface>
-#include <QDBusInterface>
-
-
-#include <QLabel>
-#include <QTimer>
-
-
 #include "applicationinfo.h"
 #include "dbus.h"
 
-
-
-
+#include <QByteArray>
+#include <QCoreApplication>
+#include <QDBusConnection>
+#include <QDBusConnectionInterface>
+#include <QDBusInterface>
+#include <QLabel>
+#include <QString>
+#include <QStringList>
+#include <QTimer>
 
 /** \brief encodes a string to "[A-Z][a-z][0-9]_-" ascii subset
  * [A-Z][a-z][0-9] -> [A-Z][a-z][0-9]
@@ -48,14 +39,14 @@
  */
 static QString encodeAlNumD(QString in)
 {
-    QString out;
-    QByteArray chars = in.toUtf8();
-    bool first = true;
-    foreach(char c, chars) {
+    QString          out;
+    const QByteArray chars = in.toUtf8();
+    bool             first = true;
+    for (char c : chars) {
         if (('A' <= c) && (c <= 'z')) {
-            out += (char)c;
+            out += char(c);
         } else if (('0' <= c) && (c <= '9') && !first) {
-            out += (char)c;
+            out += char(c);
         } else if ('/' == c) {
             out += "_";
         } else {
@@ -66,7 +57,6 @@ static QString encodeAlNumD(QString in)
     return out;
 }
 
-
 /** \brief DBus busname registration helper
  * \param dbusIface interface of bus
  * \param name busname to register
@@ -75,21 +65,21 @@ static QString encodeAlNumD(QString in)
  */
 static bool registerBusname(QDBusConnectionInterface *dbusIface, QString name, bool queue)
 {
-    bool ok = false;
+    bool                                                       ok = false;
     QDBusReply<QDBusConnectionInterface::RegisterServiceReply> reply;
-    reply = dbusIface->registerService(name,
-        queue ?    QDBusConnectionInterface::QueueService : QDBusConnectionInterface::DontQueueService,
-            QDBusConnectionInterface::AllowReplacement);
+    reply = dbusIface->registerService(
+        name, queue ? QDBusConnectionInterface::QueueService : QDBusConnectionInterface::DontQueueService,
+        QDBusConnectionInterface::AllowReplacement);
     if (reply.isValid()) {
         switch (reply.value()) {
-            case QDBusConnectionInterface::ServiceNotRegistered:
-                qWarning("failed to register dbus name %s:", qPrintable(name));
-                break;
-            case QDBusConnectionInterface::ServiceQueued:
-                qDebug("dbus name %s already taken, queueing", qPrintable(name));
-                break;
-            case QDBusConnectionInterface::ServiceRegistered:
-                ok = true;
+        case QDBusConnectionInterface::ServiceNotRegistered:
+            qWarning("failed to register dbus name %s:", qPrintable(name));
+            break;
+        case QDBusConnectionInterface::ServiceQueued:
+            qDebug("dbus name %s already taken, queueing", qPrintable(name));
+            break;
+        case QDBusConnectionInterface::ServiceRegistered:
+            ok = true;
         }
     } else {
         qWarning("failed to register dbus name %s: %s", qPrintable(name), qPrintable(reply.error().message()));
@@ -97,31 +87,28 @@ static bool registerBusname(QDBusConnectionInterface *dbusIface, QString name, b
     return ok;
 }
 
-
 class ActiveProfiles::Private {
 public:
-    QString profile;
+    QString     profile;
     QStringList busNames;
-    bool registerBusnames(QString prof);
+    bool        registerBusnames(QString prof);
 
     QString dbusName(QString prof);
 };
 
-
 QString ActiveProfiles::Private::dbusName(QString prof)
 {
     QString name = PSIDBUSNAME;
     name += ".";
-    name += encodeAlNumD(ApplicationInfo::homeDir(ApplicationInfo::ConfigLocation)).right(qMax(0,200-name.size()));
+    name
+        += encodeAlNumD(ApplicationInfo::homeDir(ApplicationInfo::ConfigLocation)).rightRef(qMax(0, 200 - name.size()));
     if (!prof.isEmpty()) {
         name += ".";
-        name += encodeAlNumD(prof).right(qMax(0,250-name.size()));
+        name += encodeAlNumD(prof).rightRef(qMax(0, 250 - name.size()));
     }
     return name;
 }
 
-
-
 bool ActiveProfiles::Private::registerBusnames(QString prof)
 {
     // FIXME move where?
@@ -130,8 +117,7 @@ bool ActiveProfiles::Private::registerBusnames(QString prof)
         return true;
     }
 
-
-    QDBusConnectionInterface *dbusIface = QDBusConnection::sessionBus().interface ();
+    QDBusConnectionInterface *dbusIface = QDBusConnection::sessionBus().interface();
 
     QString name = PSIDBUSNAME;
     registerBusname(dbusIface, name, true);
@@ -142,10 +128,8 @@ bool ActiveProfiles::Private::registerBusnames(QString prof)
     name = dbusName(prof);
     busNames << name;
     return registerBusname(dbusIface, name, false);
-
 }
 
-
 bool ActiveProfiles::isActive(const QString &profile) const
 {
     if (!QDBusConnection::sessionBus().isConnected()) {
@@ -153,15 +137,11 @@ bool ActiveProfiles::isActive(const QString &profile) const
         return false;
     }
 
-    QDBusConnectionInterface *dbusIface = QDBusConnection::sessionBus().interface ();
+    QDBusConnectionInterface *dbusIface = QDBusConnection::sessionBus().interface();
     return dbusIface->isServiceRegistered(d->dbusName(profile));
 }
 
-bool ActiveProfiles::isAnyActive() const
-{
-    return isActive("");
-}
-
+bool ActiveProfiles::isAnyActive() const { return isActive(""); }
 
 bool ActiveProfiles::setThisProfile(const QString &profile)
 {
@@ -183,49 +163,40 @@ bool ActiveProfiles::setThisProfile(const QString &profile)
 
 void ActiveProfiles::unsetThisProfile()
 {
-    QDBusConnectionInterface *dbusIface = QDBusConnection::sessionBus().interface ();
-    foreach(QString name, d->busNames) {
+    QDBusConnectionInterface *dbusIface = QDBusConnection::sessionBus().interface();
+    for (const QString &name : d->busNames) {
         dbusIface->unregisterService(name);
     }
     d->busNames.clear();
-    d->profile = QString::null;
+    d->profile = QString();
 }
 
-QString ActiveProfiles::thisProfile() const
-{
-    return d->profile;
-}
+QString ActiveProfiles::thisProfile() const { return d->profile; }
 
-ActiveProfiles::ActiveProfiles()
-    : QObject(QCoreApplication::instance())
-{
-    d = new ActiveProfiles::Private;
-}
+ActiveProfiles::ActiveProfiles() : QObject(QCoreApplication::instance()) { d = new ActiveProfiles::Private; }
 
 ActiveProfiles::~ActiveProfiles()
 {
     delete d;
-    d = 0;
+    d = nullptr;
 }
 
 bool ActiveProfiles::setStatus(const QString &profile, const QString &status, const QString &message) const
 {
-    QDBusInterface(d->dbusName(profile), "/Main", PSIDBUSMAINIF).call(QDBus::NoBlock,
-            "setStatus", status, message);
+    QDBusInterface(d->dbusName(profile), "/Main", PSIDBUSMAINIF).call(QDBus::NoBlock, "setStatus", status, message);
     return true;
 }
 
 bool ActiveProfiles::openUri(const QString &profile, const QString &uri) const
 {
-    QDBusInterface(d->dbusName(profile), "/Main", PSIDBUSMAINIF).call(QDBus::NoBlock,
-            "openURI", uri);
+    QDBusInterface(d->dbusName(profile), "/Main", PSIDBUSMAINIF).call(QDBus::NoBlock, "openURI", uri);
     return true;
 }
 
 bool ActiveProfiles::raise(const QString &profile, bool withUI) const
 {
-    QLabel *lab=0;
-    QDBusMessage msg = QDBusMessage::createMethodCall ( d->dbusName(profile), "/Main", PSIDBUSMAINIF, "raise" );
+    QLabel *     lab = nullptr;
+    QDBusMessage msg = QDBusMessage::createMethodCall(d->dbusName(profile), "/Main", PSIDBUSMAINIF, "raise");
     if (withUI) {
         lab = new QLabel(tr("This psi profile is already running...<br>please wait..."));
         QTimer::singleShot(250, lab, SLOT(show()));
@@ -235,7 +206,5 @@ bool ActiveProfiles::raise(const QString &profile, bool withUI) const
         lab->hide();
         delete lab;
     }
-    if (rmsg.type() == QDBusMessage::ReplyMessage) {
-        return true;
-    } else return false;
+    return rmsg.type() == QDBusMessage::ReplyMessage;
 }
