@@ -13,41 +13,33 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "ahcformdlg.h"
 
-#include <QLayout>
-#include <QPushButton>
-#include <QLabel>
-#include <QScrollArea>
-
-#include "ahcommand.h"
 #include "ahcexecutetask.h"
+#include "ahcommand.h"
+#include "busywidget.h"
+#include "psiaccount.h"
 #include "xdata_widget.h"
 #include "xmpp_client.h"
-#include "psiaccount.h"
-#include "busywidget.h"
 
-AHCFormDlg::AHCFormDlg(PsiCon *psi, const AHCommand& r, const Jid& receiver, XMPP::Client* client, bool final) :
-    QDialog(0),
-    _psi(psi),
-    _pb_prev(0),
-    _pb_next(0),
-    _pb_complete(0),
-    _pb_cancel(0),
-    _xdata(0),
-    _receiver(receiver),
-    _client(client)
+#include <QLabel>
+#include <QLayout>
+#include <QPushButton>
+#include <QScrollArea>
+
+AHCFormDlg::AHCFormDlg(PsiCon *psi, const AHCommand &r, const Jid &receiver, XMPP::Client *client, bool final) :
+    QDialog(nullptr), _psi(psi), _pb_prev(nullptr), _pb_next(nullptr), _pb_complete(nullptr), _pb_cancel(nullptr),
+    _xdata(nullptr), _receiver(receiver), _client(client)
 {
     _ui.setupUi(this);
     setAttribute(Qt::WA_DeleteOnClose);
 
     // Save node
-    node_ = r.node();
+    node_      = r.node();
     sessionId_ = r.sessionId();
 
     _ui.lb_note->setText(r.note().text);
@@ -71,9 +63,8 @@ AHCFormDlg::AHCFormDlg(PsiCon *psi, const AHCommand& r, const Jid& receiver, XMP
         if (r.actions().empty()) {
             // Single stage dialog
             _pb_complete = _ui.buttonBox->addButton(tr("Finish"), QDialogButtonBox::AcceptRole);
-            connect(_pb_complete,SIGNAL(clicked()),SLOT(doExecute()));
-        }
-        else {
+            connect(_pb_complete, SIGNAL(clicked()), SLOT(doExecute()));
+        } else {
             // Multi-stage dialog
 
             // Previous
@@ -83,10 +74,9 @@ AHCFormDlg::AHCFormDlg(PsiCon *psi, const AHCommand& r, const Jid& receiver, XMP
                     _pb_prev->setDefault(true);
                     _pb_prev->setFocus();
                 }
-                connect(_pb_prev,SIGNAL(clicked()),SLOT(doPrev()));
+                connect(_pb_prev, SIGNAL(clicked()), SLOT(doPrev()));
                 _pb_prev->setEnabled(true);
-            }
-            else {
+            } else {
                 _pb_prev->setEnabled(false);
             }
 
@@ -94,16 +84,14 @@ AHCFormDlg::AHCFormDlg(PsiCon *psi, const AHCommand& r, const Jid& receiver, XMP
             _pb_next = _ui.buttonBox->addButton(tr("Next"), QDialogButtonBox::ActionRole);
             if (r.actions().contains(AHCommand::Next)) {
                 if (r.defaultAction() == AHCommand::Next) {
-                    connect(_pb_next,SIGNAL(clicked()),SLOT(doExecute()));
+                    connect(_pb_next, SIGNAL(clicked()), SLOT(doExecute()));
                     _pb_next->setDefault(true);
                     _pb_next->setFocus();
-                }
-                else {
-                    connect(_pb_next,SIGNAL(clicked()),SLOT(doNext()));
+                } else {
+                    connect(_pb_next, SIGNAL(clicked()), SLOT(doNext()));
                 }
                 _pb_next->setEnabled(true);
-            }
-            else {
+            } else {
                 _pb_next->setEnabled(false);
             }
 
@@ -111,77 +99,77 @@ AHCFormDlg::AHCFormDlg(PsiCon *psi, const AHCommand& r, const Jid& receiver, XMP
             _pb_complete = _ui.buttonBox->addButton(tr("Finish"), QDialogButtonBox::AcceptRole);
             if (r.actions().contains(AHCommand::Complete)) {
                 if (r.defaultAction() == AHCommand::Complete) {
-                    connect(_pb_complete,SIGNAL(clicked()),SLOT(doExecute()));
+                    connect(_pb_complete, SIGNAL(clicked()), SLOT(doExecute()));
                     _pb_complete->setDefault(true);
                     _pb_complete->setFocus();
-                }
-                else {
-                    connect(_pb_complete,SIGNAL(clicked()),SLOT(doComplete()));
+                } else {
+                    connect(_pb_complete, SIGNAL(clicked()), SLOT(doComplete()));
                 }
                 _pb_complete->setEnabled(true);
-            }
-            else {
+            } else {
                 _pb_complete->setEnabled(false);
             }
         }
 
         _pb_cancel = _ui.buttonBox->addButton(QDialogButtonBox::Cancel);
-        connect(_pb_cancel, SIGNAL(clicked()),SLOT(doCancel()));
-    }
-    else {
+        connect(_pb_cancel, SIGNAL(clicked()), SLOT(doCancel()));
+    } else {
         _pb_complete = _ui.buttonBox->addButton(QDialogButtonBox::Ok);
-        connect(_pb_complete,SIGNAL(clicked()),SLOT(close()));
+        connect(_pb_complete, SIGNAL(clicked()), SLOT(close()));
     }
 
     if (!r.data().title().isEmpty()) {
-        setWindowTitle(QString("%1 (%2)").arg(r.data().title()).arg(receiver.full()));
-    }
-    else {
+        setWindowTitle(QString("%1 (%2)").arg(r.data().title(), receiver.full()));
+    } else {
         setWindowTitle(QString("%1").arg(receiver.full()));
     }
 
     adjustSize();
     show();
-    setParent(0);
+    setParent(nullptr);
 }
 
 void AHCFormDlg::doPrev()
 {
     _ui.busy->start();
-    AHCExecuteTask* t = new AHCExecuteTask(_receiver,AHCommand(node_,data(),sessionId_,AHCommand::Prev), _client->rootTask());
-    connect(t,SIGNAL(finished()),SLOT(commandExecuted()));
+    AHCExecuteTask *t
+        = new AHCExecuteTask(_receiver, AHCommand(node_, data(), sessionId_, AHCommand::Prev), _client->rootTask());
+    connect(t, SIGNAL(finished()), SLOT(commandExecuted()));
     t->go(true);
 }
 
 void AHCFormDlg::doNext()
 {
     _ui.busy->start();
-    AHCExecuteTask* t = new AHCExecuteTask(_receiver,AHCommand(node_,data(),sessionId_,AHCommand::Next),_client->rootTask());
-    connect(t,SIGNAL(finished()),SLOT(commandExecuted()));
+    AHCExecuteTask *t
+        = new AHCExecuteTask(_receiver, AHCommand(node_, data(), sessionId_, AHCommand::Next), _client->rootTask());
+    connect(t, SIGNAL(finished()), SLOT(commandExecuted()));
     t->go(true);
 }
 
 void AHCFormDlg::doExecute()
 {
     _ui.busy->start();
-    AHCExecuteTask* t = new AHCExecuteTask(_receiver,AHCommand(node_,data(),sessionId_),_client->rootTask());
-    connect(t,SIGNAL(finished()),SLOT(commandExecuted()));
+    AHCExecuteTask *t = new AHCExecuteTask(_receiver, AHCommand(node_, data(), sessionId_), _client->rootTask());
+    connect(t, SIGNAL(finished()), SLOT(commandExecuted()));
     t->go(true);
 }
 
 void AHCFormDlg::doComplete()
 {
     _ui.busy->start();
-    AHCExecuteTask* t = new AHCExecuteTask(_receiver,AHCommand(node_,data(),sessionId_,AHCommand::Complete), _client->rootTask());
-    connect(t,SIGNAL(finished()),SLOT(commandExecuted()));
+    AHCExecuteTask *t
+        = new AHCExecuteTask(_receiver, AHCommand(node_, data(), sessionId_, AHCommand::Complete), _client->rootTask());
+    connect(t, SIGNAL(finished()), SLOT(commandExecuted()));
     t->go(true);
 }
 
 void AHCFormDlg::doCancel()
 {
     _ui.busy->start();
-    AHCExecuteTask* t = new AHCExecuteTask(_receiver,AHCommand(node_,sessionId_,AHCommand::Cancel), _client->rootTask());
-    connect(t,SIGNAL(finished()),SLOT(commandExecuted()));
+    AHCExecuteTask *t
+        = new AHCExecuteTask(_receiver, AHCommand(node_, sessionId_, AHCommand::Cancel), _client->rootTask());
+    connect(t, SIGNAL(finished()), SLOT(commandExecuted()));
     t->go(true);
 }
 
@@ -203,4 +191,3 @@ XData AHCFormDlg::data() const
     x.setType(XData::Data_Submit);
     return x;
 }
-
