@@ -13,18 +13,18 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
+#include "ahcommand.h"
+
+#include "xmpp_xdata.h"
+
 #include <QDomDocument>
 #include <QDomElement>
 #include <QSharedData>
 
-#include "ahcommand.h"
-#include "xmpp_xdata.h"
-
 #define AHC_NS "http://jabber.org/protocol/commands"
 #define XMPPSTANZA_NS "urn:ietf:params:xml:ns:xmpp-stanzas"
 
@@ -34,73 +34,55 @@ using namespace XMPP;
 // AHCommand: The class representing an Ad-Hoc command request or reply.
 // --------------------------------------------------------------------------
 
-class AHCommandPrivate : public QSharedData
-{
+class AHCommandPrivate : public QSharedData {
 public:
-    QString node;
-    bool hasData = false;
-    XMPP::XData data;
-    AHCommand::Status status = AHCommand::NoStatus;
-    AHCommand::Action defaultAction = AHCommand::NoAction;
+    QString               node;
+    bool                  hasData = false;
+    XMPP::XData           data;
+    AHCommand::Status     status        = AHCommand::NoStatus;
+    AHCommand::Action     defaultAction = AHCommand::NoAction;
     AHCommand::ActionList actions;
-    AHCommand::Action action = AHCommand::NoAction;
-    QString sessionId;
-    AHCError error;
-    AHCommand::Note note;
+    AHCommand::Action     action = AHCommand::NoAction;
+    QString               sessionId;
+    AHCError              error;
+    AHCommand::Note       note;
 
-    AHCommandPrivate() {}
+    AHCommandPrivate() { }
     AHCommandPrivate(const AHCommandPrivate &other) :
-        QSharedData(other),
-        node(other.node),
-        hasData(other.hasData),
-        data(other.data),
-        status(other.status),
-        defaultAction(other.defaultAction),
-        actions(other.actions),
-        action(other.action),
-        sessionId(other.sessionId),
-        error(other.error),
-        note(other.note)
+        QSharedData(other), node(other.node), hasData(other.hasData), data(other.data), status(other.status),
+        defaultAction(other.defaultAction), actions(other.actions), action(other.action), sessionId(other.sessionId),
+        error(other.error), note(other.note)
     {
-
     }
     ~AHCommandPrivate() { }
 };
 
-AHCommand::AHCommand() :
-    d(new AHCommandPrivate)
-{
+AHCommand::AHCommand() : d(new AHCommandPrivate) { }
 
-}
-
-AHCommand::AHCommand(const QString& node, const QString& sessionId, Action action) :
-    d(new AHCommandPrivate)
+AHCommand::AHCommand(const QString &node, const QString &sessionId, Action action) : d(new AHCommandPrivate)
 {
-    d->node = node;
-    d->action = action;
+    d->node      = node;
+    d->action    = action;
     d->sessionId = sessionId;
 }
 
-AHCommand::AHCommand(const QString& node, XData data, const QString& sessionId, Action action) :
-    d(new AHCommandPrivate)
+AHCommand::AHCommand(const QString &node, XData data, const QString &sessionId, Action action) : d(new AHCommandPrivate)
 {
-    d->node = node;
-    d->action = action;
+    d->node      = node;
+    d->action    = action;
     d->sessionId = sessionId;
 
     d->hasData = true;
-    d->data = data;
-
+    d->data    = data;
 }
 
-AHCommand::AHCommand(const QDomElement& q) :
-    d(new AHCommandPrivate)
+AHCommand::AHCommand(const QDomElement &q) : d(new AHCommandPrivate)
 {
     // Parse attributes
     QString status = q.attribute("status");
     setStatus(string2status(status));
-    d->node = q.attribute("node");
-    d->action = string2action(q.attribute("action"));
+    d->node      = q.attribute("node");
+    d->action    = string2action(q.attribute("action"));
     d->sessionId = q.attribute("sessionid");
 
     // Parse the body
@@ -112,7 +94,7 @@ AHCommand::AHCommand(const QDomElement& q) :
         QString tag = e.tagName();
 
         // A form
-        if (tag == "x" && e.attribute("xmlns") =="jabber:x:data") {
+        if (tag == "x" && e.namespaceURI() == "jabber:x:data") {
             d->data.fromXml(e);
             d->hasData = true;
         }
@@ -144,15 +126,9 @@ AHCommand::AHCommand(const QDomElement& q) :
     }
 }
 
-AHCommand::AHCommand(const AHCommand &other) :
-    d(other.d)
-{
-}
+AHCommand::AHCommand(const AHCommand &other) : d(other.d) { }
 
-AHCommand::~AHCommand()
-{
-
-}
+AHCommand::~AHCommand() { }
 
 AHCommand &AHCommand::operator=(const AHCommand &other)
 {
@@ -182,16 +158,15 @@ bool AHCommand::hasNote() const { return !d->note.text.isEmpty(); }
 
 const AHCommand::Note &AHCommand::note() const { return d->note; }
 
-QDomElement AHCommand::toXml(QDomDocument* doc, bool submit) const
+QDomElement AHCommand::toXml(QDomDocument *doc, bool submit) const
 {
-    QDomElement command = doc->createElement("command");
-    command.setAttribute("xmlns", AHC_NS);
+    QDomElement command = doc->createElementNS(AHC_NS, "command");
     if (d->status != NoStatus)
-        command.setAttribute("status",status2string(status()));
+        command.setAttribute("status", status2string(status()));
     if (hasData())
         command.appendChild(data().toXml(doc, submit));
     if (d->action != Execute)
-        command.setAttribute("action",action2string(d->action));
+        command.setAttribute("action", action2string(d->action));
     command.setAttribute("node", d->node);
     if (!d->sessionId.isEmpty())
         command.setAttribute("sessionid", d->sessionId);
@@ -199,72 +174,70 @@ QDomElement AHCommand::toXml(QDomDocument* doc, bool submit) const
     return command;
 }
 
-
-AHCommand AHCommand::formReply(const AHCommand& c, const XData& data)
+AHCommand AHCommand::formReply(const AHCommand &c, const XData &data)
 {
     AHCommand r(c.node(), data, c.sessionId());
     r.setStatus(AHCommand::Executing);
     return r;
 }
 
-AHCommand AHCommand::formReply(const AHCommand& c, const XData& data, const QString& sessionId)
+AHCommand AHCommand::formReply(const AHCommand &c, const XData &data, const QString &sessionId)
 {
     AHCommand r(c.node(), data, sessionId);
     r.setStatus(AHCommand::Executing);
     return r;
 }
 
-AHCommand AHCommand::canceledReply(const AHCommand& c)
+AHCommand AHCommand::canceledReply(const AHCommand &c)
 {
     AHCommand r(c.node(), c.sessionId());
     r.setStatus(Canceled);
     return r;
 }
 
-AHCommand AHCommand::completedReply(const AHCommand& c)
+AHCommand AHCommand::completedReply(const AHCommand &c)
 {
     AHCommand r(c.node(), c.sessionId());
     r.setStatus(Completed);
     return r;
 }
 
-AHCommand AHCommand::completedReply(const AHCommand& c, const XData& d)
+AHCommand AHCommand::completedReply(const AHCommand &c, const XData &d)
 {
     AHCommand r(c.node(), d, c.sessionId());
     r.setStatus(Completed);
     return r;
 }
 
-//AHCommand AHCommand::errorReply(const AHCommand& c, const AHCError& error)
+// AHCommand AHCommand::errorReply(const AHCommand& c, const AHCError& error)
 //{
 //    AHCommand r(c.node(), c.sessionId());
 //    r.setError(error);
 //    return r;
 //}
 
-void AHCommand::setStatus(Status s)
-{
-    d->status = s;
-}
+void AHCommand::setStatus(Status s) { d->status = s; }
 
-void AHCommand::setError(const AHCError& e)
-{
-    d->error = e;
-}
+void AHCommand::setError(const AHCError &e) { d->error = e; }
 
-void AHCommand::setDefaultAction(Action a)
-{
-    d->defaultAction = a;
-}
+void AHCommand::setDefaultAction(Action a) { d->defaultAction = a; }
 
 QString AHCommand::status2string(Status status)
 {
     QString s;
     switch (status) {
-        case Executing : s = "executing"; break;
-        case Completed : s = "completed"; break;
-        case Canceled : s = "canceled"; break;
-        case NoStatus : s = ""; break;
+    case Executing:
+        s = "executing";
+        break;
+    case Completed:
+        s = "completed";
+        break;
+    case Canceled:
+        s = "canceled";
+        break;
+    case NoStatus:
+        s = "";
+        break;
     }
     return s;
 }
@@ -273,16 +246,25 @@ QString AHCommand::action2string(Action action)
 {
     QString s;
     switch (action) {
-        case Prev : s = "prev"; break;
-        case Next : s = "next"; break;
-        case Cancel : s = "cancel"; break;
-        case Complete : s = "complete"; break;
-        default: break;
+    case Prev:
+        s = "prev";
+        break;
+    case Next:
+        s = "next";
+        break;
+    case Cancel:
+        s = "cancel";
+        break;
+    case Complete:
+        s = "complete";
+        break;
+    default:
+        break;
     }
     return s;
 }
 
-AHCommand::Action AHCommand::string2action(const QString& s)
+AHCommand::Action AHCommand::string2action(const QString &s)
 {
     if (s == "prev")
         return Prev;
@@ -296,7 +278,7 @@ AHCommand::Action AHCommand::string2action(const QString& s)
         return Execute;
 }
 
-AHCommand::Status AHCommand::string2status(const QString& s)
+AHCommand::Status AHCommand::string2status(const QString &s)
 {
     if (s == "canceled")
         return Canceled;
@@ -308,30 +290,30 @@ AHCommand::Status AHCommand::string2status(const QString& s)
         return NoStatus;
 }
 
-
 // --------------------------------------------------------------------------
 // AHCError: The class representing an Ad-Hoc command error
 // --------------------------------------------------------------------------
 
-AHCError::AHCError(ErrorType t) : type_(t)
-{
-}
+AHCError::AHCError(ErrorType t) : type_(t) { }
 
-AHCError::AHCError(const QDomElement& e) : type_(None)
+AHCError::AHCError(const QDomElement &e) : type_(None)
 {
     QString errorGeneral = "", errorSpecific = "";
 
-    for(QDomNode n = e.firstChild(); !n.isNull(); n = n.nextSibling()) {
+    for (QDomNode n = e.firstChild(); !n.isNull(); n = n.nextSibling()) {
         QDomElement i = n.toElement();
-        if(i.isNull())
+        if (i.isNull())
             continue;
 
         QString tag = i.tagName();
 
-        if ((tag == "bad-request" || tag == "not-allowed" || tag == "forbidden" || tag == "forbidden" || tag == "item-not-found" || tag == "feature-not-implemented") && e.attribute("xmlns") == XMPPSTANZA_NS) {
+        if ((tag == "bad-request" || tag == "not-allowed" || tag == "forbidden" || tag == "forbidden"
+             || tag == "item-not-found" || tag == "feature-not-implemented")
+            && e.namespaceURI() == XMPPSTANZA_NS) {
             errorGeneral = tag;
-        }
-        else if ((tag == "malformed-action" || tag == "bad-action" || tag == "bad-locale" || tag == "bad-payload" || tag == "bad-sessionid" || tag == "session-expired") && e.attribute("xmlns") == AHC_NS) {
+        } else if ((tag == "malformed-action" || tag == "bad-action" || tag == "bad-locale" || tag == "bad-payload"
+                    || tag == "bad-sessionid" || tag == "session-expired")
+                   && e.namespaceURI() == AHC_NS) {
             errorSpecific = tag;
         }
     }
@@ -339,7 +321,7 @@ AHCError::AHCError(const QDomElement& e) : type_(None)
     type_ = strings2error(errorGeneral, errorSpecific);
 }
 
-QDomElement AHCError::toXml(QDomDocument* doc) const
+QDomElement AHCError::toXml(QDomDocument *doc) const
 {
     QDomElement err = doc->createElement("error");
 
@@ -347,52 +329,50 @@ QDomElement AHCError::toXml(QDomDocument* doc) const
     if (type_ != None) {
         QString desc, specificCondition = "";
         switch (type_) {
-            case MalformedAction:
-                desc = "bad-request";
-                specificCondition = "malformed-action";
-                break;
-            case BadAction:
-                desc = "bad-request";
-                specificCondition = "bad-action";
-                break;
-            case BadLocale:
-                desc = "bad-request";
-                specificCondition = "bad-locale";
-                break;
-            case BadPayload:
-                desc = "bad-request";
-                specificCondition = "bad-payload";
-                break;
-            case BadSessionID:
-                desc = "bad-request";
-                specificCondition = "bad-sessionid";
-                break;
-            case SessionExpired:
-                desc = "not-allowed";
-                specificCondition = "session-expired";
-                break;
-            case Forbidden:
-                desc = "forbidden";
-                break;
-            case ItemNotFound:
-                desc = "item-not-found";
-                break;
-            case FeatureNotImplemented:
-                desc = "feature-not-implemented";
-                break;
-            case None:
-                break;
+        case MalformedAction:
+            desc              = "bad-request";
+            specificCondition = "malformed-action";
+            break;
+        case BadAction:
+            desc              = "bad-request";
+            specificCondition = "bad-action";
+            break;
+        case BadLocale:
+            desc              = "bad-request";
+            specificCondition = "bad-locale";
+            break;
+        case BadPayload:
+            desc              = "bad-request";
+            specificCondition = "bad-payload";
+            break;
+        case BadSessionID:
+            desc              = "bad-request";
+            specificCondition = "bad-sessionid";
+            break;
+        case SessionExpired:
+            desc              = "not-allowed";
+            specificCondition = "session-expired";
+            break;
+        case Forbidden:
+            desc = "forbidden";
+            break;
+        case ItemNotFound:
+            desc = "item-not-found";
+            break;
+        case FeatureNotImplemented:
+            desc = "feature-not-implemented";
+            break;
+        case None:
+            break;
         }
 
         // General error condition
-        QDomElement generalElement = doc->createElement(desc);
-        generalElement.setAttribute("xmlns", XMPPSTANZA_NS);
+        QDomElement generalElement = doc->createElementNS(XMPPSTANZA_NS, desc);
         err.appendChild(generalElement);
 
         // Specific error condition
         if (!specificCondition.isEmpty()) {
-            QDomElement generalElement = doc->createElement(specificCondition);
-            generalElement.setAttribute("xmlns", AHC_NS);
+            QDomElement generalElement = doc->createElementNS(AHC_NS, specificCondition);
             err.appendChild(generalElement);
         }
     }
@@ -400,7 +380,7 @@ QDomElement AHCError::toXml(QDomDocument* doc) const
     return err;
 }
 
-AHCError::ErrorType AHCError::strings2error(const QString& g, const QString& s)
+AHCError::ErrorType AHCError::strings2error(const QString &g, const QString &s)
 {
     if (s == "malformed-action")
         return MalformedAction;
@@ -423,39 +403,41 @@ AHCError::ErrorType AHCError::strings2error(const QString& g, const QString& s)
     return None;
 }
 
-QString AHCError::error2description(const AHCError& e)
+QString AHCError::error2description(const AHCError &e)
 {
     QString desc;
     switch (e.type()) {
-        case MalformedAction:
-            desc = QString("The responding JID does not understand the specified action");
-            break;
-        case BadAction:
-            desc = QString("The responding JID cannot accept the specified action");
-            break;
-        case BadLocale:
-            desc = QString("The responding JID cannot accept the specified language/locale");
-            break;
-        case BadPayload:
-            desc = QString("The responding JID cannot accept the specified payload (eg the data form did not provide one or more required fields)");
-            break;
-        case BadSessionID:
-            desc = QString("The responding JID cannot accept the specified sessionid");
-            break;
-        case SessionExpired:
-            desc = QString("The requesting JID specified a sessionid that is no longer active (either because it was completed, canceled, or timed out)");
-            break;
-        case Forbidden:
-            desc = QString("The requesting JID is not allowed to execute the command");
-            break;
-        case ItemNotFound:
-            desc = QString("The responding JID cannot find the requested command node");
-            break;
-        case FeatureNotImplemented:
-            desc = QString("The responding JID does not support Ad-hoc commands");
-            break;
-        case None:
-            break;
+    case MalformedAction:
+        desc = QString("The responding JID does not understand the specified action");
+        break;
+    case BadAction:
+        desc = QString("The responding JID cannot accept the specified action");
+        break;
+    case BadLocale:
+        desc = QString("The responding JID cannot accept the specified language/locale");
+        break;
+    case BadPayload:
+        desc = QString("The responding JID cannot accept the specified payload (eg the data form did not provide one "
+                       "or more required fields)");
+        break;
+    case BadSessionID:
+        desc = QString("The responding JID cannot accept the specified sessionid");
+        break;
+    case SessionExpired:
+        desc = QString("The requesting JID specified a sessionid that is no longer active (either because it was "
+                       "completed, canceled, or timed out)");
+        break;
+    case Forbidden:
+        desc = QString("The requesting JID is not allowed to execute the command");
+        break;
+    case ItemNotFound:
+        desc = QString("The responding JID cannot find the requested command node");
+        break;
+    case FeatureNotImplemented:
+        desc = QString("The responding JID does not support Ad-hoc commands");
+        break;
+    case None:
+        break;
     }
     return desc;
 }
