@@ -13,26 +13,18 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "ahcommandserver.h"
+
 #include "ahcservermanager.h"
 
 // --------------------------------------------------------------------------
 // AHCommandServer: The server-side implementation of an Ad-hoc command.
 // --------------------------------------------------------------------------
 
-AHCommandServer::AHCommandServer(AHCServerManager* manager) : manager_(manager)
-{
-    manager_->addServer(this);
-}
-
-AHCommandServer::~AHCommandServer()
-{
-    manager_->removeServer(this);
-}
-
+AHCommandServer::AHCommandServer(AHCServerManager *manager) : manager_(manager) { manager_->addServer(this); }
 
+AHCommandServer::~AHCommandServer() { manager_->removeServer(this); }
