@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -22,29 +21,29 @@
 #define AHCOMMANDSERVER_H
 
 class AHCServerManager;
-class QString;
 class AHCommand;
+class QString;
+
 namespace XMPP {
-    class Jid;
+class Jid;
 }
 
-class AHCommandServer
-{
+class AHCommandServer {
 public:
-    AHCommandServer(AHCServerManager*);
+    AHCommandServer(AHCServerManager *);
     virtual ~AHCommandServer();
 
-    virtual QString name() const = 0;
-    virtual QString node() const = 0;
-    virtual bool isAllowed(const XMPP::Jid&) const { return true; }
-    virtual AHCommand execute(const AHCommand&, const XMPP::Jid& requester) = 0;
-    virtual void cancel(const AHCommand&) { }
+    virtual QString   name() const = 0;
+    virtual QString   node() const = 0;
+    virtual bool      isAllowed(const XMPP::Jid &) const { return true; }
+    virtual AHCommand execute(const AHCommand &, const XMPP::Jid &requester) = 0;
+    virtual void      cancel(const AHCommand &) { }
 
 protected:
-    AHCServerManager* manager() const { return manager_; }
+    AHCServerManager *manager() const { return manager_; }
 
 private:
-    AHCServerManager* manager_;
+    AHCServerManager *manager_;
 };
 
-#endif
+#endif // AHCOMMANDSERVER_H
