@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -27,20 +26,19 @@ class AlertIcon;
 class PsiIcon;
 class QIcon;
 
-class Alertable : public QObject
-{
+class Alertable : public QObject {
     Q_OBJECT
 public:
-    Alertable(QObject* parent = 0);
+    Alertable(QObject *parent = nullptr);
     ~Alertable();
 
-    bool alerting() const;
+    bool  alerting() const;
     QIcon currentAlertFrame() const;
 
-    void setAlert(const PsiIcon* icon);
+    void setAlert(const PsiIcon *icon);
 
 private:
-    AlertIcon* alert_;
+    AlertIcon *alert_;
 };
 
-#endif
+#endif // ALERTABLE_H
