@@ -1,36 +1,34 @@
-#include <QString>
-#include <QLatin1String>
+#include "applicationinfo.h"
+
+#include "activeprofiles.h"
+#ifdef HAVE_CONFIG
+#include "config.h"
+#endif
+#include "profiles.h"
+#include "psiapplication.h"
+#include "systeminfo.h"
+#include "translationmanager.h"
+
+#include <QDesktopServices>
 #include <QDir>
 #include <QFile>
-#include <QSettings>
+#include <QLatin1String>
 #include <QLocale>
-#include <QDesktopServices>
 #include <QMessageBox>
+#include <QSettings>
 #include <QStandardPaths>
-
+#include <QString>
+#ifdef Q_OS_MAC
+#include <CoreServices/CoreServices.h>
+#include <sys/stat.h> // chmod
+#endif
 #ifdef Q_OS_UNIX
 #include <sys/stat.h> // chmod
 #endif
-
 #ifdef Q_OS_WIN
-#include <windows.h>
 #include <shellapi.h>
 #include <shlobj.h>
-#endif
-
-#ifdef Q_OS_MAC
-#include <sys/stat.h> // chmod
-#include <CoreServices/CoreServices.h>
-#endif
-
-#include "psiapplication.h"
-#include "applicationinfo.h"
-#include "systeminfo.h"
-#include "profiles.h"
-#include "activeprofiles.h"
-#include "translationmanager.h"
-#ifdef HAVE_CONFIG
-#include "config.h"
+#include <windows.h>
 #endif
 
 #define xstr(a) str(a)
@@ -42,100 +40,101 @@
 //
 // PROG_SNAME - read as small name, system name, soname, short name, fs name
 
-#define PROG_NAME "Psi+"
-#define PROG_SNAME "psi+"
+#define PROG_NAME CLIENT_NAME
+#define PROG_SNAME CLIENT_SNAME
 #define PROG_VERSION PSI_VERSION
-//#define PROG_VERSION "0.15-dev" " (" __DATE__ ")" //CVS Builds are dated
-//#define PROG_VERSION "0.15";
-#define PROG_CAPS_NODE "http://psi-plus.com"
-#define PROG_IPC_NAME "org.psi-im.Psi"    // must not contain '\\' character on Windows
+#define PROG_CAPS_NODE CLIENT_CAPS_NODE
+#define PROG_IPC_NAME "org.psi-im.Psi" // must not contain '\\' character on Windows
 #define PROG_OPTIONS_NS "http://psi-im.org/options"
 #define PROG_STORAGE_NS "http://psi-im.org/storage"
 #define PROG_FILECACHE_NS "http://psi-im.org/filecache"
 #ifdef Q_OS_MAC
-#define PROG_APPCAST_URL "http://psi-im.org/appcast/psi-mac.xml"
+#define PROG_APPCAST_URL "https://psi-im.org/appcast/psi-mac.xml"
 #else
 #define PROG_APPCAST_URL ""
 #endif
 
-QString ApplicationInfo::name()
-{
-    return PROG_NAME;
-}
+QString ApplicationInfo::name() { return PROG_NAME; }
 
-QLatin1String ApplicationInfo::sname()
-{
-    return QLatin1String(PROG_SNAME);
-}
+QLatin1String ApplicationInfo::sname() { return QLatin1String(PROG_SNAME); }
 
-QString ApplicationInfo::version()
-{
-    return PROG_VERSION;
-}
+QString ApplicationInfo::version() { return PROG_VERSION; }
 
-QString ApplicationInfo::capsNode()
-{
-    return PROG_CAPS_NODE;
-}
+QString ApplicationInfo::capsNode() { return PROG_CAPS_NODE; }
 
-QString ApplicationInfo::osName()
-{
-    return SystemInfo::instance()->os();
-}
+QString ApplicationInfo::osName() { return SystemInfo::instance()->os(); }
 
-QString ApplicationInfo::IPCName()
-{
-    return PROG_IPC_NAME;
-}
+QString ApplicationInfo::IPCName() { return PROG_IPC_NAME; }
 
-QString ApplicationInfo::getAppCastURL()
-{
-    return PROG_APPCAST_URL;
-}
+QString ApplicationInfo::getAppCastURL() { return PROG_APPCAST_URL; }
 
-QString ApplicationInfo::optionsNS()
-{
-    return PROG_OPTIONS_NS;
-}
+QString ApplicationInfo::optionsNS() { return PROG_OPTIONS_NS; }
 
-QString ApplicationInfo::storageNS()
-{
-    return PROG_STORAGE_NS;
-}
+QString ApplicationInfo::storageNS() { return PROG_STORAGE_NS; }
 
-QString ApplicationInfo::fileCacheNS()
-{
-    return PROG_FILECACHE_NS;
-}
+QString ApplicationInfo::fileCacheNS() { return PROG_FILECACHE_NS; }
 
 QStringList ApplicationInfo::getCertificateStoreDirs()
 {
-    QStringList l;
-    l += ApplicationInfo::resourcesDir() + "/certs";
-    l += ApplicationInfo::homeDir(ApplicationInfo::DataLocation) + "/certs";
-    return l;
+#if defined(Q_OS_LINUX) && defined(SHARE_SUFF)
+    // Special hack for correct work of AppImage, snap and flatpak builds
+    static const QString &&additionalPath
+        = QDir().absoluteFilePath(qApp->applicationDirPath() + "/../share/" SHARE_SUFF "/certs");
+#endif
+
+    static const QStringList &&dirs = {
+#if defined(Q_OS_LINUX) && defined(SHARE_SUFF)
+        additionalPath,
+#endif
+        ApplicationInfo::resourcesDir() + "/certs",
+        ApplicationInfo::homeDir(ApplicationInfo::DataLocation) + "/certs"
+    };
+    return dirs;
 }
 
 QStringList ApplicationInfo::dataDirs()
 {
-    const static QStringList dirs = QStringList() << ":" << "." << homeDir(DataLocation)
-                                                  << resourcesDir();
-    return  dirs;
+#if defined(Q_OS_LINUX) && defined(SHARE_SUFF)
+    // Special hack for correct work of AppImage, snap and flatpak builds
+    static const QString &&additionalPath
+        = QDir().absoluteFilePath(qApp->applicationDirPath() + "/../share/" SHARE_SUFF);
+#endif
+
+    static const QStringList &&dirs = {
+#if defined(Q_OS_LINUX) && defined(SHARE_SUFF)
+        additionalPath,
+#endif
+        ":",
+        ".",
+        homeDir(DataLocation),
+        resourcesDir()
+    };
+    return dirs;
 }
 
 QStringList ApplicationInfo::pluginDirs()
 {
-    QStringList l;
-    l += ApplicationInfo::resourcesDir() + "/plugins";
-    l += homeDir(ApplicationInfo::DataLocation) + "/plugins";
-    l += libDir() + "/plugins";
-    return l;
+#if defined(Q_OS_LINUX) && defined(SHARE_SUFF)
+    // Special hack for correct work of AppImage, snap and flatpak builds
+    static const QString &&additionalPath
+        = QDir().absoluteFilePath(qApp->applicationDirPath() + "/../lib/" SHARE_SUFF "/plugins");
+#endif
+
+    static const QStringList &&dirs = {
+#if defined(Q_OS_LINUX) && defined(SHARE_SUFF)
+        additionalPath,
+#endif
+        ApplicationInfo::resourcesDir() + "/plugins",
+        homeDir(ApplicationInfo::DataLocation) + "/plugins",
+        libDir() + "/plugins"
+    };
+    return dirs;
 }
 
 QString ApplicationInfo::getCertificateStoreSaveDir()
 {
     QDir certsave(homeDir(DataLocation) + "/certs");
-    if(!certsave.exists()) {
+    if (!certsave.exists()) {
         QDir home(homeDir(DataLocation));
         home.mkdir("certs");
     }
@@ -145,41 +144,40 @@ QString ApplicationInfo::getCertificateStoreSaveDir()
 
 QString ApplicationInfo::resourcesDir()
 {
-#if defined(Q_OS_WIN)
+#if defined(Q_OS_WIN) || defined(Q_OS_HAIKU)
     return qApp->applicationDirPath();
 #elif defined(Q_OS_MAC)
     // FIXME: Clean this up (remko)
     // System routine locates resource files. We "know" that Psi.icns is
     // in the Resources directory.
-    QString resourcePath;
-    CFBundleRef mainBundle = CFBundleGetMainBundle();
-    CFStringRef resourceCFStringRef = CFStringCreateWithCString(NULL,
-                                    "application.icns", kCFStringEncodingASCII);
-    CFURLRef resourceURLRef = CFBundleCopyResourceURL(mainBundle,
-                                            resourceCFStringRef, NULL, NULL);
+    QString     resourcePath;
+    CFBundleRef mainBundle          = CFBundleGetMainBundle();
+#ifdef PSI_PLUS
+    const char *appIconName         = "application-plus.icns";
+#else
+    const char *appIconName = "application.icns";
+#endif
+    CFStringRef resourceCFStringRef = CFStringCreateWithCString(nullptr, appIconName, kCFStringEncodingASCII);
+    CFURLRef    resourceURLRef      = CFBundleCopyResourceURL(mainBundle, resourceCFStringRef, nullptr, nullptr);
     if (resourceURLRef) {
-        CFStringRef resourcePathStringRef = CFURLCopyFileSystemPath(
-                    resourceURLRef, kCFURLPOSIXPathStyle);
-        const char* resourcePathCString = CFStringGetCStringPtr(
-                    resourcePathStringRef, kCFStringEncodingASCII);
+        CFStringRef resourcePathStringRef = CFURLCopyFileSystemPath(resourceURLRef, kCFURLPOSIXPathStyle);
+        const char *resourcePathCString   = CFStringGetCStringPtr(resourcePathStringRef, kCFStringEncodingASCII);
         if (resourcePathCString) {
             resourcePath = resourcePathCString;
-        }
-        else { // CFStringGetCStringPtr failed; use fallback conversion
-            CFIndex bufferLength = CFStringGetLength(resourcePathStringRef) + 1;
-            char* resourcePathCString = new char[ bufferLength ];
-            Boolean conversionSuccess = CFStringGetCString(
-                        resourcePathStringRef, resourcePathCString,
-                        bufferLength, kCFStringEncodingASCII);
+        } else { // CFStringGetCStringPtr failed; use fallback conversion
+            CFIndex bufferLength        = CFStringGetLength(resourcePathStringRef) + 1;
+            char *  resourcePathCString = new char[bufferLength];
+            Boolean conversionSuccess
+                = CFStringGetCString(resourcePathStringRef, resourcePathCString, bufferLength, kCFStringEncodingASCII);
             if (conversionSuccess) {
                 resourcePath = resourcePathCString;
             }
-            delete [] resourcePathCString;  // I own this
+            delete[] resourcePathCString; // I own this
         }
-        CFRelease( resourcePathStringRef ); // I own this
+        CFRelease(resourcePathStringRef); // I own this
     }
     // Remove the tail component of the path
-    if (! resourcePath.isNull()) {
+    if (!resourcePath.isNull()) {
         QFileInfo fileInfo(resourcePath);
         resourcePath = fileInfo.absolutePath();
     }
@@ -191,7 +189,7 @@ QString ApplicationInfo::resourcesDir()
 
 QString ApplicationInfo::libDir()
 {
-#if defined(Q_OS_UNIX)
+#if defined(Q_OS_UNIX) && !defined(Q_OS_HAIKU)
     return PSI_LIBDIR;
 #else
     return QCoreApplication::applicationDirPath();
@@ -199,9 +197,9 @@ QString ApplicationInfo::libDir()
 }
 
 /** \brief return psi's private read write data directory
-  * unix+mac: $HOME/.psi
-  * environment variable "PSIDATADIR" overrides
-  */
+ * unix+mac: $HOME/.psi
+ * environment variable "PSIDATADIR" overrides
+ */
 QString ApplicationInfo::homeDir(ApplicationInfo::HomedirType type)
 {
     static QString configDir_;
@@ -213,11 +211,11 @@ QString ApplicationInfo::homeDir(ApplicationInfo::HomedirType type)
         configDir_ = QString::fromLocal8Bit(getenv("PSIDATADIR"));
 
         if (configDir_.isEmpty()) {
-#if defined Q_OS_WIN
-            QString base = ApplicationInfo::isPortable()? QCoreApplication::applicationDirPath() : "";
+#if defined(Q_OS_WIN)
+            QString base = ApplicationInfo::isPortable() ? QCoreApplication::applicationDirPath() : "";
             if (base.isEmpty()) {
                 wchar_t path[MAX_PATH];
-                if (SHGetFolderPathW(NULL, CSIDL_APPDATA, NULL, 0, path) == S_OK) {
+                if (SHGetFolderPathW(nullptr, CSIDL_APPDATA, nullptr, 0, path) == S_OK) {
                     configDir_ = QString::fromWCharArray(path) + "\\" + name();
                 } else {
                     configDir_ = QDir::homePath() + "/" + name();
@@ -232,11 +230,11 @@ QString ApplicationInfo::homeDir(ApplicationInfo::HomedirType type)
             QDir configDir(configDir_);
             QDir cacheDir(cacheDir_);
             QDir dataDir(dataDir_);
-#elif defined Q_OS_MAC
+#elif defined(Q_OS_MAC)
             QDir configDir(QDir::homePath() + "/Library/Application Support/" + name());
             QDir cacheDir(QDir::homePath() + "/Library/Caches/" + name());
             QDir dataDir(configDir);
-#elif defined HAVE_FREEDESKTOP
+#elif defined(HAVE_FREEDESKTOP)
 
             QString XdgConfigHome(QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation));
             QString XdgDataHome(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation));
@@ -255,10 +253,14 @@ QString ApplicationInfo::homeDir(ApplicationInfo::HomedirType type)
             QDir dataDir(XdgDataHome + "/" + sname());
             QDir cacheDir(XdgCacheHome + "/" + sname());
 
+#elif defined(Q_OS_HAIKU)
+            QDir configDir(QDir::homePath() + "/config/settings/Qt/.config/" + sname());
+            QDir cacheDir(QDir::homePath() + "/config/cache/" + sname());
+            QDir dataDir(configDir);
 #endif
             configDir_ = configDir.path();
-            cacheDir_ = cacheDir.path();
-            dataDir_ = dataDir.path();
+            cacheDir_  = cacheDir.path();
+            dataDir_   = dataDir.path();
 
             if (!dataDir.exists()) {
                 dataDir.mkpath(".");
@@ -266,15 +268,14 @@ QString ApplicationInfo::homeDir(ApplicationInfo::HomedirType type)
             if (!cacheDir.exists()) {
                 cacheDir.mkpath(".");
             }
-        }
-        else {
+        } else {
             cacheDir_ = configDir_;
-            dataDir_ = configDir_;
+            dataDir_  = configDir_;
         }
     }
 
     QString ret;
-    switch(type) {
+    switch (type) {
     case ApplicationInfo::ConfigLocation:
         ret = configDir_;
         break;
@@ -314,37 +315,38 @@ QString ApplicationInfo::makeSubprofilePath(const QString &path, ApplicationInfo
     return QString();
 }
 
-QString ApplicationInfo::historyDir()
+QString ApplicationInfo::historyDir() { return makeSubprofilePath("history", ApplicationInfo::DataLocation); }
+
+QString ApplicationInfo::vCardDir() { return makeSubprofilePath("vcard", ApplicationInfo::CacheLocation); }
+
+QString ApplicationInfo::bobDir() { return makeSubhomePath("bob", ApplicationInfo::CacheLocation); }
+
+QString ApplicationInfo::documentsDir()
 {
-    return makeSubprofilePath("history", ApplicationInfo::DataLocation);
+    QString docDir(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/" + name());
+    QDir    d(docDir);
+    if (!d.exists()) {
+        if (!d.mkpath("."))
+            return QString();
+    }
+    return docDir;
 }
 
-QString ApplicationInfo::vCardDir()
-{
-    return makeSubprofilePath("vcard", ApplicationInfo::CacheLocation);
-}
-
-QString ApplicationInfo::bobDir()
-{
-    return makeSubhomePath("bob", ApplicationInfo::CacheLocation);
-}
-
-QString ApplicationInfo::profilesDir(ApplicationInfo::HomedirType type)
-{
-    return makeSubhomePath("profiles", type);
-}
+QString ApplicationInfo::profilesDir(ApplicationInfo::HomedirType type) { return makeSubhomePath("profiles", type); }
 
 QString ApplicationInfo::currentProfileDir(ApplicationInfo::HomedirType type)
 {
     return pathToProfile(activeProfile, type);
 }
 
+QString ApplicationInfo::desktopFileBaseName() { return QLatin1String(xstr(APP_BIN_NAME) ".desktop"); }
+
 QString ApplicationInfo::desktopFile()
 {
     QString dFile;
-    const QString _desktopFile(xstr(APP_PREFIX) "/share/applications/" xstr(APP_BIN_NAME) ".desktop");
-    QFile f(_desktopFile);
-    if(f.open(QIODevice::ReadOnly)) {
+    auto    _desktopFile = QString(xstr(APP_PREFIX) "/share/applications/") + desktopFileBaseName();
+    QFile   f(_desktopFile);
+    if (f.open(QIODevice::ReadOnly)) {
         dFile = QString::fromUtf8(f.readAll());
     }
     return dFile;
@@ -352,7 +354,7 @@ QString ApplicationInfo::desktopFile()
 
 bool ApplicationInfo::isPortable()
 {
-    static bool portable = QFileInfo(QCoreApplication::applicationFilePath()).fileName()
-                           .toLower().indexOf("portable") != -1;
+    static bool portable
+        = QFileInfo(QCoreApplication::applicationFilePath()).fileName().toLower().indexOf("portable") != -1;
     return portable;
 }
