@@ -1,6 +1,6 @@
 /*
  * bob.cpp - Bits of Binary server and manager
- * Copyright (C) 2010 Rion
+ * Copyright (C) 2010  Sergey Ilinykh
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -12,28 +12,27 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "bobfilecache.h"
+
 #include "applicationinfo.h"
 #include "filecache.h"
+
 #include <QApplication>
 
 using namespace XMPP;
 
-
-BoBFileCache::BoBFileCache()
-    : BoBCache(0)
+BoBFileCache::BoBFileCache() : BoBCache(nullptr)
 {
     setParent(QApplication::instance());
     _fileCache = new FileCache(ApplicationInfo::bobDir(), this);
 }
 
-BoBFileCache* BoBFileCache::instance()
+BoBFileCache *BoBFileCache::instance()
 {
     if (!_instance) {
         _instance = new BoBFileCache;
@@ -45,15 +44,15 @@ void BoBFileCache::put(const BoBData &data)
 {
     QVariantMap md;
     md.insert(QLatin1String("type"), data.type());
-    _fileCache->append(data.cid(), data.data(), md, data.maxAge());
+    _fileCache->append(data.hash(), data.data(), md, data.maxAge());
 }
 
-BoBData BoBFileCache::get(const QString &cid)
+BoBData BoBFileCache::get(const Hash &h)
 {
-    FileCacheItem *item = _fileCache->get(cid);
-    BoBData bd;
+    FileCacheItem *item = _fileCache->get(h);
+    BoBData        bd;
     if (item) {
-        bd.setCid(item->id());
+        bd.setHash(h);
         bd.setData(item->data());
         bd.setMaxAge(item->maxAge());
         QVariantMap md = item->metadata();
@@ -62,4 +61,4 @@ BoBData BoBFileCache::get(const QString &cid)
     return bd;
 }
 
-BoBFileCache* BoBFileCache::_instance = 0;
+BoBFileCache *BoBFileCache::_instance = nullptr;
