@@ -13,37 +13,34 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "bookmarkmanagedlg.h"
 
-#include <QStandardItemModel>
-#include <QPushButton>
+#include "bookmarkmanager.h"
+#include "fileutil.h"
+#include "iconset.h"
+#include "psiaccount.h"
+
 #include <QAction>
 #include <QFile>
 #include <QMessageBox>
+#include <QPushButton>
+#include <QStandardItemModel>
 
-#include "bookmarkmanager.h"
-#include "psiaccount.h"
-#include "fileutil.h"
-#include "iconset.h"
-
-BookmarkManageDlg::BookmarkManageDlg(PsiAccount* account)
-    : QDialog()
-    , account_(account)
-    , model_(0)
+BookmarkManageDlg::BookmarkManageDlg(PsiAccount *account) : QDialog(), account_(account), model_(nullptr)
 {
     setAttribute(Qt::WA_DeleteOnClose, true);
-    setWindowFlags(Qt::Dialog | Qt::WindowTitleHint | Qt::WindowMinimizeButtonHint | Qt::WindowMaximizeButtonHint | Qt::WindowCloseButtonHint | Qt::CustomizeWindowHint);
+    setWindowFlags(Qt::Dialog | Qt::WindowTitleHint | Qt::WindowMinMaxButtonsHint | Qt::WindowCloseButtonHint
+                   | Qt::CustomizeWindowHint);
     ui_.setupUi(this);
     setWindowIcon(IconsetFactory::icon("psi/bookmarks").icon());
 
     account_->dialogRegister(this);
 
-    QAction* removeBookmarkAction = new QAction(this);
+    QAction *removeBookmarkAction = new QAction(this);
     connect(removeBookmarkAction, SIGNAL(triggered()), SLOT(removeBookmark()));
     removeBookmarkAction->setShortcuts(QKeySequence::Delete);
     ui_.listView->addAction(removeBookmarkAction);
@@ -55,22 +52,24 @@ BookmarkManageDlg::BookmarkManageDlg(PsiAccount* account)
     connect(ui_.pb_import, SIGNAL(clicked()), SLOT(importBookmarks()));
     connect(ui_.pb_export, SIGNAL(clicked()), SLOT(exportBookmarks()));
 
-    addButton_    = ui_.bookmarkButtonBox->addButton(tr("&Add"),    QDialogButtonBox::ActionRole);
+    addButton_    = ui_.bookmarkButtonBox->addButton(tr("&Add"), QDialogButtonBox::ActionRole);
     removeButton_ = ui_.bookmarkButtonBox->addButton(tr("&Remove"), QDialogButtonBox::DestructiveRole);
-    joinButton_   = ui_.bookmarkButtonBox->addButton(tr("&Join"),   QDialogButtonBox::ActionRole);
+    joinButton_   = ui_.bookmarkButtonBox->addButton(tr("&Join"), QDialogButtonBox::ActionRole);
     connect(addButton_, SIGNAL(clicked()), SLOT(addBookmark()));
     connect(removeButton_, SIGNAL(clicked()), SLOT(removeBookmark()));
     connect(joinButton_, SIGNAL(clicked()), SLOT(joinCurrentRoom()));
 
     model_ = new QStandardItemModel(this);
     ui_.listView->setModel(model_);
-    connect(ui_.listView->itemDelegate(), SIGNAL(closeEditor(QWidget*, QAbstractItemDelegate::EndEditHint)), SLOT(closeEditor(QWidget*, QAbstractItemDelegate::EndEditHint)));
-    connect(ui_.listView->selectionModel(), SIGNAL(selectionChanged(const QItemSelection&, const QItemSelection&)), SLOT(selectionChanged(const QItemSelection&, const QItemSelection&)));
+    connect(ui_.listView->itemDelegate(), SIGNAL(closeEditor(QWidget *, QAbstractItemDelegate::EndEditHint)),
+            SLOT(closeEditor(QWidget *, QAbstractItemDelegate::EndEditHint)));
+    connect(ui_.listView->selectionModel(), SIGNAL(selectionChanged(const QItemSelection &, const QItemSelection &)),
+            SLOT(selectionChanged(const QItemSelection &, const QItemSelection &)));
 
-    connect(ui_.host, SIGNAL(textEdited(const QString&)), SLOT(updateCurrentItem()));
-    connect(ui_.room, SIGNAL(textEdited(const QString&)), SLOT(updateCurrentItem()));
-    connect(ui_.nickname, SIGNAL(textEdited(const QString&)), SLOT(updateCurrentItem()));
-    connect(ui_.password, SIGNAL(textEdited(const QString&)), SLOT(updateCurrentItem()));
+    connect(ui_.host, SIGNAL(textEdited(const QString &)), SLOT(updateCurrentItem()));
+    connect(ui_.room, SIGNAL(textEdited(const QString &)), SLOT(updateCurrentItem()));
+    connect(ui_.nickname, SIGNAL(textEdited(const QString &)), SLOT(updateCurrentItem()));
+    connect(ui_.password, SIGNAL(textEdited(const QString &)), SLOT(updateCurrentItem()));
     connect(ui_.autoJoin, SIGNAL(currentIndexChanged(int)), SLOT(updateCurrentItem()));
 
     loadBookmarks();
@@ -79,21 +78,16 @@ BookmarkManageDlg::BookmarkManageDlg(PsiAccount* account)
     selectionChanged(dummy, dummy);
 }
 
-BookmarkManageDlg::~BookmarkManageDlg()
-{
-    account_->dialogUnregister(this);
-}
+BookmarkManageDlg::~BookmarkManageDlg() { account_->dialogUnregister(this); }
 
-void BookmarkManageDlg::reject()
-{
-    QDialog::reject();
-}
+void BookmarkManageDlg::reject() { QDialog::reject(); }
 
 void BookmarkManageDlg::accept()
 {
-    QStandardItem* item = model_->item(ui_.listView->currentIndex().row());
-    if(item && item->data(Qt::DisplayRole).toString().isEmpty())
-        item->setData(QVariant(item->data(JidRole)), Qt::DisplayRole);
+    QStandardItem *item = model_->item(ui_.listView->currentIndex().row());
+    if (item)
+        if (item->data(Qt::DisplayRole).toString().isEmpty())
+            item->setData(QVariant(item->data(JidRole)), Qt::DisplayRole);
 
     if (account_->checkConnected(this)) {
         saveBookmarks();
@@ -105,23 +99,21 @@ void BookmarkManageDlg::loadBookmarks()
 {
     model_->clear();
 
-    foreach(ConferenceBookmark c, account_->bookmarkManager()->conferences()) {
-        QStandardItem* item = new QStandardItem(c.name());
+    for (ConferenceBookmark c : account_->bookmarkManager()->conferences()) {
+        QStandardItem *item = new QStandardItem(c.name());
         item->setData(QVariant(c.jid().full()), JidRole);
-        item->setData(QVariant(c.autoJoin()),   AutoJoinRole);
-        item->setData(QVariant(c.nick()),       NickRole);
-        item->setData(QVariant(c.password()),   PasswordRole);
+        item->setData(QVariant(c.autoJoin()), AutoJoinRole);
+        item->setData(QVariant(c.nick()), NickRole);
+        item->setData(QVariant(c.password()), PasswordRole);
         appendItem(item);
     }
 }
 
-ConferenceBookmark BookmarkManageDlg::bookmarkFor(const QModelIndex& index) const
+ConferenceBookmark BookmarkManageDlg::bookmarkFor(const QModelIndex &index) const
 {
-    return ConferenceBookmark(index.data(Qt::DisplayRole).toString(),
-                              index.data(JidRole).toString(),
-                              (ConferenceBookmark::JoinType)index.data(AutoJoinRole).toInt(),
-                              index.data(NickRole).toString(),
-                              index.data(PasswordRole).toString());
+    return ConferenceBookmark(index.data(Qt::DisplayRole).toString(), index.data(JidRole).toString(),
+                              ConferenceBookmark::JoinType(index.data(AutoJoinRole).toInt()),
+                              index.data(NickRole).toString(), index.data(PasswordRole).toString());
 }
 
 void BookmarkManageDlg::saveBookmarks()
@@ -137,26 +129,23 @@ void BookmarkManageDlg::saveBookmarks()
 
 void BookmarkManageDlg::addBookmark()
 {
-    QStandardItem* item = new QStandardItem(tr("Unnamed"));
+    QStandardItem *item = new QStandardItem(tr("Unnamed"));
     appendItem(item);
     ui_.listView->reset(); // ensure that open editors won't get in our way
     ui_.listView->setCurrentIndex(item->index());
     ui_.listView->edit(item->index());
 }
 
-void BookmarkManageDlg::removeBookmark()
-{
-    model_->removeRow(currentIndex().row());
-}
+void BookmarkManageDlg::removeBookmark() { model_->removeRow(currentIndex().row()); }
 
-void BookmarkManageDlg::closeEditor(QWidget* editor, QAbstractItemDelegate::EndEditHint hint)
+void BookmarkManageDlg::closeEditor(QWidget *editor, QAbstractItemDelegate::EndEditHint hint)
 {
     Q_UNUSED(editor);
 
     if (hint == QAbstractItemDelegate::SubmitModelCache) {
-        QList<QLineEdit*> lineEdits;
+        QList<QLineEdit *> lineEdits;
         lineEdits << ui_.host << ui_.room << ui_.nickname;
-        foreach(QLineEdit* lineEdit, lineEdits) {
+        for (QLineEdit *lineEdit : lineEdits) {
             if (lineEdit->text().isEmpty()) {
                 lineEdit->setFocus();
                 break;
@@ -165,16 +154,17 @@ void BookmarkManageDlg::closeEditor(QWidget* editor, QAbstractItemDelegate::EndE
     }
 }
 
-void BookmarkManageDlg::selectionChanged(const QItemSelection& selected, const QItemSelection& deselected)
+void BookmarkManageDlg::selectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
 {
     QModelIndex current;
     if (!selected.indexes().isEmpty())
         current = selected.indexes().first();
 
-    if(!deselected.isEmpty()) {
-        QStandardItem* item = model_->item(deselected.indexes().first().row());
-        if(item && item->data(Qt::DisplayRole).toString().isEmpty())
-            item->setData(QVariant(item->data(JidRole)), Qt::DisplayRole);
+    if (!deselected.isEmpty()) {
+        QStandardItem *item = model_->item(deselected.indexes().first().row());
+        if (item)
+            if (item->data(Qt::DisplayRole).toString().isEmpty())
+                item->setData(QVariant(item->data(JidRole)), Qt::DisplayRole);
     }
 
     XMPP::Jid jid = XMPP::Jid(current.data(JidRole).toString());
@@ -183,9 +173,9 @@ void BookmarkManageDlg::selectionChanged(const QItemSelection& selected, const Q
     ui_.nickname->setText(current.data(NickRole).toString());
     ui_.password->setText(current.data(PasswordRole).toString());
     ui_.autoJoin->setCurrentIndex(current.data(AutoJoinRole).toInt());
-    QList<QWidget*> editors;
+    QList<QWidget *> editors;
     editors << ui_.host << ui_.room << ui_.nickname << ui_.password << ui_.autoJoin;
-    foreach(QWidget* w, editors) {
+    for (QWidget *w : editors) {
         w->setEnabled(current.isValid());
     }
 
@@ -193,21 +183,18 @@ void BookmarkManageDlg::selectionChanged(const QItemSelection& selected, const Q
     updateCurrentItem();
 }
 
-XMPP::Jid BookmarkManageDlg::jid() const
-{
-    return XMPP::Jid(ui_.room->text(), ui_.host->text());
-}
+XMPP::Jid BookmarkManageDlg::jid() const { return XMPP::Jid(ui_.room->text(), ui_.host->text()); }
 
 void BookmarkManageDlg::updateCurrentItem()
 {
     joinButton_->setEnabled(!jid().domain().isEmpty() && !jid().node().isEmpty() && !ui_.nickname->text().isEmpty());
 
-    QStandardItem* item = model_->item(currentIndex().row());
+    QStandardItem *item = model_->item(currentIndex().row());
     if (item) {
-        item->setData(QVariant(jid().full()),              JidRole);
+        item->setData(QVariant(jid().full()), JidRole);
         item->setData(QVariant(ui_.autoJoin->currentIndex()), AutoJoinRole);
-        item->setData(QVariant(ui_.nickname->text()),      NickRole);
-        item->setData(QVariant(ui_.password->text()),      PasswordRole);
+        item->setData(QVariant(ui_.nickname->text()), NickRole);
+        item->setData(QVariant(ui_.password->text()), PasswordRole);
     }
 }
 
@@ -218,12 +205,9 @@ QModelIndex BookmarkManageDlg::currentIndex() const
     return QModelIndex();
 }
 
-void BookmarkManageDlg::joinCurrentRoom()
-{
-    account_->actionJoin(bookmarkFor(currentIndex()), true);
-}
+void BookmarkManageDlg::joinCurrentRoom() { account_->actionJoin(bookmarkFor(currentIndex()), true); }
 
-void BookmarkManageDlg::appendItem(QStandardItem* item)
+void BookmarkManageDlg::appendItem(QStandardItem *item)
 {
     item->setDragEnabled(true);
     item->setDropEnabled(false);
@@ -233,32 +217,31 @@ void BookmarkManageDlg::appendItem(QStandardItem* item)
 void BookmarkManageDlg::importBookmarks()
 {
     QString fileName = FileUtil::getOpenFileName(this, tr("Import bookmarks"));
-    if(fileName.isEmpty())
+    if (fileName.isEmpty())
         return;
 
     QFile file(fileName);
-    if(file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+    if (file.open(QIODevice::ReadOnly | QIODevice::Text)) {
         QDomDocument doc;
-        QString error;
-        if(doc.setContent(&file, &error)) {
+        QString      error;
+        if (doc.setContent(&file, &error)) {
             QDomElement root = doc.firstChildElement("bookmarks");
-            if(root.isNull())
+            if (root.isNull())
                 return;
             QDomElement elem = root.firstChildElement("conference");
-            while(!elem.isNull()) {
+            while (!elem.isNull()) {
                 ConferenceBookmark c(elem);
 
-                QStandardItem* item = new QStandardItem(c.name());
+                QStandardItem *item = new QStandardItem(c.name());
                 item->setData(QVariant(c.jid().full()), JidRole);
-                item->setData(QVariant(c.autoJoin()),   AutoJoinRole);
-                item->setData(QVariant(c.nick()),       NickRole);
-                item->setData(QVariant(c.password()),   PasswordRole);
+                item->setData(QVariant(c.autoJoin()), AutoJoinRole);
+                item->setData(QVariant(c.nick()), NickRole);
+                item->setData(QVariant(c.password()), PasswordRole);
                 appendItem(item);
 
                 elem = elem.nextSiblingElement("conference");
             }
-        }
-        else {
+        } else {
             QMessageBox::warning(this, tr("Error!"), error);
         }
     }
@@ -267,17 +250,17 @@ void BookmarkManageDlg::importBookmarks()
 void BookmarkManageDlg::exportBookmarks()
 {
     QString fileName = FileUtil::getSaveFileName(this, tr("Export bookmarks"), "bookmarks.txt");
-    if(fileName.isEmpty())
+    if (fileName.isEmpty())
         return;
 
     QFile file(fileName);
-    if(file.open(QIODevice::WriteOnly | QIODevice::Truncate | QIODevice::Text)) {
+    if (file.open(QIODevice::WriteOnly | QIODevice::Truncate | QIODevice::Text)) {
         QDomDocument doc;
-        QDomElement root = doc.createElement("bookmarks");
+        QDomElement  root = doc.createElement("bookmarks");
         doc.appendChild(root);
         for (int row = 0; row < model_->rowCount(); ++row) {
-            QModelIndex index = model_->index(row, 0, QModelIndex());
-            ConferenceBookmark cb = bookmarkFor(index);
+            QModelIndex        index = model_->index(row, 0, QModelIndex());
+            ConferenceBookmark cb    = bookmarkFor(index);
             root.appendChild(cb.toXml(doc));
         }
         file.write(doc.toString().toLocal8Bit());
