@@ -13,73 +13,67 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "bookmarkmanager.h"
 
-#include "xmpp_task.h"
-#include "xmpp_client.h"
-#include "xmpp_xmlcommon.h"
 #include "psiaccount.h"
 #include "psioptions.h"
+#include "xmpp_client.h"
+#include "xmpp_task.h"
+#include "xmpp_xmlcommon.h"
 
 // -----------------------------------------------------------------------------
 
-class BookmarkTask : public Task
-{
+class BookmarkTask : public Task {
 public:
-    BookmarkTask(Task* parent) : Task(parent) {
-    }
+    BookmarkTask(Task *parent) : Task(parent) { }
 
-    void set(const QList<URLBookmark>& urls, const QList<ConferenceBookmark>& conferences) {
+    void set(const QList<URLBookmark> &urls, const QList<ConferenceBookmark> &conferences)
+    {
         // Store it here to take back if necessary
-        urls_ = urls;
+        urls_        = urls;
         conferences_ = conferences;
 
         iq_ = createIQ(doc(), "set", "", id());
 
-        QDomElement prvt = doc()->createElement("query");
-        prvt.setAttribute("xmlns", "jabber:iq:private");
+        QDomElement prvt = doc()->createElementNS("jabber:iq:private", "query");
         iq_.appendChild(prvt);
 
-        QDomElement storage = doc()->createElement("storage");
-        storage.setAttribute("xmlns", "storage:bookmarks");
+        QDomElement storage = doc()->createElementNS("storage:bookmarks", "storage");
         prvt.appendChild(storage);
 
-        foreach(URLBookmark u, urls)
+        for (URLBookmark u : urls)
             storage.appendChild(u.toXml(*doc()));
-        foreach(ConferenceBookmark c, conferences)
+        for (ConferenceBookmark c : conferences)
             storage.appendChild(c.toXml(*doc()));
     }
 
-    void get() {
+    void get()
+    {
         iq_ = createIQ(doc(), "get", "", id());
 
-        QDomElement prvt = doc()->createElement("query");
-        prvt.setAttribute("xmlns", "jabber:iq:private");
+        QDomElement prvt = doc()->createElementNS("jabber:iq:private", "query");
         iq_.appendChild(prvt);
 
-        QDomElement bookmarks = doc()->createElement("storage");
-        bookmarks.setAttribute("xmlns", "storage:bookmarks");
+        QDomElement bookmarks = doc()->createElementNS("storage:bookmarks", "storage");
         prvt.appendChild(bookmarks);
     }
 
-    void onGo() {
-        send(iq_);
-    }
+    void onGo() { send(iq_); }
 
-    bool take(const QDomElement& x) {
-        if(!iqVerify(x, "", id()))
+    bool take(const QDomElement &x)
+    {
+        if (!iqVerify(x, "", id()))
             return false;
 
-        if(x.attribute("type") == "result") {
+        if (x.attribute("type") == "result") {
             QDomElement q = queryTag(x);
             for (QDomNode n = q.firstChild(); !n.isNull(); n = n.nextSibling()) {
                 QDomElement e = n.toElement();
-                if (!e.isNull() && e.tagName() == "storage" && e.attribute("xmlns") == "storage:bookmarks") {
+                if (!e.isNull() && e.tagName() == "storage" && e.namespaceURI() == "storage:bookmarks") {
                     for (QDomNode m = e.firstChild(); !m.isNull(); m = m.nextSibling()) {
                         QDomElement f = m.toElement();
                         if (f.isNull())
@@ -89,8 +83,7 @@ public:
                             URLBookmark u(f);
                             if (!u.isNull())
                                 urls_ += u;
-                        }
-                        else if (f.tagName() == "conference") {
+                        } else if (f.tagName() == "conference") {
                             ConferenceBookmark c(f);
                             if (!c.isNull()) {
                                 conferences_ += c;
@@ -100,41 +93,30 @@ public:
                 }
             }
             setSuccess();
-        }
-        else {
+        } else {
             setError(x);
         }
         return true;
     }
 
-    const QList<URLBookmark>& urls() const {
-        return urls_;
-    }
+    const QList<URLBookmark> &urls() const { return urls_; }
 
-    const QList<ConferenceBookmark>& conferences() const {
-        return conferences_;
-    }
+    const QList<ConferenceBookmark> &conferences() const { return conferences_; }
 
 private:
-    QDomElement iq_;
-    QList<URLBookmark> urls_;
+    QDomElement               iq_;
+    QList<URLBookmark>        urls_;
     QList<ConferenceBookmark> conferences_;
 };
 
 // -----------------------------------------------------------------------------
 
-BookmarkManager::BookmarkManager(PsiAccount* account)
-    : account_(account)
-    , accountAvailable_(false)
-    , isAvailable_(false)
+BookmarkManager::BookmarkManager(PsiAccount *account) : account_(account), accountAvailable_(false), isAvailable_(false)
 {
     connect(account_, SIGNAL(updatedActivity()), SLOT(accountStateChanged()));
 }
 
-bool BookmarkManager::isAvailable() const
-{
-    return isAvailable_;
-}
+bool BookmarkManager::isAvailable() const { return isAvailable_; }
 
 void BookmarkManager::setIsAvailable(bool available)
 {
@@ -144,16 +126,26 @@ void BookmarkManager::setIsAvailable(bool available)
     }
 }
 
-bool BookmarkManager::isBookmarked(const XMPP::Jid &j)
+bool BookmarkManager::isBookmarked(const XMPP::Jid &j) { return indexOfConference(j) >= 0; }
+
+void BookmarkManager::addConference(const ConferenceBookmark &newb)
 {
-    return indexOfConference(j) >= 0;
+    if (!isAvailable_ && !newb.isNull())
+        return;
+    auto it = std::find_if(conferences_.begin(), conferences_.end(),
+                           [newb](auto const &c) { return newb.jid().compare(c.jid(), false); });
+    if (it == conferences_.end()) {
+        auto copy = conferences_;
+        copy.append(newb);
+        setBookmarks(copy);
+    }
 }
 
 void BookmarkManager::removeConference(const XMPP::Jid &j)
 {
     if (isAvailable_) {
         QList<ConferenceBookmark> confs;
-        foreach (ConferenceBookmark c, conferences_) {
+        for (ConferenceBookmark c : conferences_) {
             if (!c.jid().compare(j, false)) {
                 confs.push_back(c);
             }
@@ -162,21 +154,15 @@ void BookmarkManager::removeConference(const XMPP::Jid &j)
     }
 }
 
-QList<URLBookmark> BookmarkManager::urls() const
-{
-    return urls_;
-}
+const QList<URLBookmark> &BookmarkManager::urls() const { return urls_; }
 
-QList<ConferenceBookmark> BookmarkManager::conferences() const
-{
-    return conferences_;
-}
+const QList<ConferenceBookmark> &BookmarkManager::conferences() const { return conferences_; }
 
 int BookmarkManager::indexOfConference(const XMPP::Jid &j) const
 {
     if (isAvailable_) {
         int i = 0;
-        foreach(ConferenceBookmark c, conferences_) {
+        for (ConferenceBookmark c : conferences_) {
             if (c.jid().compare(j, false)) {
                 return i;
             }
@@ -210,41 +196,35 @@ void BookmarkManager::accountStateChanged()
 
 void BookmarkManager::getBookmarks()
 {
-    BookmarkTask* t = new BookmarkTask(account_->client()->rootTask());
-    connect(t,SIGNAL(finished()),SLOT(getBookmarks_finished()));
+    BookmarkTask *t = new BookmarkTask(account_->client()->rootTask());
+    connect(t, SIGNAL(finished()), SLOT(getBookmarks_finished()));
     t->get();
     t->go(true);
 }
 
-void BookmarkManager::setBookmarks(const QList<URLBookmark>& urls, const QList<ConferenceBookmark>& conferences)
+void BookmarkManager::setBookmarks(const QList<URLBookmark> &urls, const QList<ConferenceBookmark> &conferences)
 {
-    BookmarkTask* t = new BookmarkTask(account_->client()->rootTask());
-    connect(t,SIGNAL(finished()),SLOT(setBookmarks_finished()));
-    t->set(urls,conferences);
+    BookmarkTask *t = new BookmarkTask(account_->client()->rootTask());
+    connect(t, SIGNAL(finished()), SLOT(setBookmarks_finished()));
+    t->set(urls, conferences);
     t->go(true);
 }
 
-void BookmarkManager::setBookmarks(const QList<URLBookmark>& urls)
-{
-    setBookmarks(urls, conferences());
-}
+void BookmarkManager::setBookmarks(const QList<URLBookmark> &urls) { setBookmarks(urls, conferences()); }
 
-void BookmarkManager::setBookmarks(const QList<ConferenceBookmark>& conferences)
-{
-    setBookmarks(urls(), conferences);
-}
+void BookmarkManager::setBookmarks(const QList<ConferenceBookmark> &conferences) { setBookmarks(urls(), conferences); }
 
 void BookmarkManager::getBookmarks_finished()
 {
-    BookmarkTask* t = static_cast<BookmarkTask*>(sender());
+    BookmarkTask *t = static_cast<BookmarkTask *>(sender());
     if (t->success()) {
-        bool urlsWereChanged = urls_ != t->urls();
+        bool urlsWereChanged        = urls_ != t->urls();
         bool conferencesWereChanged = conferences_ != t->conferences();
-        urls_ = t->urls();
-        QStringList localMucs = account_->localMucBookmarks();
-        QStringList mucIgnore = account_->ignoreMucBookmarks();
+        urls_                       = t->urls();
+        QStringList   localMucs     = account_->localMucBookmarks();
+        QStringList   mucIgnore     = account_->ignoreMucBookmarks();
         QSet<QString> strippedMucs;
-        for (const QString &m: localMucs) {
+        for (const QString &m : localMucs) {
             Jid j(m);
             if (j.isValid()) {
                 strippedMucs.insert(j.bare());
@@ -252,7 +232,7 @@ void BookmarkManager::getBookmarks_finished()
         }
 
         conferences_ = t->conferences();
-        for (auto &muc: conferences_) {
+        for (auto &muc : conferences_) {
             if (strippedMucs.contains(muc.jid().bare())) {
                 muc.setAutoJoin(ConferenceBookmark::OnlyThisComputer);
             }
@@ -267,25 +247,24 @@ void BookmarkManager::getBookmarks_finished()
             emit conferencesChanged(conferences_);
 
         setIsAvailable(true);
-    }
-    else {
+    } else {
         setIsAvailable(false);
     }
 }
 
 void BookmarkManager::setBookmarks_finished()
 {
-    BookmarkTask* t = static_cast<BookmarkTask*>(sender());
+    BookmarkTask *t = static_cast<BookmarkTask *>(sender());
     if (t->success()) {
         bool conferencesWereChanged = conferences_ != t->conferences();
-        bool urlsWereChanged = urls_ != t->urls();
-        conferences_ = t->conferences();
-        urls_ = t->urls();
+        bool urlsWereChanged        = urls_ != t->urls();
+        conferences_                = t->conferences();
+        urls_                       = t->urls();
 
         QStringList localMucs;
         QStringList ignoreMucs;
 
-        for (const ConferenceBookmark &cb: conferences_) {
+        for (const ConferenceBookmark &cb : conferences_) {
             if (cb.autoJoin() == ConferenceBookmark::OnlyThisComputer) {
                 localMucs.append(cb.jid().withResource(cb.nick()).full());
             }
