@@ -1,6 +1,6 @@
 /*
  * bytearrayreply.cpp - Base class for QNetworReply'es returning QByteArray
- * Copyright (C) 2010 senu, Rion
+ * Copyright (C) 2010  senu, Sergey Ilinykh
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -22,13 +21,10 @@
 
 #include <QTimer>
 
-ByteArrayReply::ByteArrayReply(const QNetworkRequest &request,
-                               const QByteArray &ba, const QString& mimeType,
+ByteArrayReply::ByteArrayReply(const QNetworkRequest &request, const QByteArray &ba, const QString &mimeType,
                                QObject *parent) :
     QNetworkReply(parent),
-    origLen(ba.size()),
-    data(ba),
-    buffer(&data)
+    origLen(ba.size()), data(ba), buffer(&data)
 {
     setRequest(request);
     setOpenMode(QIODevice::ReadOnly);
@@ -51,19 +47,14 @@ ByteArrayReply::ByteArrayReply(const QNetworkRequest &request,
     }
 }
 
-ByteArrayReply::~ByteArrayReply() {
+ByteArrayReply::~ByteArrayReply() { }
 
-}
-
-void ByteArrayReply::abort() {
+void ByteArrayReply::abort()
+{
     // its ok for abort here. webkit calls it in any case on finish
 }
 
-qint64 ByteArrayReply::bytesAvailable() const
-{
-    return data.length() - buffer.pos() + QNetworkReply::bytesAvailable();
-}
-
+qint64 ByteArrayReply::bytesAvailable() const { return data.length() - buffer.pos() + QNetworkReply::bytesAvailable(); }
 
 qint64 ByteArrayReply::readData(char *buf, qint64 maxlen)
 {
@@ -73,13 +64,17 @@ qint64 ByteArrayReply::readData(char *buf, qint64 maxlen)
     return len;
 }
 
-
-bool ByteArrayReply::open(OpenMode mode) {
+bool ByteArrayReply::open(OpenMode mode)
+{
     Q_ASSERT(0); // we don't come here
     return buffer.open(mode);
 }
 
 void ByteArrayReply::signalError()
 {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+    emit errorOccurred(error());
+#else
     emit error(error());
+#endif
 }
