@@ -13,28 +13,26 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef CHATSPLITTER_H
 #define CHATSPLITTER_H
 
-#include <QWidget>
 #include <QList>
+#include <QWidget>
 
 class QSplitter;
 
-class ChatSplitter : public QWidget
-{
+class ChatSplitter : public QWidget {
     Q_OBJECT
 public:
-    ChatSplitter(QWidget* parent);
+    ChatSplitter(QWidget *parent);
 
-    void setOrientation(Qt::Orientation orientation);
-    void addWidget(QWidget* widget);
-    void setSizes(const QList<int>& list);
+    void       setOrientation(Qt::Orientation orientation);
+    void       addWidget(QWidget *widget);
+    void       setSizes(const QList<int> &list);
     QList<int> sizes();
 
 protected:
@@ -48,19 +46,19 @@ public slots:
     void optionsChanged();
 
 private slots:
-    void childDestroyed(QObject* obj);
+    void childDestroyed(QObject *obj);
 
 signals:
-    void splitterMoved(int,int);
+    void splitterMoved(int, int);
 
 private:
-    void updateChildLayout(QWidget* child);
+    void updateChildLayout(QWidget *child);
     void updateLayout();
 
-    bool splitterEnabled_;
-    QList<QWidget*> children_;
-    QSplitter* splitter_;
-    QLayout* layout_;
+    bool             splitterEnabled_;
+    QList<QWidget *> children_;
+    QSplitter *      splitter_;
+    QLayout *        layout_;
 };
 
-#endif
+#endif // CHATSPLITTER_H
