@@ -1,6 +1,6 @@
 /*
  * chatview_te.h - subclass of PsiTextView to handle various hotkeys
- * Copyright (C) 2001-2010  Justin Karneges, Michail Pishchagin, Rion
+ * Copyright (C) 2001-2010  Justin Karneges, Michail Pishchagin, Sergey Ilinykh
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -13,48 +13,49 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef CHATVIEW_TE_H
 #define CHATVIEW_TE_H
 
-#include <QWidget>
+#include "chatviewcommon.h"
+#include "psitextview.h"
+#include "xmpp/jid/jid.h"
+
+#include <QContextMenuEvent>
 #include <QDateTime>
 #include <QPointer>
-#include <QContextMenuEvent>
-
-#include "psitextview.h"
-#include "chatviewcommon.h"
-#include "xmpp/jid/jid.h"
+#include <QWidget>
 
 class ChatEdit;
 class ChatViewBase;
+class ITEAudioController;
+class ITEMediaOpener;
 class MessageView;
+
 namespace XMPP {
-    class Jid;
+class Jid;
 }
 
-class ChatView : public PsiTextView, public ChatViewCommon
-{
+class ChatView : public PsiTextView, public ChatViewCommon {
     Q_OBJECT
 public:
-    ChatView(QWidget* parent);
+    ChatView(QWidget *parent);
     ~ChatView();
 
     void addLogIconsResources();
     void markReceived(QString id);
 
     // reimplemented
-    QSize sizeHint() const;
-    void clear();
-    void contextMenuEvent(QContextMenuEvent *e);
-    QMenu* createStandardContextMenu(const QPoint &position);
+    QSize  sizeHint() const;
+    void   clear();
+    void   contextMenuEvent(QContextMenuEvent *e);
+    QMenu *createStandardContextMenu(const QPoint &position);
 
     void init();
-    void setDialog(QWidget* dialog);
+    void setDialog(QWidget *dialog);
     void setSessionData(bool isMuc, bool isMucPrivate, const XMPP::Jid &jid, const QString name);
 
     void insertText(const QString &text, QTextCursor &insertCursor);
@@ -62,11 +63,10 @@ public:
     void dispatchMessage(const MessageView &);
     bool handleCopyEvent(QObject *object, QEvent *event, ChatEdit *chatEdit);
 
-    void deferredScroll();
-    void doTrackBar();
-    bool internalFind(QString str, bool startFromBeginning = false);
+    void      deferredScroll();
+    void      doTrackBar();
     ChatView *textWidget();
-    QWidget *realTextWidget();
+    QWidget * realTextWidget();
 
     void updateAvatar(const XMPP::Jid &jid, ChatViewCommon::UserType utype);
 public slots:
@@ -84,12 +84,12 @@ protected:
     QString colorString(bool local, bool spooled) const;
 
     QString replaceMarker(const MessageView &mv) const;
-    void renderMucMessage(const MessageView &, QTextCursor &insertCursor);
-    void renderMessage(const MessageView &, QTextCursor &insertCursor);
-    void renderSysMessage(const MessageView &);
-    void renderSubject(const MessageView &);
-    void renderMucSubject(const MessageView &);
-    void renderUrls(const MessageView &);
+    void    renderMucMessage(const MessageView &, QTextCursor &insertCursor);
+    void    renderMessage(const MessageView &, QTextCursor &insertCursor);
+    void    renderSysMessage(const MessageView &);
+    void    renderSubject(const MessageView &);
+    void    renderMucSubject(const MessageView &);
+    void    renderUrls(const MessageView &);
 
 protected slots:
     void autoCopy();
@@ -98,31 +98,20 @@ private slots:
     void slotScroll();
 
 signals:
-    void showNM(const QString&);
+    void showNM(const QString &);
     void quote(const QString &text);
     void nickInsertClick(const QString &nick);
 
 private:
-    bool isMuc_;
-    bool isMucPrivate_;
-    bool isEncryptionEnabled_;
-    XMPP::Jid jid_;
-    QString name_;
-    int  oldTrackBarPosition;
+    bool              isMuc_;
+    bool              isMucPrivate_;
+    bool              isEncryptionEnabled_;
+    bool              useMessageIcons_;
+    int               oldTrackBarPosition;
+    XMPP::Jid         jid_;
+    QString           name_;
     QPointer<QWidget> dialog_;
-    bool useMessageIcons_;
-
-    QPixmap logIconSend;
-    QPixmap logIconReceive;
-    QPixmap logIconDelivered;
-    QPixmap logIconSendPgp;
-    QPixmap logIconReceivePgp;
-    QPixmap logIconDeliveredPgp;
-    QPixmap logIconTime;
-    QPixmap logIconInfo;
-    QPixmap logIconCorrected;
-    QPixmap logIconHistory;
-    QAction *actQuote_;
+    QAction *         actQuote_;
 };
 
-#endif
+#endif // CHATVIEW_TE_H
