@@ -13,36 +13,36 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
-#ifndef CHATVIEW_H
-#define CHATVIEW_H
+#ifndef CHATVIEW_WEBKIT_H
+#define CHATVIEW_WEBKIT_H
+
+#include "chatviewcommon.h"
+#include "webview.h"
 
-#include <QWidget>
 #include <QDateTime>
 #include <QFrame>
 #include <QPointer>
-#include "webview.h"
-#include "chatviewcommon.h"
+#include <QWidget>
 
 class ChatEdit;
 class ChatView;
+class ChatViewPrivate;
+class ChatViewTheme;
 class MessageView;
 class PsiAccount;
-class ChatViewTheme;
-class ChatViewPrivate;
+
 namespace XMPP {
-    class Jid;
+class Jid;
 }
 
-class ChatView : public QFrame, public ChatViewCommon
-{
+class ChatView : public QFrame, public ChatViewCommon {
     Q_OBJECT
 public:
-    ChatView(QWidget* parent);
+    ChatView(QWidget *parent);
     ~ChatView();
 
     void markReceived(QString id);
@@ -50,23 +50,22 @@ public:
     // reimplemented
     QSize sizeHint() const;
 
-    void setDialog(QWidget* dialog);
+    void setDialog(QWidget *dialog);
     void setSessionData(bool isMuc, bool isMucPrivate, const XMPP::Jid &jid, const QString name);
     void setAccount(PsiAccount *acc);
 
-    void contextMenuEvent(QContextMenuEvent* event);
+    void contextMenuEvent(QContextMenuEvent *event);
     bool handleCopyEvent(QObject *object, QEvent *event, ChatEdit *chatEdit);
 
     void sendJsObject(const QVariantMap &);
     void dispatchMessage(const MessageView &m);
     void sendJsCode(const QString &js);
 
-    void clear();
-    void doTrackBar();
-    bool internalFind(QString str, bool startFromBeginning = false);
-    WebView * textWidget();
-    QWidget * realTextWidget();
-    QObject * jsBridge();
+    void     clear();
+    void     doTrackBar();
+    WebView *textWidget();
+    QWidget *realTextWidget();
+    QObject *jsBridge();
 
 public slots:
     void scrollUp();
@@ -78,12 +77,12 @@ public slots:
 protected:
     // override the tab/esc behavior
     bool focusNextPrevChild(bool next);
-    void changeEvent(QEvent * event);
-    //void keyPressEvent(QKeyEvent *);
+    void changeEvent(QEvent *event);
+    // void keyPressEvent(QKeyEvent *);
 
 protected slots:
     void psiOptionChanged(const QString &);
-    //void autoCopy();
+    // void autoCopy();
 
 public slots:
     void init();
@@ -93,7 +92,7 @@ private slots:
     void sessionInited();
 
 signals:
-    void showNM(const QString&);
+    void showNM(const QString &);
     void nickInsertClick(const QString &nick);
 
 private:
@@ -102,4 +101,4 @@ private:
     QScopedPointer<ChatViewPrivate> d;
 };
 
-#endif
+#endif // CHATVIEW_WEBKIT_H
