@@ -1,6 +1,6 @@
 /*
  * chatviewcommon.cpp - shared part of any chatview
- * Copyright (C) 2010 Rion
+ * Copyright (C) 2010  Sergey Ilinykh
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -13,42 +13,38 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
-#include <QApplication>
-#include <QWidget>
-#include <QColor>
-#include <QRegExp>
-
-#include <math.h>
-
 #include "chatviewcommon.h"
+
 #include "psioptions.h"
 
+#include <QApplication>
+#include <QRegExp>
+#include <QWidget>
+#include <math.h>
+
 void ChatViewCommon::setLooks(QWidget *w)
 {
     QPalette pal = w->palette(); // copy widget's palette to non const QPalette
-    pal.setColor(QPalette::Inactive, QPalette::HighlightedText,
-                 pal.color(QPalette::Active, QPalette::HighlightedText));
-    pal.setColor(QPalette::Inactive, QPalette::Highlight,
-                 pal.color(QPalette::Active, QPalette::Highlight));
-    w->setPalette(pal);        // set the widget's palette
+    pal.setColor(QPalette::Inactive, QPalette::HighlightedText, pal.color(QPalette::Active, QPalette::HighlightedText));
+    pal.setColor(QPalette::Inactive, QPalette::Highlight, pal.color(QPalette::Active, QPalette::Highlight));
+    w->setPalette(pal); // set the widget's palette
 }
 
 bool ChatViewCommon::updateLastMsgTime(QDateTime t)
 {
     bool doInsert = t.date() != _lastMsgTime.date();
-    _lastMsgTime = t;
+    _lastMsgTime  = t;
     return doInsert;
 }
 
-QString ChatViewCommon::getMucNickColor(const QString &nick, bool isSelf, QStringList validList)
+QString ChatViewCommon::getMucNickColor(const QString &nick, bool isSelf)
 {
     do {
-        if(!PsiOptions::instance()->getOption("options.ui.muc.use-nick-coloring").toBool()) {
+        if (!PsiOptions::instance()->getOption("options.ui.muc.use-nick-coloring").toBool()) {
             break;
         }
 
@@ -57,37 +53,36 @@ QString ChatViewCommon::getMucNickColor(const QString &nick, bool isSelf, QStrin
 
         if (PsiOptions::instance()->getOption("options.ui.muc.use-hash-nick-coloring").toBool()) {
             /* Hash-driven colors */
-            quint32 hash = qHash(nickwoun); // almost unique hash
+            quint32        hash     = qHash(nickwoun); // almost unique hash
             QList<QColor> &_palette = generatePalette();
-            return _palette.at(hash % _palette.size()).name();
+            return _palette.at(int(hash % uint(_palette.size()))).name();
         }
 
-        QStringList nickColors = validList.isEmpty()
-            ? PsiOptions::instance()->getOption("options.ui.look.colors.muc.nick-colors").toStringList()
-            : validList;
+        QStringList nickColors
+            = PsiOptions::instance()->getOption("options.ui.look.colors.muc.nick-colors").toStringList();
 
         if (nickColors.empty()) {
             break;
         }
 
-        if(isSelf || nickwoun.isEmpty() || nickColors.size() == 1) {
+        if (isSelf || nickwoun.isEmpty() || nickColors.size() == 1) {
             return nickColors[0];
         }
-        QMap<QString,int>::iterator it = _nicks.find(nickwoun);
+        QMap<QString, int>::iterator it = _nicks.find(nickwoun);
         if (it == _nicks.end()) {
-            //not found in map
+            // not found in map
             it = _nicks.insert(nickwoun, _nickNumber);
             _nickNumber++;
         }
-        return nickColors[ it.value() % (nickColors.size()-1) ];
+        return nickColors[it.value() % (nickColors.size() - 1)];
     } while (false);
 
     return QLatin1String("#000000"); // FIXME it's bad for fallback color
 }
 
-QList<QColor>& ChatViewCommon::generatePalette()
+QList<QColor> &ChatViewCommon::generatePalette()
 {
-    static QColor bg;
+    static QColor        bg;
     static QList<QColor> result;
 
     QColor cbg = qApp->palette().color(QPalette::Base); // background color
@@ -95,12 +90,12 @@ QList<QColor>& ChatViewCommon::generatePalette()
         result.clear();
         bg = cbg;
         QColor color;
-        for (int k = 0; k < 10 ; ++k) {
-            color = QColor::fromHsv(36*k, 255, 255);
+        for (int k = 0; k < 10; ++k) {
+            color = QColor::fromHsv(36 * k, 255, 255);
             if (compatibleColors(color, bg)) {
                 result << color;
             }
-            color = QColor::fromHsv(36*k, 255, 170);
+            color = QColor::fromHsv(36 * k, 255, 170);
             if (compatibleColors(color, bg)) {
                 result << color;
             }
@@ -111,18 +106,12 @@ QList<QColor>& ChatViewCommon::generatePalette()
 
 bool ChatViewCommon::compatibleColors(const QColor &c1, const QColor &c2)
 {
-    int dR = c1.red()-c2.red();
-    int dG = c1.green()-c2.green();
-    int dB = c1.blue()-c2.blue();
+    int dR = c1.red() - c2.red();
+    int dG = c1.green() - c2.green();
+    int dB = c1.blue() - c2.blue();
 
-    double dV = abs(c1.value()-c2.value());
-    double dC = sqrt(0.2126*dR*dR + 0.7152*dG*dG + 0.0722*dB*dB);
+    double dV = abs(c1.value() - c2.value());
+    double dC = sqrt(0.2126 * dR * dR + 0.7152 * dG * dG + 0.0722 * dB * dB);
 
-    if ((dC < 80. && dV > 100) ||
-        (dC < 110. && dV <= 100 && dV > 10) ||
-        (dC < 125. && dV <= 10)) {
-        return false;
-    }
-
-    return true;
+    return !((dC < 80. && dV > 100) || (dC < 110. && dV <= 100 && dV > 10) || (dC < 125. && dV <= 10));
 }
