@@ -1,6 +1,6 @@
 /*
  * chatviewtheme.cpp - theme for webkit based chatview
- * Copyright (C) 2010-2017 Sergey Ilinykh
+ * Copyright (C) 2010-2017  Sergey Ilinykh
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -13,69 +13,47 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
-#ifdef WEBENGINE
-#include <QWebEnginePage>
-#include <QWebChannel>
-#include <QWebEngineScript>
-#include <QWebEngineScriptCollection>
-#include <QWebEngineProfile>
-#include <functional>
-#else
-#include <QWebPage>
-#include <QWebFrame>
-#include <QNetworkRequest>
-#endif
-#include <QJsonObject>
-#include <QJsonDocument>
-#include <QMetaProperty>
-#include <QFileInfo>
+#include "chatviewtheme.h"
+
+#include "avatars.h"
+#include "chatviewtheme_p.h"
+#include "chatviewthemeprovider.h"
+#include "chatviewthemeprovider_priv.h"
+#include "coloropt.h"
+#include "common.h"
+#include "jsutil.h"
+#include "psicon.h"
+#include "psioptions.h"
+#include "theme_p.h"
+#include "webview.h"
+
 #include <QApplication>
+#include <QFileInfo>
+#include <QJsonDocument>
+#include <QJsonObject>
+#include <QMetaProperty>
 #include <QScopedPointer>
 #include <QTimer>
 #include <time.h>
 #include <tuple>
-
-#include "chatviewtheme.h"
-#include "chatviewtheme_p.h"
-#include "psioptions.h"
-#include "coloropt.h"
-#include "jsutil.h"
-#include "webview.h"
-#include "chatviewthemeprovider.h"
 #ifdef WEBENGINE
-# include "themeserver.h"
+#include <QWebChannel>
+#include <QWebEnginePage>
+#include <QWebEngineProfile>
+#include <QWebEngineScript>
+#include <QWebEngineScriptCollection>
+#include <functional>
+#else
+#include <QNetworkRequest>
+#include <QWebFrame>
+#include <QWebPage>
 #endif
-#include "avatars.h"
-#include "common.h"
-#include "psicon.h"
-#include "theme_p.h"
-#include "jsutil.h"
 
 #ifndef WEBENGINE
-class SessionRequestHandler : public NAMDataHandler
-{
-    ChatViewThemeSession *session;
-
-public:
-    SessionRequestHandler(ChatViewThemeSession *session) :
-        session(session) {}
-
-    bool data(const QNetworkRequest &req, QByteArray &data, QByteArray &mime) const
-    {
-        Q_UNUSED(mime)
-        data = session->theme.loadData(session->theme.priv<ChatViewThemePrivate>()->httpRelPath + req.url().path());
-        if (!data.isNull()) {
-            return true;
-        }
-        return false;
-    }
-};
-
 QVariant ChatViewThemePrivate::evaluateFromFile(const QString fileName, QWebFrame *frame)
 {
     QFile f(fileName);
@@ -86,13 +64,12 @@ QVariant ChatViewThemePrivate::evaluateFromFile(const QString fileName, QWebFram
 }
 #endif
 
-ChatViewThemePrivate::ChatViewThemePrivate(ChatViewThemeProvider *provider) :
-    ThemePrivate(provider)
+ChatViewThemePrivate::ChatViewThemePrivate(ChatViewThemeProvider *provider) : ThemePrivate(provider)
 {
     nam = provider->psi()->networkAccessManager();
 }
 
-
+ChatViewThemePrivate::~ChatViewThemePrivate() { delete wv; }
 
 bool ChatViewThemePrivate::exists()
 {
@@ -125,65 +102,68 @@ bool ChatViewThemePrivate::load(std::function<void(bool)> loadCallback)
         return true;
     }
 
-    qDebug("Starting loading \"%s\" theme at \"%s\" for %s", qPrintable(id), qPrintable(filepath), isMuc()? "muc": "chat");
+    qDebug("Starting loading \"%s\" theme at \"%s\" for %s", qPrintable(id), qPrintable(filepath),
+           isMuc() ? "muc" : "chat");
     state = Theme::State::Loading;
     if (jsUtil.isNull()) {
         jsLoader.reset(new ChatViewJSLoader(this));
         jsUtil.reset(new ChatViewThemeJSUtil(this));
     }
     if (wv.isNull()) {
-        wv = new WebView(0);
+        wv = new WebView(nullptr);
     }
 
     QString themeType = id.section('/', 0, 0);
 #ifdef WEBENGINE
-    QWebChannel * channel = new QWebChannel(wv->page());
+    QWebChannel *channel = new QWebChannel(wv->page());
     wv->page()->setWebChannel(channel);
     channel->registerObject(QLatin1String("srvLoader"), jsLoader.data());
     channel->registerObject(QLatin1String("srvUtil"), jsUtil.data());
 
-    //QString themeServer = ChatViewThemeProvider::serverAddr();
-    wv->page()->setHtml(QString(
-        "<html><head>\n"
-        "<script src=\"/psithemes/chatview/moment-with-locales.js\"></script>\n"
-        "<script src=\"/psithemes/chatview/util.js\"></script>\n"
-        "<script src=\"/psithemes/chatview/%1/adapter.js\"></script>\n"
-        "<script src=\"/psiglobal/qwebchannel.js\"></script>\n"
-        "<script type=\"text/javascript\">\n"
-            "document.addEventListener(\"DOMContentLoaded\", function () {\n"
-                "new QWebChannel(qt.webChannelTransport, function (channel) {\n"
-                    "window.srvLoader = channel.objects.srvLoader;\n"
-                    "window.srvUtil = channel.objects.srvUtil;\n"
-                    "initPsiTheme().adapter.loadTheme();\n"
-                "});\n"
-            "});\n"
-        "</script></head></html>").arg(themeType), jsLoader->serverUrl()
-    );
+    // QString themeServer = ChatViewThemeProvider::serverAddr();
+    wv->page()->setHtml(QString("<html><head>\n"
+                                "<script src=\"/psi/themes/chatview/moment-with-locales.js\"></script>\n"
+                                "<script src=\"/psi/themes/chatview/util.js\"></script>\n"
+                                "<script src=\"/psi/themes/chatview/%1/adapter.js\"></script>\n"
+                                "<script src=\"/psi/static/qwebchannel.js\"></script>\n"
+                                "<script type=\"text/javascript\">\n"
+                                "document.addEventListener(\"DOMContentLoaded\", function () {\n"
+                                "new QWebChannel(qt.webChannelTransport, function (channel) {\n"
+                                "window.srvLoader = channel.objects.srvLoader;\n"
+                                "window.srvUtil = channel.objects.srvUtil;\n"
+                                "initPsiTheme().adapter.loadTheme();\n"
+                                "});\n"
+                                "});\n"
+                                "</script></head></html>")
+                            .arg(themeType),
+                        jsLoader->serverUrl());
     return true;
 #else
     wv->page()->setNetworkAccessManager(nam);
     QStringList scriptPaths = QStringList()
-            << PsiThemeProvider::themePath(QLatin1String("chatview/moment-with-locales.js"))
-            << PsiThemeProvider::themePath(QLatin1String("chatview/util.js"))
-            << PsiThemeProvider::themePath(QLatin1String("chatview/") + themeType + QLatin1String("/adapter.js"));
-
+        << PsiThemeProvider::themePath(QLatin1String("chatview/moment-with-locales.js"))
+        << PsiThemeProvider::themePath(QLatin1String("chatview/util.js"))
+        << PsiThemeProvider::themePath(QLatin1String("chatview/") + themeType + QLatin1String("/adapter.js"));
 
     wv->page()->mainFrame()->addToJavaScriptWindowObject("srvLoader", jsLoader.data(), QWebFrame::QtOwnership);
     wv->page()->mainFrame()->addToJavaScriptWindowObject("srvUtil", jsUtil.data(), QWebFrame::QtOwnership);
 
-    foreach (const QString &sp, scriptPaths) {
+    for (const QString &sp : scriptPaths) {
         evaluateFromFile(sp, wv->page()->mainFrame());
     }
 
-    QString resStr = wv->page()->mainFrame()->evaluateJavaScript(
-                "try { initPsiTheme().adapter.loadTheme(); \"ok\"; } "
-                "catch(e) { \"Error:\" + e + \"\\n\" + window.psiim.util.props(e); }").toString();
+    QString resStr = wv->page()
+                         ->mainFrame()
+                         ->evaluateJavaScript("try { initPsiTheme().adapter.loadTheme(); \"ok\"; } "
+                                              "catch(e) { \"Error:\" + e + \"\\n\" + window.psiim.util.props(e); }")
+                         .toString();
 
     if (resStr == "ok") {
         return true;
     }
     qWarning("javascript part of the theme loader "
-             "didn't return expected result: %s", qPrintable(resStr));
+             "didn't return expected result: %s",
+             qPrintable(resStr));
     return false;
 #endif
 }
@@ -201,34 +181,32 @@ QWidget *ChatViewThemePrivate::previewWidget()
 {
     QLabel *l = new QLabel;
     l->setPixmap(QPixmap::fromImage(QImage::fromData(loadData("screenshot.png"))));
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+    if (l->pixmap(Qt::ReturnByValue).isNull()) {
+#else
     if (l->pixmap()->isNull()) {
+#endif
         delete l;
         return nullptr;
     }
     return l;
 }
 
-bool ChatViewThemePrivate::isMuc() const
-{
-    return dynamic_cast<GroupChatViewThemeProvider*>(provider);
-}
+bool ChatViewThemePrivate::isMuc() const { return bool(dynamic_cast<GroupChatViewThemeProvider *>(provider)); }
 
 QVariantMap ChatViewThemePrivate::loadFromCacheMulti(const QVariantList &list)
 {
     QVariantMap ret;
     for (auto &item : list) {
         QString key = item.toString();
-        ret[key] = cache.value(key);
-        //if (key.endsWith("html"))
+        ret[key]    = cache.value(key);
+        // if (key.endsWith("html"))
         //    qDebug() << "Loaded from cache" << key << ret[key].toString().left(50) << "priv=" << (void*)this;
     }
     return ret;
 }
 
-bool ChatViewThemePrivate::isTransparentBackground() const
-{
-    return transparentBackground;
-}
+bool ChatViewThemePrivate::isTransparentBackground() const { return transparentBackground; }
 
 #ifndef WEBENGINE
 void ChatViewThemePrivate::embedSessionJsObject(ChatViewThemeSession *session)
@@ -238,11 +216,12 @@ void ChatViewThemePrivate::embedSessionJsObject(ChatViewThemeSession *session)
     wf->addToJavaScriptWindowObject("srvSession", session);
 
     QStringList scriptPaths = QStringList()
-            << PsiThemeProvider::themePath(QLatin1String("chatview/moment-with-locales.js"))
-            << PsiThemeProvider::themePath(QLatin1String("chatview/util.js"))
-            << PsiThemeProvider::themePath(QLatin1String("chatview/") + id.section('/', 0, 0) + QLatin1String("/adapter.js"));
+        << PsiThemeProvider::themePath(QLatin1String("chatview/moment-with-locales.js"))
+        << PsiThemeProvider::themePath(QLatin1String("chatview/util.js"))
+        << PsiThemeProvider::themePath(QLatin1String("chatview/") + id.section('/', 0, 0)
+                                       + QLatin1String("/adapter.js"));
 
-    foreach (const QString &script, scriptPaths) {
+    for (const QString &script : scriptPaths) {
         evaluateFromFile(script, wf);
     }
 }
@@ -257,7 +236,7 @@ bool ChatViewThemePrivate::applyToSession(ChatViewThemeSession *session)
     }
 
     QWebChannel *channel = page->webChannel();
-    QObject *oldUtil = nullptr;
+    QObject *    oldUtil = nullptr;
     if (channel) {
         oldUtil = channel->registeredObjects()[QLatin1String("srvUtil")];
         oldUtil->deleteLater();
@@ -268,28 +247,23 @@ bool ChatViewThemePrivate::applyToSession(ChatViewThemeSession *session)
     channel->registerObject(QLatin1String("srvSession"), session);
     page->setWebChannel(channel);
 
-    ChatViewThemeProvider *cvProvider = static_cast<ChatViewThemeProvider*>(provider);
-
-    auto server = cvProvider->themeServer();
-    session->server = server;
-
     QPointer<ChatViewThemeSession> weakSession(session);
-    auto handler = [weakSession,this](qhttp::server::QHttpRequest* req, qhttp::server::QHttpResponse* res) -> bool
-    {
+    auto handler = [weakSession, this](qhttp::server::QHttpRequest *req, qhttp::server::QHttpResponse *res) -> bool {
         auto session = weakSession.data();
         if (!weakSession) {
             return false;
         }
-        bool handled = session->getContents(req->url(), [res](const QByteArray &data, const QByteArray &ctype){
-            if (data.isNull()) {
-                res->setStatusCode(qhttp::ESTATUS_NOT_FOUND);
-            } else {
-                res->setStatusCode(qhttp::ESTATUS_OK);
-                res->headers().insert("Content-Type", ctype);
-            }
-            res->end(data);
-        });
-        if(handled) {
+        bool handled
+            = session->getContents(req->url(), [res](bool success, const QByteArray &data, const QByteArray &ctype) {
+                  if (success) {
+                      res->setStatusCode(qhttp::ESTATUS_OK);
+                      res->headers().insert("Content-Type", ctype);
+                  } else {
+                      res->setStatusCode(qhttp::ESTATUS_NOT_FOUND);
+                  }
+                  res->end(data);
+              });
+        if (handled) {
             return true;
         }
         // not handled by chat. try handle by theme
@@ -298,7 +272,6 @@ bool ChatViewThemePrivate::applyToSession(ChatViewThemeSession *session)
             res->setStatusCode(qhttp::ESTATUS_OK);
             res->headers().insert("Content-Type", "text/html;charset=utf-8");
 
-
             if (prepareSessionHtml) { // html should be prepared for ech individual session
                 // Even crazier stuff starts here.
                 // Basically we send to theme's webview instance a signal to
@@ -307,45 +280,40 @@ bool ChatViewThemePrivate::applyToSession(ChatViewThemeSession *session)
                 // indicating sessionId and html contents.
                 // And only then we close the request with hot html.
 
-                jsLoader->connect(jsLoader.data(),
-                                  &ChatViewJSLoader::sessionHtmlReady,
-                                  session,
-                [weakSession, res, this](const QString &sessionId, const QString &html)
-                {
-                    auto session = weakSession.data();
-                    if (!weakSession) {
-                        return;
-                    }
-                    if (session->sessId == sessionId) {
-                        res->end(html.toUtf8()); // return html to client
-                        // and disconnect from loader
-                        jsLoader->disconnect(
-                                    jsLoader.data(),
-                                    &ChatViewJSLoader::sessionHtmlReady,
-                                    session, nullptr);
-                        jsLoader->unregisterSession(session->sessId);
-                    }
-                });
+                jsLoader->connect(jsLoader.data(), &ChatViewJSLoader::sessionHtmlReady, session,
+                                  [weakSession, res, this](const QString &sessionId, const QString &html) {
+                                      auto session = weakSession.data();
+                                      if (!weakSession) {
+                                          return;
+                                      }
+                                      if (session->sessId == sessionId) {
+                                          res->end(html.toUtf8()); // return html to client
+                                          // and disconnect from loader
+                                          jsLoader->disconnect(jsLoader.data(), &ChatViewJSLoader::sessionHtmlReady,
+                                                               session, nullptr);
+                                          jsLoader->unregisterSession(session->sessId);
+                                      }
+                                  });
                 jsLoader->registerSession(session);
                 QString basePath = req->property("basePath").toString();
                 wv->page()->runJavaScript(
-                            QString(QLatin1String("psiim.adapter.generateSessionHtml(\"%1\", %2, \"%3\")"))
-                            .arg(session->sessId, session->propsAsJsonString(), basePath));
+                    QString(QLatin1String("psiim.adapter.generateSessionHtml(\"%1\", %2, \"%3\")"))
+                        .arg(session->sessId, session->propsAsJsonString(), basePath));
 
             } else {
                 res->end(html.toUtf8());
             }
             return true;
         } else {
-            bool loaded;
-            QByteArray data = Theme(this).loadData(httpRelPath + path, &loaded);
+            bool       loaded;
+            QByteArray data = loadData(httpRelPath + path, &loaded);
             if (loaded) {
                 if (!data.isNull() && path.endsWith(QLatin1String(".tiff"))) {
                     // seems like we are loading tiff image which is supported by safari only.
                     // let's convert it
-                    QImage image(QImage::fromData(data));
+                    QImage     image(QImage::fromData(data));
                     QByteArray ba;
-                    QBuffer buffer(&ba);
+                    QBuffer    buffer(&ba);
                     buffer.open(QIODevice::WriteOnly);
                     image.save(&buffer, "PNG");
                     if (!ba.isNull()) {
@@ -363,15 +331,15 @@ bool ChatViewThemePrivate::applyToSession(ChatViewThemeSession *session)
         return false;
     };
 
-    session->sessId = server->registerSessionHandler(handler);
-    QUrl url = server->serverUrl();
+    session->sessId = ChatViewCon::instance()->registerSessionHandler(handler);
+    QUrl      url   = ChatViewCon::instance()->serverUrl();
     QUrlQuery q;
     q.addQueryItem(QLatin1String("psiId"), session->sessId);
     url.setQuery(q);
 
     page->load(url);
 
-    //QString id = provider->themeServer()->registerHandler(sessionObject);
+    // QString id = provider->themeServer()->registerHandler(sessionObject);
     return true;
 #else
     QWebPage *page = session->webView()->page();
@@ -385,16 +353,25 @@ bool ChatViewThemePrivate::applyToSession(ChatViewThemeSession *session)
 
     page->setNetworkAccessManager(nam);
 
-    SessionRequestHandler *handler = new SessionRequestHandler(session);
-    session->sessId = nam->registerSessionHandler(QSharedPointer<NAMDataHandler>(handler));
+    session->sessId = nam->registerSessionHandler(
+        [session](const QNetworkRequest &req, QByteArray &data, QByteArray &mime) {
+            Q_UNUSED(mime)
+            data = session->theme.loadData(session->theme.priv<ChatViewThemePrivate>()->httpRelPath + req.url().path());
+            if (!data.isNull()) {
+                return true;
+            }
+            return false;
+        });
 
     QString html;
     if (prepareSessionHtml) {
         QString basePath = "";
         jsLoader->registerSession(session);
-        html = wv->page()->mainFrame()->evaluateJavaScript(
-                QString(QLatin1String("psiim.adapter.generateSessionHtml(\"%1\", %2, \"%3\")"))
-                .arg(session->sessId, session->propsAsJsonString(), basePath)).toString();
+        html = wv->page()
+                   ->mainFrame()
+                   ->evaluateJavaScript(QString(QLatin1String("psiim.adapter.generateSessionHtml(\"%1\", %2, \"%3\")"))
+                                            .arg(session->sessId, session->propsAsJsonString(), basePath))
+                   .toString();
         jsLoader->unregisterSession(session->sessId);
     } else {
         html = this->html;
@@ -406,31 +383,19 @@ bool ChatViewThemePrivate::applyToSession(ChatViewThemeSession *session)
 #endif
 }
 
-
 //------------------------------------------------------------------------------
 // ChatViewThemeJSLoader
 //------------------------------------------------------------------------------
-ChatViewJSLoader::ChatViewJSLoader(Theme theme, QObject *parent) :
-    QObject(parent),
-    theme(theme.priv<ChatViewThemePrivate>())
-{}
+ChatViewJSLoader::ChatViewJSLoader(ChatViewThemePrivate *theme, QObject *parent) : QObject(parent), theme(theme) { }
 
-const QString ChatViewJSLoader::themeId() const
-{
-    return theme->id;
-}
+const QString ChatViewJSLoader::themeId() const { return theme->id; }
 
-bool ChatViewJSLoader::isMuc() const
-{
-    return theme->isMuc();
-}
+bool ChatViewJSLoader::isMuc() const { return theme->isMuc(); }
 
 QString ChatViewJSLoader::serverUrl() const
 {
 #ifdef WEBENGINE
-    ChatViewThemeProvider *cvProvider = static_cast<ChatViewThemeProvider*>(theme->provider);
-    auto server = cvProvider->themeServer();
-    QUrl url = server->serverUrl();
+    QUrl url = ChatViewCon::instance()->serverUrl();
     return url.url();
 #else
     static QString url("http://psi");
@@ -443,16 +408,14 @@ void ChatViewJSLoader::registerSession(ChatViewThemeSession *session)
     _sessions.insert(session->sessionId(), session);
 }
 
-void ChatViewJSLoader::unregisterSession(const QString &sessId)
-{
-    _sessions.remove(sessId);
-}
+void ChatViewJSLoader::unregisterSession(const QString &sessId) { _sessions.remove(sessId); }
 
 void ChatViewJSLoader::_callFinishLoadCalbacks()
 {
     for (auto &cb : theme->loadCallbacks) {
         cb(theme->state == Theme::State::Loaded);
     }
+    theme->loadCallbacks.clear();
 }
 
 void ChatViewJSLoader::setMetaData(const QVariantMap &map)
@@ -485,7 +448,7 @@ void ChatViewJSLoader::setMetaData(const QVariantMap &map)
 
 void ChatViewJSLoader::finishThemeLoading()
 {
-    qDebug("%s theme is successfully loaded for %s", qPrintable(theme->id), theme->isMuc()? "muc": "chat");
+    qDebug("%s theme is successfully loaded for %s", qPrintable(theme->id), theme->isMuc() ? "muc" : "chat");
     Theme(theme).setState(Theme::State::Loaded);
 #ifdef WEBENGINE
     _callFinishLoadCalbacks();
@@ -505,30 +468,21 @@ void ChatViewJSLoader::errorThemeLoading(const QString &error)
 #endif
 }
 
-void ChatViewJSLoader::setHtml(const QString &h)
-{
-    theme->html = h;
-}
+void ChatViewJSLoader::setHtml(const QString &h) { theme->html = h; }
 
-void ChatViewJSLoader::setHttpResourcePath(const QString &relPath)
-{
-    theme->httpRelPath = relPath;
-}
+void ChatViewJSLoader::setHttpResourcePath(const QString &relPath) { theme->httpRelPath = relPath; }
 
-void ChatViewJSLoader::toCache(const QString &name, const QVariant &data)
-{
-    theme->cache.insert(name, data);
-}
+void ChatViewJSLoader::toCache(const QString &name, const QVariant &data) { theme->cache.insert(name, data); }
 
 void ChatViewJSLoader::saveFilesToCache(const QVariantMap &map)
 {
     auto it = map.constBegin();
     while (it != map.constEnd()) {
-        bool loaded;
+        bool       loaded;
         QByteArray ba = Theme(theme).loadData(it.value().toString(), &loaded);
         if (loaded) {
             theme->cache.insert(it.key(), QString::fromUtf8(ba));
-            //qDebug() << "Caching" << it.value() << "from" << Theme(theme).filePath()
+            // qDebug() << "Caching" << it.value() << "from" << Theme(theme).filePath()
             //         << theme->cache[it.key()] << "priv=" << (void*)theme;
         }
         ++it;
@@ -537,7 +491,7 @@ void ChatViewJSLoader::saveFilesToCache(const QVariantMap &map)
 
 QVariantMap ChatViewJSLoader::sessionProperties(const QString &sessionId, const QVariantList &props)
 {
-    auto sess = _sessions.value(sessionId);
+    auto        sess = _sessions.value(sessionId);
     QVariantMap ret;
     if (sess) {
         for (auto &p : props) {
@@ -548,15 +502,9 @@ QVariantMap ChatViewJSLoader::sessionProperties(const QString &sessionId, const
     return ret;
 }
 
-void ChatViewJSLoader::setCaseInsensitiveFS(bool state)
-{
-    Theme(theme).setCaseInsensitiveFS(state);
-}
+void ChatViewJSLoader::setCaseInsensitiveFS(bool state) { Theme(theme).setCaseInsensitiveFS(state); }
 
-void ChatViewJSLoader::setPrepareSessionHtml(bool enabled)
-{
-    theme->prepareSessionHtml = enabled;
-}
+void ChatViewJSLoader::setPrepareSessionHtml(bool enabled) { theme->prepareSessionHtml = enabled; }
 
 void ChatViewJSLoader::setSessionHtml(const QString &sessionId, const QString &html)
 {
@@ -565,28 +513,25 @@ void ChatViewJSLoader::setSessionHtml(const QString &sessionId, const QString &h
 
 QVariantMap ChatViewJSLoader::checkFilesExist(const QStringList &files, const QString baseDir)
 {
-    QVariantMap ret;
+    QVariantMap                           ret;
     QScopedPointer<Theme::ResourceLoader> loader(Theme(theme).resourceLoader());
 
     QString d(baseDir);
     if (!d.isEmpty()) {
         d += QLatin1Char('/');
     }
-    foreach (const QString &f, files) {
+    for (const QString &f : files) {
         ret.insert(f, loader->fileExists(d + f));
     }
 
     return ret;
 }
 
-QString ChatViewJSLoader::getFileContents(const QString &name) const
-{
-    return QString(Theme(theme).loadData(name));
-}
+QString ChatViewJSLoader::getFileContents(const QString &name) const { return QString(Theme(theme).loadData(name)); }
 
 QString ChatViewJSLoader::getFileContentsFromAdapterDir(const QString &name) const
 {
-    QString relPath = QLatin1String("chatview/") + theme->id.split('/').first() + QLatin1Char('/') + name;
+    QString relPath  = QLatin1String("chatview/") + theme->id.split('/').first() + QLatin1Char('/') + name;
     QString filePath = theme->provider->themePath(relPath);
     if (filePath.isEmpty()) {
         qDebug("%s is not found", qPrintable(relPath));
@@ -598,37 +543,25 @@ QString ChatViewJSLoader::getFileContentsFromAdapterDir(const QString &name) con
         file.close();
         return QString::fromUtf8(result.constData(), result.size());
     } else {
-        qDebug("Failed to open file %s: %s", qPrintable(file.fileName()),
-               qPrintable(file.errorString()));
+        qDebug("Failed to open file %s: %s", qPrintable(file.fileName()), qPrintable(file.errorString()));
     }
     return QString();
 }
 
-void ChatViewJSLoader::setTransparent()
-{
-    theme->transparentBackground = true;
-}
-
-
-
-
-
-
+void ChatViewJSLoader::setTransparent() { theme->transparentBackground = true; }
 
 //------------------------------------------------------------------------------
 // ChatViewThemeJSUtil
 //------------------------------------------------------------------------------
-ChatViewThemeJSUtil::ChatViewThemeJSUtil(Theme theme, QObject *parent) :
-    QObject(parent),
-    theme(theme)
+ChatViewThemeJSUtil::ChatViewThemeJSUtil(ChatViewThemePrivate *theme, QObject *parent) : QObject(parent), theme(theme)
 {
-    psiDefaultAvatarUrl = "psiglobal/avatar/default.png"; // relative to session url
+    psiDefaultAvatarUrl = "psi/avatar/default.png"; // relative to session url
     // may be in the future we can make different defaults. per transport for example
 
     optChangeTimer.setSingleShot(true);
     optChangeTimer.setInterval(0);
     connect(&optChangeTimer, SIGNAL(timeout()), SLOT(sendOptionsChanges()));
-    connect(PsiOptions::instance(), SIGNAL(optionChanged(const QString&)), SLOT(optionsChanged(const QString&)));
+    connect(PsiOptions::instance(), SIGNAL(optionChanged(const QString &)), SLOT(optionsChanged(const QString &)));
 }
 
 void ChatViewThemeJSUtil::sendOptionsChanges()
@@ -643,20 +576,14 @@ void ChatViewThemeJSUtil::optionsChanged(const QString &option)
     optChangeTimer.start();
 }
 
-void ChatViewThemeJSUtil::putToCache(const QString &key, const QVariant &data)
-{
-    theme.priv<ChatViewThemePrivate>()->cache.insert(key, data);
-}
+void ChatViewThemeJSUtil::putToCache(const QString &key, const QVariant &data) { theme->cache.insert(key, data); }
 
 QVariantMap ChatViewThemeJSUtil::loadFromCacheMulti(const QVariantList &list)
 {
-    return theme.priv<ChatViewThemePrivate>()->loadFromCacheMulti(list);
+    return theme->loadFromCacheMulti(list);
 }
 
-QVariant ChatViewThemeJSUtil::cache(const QString &name) const
-{
-    return theme.priv<ChatViewThemePrivate>()->cache.value(name);
-}
+QVariant ChatViewThemeJSUtil::cache(const QString &name) const { return theme->cache.value(name); }
 
 QString ChatViewThemeJSUtil::psiOption(const QString &option) const
 {
@@ -666,7 +593,7 @@ QString ChatViewThemeJSUtil::psiOption(const QString &option) const
 QString ChatViewThemeJSUtil::psiOptions(const QStringList &options) const
 {
     QVariantList ret;
-    for (auto &option: options) {
+    for (auto &option : options) {
         ret.append(PsiOptions::instance()->getOption(option));
     }
     QString retStr = JSUtil::variant2js(ret);
@@ -685,48 +612,35 @@ QString ChatViewThemeJSUtil::formatDate(const QDateTime &dt, const QString &form
 
 QString ChatViewThemeJSUtil::strftime(const QDateTime &dt, const QString &format) const
 {
-    char str[256];
+    char   str[256];
     time_t t = dt.toTime_t();
-    int s = ::strftime(str, 256, format.toLocal8Bit(), localtime(&t));
+    int    s = int(::strftime(str, 256, format.toLocal8Bit(), localtime(&t)));
     if (s) {
         return QString::fromLocal8Bit(str, s);
     }
     return QString();
 }
 
-void ChatViewThemeJSUtil::console(const QString &text) const
-{
-    qDebug("%s", qPrintable(text));
-}
+void ChatViewThemeJSUtil::console(const QString &text) const { qDebug("%s", qPrintable(text)); }
 
-QString ChatViewThemeJSUtil::status2text(int status) const
-{
-    return ::status2txt(status);
-}
+QString ChatViewThemeJSUtil::status2text(int status) const { return ::status2txt(status); }
 
 QString ChatViewThemeJSUtil::hex2rgba(const QString &hex, float opacity)
 {
     QColor color("#" + hex);
-    color.setAlphaF(opacity);
-    return QString("rgba(%1,%2,%3,%4)").arg(color.red()).arg(color.green())
-            .arg(color.blue()).arg(color.alpha());
+    color.setAlphaF(qreal(opacity));
+    return QString("rgba(%1,%2,%3,%4)").arg(color.red()).arg(color.green()).arg(color.blue()).arg(color.alpha());
 }
 
 //------------------------------------------------------------------------------
 // ChatViewTheme
 //------------------------------------------------------------------------------
-ChatViewThemeSession::ChatViewThemeSession(QObject *parent) :
-    QObject(parent)
-{
-
-}
+ChatViewThemeSession::ChatViewThemeSession(QObject *parent) : QObject(parent) { }
 
 ChatViewThemeSession::~ChatViewThemeSession()
 {
 #ifdef WEBENGINE
-    if (server) {
-        server->unregisterSessionHandler(sessId);
-    }
+    ChatViewCon::instance()->unregisterSessionHandler(sessId);
 #else
     theme.priv<ChatViewThemePrivate>()->nam->unregisterSessionHandler(sessId);
 #endif
@@ -735,7 +649,7 @@ ChatViewThemeSession::~ChatViewThemeSession()
 QString ChatViewThemeSession::propsAsJsonString()
 {
     QJsonObject jsObj;
-    int pc = metaObject()->propertyCount();
+    int         pc = metaObject()->propertyCount();
     for (int i = 0; i < pc; i++) {
         QMetaProperty p = metaObject()->property(i);
         if (p.isReadable()) {
@@ -751,10 +665,17 @@ QString ChatViewThemeSession::propsAsJsonString()
 
 void ChatViewThemeSession::init(const Theme &theme)
 {
+    if (this->theme.isValid() && !sessId.isEmpty()) {
+#ifdef WEBENGINE
+        ChatViewCon::instance()->unregisterSessionHandler(sessId);
+#else
+        theme.priv<ChatViewThemePrivate>()->nam->unregisterSessionHandler(sessId);
+#endif
+    }
     this->theme = theme;
 #ifndef WEBENGINE
-    connect(webView()->page()->mainFrame(),
-            SIGNAL(javaScriptWindowObjectCleared()), SLOT(embedJsObject()), Qt::UniqueConnection);
+    connect(webView()->page()->mainFrame(), SIGNAL(javaScriptWindowObjectCleared()), this, SLOT(embedJsObject()),
+            Qt::UniqueConnection);
 #endif
     auto priv = theme.priv<ChatViewThemePrivate>();
     priv->applyToSession(this);
