@@ -13,39 +13,36 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef CHATVIEWTHEME_P_H
 #define CHATVIEWTHEME_P_H
 
-#include <QTimer>
-#include <QScopedPointer>
+#include "chatviewtheme.h"
+#include "theme_p.h"
+
 #include <QPointer>
+#include <QScopedPointer>
+#include <QTimer>
 #ifdef WEBENGINE
-# include <QWebEngineScript>
+#include <QWebEngineScript>
 #else
 #endif
 
-#include "theme_p.h"
-#include "chatviewtheme.h"
-
-class QWebFrame;
-
-class WebView;
-class NetworkAccessManager;
-class ChatViewThemeProvider;
 class ChatViewThemePrivate;
+class ChatViewThemeProvider;
+class NetworkAccessManager;
+class QWebFrame;
+class WebView;
 
-class ChatViewJSLoader : public QObject
-{
+class ChatViewJSLoader : public QObject {
     Q_OBJECT
 
-    ChatViewThemePrivate *theme;
-    QString _loadError;
-    QHash<QString, QObject*> _sessions;
+    ChatViewThemePrivate *    theme;
+    QString                   _loadError;
+    QHash<QString, QObject *> _sessions;
 
     Q_PROPERTY(QString themeId READ themeId CONSTANT)
     Q_PROPERTY(QString isMuc READ isMuc CONSTANT)
@@ -55,12 +52,12 @@ signals:
     void sessionHtmlReady(const QString &sessionId, const QString &html);
 
 public:
-    ChatViewJSLoader(Theme theme, QObject *parent = 0);
+    ChatViewJSLoader(ChatViewThemePrivate *theme, QObject *parent = nullptr);
     const QString themeId() const;
-    bool isMuc() const;
-    QString serverUrl() const;
-    void registerSession(ChatViewThemeSession *session);
-    void unregisterSession(const QString &sessId);
+    bool          isMuc() const;
+    QString       serverUrl() const;
+    void          registerSession(ChatViewThemeSession *session);
+    void          unregisterSession(const QString &sessId);
 
 private slots:
     void _callFinishLoadCalbacks();
@@ -91,24 +88,23 @@ public slots:
      * @return filled map prop=>value
      */
     QVariantMap sessionProperties(const QString &sessionId, const QVariantList &props);
-    void setCaseInsensitiveFS(bool state = true);
-    void setPrepareSessionHtml(bool enabled = true);
-    void setSessionHtml(const QString &sessionId, const QString &html);
+    void        setCaseInsensitiveFS(bool state = true);
+    void        setPrepareSessionHtml(bool enabled = true);
+    void        setSessionHtml(const QString &sessionId, const QString &html);
     QVariantMap checkFilesExist(const QStringList &files, const QString baseDir = QString());
-    QString getFileContents(const QString &name) const;
-    QString getFileContentsFromAdapterDir(const QString &name) const;
-    void setTransparent();
+    QString     getFileContents(const QString &name) const;
+    QString     getFileContentsFromAdapterDir(const QString &name) const;
+    void        setTransparent();
 };
 
-
 // JS Bridge object emedded by theme. Has any logic unrelted to contact itself
 class ChatViewThemeJSUtil : public QObject {
     Q_OBJECT
 
-    Theme theme;
-    QString psiDefaultAvatarUrl;
-    QStringList changedOptions;
-    QTimer optChangeTimer;
+    ChatViewThemePrivate *theme;
+    QString               psiDefaultAvatarUrl;
+    QStringList           changedOptions;
+    QTimer                optChangeTimer;
 
     Q_PROPERTY(QString psiDefaultAvatarUrl MEMBER psiDefaultAvatarUrl CONSTANT)
 
@@ -116,36 +112,35 @@ signals:
     void optionsChanged(const QStringList &);
 
 public:
-    ChatViewThemeJSUtil(Theme theme, QObject *parent = 0);
+    ChatViewThemeJSUtil(ChatViewThemePrivate *theme, QObject *parent = nullptr);
     void putToCache(const QString &key, const QVariant &data);
 
 public slots:
     QVariantMap loadFromCacheMulti(const QVariantList &list);
-    QVariant cache(const QString &name) const;
-    QString psiOption(const QString &option) const;
-    QString psiOptions(const QStringList &options) const;
-    QString colorOption(const QString &option) const;
-    QString formatDate(const QDateTime &dt, const QString &format) const;
-    QString strftime(const QDateTime &dt, const QString &format) const;
-    void console(const QString &text) const;
-    QString status2text(int status) const;
-    QString hex2rgba(const QString &hex, float opacity);
+    QVariant    cache(const QString &name) const;
+    QString     psiOption(const QString &option) const;
+    QString     psiOptions(const QStringList &options) const;
+    QString     colorOption(const QString &option) const;
+    QString     formatDate(const QDateTime &dt, const QString &format) const;
+    QString     strftime(const QDateTime &dt, const QString &format) const;
+    void        console(const QString &text) const;
+    QString     status2text(int status) const;
+    QString     hex2rgba(const QString &hex, float opacity);
 private slots:
     void sendOptionsChanges();
     void optionsChanged(const QString &option);
 };
 
-class ChatViewThemePrivate : public ThemePrivate
-{
+class ChatViewThemePrivate : public ThemePrivate {
 public:
-    QString html;
-    QString httpRelPath;
-    QScopedPointer<ChatViewJSLoader> jsLoader;
-    QScopedPointer<ChatViewThemeJSUtil> jsUtil;// it's abslutely the same object for every theme.
-    QPointer<WebView> wv;
-    QMap<QString,QVariant> cache;
-    bool prepareSessionHtml = false; // if html should be generated by JS for each session.
-    bool transparentBackground = false;
+    QString                             html;
+    QString                             httpRelPath;
+    QScopedPointer<ChatViewJSLoader>    jsLoader;
+    QScopedPointer<ChatViewThemeJSUtil> jsUtil; // it's abslutely the same object for every theme.
+    QPointer<WebView>                   wv;
+    QMap<QString, QVariant>             cache;
+    bool                           prepareSessionHtml    = false; // if html should be generated by JS for each session.
+    bool                           transparentBackground = false;
     QPointer<NetworkAccessManager> nam;
 
 #ifdef WEBENGINE
@@ -160,16 +155,14 @@ public:
 #endif
 
     friend class ChatViewThemeJSUtil;
-#ifndef WEBENGINE
-    friend class SessionRequestHandler;
-#endif
 
     ChatViewThemePrivate(ChatViewThemeProvider *provider);
+    ~ChatViewThemePrivate();
 
-    bool exists();
-    bool load(std::function<void(bool)> loadCallback);
-    bool hasPreview() const;
-    QWidget* previewWidget();
+    bool     exists();
+    bool     load(std::function<void(bool)> loadCallback);
+    bool     hasPreview() const;
+    QWidget *previewWidget();
 
     bool isMuc() const;
 
