@@ -13,87 +13,66 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
+#include "conferencebookmark.h"
+
+#include "xmpp_xmlcommon.h"
+
 #include <QDomDocument>
 #include <QDomElement>
 #include <QObject>
-#include <QVector>
 #include <QStringList>
+#include <QVector>
 
-#include "conferencebookmark.h"
-#include "xmpp_xmlcommon.h"
-
-ConferenceBookmark::ConferenceBookmark(const QString& name, const XMPP::Jid& jid, JoinType auto_join, const QString& nick, const QString& password) : name_(name), jid_(jid), auto_join_(auto_join), nick_(nick), password_(password)
+ConferenceBookmark::ConferenceBookmark(const QString &name, const XMPP::Jid &jid, JoinType auto_join,
+                                       const QString &nick, const QString &password) :
+    name_(name),
+    jid_(jid), auto_join_(auto_join), nick_(nick), password_(password)
 {
 }
 
-ConferenceBookmark::ConferenceBookmark(const QDomElement& el) : auto_join_(Never)
-{
-    fromXml(el);
-}
+ConferenceBookmark::ConferenceBookmark(const QDomElement &el) { fromXml(el); }
 
 QStringList ConferenceBookmark::joinTypeNames()
 {
     static QStringList jtn;
     if (jtn.isEmpty()) {
         QVector<QString> tmp(LastJoinType);
-        tmp[Never] = QObject::tr("Never");
-        tmp[Always] = QObject::tr("Always");
-        tmp[OnlyThisComputer] = QObject::tr("This computer only");
+        tmp[Never]              = QObject::tr("Never");
+        tmp[Always]             = QObject::tr("Always");
+        tmp[OnlyThisComputer]   = QObject::tr("This computer only");
         tmp[ExceptThisComputer] = QObject::tr("Except this computer");
-        jtn = tmp.toList();
+        jtn                     = tmp.toList();
     }
     return jtn;
 }
 
-const QString& ConferenceBookmark::name() const
-{
-    return name_;
-}
+const QString &ConferenceBookmark::name() const { return name_; }
 
-const XMPP::Jid& ConferenceBookmark::jid() const
-{
-    return jid_;
-}
+const XMPP::Jid &ConferenceBookmark::jid() const { return jid_; }
 
-void ConferenceBookmark::setAutoJoin(JoinType type)
-{
-    auto_join_ = type;
-}
+void ConferenceBookmark::setAutoJoin(JoinType type) { auto_join_ = type; }
 
-ConferenceBookmark::JoinType ConferenceBookmark::autoJoin() const
-{
-    return auto_join_;
-}
+ConferenceBookmark::JoinType ConferenceBookmark::autoJoin() const { return auto_join_; }
 
 bool ConferenceBookmark::needJoin() const
 {
     return auto_join_ == ConferenceBookmark::Always || auto_join_ == ConferenceBookmark::OnlyThisComputer;
 }
 
-const QString& ConferenceBookmark::nick() const
-{
-    return nick_;
-}
+const QString &ConferenceBookmark::nick() const { return nick_; }
 
-const QString& ConferenceBookmark::password() const
-{
-    return password_;
-}
+const QString &ConferenceBookmark::password() const { return password_; }
 
-bool ConferenceBookmark::isNull() const
-{
-    return name_.isEmpty() && jid_.isEmpty();
-}
+bool ConferenceBookmark::isNull() const { return name_.isEmpty() && jid_.isEmpty(); }
 
-void ConferenceBookmark::fromXml(const QDomElement& e)
+void ConferenceBookmark::fromXml(const QDomElement &e)
 {
-    jid_ = e.attribute("jid");
-    name_ = e.attribute("name");
+    jid_       = e.attribute("jid");
+    name_      = e.attribute("name");
     auto_join_ = Never;
     if (e.attribute("autojoin") == "true" || e.attribute("autojoin") == "1")
         auto_join_ = Always;
@@ -104,34 +83,29 @@ void ConferenceBookmark::fromXml(const QDomElement& e)
             continue;
         else if (i.tagName() == "nick") {
             nick_ = i.text();
-        }
-        else if (i.tagName() == "password") {
+        } else if (i.tagName() == "password") {
             password_ = i.text();
         }
     }
 }
 
-QDomElement ConferenceBookmark::toXml(QDomDocument& doc) const
+QDomElement ConferenceBookmark::toXml(QDomDocument &doc) const
 {
     QDomElement e = doc.createElement("conference");
-    e.setAttribute("jid",jid_.full());
-    e.setAttribute("name",name_);
+    e.setAttribute("jid", jid_.full());
+    e.setAttribute("name", name_);
     if (auto_join_ == Always || auto_join_ == ExceptThisComputer)
-        e.setAttribute("autojoin","true");
+        e.setAttribute("autojoin", "true");
     if (!nick_.isEmpty())
-        e.appendChild(textTag(&doc,"nick",nick_));
+        e.appendChild(textTag(&doc, "nick", nick_));
     if (!password_.isEmpty())
-        e.appendChild(textTag(&doc,"password",password_));
+        e.appendChild(textTag(&doc, "password", password_));
 
     return e;
 }
 
-bool ConferenceBookmark::operator==(const ConferenceBookmark & other) const
+bool ConferenceBookmark::operator==(const ConferenceBookmark &other) const
 {
-    return
-        name_       == other.name_       &&
-        jid_.full() == other.jid_.full() &&
-        auto_join_  == other.auto_join_  &&
-        nick_       == other.nick_       &&
-        password_   == other.password_;
+    return name_ == other.name_ && jid_.full() == other.jid_.full() && auto_join_ == other.auto_join_
+        && nick_ == other.nick_ && password_ == other.password_;
 }
