@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -25,8 +24,7 @@
 
 class PsiAccount;
 
-class ContactListAccountMenu : public ContactListItemMenu
-{
+class ContactListAccountMenu : public ContactListItemMenu {
     Q_OBJECT
 public:
     ContactListAccountMenu(PsiAccount *account, ContactListModel *model);
@@ -34,7 +32,7 @@ public:
 
 private:
     class Private;
-    Private* d;
+    Private *d;
 };
 
-#endif
+#endif // CONTACTLISTACCOUNTMENU_H
