@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -25,8 +24,7 @@
 
 class QMimeData;
 
-class ContactListGroupMenu : public ContactListItemMenu
-{
+class ContactListGroupMenu : public ContactListItemMenu {
     Q_OBJECT
 public:
     ContactListGroupMenu(ContactListItem *item, ContactListModel *model);
@@ -34,11 +32,11 @@ public:
 
 signals:
     void removeSelection();
-    void removeGroupWithoutContacts(QMimeData*);
+    void removeGroupWithoutContacts(QMimeData *);
 
 private:
     class Private;
-    Private* d;
+    Private *d;
 };
 
-#endif
+#endif // CONTACTLISTGROUPMENU_H
