@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -23,28 +22,21 @@
 #include "abstracttreeitem.h"
 
 #include <QObject>
+#include <QPointer>
 #include <QString>
 #include <QVariant>
-#include <QPointer>
 
-class PsiContact;
-class PsiAccount;
-class ContactListModel;
 class ContactListItem;
 class ContactListItemMenu;
+class ContactListModel;
+class PsiAccount;
+class PsiContact;
 
-typedef QList<ContactListItem*> ContactListItemList;
+typedef QList<ContactListItem *> ContactListItemList;
 
-class ContactListItem : public AbstractTreeItem
-{
+class ContactListItem : public AbstractTreeItem {
 public:
-    enum class Type : unsigned char {
-        InvalidType = 0,
-        RootType    = 1,
-        AccountType = 2,
-        GroupType   = 3,
-        ContactType = 4
-    };
+    enum class Type : unsigned char { InvalidType = 0, RootType = 1, AccountType = 2, GroupType = 3, ContactType = 4 };
 
     enum class SpecialGroupType : unsigned char {
         GeneralSpecialGroupType         = 0,
@@ -55,12 +47,13 @@ public:
         TransportsSpecialGroupType      = 5
     };
 
-    ContactListItem(ContactListModel *model, Type type = Type::InvalidType, SpecialGroupType specialGropType = SpecialGroupType::NoneSpecialGroupType);
+    ContactListItem(ContactListModel *model, Type type = Type::InvalidType,
+                    SpecialGroupType specialGropType = SpecialGroupType::NoneSpecialGroupType);
     ~ContactListItem();
 
     ContactListModel *model() const;
 
-    Type type() const;
+    Type             type() const;
     SpecialGroupType specialGroupType() const;
 
     bool isRoot() const;
@@ -69,7 +62,7 @@ public:
     bool isContact() const;
 
     QString name() const;
-    void setName(const QString& name);
+    void    setName(const QString &name);
     QString internalName() const;
 
     bool isEditable() const;
@@ -84,15 +77,15 @@ public:
 
     bool isFixedSize() const;
 
-    bool lessThan(const ContactListItem* other) const;
+    bool lessThan(const ContactListItem *other) const;
 
     bool editing() const;
     void setEditing(bool editing);
 
-    void setContact(PsiContact *contact);
+    void        setContact(PsiContact *contact);
     PsiContact *contact() const;
 
-    void setAccount(PsiAccount *account);
+    void        setAccount(PsiAccount *account);
     PsiAccount *account() const;
 
     bool shouldBeVisible() const;
@@ -100,40 +93,43 @@ public:
     void setHidden(bool hidden);
     bool isHidden() const;
 
-    QList<PsiContact*> contacts();
+    QList<PsiContact *> contacts();
 
     ContactListItem *findAccount(PsiAccount *account);
     ContactListItem *findGroup(const QString &groupName);
     ContactListItem *findGroup(SpecialGroupType specialGroupType);
     ContactListItem *findContact(PsiContact *contact);
 
-    void setValue(int role, const QVariant &value);
+    void     setValue(int role, const QVariant &value);
     QVariant value(int role) const;
 
     void updateContactsCount() const;
 
-    QList<ContactListItem*> allChildren() const;
+    QList<ContactListItem *> allChildren() const;
 
     // fake reimplemented
-    inline ContactListItem *parent() const { return static_cast<ContactListItem*>(AbstractTreeItem::parent()); }
-    inline ContactListItem *child(int row) const { return static_cast<ContactListItem*>(AbstractTreeItem::child(row)); }
+    inline ContactListItem *parent() const { return static_cast<ContactListItem *>(AbstractTreeItem::parent()); }
+    inline ContactListItem *child(int row) const
+    {
+        return static_cast<ContactListItem *>(AbstractTreeItem::child(row));
+    }
 
 private:
     ContactListModel *_model;
-    Type _type;
-    SpecialGroupType _specialGroupType;
-    bool _editing;
+    Type              _type;
+    SpecialGroupType  _specialGroupType;
+    bool              _editing;
     bool _selfValid; // hack hack! just to find one crash in roster. remove this and QPointer wrapper below when fixed
     QPointer<PsiContact> _contact;
-    PsiAccount *_account;
-    bool _expanded;
-    QString _internalName;
-    QString _displayName;
-    mutable int _totalContacts;
-    mutable int _onlineContacts;
-    mutable bool _shouldBeVisible;
-    bool _hidden;
+    PsiAccount *         _account;
+    bool                 _expanded;
+    QString              _internalName;
+    QString              _displayName;
+    mutable int          _totalContacts;
+    mutable int          _onlineContacts;
+    mutable bool         _shouldBeVisible;
+    bool                 _hidden;
 };
 
-Q_DECLARE_METATYPE(ContactListItem*)
+Q_DECLARE_METATYPE(ContactListItem *)
 Q_DECLARE_METATYPE(ContactListItem::Type)
