@@ -13,24 +13,20 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "contactlistitemmenu.h"
 
-#include "shortcutmanager.h"
 #include "psioptions.h"
+#include "shortcutmanager.h"
 
-#include <QWidgetAction>
 #include <QLabel>
+#include <QWidgetAction>
 
-ContactListItemMenu::ContactListItemMenu(ContactListItem* item, ContactListModel* model)
-    : QMenu(0)
-    , item_(item)
-    , model_(model)
-    , _lblTitle(nullptr)
+ContactListItemMenu::ContactListItemMenu(ContactListItem *item, ContactListModel *model) :
+    QMenu(nullptr), item_(item), model_(model), _lblTitle(nullptr)
 {
     const QString css = PsiOptions::instance()->getOption("options.ui.contactlist.css").toString();
     if (!css.isEmpty()) {
@@ -38,11 +34,11 @@ ContactListItemMenu::ContactListItemMenu(ContactListItem* item, ContactListModel
     }
 
     if (PsiOptions::instance()->getOption("options.ui.contactlist.menu-titles", false).toBool()) {
-        _lblTitle = new QLabel;
-        QPalette palette = _lblTitle->palette();
-        QColor textColor = palette.color(QPalette::BrightText);
-        QColor bcgColor = palette.color(QPalette::Dark);
-        QFont font = _lblTitle->font();
+        _lblTitle          = new QLabel;
+        QPalette palette   = _lblTitle->palette();
+        QColor   textColor = palette.color(QPalette::BrightText);
+        QColor   bcgColor  = palette.color(QPalette::Dark);
+        QFont    font      = _lblTitle->font();
         font.setBold(true);
         palette.setColor(QPalette::WindowText, textColor);
         palette.setColor(QPalette::Window, bcgColor);
@@ -58,14 +54,9 @@ ContactListItemMenu::ContactListItemMenu(ContactListItem* item, ContactListModel
     }
 }
 
-ContactListItemMenu::~ContactListItemMenu()
-{
-}
+ContactListItemMenu::~ContactListItemMenu() { }
 
-ContactListItem* ContactListItemMenu::item() const
-{
-    return item_;
-}
+ContactListItem *ContactListItemMenu::item() const { return item_; }
 
 void ContactListItemMenu::setLabelTitle(const QString &title)
 {
@@ -79,8 +70,8 @@ void ContactListItemMenu::setLabelTitle(const QString &title)
  */
 void ContactListItemMenu::removeActions(QStringList actionNames)
 {
-    for (const QString &actionName: actionNames) {
-        for (QAction *action: actions()) {
+    for (const QString &actionName : actionNames) {
+        for (QAction *action : actions()) {
             if (action->objectName() == actionName) {
                 delete action;
                 break;
@@ -89,26 +80,23 @@ void ContactListItemMenu::removeActions(QStringList actionNames)
     }
 }
 
-QList<QAction*> ContactListItemMenu::availableActions() const
+QList<QAction *> ContactListItemMenu::availableActions() const
 {
-    QList<QAction*> result;
-    for (QAction* action: actions())
+    QList<QAction *> result;
+    for (QAction *action : actions())
         if (!action->isSeparator())
             result << action;
     return result;
 }
 
-QList<QKeySequence> ContactListItemMenu::shortcuts(const QString& name) const
+QList<QKeySequence> ContactListItemMenu::shortcuts(const QString &name) const
 {
     return ShortcutManager::instance()->shortcuts(name);
 }
 
-QKeySequence ContactListItemMenu::shortcut(const QString& name) const
+QKeySequence ContactListItemMenu::shortcut(const QString &name) const
 {
     return ShortcutManager::instance()->shortcut(name);
 }
 
-ContactListModel* ContactListItemMenu::model() const
-{
-    return model_;
-}
+ContactListModel *ContactListItemMenu::model() const { return model_; }
