@@ -13,45 +13,44 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
-#include <QTreeView>
-#include <QHeaderView>
-#include <QContextMenuEvent>
-#include <QSortFilterProxyModel>
-#include <QLineEdit>
-#include <QPainter>
-#include <QLinearGradient>
-#include <QScrollBar>
-#include <QCoreApplication>
+#include "contactlistview.h"
 
 #include "contactlistitem.h"
 #include "contactlistitemmenu.h"
 #include "contactlistmodel.h"
-#include "contactlistview.h"
-#include "psioptions.h"
-#include "psitooltip.h"
 #include "contactlistproxymodel.h"
 #include "debug.h"
+#include "psioptions.h"
+#include "psitooltip.h"
 
-ContactListView::ContactListView(QWidget* parent)
-    : HoverableTreeView(parent)
-    , contextMenuActive_(false)
+#include <QContextMenuEvent>
+#include <QCoreApplication>
+#include <QHeaderView>
+#include <QLineEdit>
+#include <QLinearGradient>
+#include <QPainter>
+#include <QScrollBar>
+#include <QSortFilterProxyModel>
+#include <QTreeView>
+
+ContactListView::ContactListView(QWidget *parent) : HoverableTreeView(parent), contextMenuActive_(false)
 {
     setUniformRowHeights(false);
     setAlternatingRowColors(true);
     setRootIsDecorated(false);
     // on Macs Enter key is the default EditKey, so we can't use EditKeyPressed
-    setEditTriggers(QAbstractItemView::EditKeyPressed); // lesser evil, otherwise no editing will be possible at all due to Qt bug
+    setEditTriggers(
+        QAbstractItemView::EditKeyPressed); // lesser evil, otherwise no editing will be possible at all due to Qt bug
     // setEditTriggers(QAbstractItemView::NoEditTriggers);
     setIndentation(5);
     header()->hide();
     setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);
-#if QT_VERSION < QT_VERSION_CHECK(5,7,0)
+#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
     verticalScrollBar()->setSingleStep(1); // makes scrolling really slow with qt>=5.7. w/o it Qt has some adaptive algo
 #endif
     // setItemDelegate(new PsiContactListViewDelegate(this));
@@ -60,7 +59,7 @@ ContactListView::ContactListView(QWidget* parent)
     setFrameShape(QFrame::NoFrame);
 #endif
 
-    connect(this, SIGNAL(doubleClicked(const QModelIndex&)), SLOT(itemActivated(const QModelIndex&)));
+    connect(this, &ContactListView::doubleClicked, this, &ContactListView::itemActivated);
     // showStatus_ = PsiOptions::instance()->getOption("options.ui.contactlist.status-messages.show").toBool();
 }
 
@@ -77,7 +76,7 @@ static void setExpandedState(QTreeView *view, QAbstractItemModel *model, const Q
     }
 }
 
-//void ContactListView::doItemsLayout()
+// void ContactListView::doItemsLayout()
 //{
 //    if (!model())
 //        return;
@@ -93,17 +92,11 @@ void ContactListView::updateGroupExpandedState()
     setExpandedState(this, model(), QModelIndex());
 }
 
-void ContactListView::showOfflineChanged()
-{
-    updateGroupExpandedState();
-}
+void ContactListView::showOfflineChanged() { updateGroupExpandedState(); }
 
-bool ContactListView::isContextMenuVisible()
-{
-    return contextMenu_ && contextMenuActive_;
-}
+bool ContactListView::isContextMenuVisible() { return contextMenu_ && contextMenuActive_; }
 
-void ContactListView::selectionChanged(const QItemSelection& selected, const QItemSelection& deselected)
+void ContactListView::selectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
 {
     HoverableTreeView::selectionChanged(selected, deselected);
 
@@ -116,12 +109,12 @@ void ContactListView::updateContextMenu()
         return;
 
     delete contextMenu_;
-    contextMenu_ = 0;
+    contextMenu_ = nullptr;
 
     // FIXME: need to implement context menu merging
     if (selectedIndexes().count() == 1) {
-        QModelIndex index = realIndex(selectedIndexes().first());
-        ContactListItem *item = realModel()->toItem(index);
+        QModelIndex      index = realIndex(selectedIndexes().first());
+        ContactListItem *item  = realModel()->toItem(index);
         if (item) {
             contextMenu_ = createContextMenuFor(item);
             addContextMenuActions();
@@ -129,7 +122,7 @@ void ContactListView::updateContextMenu()
     }
 }
 
-ContactListItemMenu* ContactListView::createContextMenuFor(ContactListItem* item) const
+ContactListItemMenu *ContactListView::createContextMenuFor(ContactListItem *item) const
 {
     if (item)
         return item->contextMenu();
@@ -137,13 +130,13 @@ ContactListItemMenu* ContactListView::createContextMenuFor(ContactListItem* item
     return nullptr;
 }
 
-void ContactListView::focusInEvent(QFocusEvent* event)
+void ContactListView::focusInEvent(QFocusEvent *event)
 {
     HoverableTreeView::focusInEvent(event);
     addContextMenuActions();
 }
 
-void ContactListView::focusOutEvent(QFocusEvent* event)
+void ContactListView::focusOutEvent(QFocusEvent *event)
 {
     HoverableTreeView::focusOutEvent(event);
     removeContextMenuActions();
@@ -152,57 +145,56 @@ void ContactListView::focusOutEvent(QFocusEvent* event)
 void ContactListView::addContextMenuActions()
 {
     if (contextMenu_) {
-        for (QAction* action: contextMenu_->availableActions()) {
+        for (QAction *action : contextMenu_->availableActions()) {
             addContextMenuAction(action);
         }
     }
 }
 
-void ContactListView::addContextMenuAction(QAction* action)
-{
-    addAction(action);
-}
+void ContactListView::addContextMenuAction(QAction *action) { addAction(action); }
 
 void ContactListView::removeContextMenuActions()
 {
     if (contextMenu_)
-        foreach(QAction* action, contextMenu_->availableActions())
+        for (QAction *action : contextMenu_->availableActions())
             removeAction(action);
 }
 
-void ContactListView::contextMenuEvent(QContextMenuEvent* e)
+void ContactListView::contextMenuEvent(QContextMenuEvent *e)
 {
     if (contextMenu_ && contextMenu_->availableActions().count() > 0) {
         e->accept();
         contextMenuActive_ = true;
         contextMenu_->exec(e->globalPos());
         contextMenuActive_ = false;
-    }
-    else {
+    } else {
         e->ignore();
     }
 }
 
-void ContactListView::setModel(QAbstractItemModel* model)
+void ContactListView::setModel(QAbstractItemModel *model)
 {
     HoverableTreeView::setModel(model);
-    QAbstractItemModel* connectToModel = realModel();
-    if (qobject_cast<ContactListModel*>(connectToModel)) {
-        connect(this, SIGNAL(expanded(const QModelIndex&)), SLOT(itemExpanded(const QModelIndex&)));
-        connect(this, SIGNAL(collapsed(const QModelIndex&)), SLOT(itemCollapsed(const QModelIndex&)));
-        connect(this, SIGNAL(realExpanded(const QModelIndex&)), connectToModel, SLOT(expanded(const QModelIndex&)));
-        connect(this, SIGNAL(realCollapsed(const QModelIndex&)), connectToModel, SLOT(collapsed(const QModelIndex&)));
-        connect(connectToModel, SIGNAL(inPlaceRename()), SLOT(rename()));
+    QAbstractItemModel *connectToModel = realModel();
+    if (ContactListModel *clModel = qobject_cast<ContactListModel *>(connectToModel)) {
+        connect(this, &ContactListView::expanded,
+                [&](const QModelIndex &index) { emit realExpanded(realIndex(index)); });
+        connect(this, &ContactListView::collapsed,
+                [&](const QModelIndex &index) { emit realCollapsed(realIndex(index)); });
+        connect(this, &ContactListView::realExpanded, clModel, &ContactListModel::expanded);
+        connect(this, &ContactListView::realCollapsed, clModel, &ContactListModel::collapsed);
+        connect(clModel, &ContactListModel::inPlaceRename, this, &ContactListView::rename);
 
         // connection to showOfflineChanged() should be established after the proxy model does so,
         // otherwise we won't get consistently re-expanded groups. Qt::QueuedConnection could
         // be advised for in such case.
         // connect(connectToModel, SIGNAL(showOfflineChanged()), SLOT(showOfflineChanged()));
-        connect(model, SIGNAL(layoutChanged()), SLOT(showOfflineChanged()));
+        connect(model, &QAbstractItemModel::layoutChanged, this, &ContactListView::showOfflineChanged);
+        connect(model, &QAbstractItemModel::dataChanged, this, &ContactListView::modelItemsUpdated);
     }
 }
 
-void ContactListView::resizeEvent(QResizeEvent* e)
+void ContactListView::resizeEvent(QResizeEvent *e)
 {
     HoverableTreeView::resizeEvent(e);
     if (header()->count() > 0)
@@ -213,30 +205,18 @@ void ContactListView::rowsInserted(const QModelIndex &parent, int start, int end
 {
     HoverableTreeView::rowsInserted(parent, start, end);
     for (int i = start; i <= end; ++i) {
-        QModelIndex index = parent.child(i, 0);
+        QModelIndex index = model()->index(i, 0, parent);
         if (realIndex(index).data(ContactListModel::ExpandedRole).toBool())
             setExpanded(index, true);
     }
 }
 
-void ContactListView::itemExpanded(const QModelIndex& index)
-{
-    emit realExpanded(realIndex(index));
-}
-
-void ContactListView::itemCollapsed(const QModelIndex& index)
-{
-    emit realCollapsed(realIndex(index));
-}
-
 /**
  * Branches? We don't want no steenking branches!
  */
-void ContactListView::drawBranches(QPainter*, const QRect&, const QModelIndex&) const
-{
-}
+void ContactListView::drawBranches(QPainter *, const QRect &, const QModelIndex &) const { }
 
-void ContactListView::toggleExpandedState(const QModelIndex& index)
+void ContactListView::toggleExpandedState(const QModelIndex &index)
 {
     setExpanded(index, !index.data(ContactListModel::ExpandedRole).toBool());
 }
@@ -244,7 +224,7 @@ void ContactListView::toggleExpandedState(const QModelIndex& index)
 /**
  * Make Enter/Return/F2 to not trigger editing, and make Enter/Return call activated().
  */
-void ContactListView::keyPressEvent(QKeyEvent* event)
+void ContactListView::keyPressEvent(QKeyEvent *event)
 {
     switch (event->key()) {
     case Qt::Key_F2:
@@ -255,28 +235,26 @@ void ContactListView::keyPressEvent(QKeyEvent* event)
         if (state() != EditingState || hasFocus()) {
             if (currentIndex().isValid())
                 emit doubleClicked(currentIndex());
-        }
-        else {
+        } else {
             event->ignore();
         }
         break;
     case Qt::Key_Space:
         if (state() != EditingState) {
 
-            ContactListItem *item = qvariant_cast<ContactListItem*>(currentIndex().data(ContactListModel::ContactListItemRole));
+            ContactListItem *item
+                = qvariant_cast<ContactListItem *>(currentIndex().data(ContactListModel::ContactListItemRole));
 
             if (item->isGroup()) {
                 toggleExpandedState(currentIndex());
-            }
-            else {
+            } else {
                 QContextMenuEvent e(QContextMenuEvent::Keyboard, visualRect(currentIndex()).center());
                 QCoreApplication::sendEvent(this, &e);
             }
-        }
-        else {
+        } else {
             event->ignore();
         }
-    break;
+        break;
     default:
         HoverableTreeView::keyPressEvent(event);
     }
@@ -297,7 +275,7 @@ void ContactListView::rename()
     }
 
     QModelIndex indexToEdit = indexes.first();
-    QModelIndex parent = indexToEdit.parent();
+    QModelIndex parent      = indexToEdit.parent();
     while (parent.isValid()) {
         expand(parent);
         parent = parent.parent();
@@ -310,12 +288,10 @@ void ContactListView::rename()
 /**
  * Re-implemented in order to use PsiToolTip class to display tooltips.
  */
-bool ContactListView::viewportEvent(QEvent* event)
+bool ContactListView::viewportEvent(QEvent *event)
 {
-    if (event->type() == QEvent::ToolTip &&
-        (isActiveWindow() || window()->testAttribute(Qt::WA_AlwaysShowToolTips)))
-    {
-        QHelpEvent* he = static_cast<QHelpEvent*>(event);
+    if (event->type() == QEvent::ToolTip && (isActiveWindow() || window()->testAttribute(Qt::WA_AlwaysShowToolTips))) {
+        QHelpEvent *he = static_cast<QHelpEvent *>(event);
         showToolTip(indexAt(he->pos()), he->globalPos());
         return true;
     }
@@ -323,7 +299,7 @@ bool ContactListView::viewportEvent(QEvent* event)
     return HoverableTreeView::viewportEvent(event);
 }
 
-void ContactListView::showToolTip(const QModelIndex& index, const QPoint& globalPos) const
+void ContactListView::showToolTip(const QModelIndex &index, const QPoint &globalPos) const
 {
     if (!model())
         return;
@@ -331,33 +307,27 @@ void ContactListView::showToolTip(const QModelIndex& index, const QPoint& global
     PsiToolTip::showText(globalPos, toolTip.toString(), this);
 }
 
-void ContactListView::activate(const QModelIndex& index)
-{
-    itemActivated(index);
-}
+void ContactListView::activate(const QModelIndex &index) { itemActivated(index); }
 
-void ContactListView::itemActivated(const QModelIndex& index)
+void ContactListView::itemActivated(const QModelIndex &index)
 {
     model()->setData(index, QVariant(true), ContactListModel::ActivateRole);
 }
 
-static QAbstractItemModel* realModel(QAbstractItemModel* model)
+static QAbstractItemModel *realModel(QAbstractItemModel *model)
 {
-    QSortFilterProxyModel* proxyModel = qobject_cast<QSortFilterProxyModel*>(model);
+    QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *>(model);
     if (proxyModel)
         return realModel(proxyModel->sourceModel());
     return model;
 }
 
-ContactListModel *ContactListView::realModel() const
-{
-    return qobject_cast<ContactListModel*>(::realModel(model()));
-}
+ContactListModel *ContactListView::realModel() const { return qobject_cast<ContactListModel *>(::realModel(model())); }
 
-QModelIndexList ContactListView::realIndexes(const QModelIndexList& indexes) const
+QModelIndexList ContactListView::realIndexes(const QModelIndexList &indexes) const
 {
     QModelIndexList result;
-    foreach(QModelIndex index, indexes) {
+    for (QModelIndex index : indexes) {
         QModelIndex ri = realIndex(index);
         if (ri.isValid())
             result << ri;
@@ -365,23 +335,20 @@ QModelIndexList ContactListView::realIndexes(const QModelIndexList& indexes) con
     return result;
 }
 
-static QModelIndex realIndex(QAbstractItemModel* model, QModelIndex index)
+static QModelIndex realIndex(QAbstractItemModel *model, QModelIndex index)
 {
-    QSortFilterProxyModel* proxyModel = qobject_cast<QSortFilterProxyModel*>(model);
+    QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *>(model);
     if (proxyModel)
         return realIndex(proxyModel->sourceModel(), proxyModel->mapToSource(index));
     return index;
 }
 
-QModelIndex ContactListView::realIndex(const QModelIndex& index) const
-{
-    return ::realIndex(model(), index);
-}
+QModelIndex ContactListView::realIndex(const QModelIndex &index) const { return ::realIndex(model(), index); }
 
-QModelIndexList ContactListView::proxyIndexes(const QModelIndexList& indexes) const
+QModelIndexList ContactListView::proxyIndexes(const QModelIndexList &indexes) const
 {
     QModelIndexList result;
-    foreach(QModelIndex index, indexes) {
+    for (QModelIndex index : indexes) {
         QModelIndex pi = proxyIndex(index);
         if (pi.isValid())
             result << pi;
@@ -389,33 +356,30 @@ QModelIndexList ContactListView::proxyIndexes(const QModelIndexList& indexes) co
     return result;
 }
 
-static QModelIndex proxyIndex(QAbstractItemModel* model, QModelIndex index)
+static QModelIndex proxyIndex(QAbstractItemModel *model, QModelIndex index)
 {
-    QSortFilterProxyModel* proxyModel = dynamic_cast<QSortFilterProxyModel*>(model);
+    QSortFilterProxyModel *proxyModel = dynamic_cast<QSortFilterProxyModel *>(model);
     if (proxyModel)
         return proxyIndex(proxyModel->sourceModel(), proxyModel->mapFromSource(index));
     return index;
 }
 
-QModelIndex ContactListView::proxyIndex(const QModelIndex &index) const
-{
-    return ::proxyIndex(model(), index);
-}
+QModelIndex ContactListView::proxyIndex(const QModelIndex &index) const { return ::proxyIndex(model(), index); }
 
-ContactListItem *ContactListView::itemProxy(const QModelIndex& index) const
+ContactListItem *ContactListView::itemProxy(const QModelIndex &index) const
 {
     if (!index.isValid())
-        return 0;
-    return static_cast<ContactListItem*>(realIndex(index).internalPointer());
+        return nullptr;
+    return static_cast<ContactListItem *>(realIndex(index).internalPointer());
 }
 
-QLineEdit* ContactListView::currentEditor() const
+QLineEdit *ContactListView::currentEditor() const
 {
-    QWidget* w = indexWidget(currentIndex());
-    return dynamic_cast<QLineEdit*>(w);
+    QWidget *w = indexWidget(currentIndex());
+    return dynamic_cast<QLineEdit *>(w);
 }
 
-void ContactListView::setEditingIndex(const QModelIndex& index, bool editing) const
+void ContactListView::setEditingIndex(const QModelIndex &index, bool editing) const
 {
     ContactListItem *item = itemProxy(index);
     if (item) {
@@ -423,14 +387,11 @@ void ContactListView::setEditingIndex(const QModelIndex& index, bool editing) co
     }
 }
 
-void ContactListView::closeEditor(QWidget* editor, QAbstractItemDelegate::EndEditHint hint)
+void ContactListView::closeEditor(QWidget *editor, QAbstractItemDelegate::EndEditHint hint)
 {
     setEditingIndex(currentIndex(), false);
 
     HoverableTreeView::closeEditor(editor, hint);
 }
 
-void ContactListView::ensureVisible(const QModelIndex& index)
-{
-    scrollTo(index, QAbstractItemView::EnsureVisible);
-}
+void ContactListView::ensureVisible(const QModelIndex &index) { scrollTo(index, QAbstractItemView::EnsureVisible); }
