@@ -1,26 +1,22 @@
-
-#include <QString>
-#include <QVector>
-#include <QDBusConnection>
-#include <QDBusConnectionInterface>
-#include <QDBusAbstractAdaptor>
-
-#include "common.h"
 #include "dbus.h"
 
-#include "psicontactlist.h"
-#include "psiaccount.h"
 #include "activeprofiles.h"
+#include "common.h"
+#include "psiaccount.h"
+#include "psicontactlist.h"
+
+#include <QDBusAbstractAdaptor>
+#include <QDBusConnection>
+#include <QDBusConnectionInterface>
+#include <QString>
+#include <QVector>
 
 #define PSIDBUSIFACE "org.psi_im.Psi"
 
-
-
-class PsiConAdapter : public QDBusAbstractAdaptor
-{
+class PsiConAdapter : public QDBusAbstractAdaptor {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.psi_im.Psi.Main")
-//    Q_CLASSINFO("D-Bus Introspection", ...)
+    //    Q_CLASSINFO("D-Bus Introspection", ...)
 
 public:
     PsiConAdapter(PsiCon *psicon_);
@@ -31,27 +27,19 @@ public Q_SLOTS:
     void raise();
     void sleep();
     void wake();
-/*Q_SIGNALS:
-    void psi_pong();
-*/
+    void recvNextEvent();
+    /*Q_SIGNALS:
+        void psi_pong();
+    */
 private:
     PsiCon *psicon;
 };
 
+PsiConAdapter::PsiConAdapter(PsiCon *psicon_) : QDBusAbstractAdaptor(psicon_) { psicon = psicon_; }
 
+PsiConAdapter::~PsiConAdapter() { }
 
-PsiConAdapter::PsiConAdapter(PsiCon *psicon_) : QDBusAbstractAdaptor(psicon_)
-{
-    psicon = psicon_;
-}
-
-PsiConAdapter::~PsiConAdapter()
-{}
-
-void PsiConAdapter::openURI(QString uri)
-{
-    emit ActiveProfiles::instance()->openUriRequested(uri);
-}
+void PsiConAdapter::openURI(QString uri) { emit ActiveProfiles::instance()->openUriRequested(uri); }
 
 void PsiConAdapter::setStatus(QString status, QString message)
 {
@@ -59,21 +47,13 @@ void PsiConAdapter::setStatus(QString status, QString message)
 }
 
 // FIXME libguniqueapp uses activate
-void PsiConAdapter::raise()
-{
-    emit ActiveProfiles::instance()->raiseRequested();
-}
+void PsiConAdapter::raise() { emit ActiveProfiles::instance()->raiseRequested(); }
 
-void PsiConAdapter::sleep()
-{
-    psicon->doSleep();
-}
+void PsiConAdapter::sleep() { psicon->doSleep(); }
 
-void PsiConAdapter::wake()
-{
-    psicon->doWakeup();
-}
+void PsiConAdapter::wake() { psicon->doWakeup(); }
 
+void PsiConAdapter::recvNextEvent() { psicon->recvNextEvent(); }
 
 void addPsiConAdapter(PsiCon *psicon)
 {
@@ -81,5 +61,4 @@ void addPsiConAdapter(PsiCon *psicon)
     QDBusConnection::sessionBus().registerObject("/Main", psicon);
 }
 
-
 #include "dbus.moc"
