@@ -13,25 +13,23 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef DESKTOPUTIL_H
 #define DESKTOPUTIL_H
 
-class QString;
 class QObject;
+class QString;
 class QUrl;
 
-namespace DesktopUtil
-{
-    bool openUrl(const QString& url);
-    bool openUrl(const QUrl& url);
+namespace DesktopUtil {
+bool openUrl(const QString &url);
+bool openUrl(const QUrl &url);
 
-    void setUrlHandler(const QString& scheme, QObject* receiver, const char* method);
-    void unsetUrlHandler(const QString& scheme);
-}
+void setUrlHandler(const QString &scheme, QObject *receiver, const char *method);
+void unsetUrlHandler(const QString &scheme);
+}; // namespace DesktopUtil
 
-#endif
+#endif // DESKTOPUTIL_H
