@@ -13,33 +13,31 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef DISCODLG_H
 #define DISCODLG_H
 
-#include <QDialog>
-
 #include "ui_disco.h"
 #include "xmpp_jid.h"
 
+#include <QDialog>
+
 class PsiAccount;
 class QString;
 
 using namespace XMPP;
 
-class DiscoDlg : public QDialog, public Ui::Disco
-{
+class DiscoDlg : public QDialog, public Ui::Disco {
     Q_OBJECT
 public:
-    DiscoDlg(PsiAccount *, const Jid &, const QString &node = QString::null);
+    DiscoDlg(PsiAccount *, const Jid &, const QString &node = QString());
     ~DiscoDlg();
 
-    void doDisco(QString host = QString::null, QString node = QString::null);
-    int  itemsPerPage() const;
+    void        doDisco(QString host = QString(), QString node = QString());
+    int         itemsPerPage() const;
     PsiAccount *account();
 
 signals:
@@ -48,10 +46,9 @@ signals:
 public:
     class Private;
     friend class Private;
+
 private:
     Private *d;
 };
 
-
-#endif
-
+#endif // DISCODLG_H
