@@ -1,6 +1,6 @@
 /*
  * edbsqlite.cpp
- * Copyright (C) 2011   Aleksey Andreev
+ * Copyright (C) 2011  Aleksey Andreev
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -13,23 +13,22 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
-#include <QSqlError>
-#include <QSqlDriver>
+#include "applicationinfo.h"
+//#include "common.h"
+#include "edbsqlite.h"
+#include "historyimp.h"
+#include "jidutil.h"
+#include "psicontactlist.h"
+
 #include <QJsonArray>
 #include <QJsonDocument>
 #include <QJsonObject>
-
-#include "edbsqlite.h"
-//#include "common.h"
-#include "applicationinfo.h"
-#include "psicontactlist.h"
-#include "jidutil.h"
-#include "historyimp.h"
+#include <QSqlDriver>
+#include <QSqlError>
 
 #define FAKEDELAY 0
 
@@ -39,15 +38,13 @@ using namespace XMPP;
 // EDBSqLite
 //----------------------------------------------------------------------------
 
-EDBSqLite::EDBSqLite(PsiCon *psi) : EDB(psi),
-    transactionsCounter(0),
-    lastCommitTime(QDateTime::currentDateTime()),
-    commitTimer(NULL),
-    mirror_(NULL)
+EDBSqLite::EDBSqLite(PsiCon *psi) :
+    EDB(psi), transactionsCounter(0), lastCommitTime(QDateTime::currentDateTime()), commitTimer(nullptr),
+    mirror_(nullptr)
 {
-    status = NotActive;
-    QString path = ApplicationInfo::historyDir() + "/history.db";
-    QSqlDatabase db = QSqlDatabase::addDatabase("QSQLITE", "history");
+    status            = NotActive;
+    QString      path = ApplicationInfo::historyDir() + "/history.db";
+    QSqlDatabase db   = QSqlDatabase::addDatabase("QSQLITE", "history");
     db.setDatabaseName(path);
     if (!db.open()) {
         qWarning("%s\n%s", "EDBSqLite::EDBSqLite(): Can't open base.", qUtf8Printable(db.lastError().text()));
@@ -60,32 +57,32 @@ EDBSqLite::EDBSqLite(PsiCon *psi) : EDB(psi),
         // no tables found.
         if (db.transaction()) {
             query.exec("CREATE TABLE `system` ("
-                "`key` TEXT, "
-                "`value` TEXT"
-                ");");
+                       "`key` TEXT, "
+                       "`value` TEXT"
+                       ");");
             query.exec("CREATE TABLE `accounts` ("
-                "`id` TEXT, "
-                "`lifetime` INTEGER"
-                ");");
+                       "`id` TEXT, "
+                       "`lifetime` INTEGER"
+                       ");");
             query.exec("CREATE TABLE `contacts` ("
-                "`id` INTEGER NOT NULL PRIMARY KEY ASC, "
-                "`acc_id` TEXT, "
-                "`type` INTEGER, "
-                "`jid` TEXT, "
-                "`lifetime` INTEGER"
-                ");");
+                       "`id` INTEGER NOT NULL PRIMARY KEY ASC, "
+                       "`acc_id` TEXT, "
+                       "`type` INTEGER, "
+                       "`jid` TEXT, "
+                       "`lifetime` INTEGER"
+                       ");");
             query.exec("CREATE TABLE `events` ("
-                "`id` INTEGER NOT NULL PRIMARY KEY ASC, "
-                "`contact_id` INTEGER NOT NULL REFERENCES `contacts`(`id`) ON DELETE CASCADE, "
-                "`resource` TEXT, "
-                "`date` TEXT, "
-                "`type` INTEGER, "
-                "`direction` INTEGER, "
-                "`subject` TEXT, "
-                "`m_text` TEXT, "
-                "`lang` TEXT, "
-                "`extra_data` TEXT"
-                ");");
+                       "`id` INTEGER NOT NULL PRIMARY KEY ASC, "
+                       "`contact_id` INTEGER NOT NULL REFERENCES `contacts`(`id`) ON DELETE CASCADE, "
+                       "`resource` TEXT, "
+                       "`date` TEXT, "
+                       "`type` INTEGER, "
+                       "`direction` INTEGER, "
+                       "`subject` TEXT, "
+                       "`m_text` TEXT, "
+                       "`lang` TEXT, "
+                       "`extra_data` TEXT"
+                       ");");
             query.exec("CREATE INDEX `key` ON `system` (`key`);");
             query.exec("CREATE INDEX `jid` ON `contacts` (`jid`);");
             query.exec("CREATE INDEX `contact_id` ON `events` (`contact_id`);");
@@ -96,8 +93,7 @@ EDBSqLite::EDBSqLite(PsiCon *psi) : EDB(psi),
                 setStorageParam("import_start", "yes");
             }
         }
-    }
-    else
+    } else
         status = Commited;
 }
 
@@ -110,6 +106,7 @@ EDBSqLite::~EDBSqLite()
             db.close();
     }
     QSqlDatabase::removeDatabase("history");
+    delete mirror_;
 }
 
 bool EDBSqLite::init()
@@ -128,22 +125,19 @@ bool EDBSqLite::init()
     return true;
 }
 
-int EDBSqLite::features() const
-{
-    return SeparateAccounts | PrivateContacts | AllContacts | AllAccounts;
-}
+int EDBSqLite::features() const { return SeparateAccounts | PrivateContacts | AllContacts | AllAccounts; }
 
 int EDBSqLite::get(const QString &accId, const XMPP::Jid &jid, QDateTime date, int direction, int start, int len)
 {
     item_query_req *r = new item_query_req;
-    r->accId = accId;
-    r->j     = jid;
-    r->type  = item_query_req::Type_get;
-    r->start = start;
-    r->len   = len < 1 ? 1 : len;
-    r->dir   = direction;
-    r->date  = date;
-    r->id    = genUniqueId();
+    r->accId          = accId;
+    r->j              = jid;
+    r->type           = item_query_req::Type_get;
+    r->start          = start;
+    r->len            = len < 1 ? 1 : len;
+    r->dir            = direction;
+    r->date           = date;
+    r->id             = genUniqueId();
     rlist.append(r);
 
     QTimer::singleShot(FAKEDELAY, this, SLOT(performRequests()));
@@ -153,14 +147,14 @@ int EDBSqLite::get(const QString &accId, const XMPP::Jid &jid, QDateTime date, i
 int EDBSqLite::find(const QString &accId, const QString &str, const XMPP::Jid &jid, const QDateTime date, int direction)
 {
     item_query_req *r = new item_query_req;
-    r->accId   = accId;
-    r->j       = jid;
-    r->type    = item_query_req::Type_find;
-    r->len     = 1;
-    r->dir     = direction;
-    r->findStr = str;
-    r->date    = date;
-    r->id      = genUniqueId();
+    r->accId          = accId;
+    r->j              = jid;
+    r->type           = item_query_req::Type_find;
+    r->len            = 1;
+    r->dir            = direction;
+    r->findStr        = str;
+    r->date           = date;
+    r->id             = genUniqueId();
     rlist.append(r);
 
     QTimer::singleShot(FAKEDELAY, this, SLOT(performRequests()));
@@ -170,17 +164,17 @@ int EDBSqLite::find(const QString &accId, const QString &str, const XMPP::Jid &j
 int EDBSqLite::append(const QString &accId, const XMPP::Jid &jid, const PsiEvent::Ptr &e, int type)
 {
     item_query_req *r = new item_query_req;
-    r->accId   = accId;
-    r->j       = jid;
-    r->jidType = type;
-    r->type    = item_query_req::Type_append;
-    r->event   = e;
-    if ( !r->event ) {
+    r->accId          = accId;
+    r->j              = jid;
+    r->jidType        = type;
+    r->type           = item_query_req::Type_append;
+    r->event          = e;
+    if (!r->event) {
         qWarning("EDBSqLite::append(): Attempted to append incompatible type.");
         delete r;
         return 0;
     }
-    r->id      = genUniqueId();
+    r->id = genUniqueId();
     rlist.append(r);
 
     QTimer::singleShot(FAKEDELAY, this, SLOT(performRequests()));
@@ -194,10 +188,10 @@ int EDBSqLite::append(const QString &accId, const XMPP::Jid &jid, const PsiEvent
 int EDBSqLite::erase(const QString &accId, const XMPP::Jid &jid)
 {
     item_query_req *r = new item_query_req;
-    r->accId = accId;
-    r->j     = jid;
-    r->type  = item_query_req::Type_erase;
-    r->id    = genUniqueId();
+    r->accId          = accId;
+    r->j              = jid;
+    r->type           = item_query_req::Type_erase;
+    r->id             = genUniqueId();
     rlist.append(r);
 
     QTimer::singleShot(FAKEDELAY, this, SLOT(performRequests()));
@@ -210,7 +204,7 @@ int EDBSqLite::erase(const QString &accId, const XMPP::Jid &jid)
 
 QList<EDB::ContactItem> EDBSqLite::contacts(const QString &accId, int type)
 {
-    QList<ContactItem> res;
+    QList<ContactItem>        res;
     EDBSqLite::PreparedQuery *query = queryes.getPreparedQuery(QueryContactsList, accId.isEmpty(), true);
     query->bindValue(":type", type);
     if (!accId.isEmpty())
@@ -227,10 +221,10 @@ QList<EDB::ContactItem> EDBSqLite::contacts(const QString &accId, int type)
 
 quint64 EDBSqLite::eventsCount(const QString &accId, const XMPP::Jid &jid)
 {
-    quint64 res = 0;
-    bool fAccAll  = accId.isEmpty();
-    bool fContAll = jid.isEmpty();
-    EDBSqLite::PreparedQuery *query = queryes.getPreparedQuery(QueryRowCount, fAccAll, fContAll);
+    quint64                   res      = 0;
+    bool                      fAccAll  = accId.isEmpty();
+    bool                      fContAll = jid.isEmpty();
+    EDBSqLite::PreparedQuery *query    = queryes.getPreparedQuery(QueryRowCount, fAccAll, fContAll);
     if (!fAccAll)
         query->bindValue(":acc_id", accId);
     if (!fContAll)
@@ -261,8 +255,7 @@ void EDBSqLite::setStorageParam(const QString &key, const QString &val)
         query.prepare("DELETE FROM `system` WHERE `key` = :key;");
         query.bindValue(":key", key);
         query.exec();
-    }
-    else {
+    } else {
         query.prepare("SELECT COUNT(*) AS `count` FROM `system` WHERE `key` = :key;");
         query.bindValue(":key", key);
         if (query.exec() && query.next() && query.record().value("count").toULongLong() != 0) {
@@ -270,8 +263,7 @@ void EDBSqLite::setStorageParam(const QString &key, const QString &val)
             query.bindValue(":key", key);
             query.bindValue(":val", val);
             query.exec();
-        }
-        else {
+        } else {
             query.prepare("INSERT INTO `system` (`key`, `value`) VALUES (:key, :val);");
             query.bindValue(":key", key);
             query.bindValue(":val", val);
@@ -308,18 +300,15 @@ void EDBSqLite::setMirror(EDBFlatFile *mirr)
     }
 }
 
-EDBFlatFile *EDBSqLite::mirror() const
-{
-    return mirror_;
-}
+EDBFlatFile *EDBSqLite::mirror() const { return mirror_; }
 
 void EDBSqLite::performRequests()
 {
     if (rlist.isEmpty())
         return;
 
-    item_query_req *r = rlist.takeFirst();
-    const int type = r->type;
+    item_query_req *r    = rlist.takeFirst();
+    const int       type = r->type;
 
     if (type == item_query_req::Type_append) {
         bool b = appendEvent(r->accId, r->j, r->event, r->jidType);
@@ -328,8 +317,8 @@ void EDBSqLite::performRequests()
 
     else if (type == item_query_req::Type_get) {
         commit();
-        bool fContAll = r->j.isEmpty();
-        bool fAccAll  = r->accId.isEmpty();
+        bool      fContAll = r->j.isEmpty();
+        bool      fAccAll  = r->accId.isEmpty();
         QueryType queryType;
         if (r->date.isNull()) {
             if (r->dir == Forward)
@@ -377,11 +366,11 @@ void EDBSqLite::performRequests()
         }
         resultReady(r->id, result, beginRow);
 
-    } else if(type == item_query_req::Type_find) {
+    } else if (type == item_query_req::Type_find) {
         commit();
-        bool fContAll = r->j.isEmpty();
-        bool fAccAll  = r->accId.isEmpty();
-        EDBSqLite::PreparedQuery *query = queryes.getPreparedQuery(QueryFindText, fAccAll, fContAll);
+        bool                      fContAll = r->j.isEmpty();
+        bool                      fAccAll  = r->accId.isEmpty();
+        EDBSqLite::PreparedQuery *query    = queryes.getPreparedQuery(QueryFindText, fAccAll, fContAll);
         if (!fContAll)
             query->bindValue(":jid", r->j.full());
         if (!fAccAll)
@@ -395,7 +384,7 @@ void EDBSqLite::performRequests()
                     continue;
                 PsiEvent::Ptr e(getEvent(rec));
                 if (e) {
-                    QString id = rec.value("id").toString();
+                    QString    id  = rec.value("id").toString();
                     EDBItemPtr eip = EDBItemPtr(new EDBItem(e, id));
                     result.append(eip);
                 }
@@ -404,7 +393,7 @@ void EDBSqLite::performRequests()
         }
         resultReady(r->id, result, 0);
 
-    } else if(type == item_query_req::Type_erase) {
+    } else if (type == item_query_req::Type_erase) {
         writeFinished(r->id, eraseHistory(r->accId, r->j));
     }
 
@@ -413,36 +402,36 @@ void EDBSqLite::performRequests()
 
 bool EDBSqLite::appendEvent(const QString &accId, const XMPP::Jid &jid, const PsiEvent::Ptr &e, int jidType)
 {
-    QSqlDatabase db = QSqlDatabase::database("history");
+    QSqlDatabase db        = QSqlDatabase::database("history");
     const qint64 contactId = ensureJidRowId(accId, jid, jidType);
     if (contactId == 0)
         return false;
 
     QDateTime dTime;
-    int nType = 0;
+    int       nType = 0;
 
     if (e->type() == PsiEvent::Message) {
         MessageEvent::Ptr me = e.staticCast<MessageEvent>();
-        const Message &m = me->message();
-        dTime = m.timeStamp();
+        const Message &   m  = me->message();
+        dTime                = m.timeStamp();
         if (m.type() == "chat")
             nType = 1;
-        else if(m.type() == "error")
+        else if (m.type() == "error")
             nType = 4;
-        else if(m.type() == "headline")
+        else if (m.type() == "headline")
             nType = 5;
 
     } else if (e->type() == PsiEvent::Auth) {
         AuthEvent::Ptr ae = e.staticCast<AuthEvent>();
-        dTime = ae->timeStamp();
-        QString subType = ae->authType();
-        if(subType == "subscribe")
+        dTime             = ae->timeStamp();
+        QString subType   = ae->authType();
+        if (subType == "subscribe")
             nType = 3;
-        else if(subType == "subscribed")
+        else if (subType == "subscribed")
             nType = 6;
-        else if(subType == "unsubscribe")
+        else if (subType == "unsubscribe")
             nType = 7;
-        else if(subType == "unsubscribed")
+        else if (subType == "unsubscribed")
             nType = 8;
     } else
         return false;
@@ -458,18 +447,18 @@ bool EDBSqLite::appendEvent(const QString &accId, const XMPP::Jid &jid, const Ps
     query->bindValue(":type", nType);
     query->bindValue(":direction", nDirection);
     if (nType == 0 || nType == 1 || nType == 4 || nType == 5) {
-        MessageEvent::Ptr me = e.staticCast<MessageEvent>();
-        const Message &m = me->message();
-        QString lang = m.lang();
+        MessageEvent::Ptr me   = e.staticCast<MessageEvent>();
+        const Message &   m    = me->message();
+        QString           lang = m.lang();
         query->bindValue(":subject", m.subject(lang));
         query->bindValue(":m_text", m.body(lang));
         query->bindValue(":lang", lang);
-        QString extraData;
+        QString        extraData;
         const UrlList &urls = m.urlList();
         if (!urls.isEmpty()) {
-            QVariantMap xepList;
+            QVariantMap  xepList;
             QVariantList urlList;
-            foreach (const Url &url, urls)
+            for (const Url &url : urls)
                 if (!url.url().isEmpty()) {
                     QVariantList urlItem;
                     urlItem.append(QVariant(url.url()));
@@ -479,11 +468,10 @@ bool EDBSqLite::appendEvent(const QString &accId, const XMPP::Jid &jid, const Ps
                 }
             xepList["jabber:x:oob"] = QVariant(urlList);
             QJsonDocument doc(QJsonObject::fromVariantMap(xepList));
-            extraData = QString::fromUtf8(doc.toBinaryData());
+            extraData = QString::fromUtf8(doc.toJson());
         }
         query->bindValue(":extra_data", extraData);
-    }
-    else {
+    } else {
         query->bindValue(":subject", QVariant(QVariant::String));
         query->bindValue(":m_text", QVariant(QVariant::String));
         query->bindValue(":lang", QVariant(QVariant::String));
@@ -499,14 +487,14 @@ PsiEvent::Ptr EDBSqLite::getEvent(const QSqlRecord &record)
 
     int type = record.value("type").toInt();
 
-    if(type == 0 || type == 1 || type == 4 || type == 5) {
+    if (type == 0 || type == 1 || type == 4 || type == 5) {
         Message m;
         m.setTimeStamp(record.value("date").toDateTime());
-        if(type == 1)
+        if (type == 1)
             m.setType("chat");
-        else if(type == 4)
+        else if (type == 4)
             m.setType("error");
-        else if(type == 5)
+        else if (type == 5)
             m.setType("headline");
         else
             m.setType("");
@@ -520,13 +508,14 @@ PsiEvent::Ptr EDBSqLite::getEvent(const QSqlRecord &record)
         m.setSpooled(true);
         QString extraStr = record.value("extra_data").toString();
         if (!extraStr.isEmpty()) {
-            bool fOk;
-            QJsonDocument doc = QJsonDocument::fromJson(extraStr.toUtf8());
-            fOk = !doc.isNull();
+            bool          fOk;
+            QJsonDocument doc     = QJsonDocument::fromJson(extraStr.toUtf8());
+            fOk                   = !doc.isNull();
             QVariantMap extraData = doc.object().toVariantMap();
 
             if (fOk) {
-                foreach (const QVariant &urlItem, extraData["jabber:x:oob"].toList()) {
+                const auto urls = extraData["jabber:x:oob"].toList();
+                for (const QVariant &urlItem : urls) {
                     QVariantList itemList = urlItem.toList();
                     if (!itemList.isEmpty()) {
                         QString url = itemList.at(0).toString();
@@ -543,16 +532,16 @@ PsiEvent::Ptr EDBSqLite::getEvent(const QSqlRecord &record)
         return me.staticCast<PsiEvent>();
     }
 
-    if(type == 2 || type == 3 || type == 6 || type == 7 || type == 8) {
+    if (type == 2 || type == 3 || type == 6 || type == 7 || type == 8) {
         QString subType = "subscribe";
         // if(type == 2) { // Not used (stupid "system message" from Psi <= 0.8.6)
-        if(type == 3)
+        if (type == 3)
             subType = "subscribe";
-        else if(type == 6)
+        else if (type == 6)
             subType = "subscribed";
-        else if(type == 7)
+        else if (type == 7)
             subType = "unsubscribe";
-        else if(type == 8)
+        else if (type == 8)
             subType = "unsubscribed";
 
         AuthEvent::Ptr ae(new AuthEvent(Jid(record.value("jid").toString()), subType, pa));
@@ -568,7 +557,7 @@ qint64 EDBSqLite::ensureJidRowId(const QString &accId, const XMPP::Jid &jid, int
         return 0;
     QString sJid = (type == GroupChatContact) ? jid.full() : jid.bare();
     QString sKey = accId + "|" + sJid;
-    qint64 id = jidsCache.value(sKey, 0);
+    qint64  id   = jidsCache.value(sKey, 0);
     if (id != 0)
         return id;
 
@@ -582,12 +571,12 @@ qint64 EDBSqLite::ensureJidRowId(const QString &accId, const XMPP::Jid &jid, int
             //
             QSqlQuery queryIns(QSqlDatabase::database("history"));
             queryIns.prepare("INSERT INTO `contacts` (`acc_id`, `type`, `jid`, `lifetime`)"
-                " VALUES (:acc_id, :type, :jid, -1);");
+                             " VALUES (:acc_id, :type, :jid, -1);");
             queryIns.bindValue(":acc_id", accId);
             queryIns.bindValue(":type", type);
             queryIns.bindValue(":jid", sJid);
             if (queryIns.exec()) {
-                id  = queryIns.lastInsertId().toLongLong();
+                id = queryIns.lastInsertId().toLongLong();
             }
         }
         query->freeResult();
@@ -599,8 +588,8 @@ qint64 EDBSqLite::ensureJidRowId(const QString &accId, const XMPP::Jid &jid, int
 
 int EDBSqLite::rowCount(const QString &accId, const XMPP::Jid &jid, QDateTime before)
 {
-    bool fAccAll  = accId.isEmpty();
-    bool fContAll = jid.isEmpty();
+    bool      fAccAll  = accId.isEmpty();
+    bool      fContAll = jid.isEmpty();
     QueryType type;
     if (before.isNull())
         type = QueryRowCount;
@@ -631,20 +620,19 @@ bool EDBSqLite::eraseHistory(const QString &accId, const XMPP::Jid &jid)
 
     if (accId.isEmpty() && jid.isEmpty()) {
         QSqlQuery query(QSqlDatabase::database("history"));
-        //if (query.exec("DELETE FROM `events`;"))
-            if (query.exec("DELETE FROM `contacts`;")) {
-                jidsCache.clear();
-                res = true;
-            }
-    }
-    else {
+        // if (query.exec("DELETE FROM `events`;"))
+        if (query.exec("DELETE FROM `contacts`;")) {
+            jidsCache.clear();
+            res = true;
+        }
+    } else {
         PreparedQuery *query = queryes.getPreparedQuery(QueryJidRowId, false, false);
         query->bindValue(":jid", jid.full());
         query->bindValue(":acc_id", accId);
         if (query->exec()) {
             if (query->next()) {
                 const qint64 id = query->record().value("id").toLongLong();
-                QSqlQuery query2(QSqlDatabase::database("history"));
+                QSqlQuery    query2(QSqlDatabase::database("history"));
                 query2.prepare("DELETE FROM `events` WHERE `contact_id` = :id;");
                 query2.bindValue(":id", id);
                 if (query2.exec()) {
@@ -673,7 +661,7 @@ bool EDBSqLite::transaction(bool now)
     if (status == NotActive)
         return false;
     if (now || transactionsCounter >= maxUncommitedRecs
-            || lastCommitTime.secsTo(QDateTime::currentDateTime()) >= maxUncommitedSecs)
+        || lastCommitTime.secsTo(QDateTime::currentDateTime()) >= maxUncommitedSecs)
         if (!commit())
             return false;
 
@@ -694,8 +682,8 @@ bool EDBSqLite::commit()
     if (status != NotActive) {
         if (status == Commited || QSqlDatabase::database("history").commit()) {
             transactionsCounter = 0;
-            lastCommitTime = QDateTime::currentDateTime();
-            status = Commited;
+            lastCommitTime      = QDateTime::currentDateTime();
+            status              = Commited;
             stopAutocommitTimer();
             return true;
         }
@@ -707,8 +695,8 @@ bool EDBSqLite::rollback()
 {
     if (status == NotCommited && QSqlDatabase::database("history").rollback()) {
         transactionsCounter = 0;
-        lastCommitTime = QDateTime::currentDateTime();
-        status = Commited;
+        lastCommitTime      = QDateTime::currentDateTime();
+        status              = Commited;
         stopAutocommitTimer();
         return true;
     }
@@ -721,7 +709,7 @@ void EDBSqLite::startAutocommitTimer()
         commitTimer = new QTimer(this);
         connect(commitTimer, SIGNAL(timeout()), this, SLOT(commit()));
         commitTimer->setSingleShot(true);
-        commitTimer->setInterval(commitByTimeoutSecs * 1000);
+        commitTimer->setInterval(int(commitByTimeoutSecs) * 1000);
     }
     commitTimer->start();
 }
@@ -734,7 +722,7 @@ void EDBSqLite::stopAutocommitTimer()
 
 bool EDBSqLite::importExecute()
 {
-    bool res = true;
+    bool           res = true;
     HistoryImport *imp = new HistoryImport(psi());
     if (imp->isNeeded()) {
         if (imp->exec() != HistoryImport::ResultNormal) {
@@ -747,13 +735,11 @@ bool EDBSqLite::importExecute()
 
 // ****************** class PreparedQueryes ********************
 
-EDBSqLite::QueryStorage::QueryStorage()
-{
-}
+EDBSqLite::QueryStorage::QueryStorage() { }
 
 EDBSqLite::QueryStorage::~QueryStorage()
 {
-    foreach (EDBSqLite::PreparedQuery *q, queryList.values()) {
+    for (EDBSqLite::PreparedQuery *q : queryList.values()) {
         if (q)
             delete q;
     }
@@ -761,9 +747,9 @@ EDBSqLite::QueryStorage::~QueryStorage()
 
 EDBSqLite::PreparedQuery *EDBSqLite::QueryStorage::getPreparedQuery(QueryType type, bool allAccounts, bool allContacts)
 {
-    QueryProperty queryProp(type, allAccounts, allContacts);
-    EDBSqLite::PreparedQuery *q = queryList.value(queryProp, NULL);
-    if (q != NULL)
+    QueryProperty             queryProp(type, allAccounts, allContacts);
+    EDBSqLite::PreparedQuery *q = queryList.value(queryProp, nullptr);
+    if (q != nullptr)
         return q;
 
     q = new EDBSqLite::PreparedQuery(QSqlDatabase::database("history"));
@@ -773,76 +759,75 @@ EDBSqLite::PreparedQuery *EDBSqLite::QueryStorage::getPreparedQuery(QueryType ty
     return q;
 }
 
-EDBSqLite::PreparedQuery::PreparedQuery(QSqlDatabase db) : QSqlQuery(db)
-{
-}
+EDBSqLite::PreparedQuery::PreparedQuery(QSqlDatabase db) : QSqlQuery(db) { }
 
 QString EDBSqLite::QueryStorage::getQueryString(QueryType type, bool allAccounts, bool allContacts)
 {
     QString queryStr;
-    switch (type)
-    {
-        case QueryContactsList:
-            queryStr = "SELECT `acc_id`, `jid` FROM `contacts` WHERE `type` = :type";
-            if (!allAccounts)
-                queryStr.append(" AND `acc_id` = :acc_id");
-            queryStr.append(" ORDER BY `jid`;");
-            break;
-        case QueryLatest:
-        case QueryOldest:
-        case QueryDateBackward:
-        case QueryDateForward:
-            queryStr = "SELECT `acc_id`, `events`.`id`, `jid`, `date`, `events`.`type`, `direction`, `subject`, `m_text`, `lang`, `extra_data`"
-                " FROM `events`, `contacts`"
-                " WHERE `contacts`.`id` = `contact_id`";
-            if (!allContacts)
-                queryStr.append(" AND `jid` = :jid");
-            if (!allAccounts)
-                queryStr.append(" AND `acc_id` = :acc_id");
-            if (type == QueryDateBackward)
-                queryStr.append(" AND `date` < :date");
-            else if (type == QueryDateForward)
-                queryStr.append(" AND `date` >= :date");
-            if (type == QueryLatest || type == QueryDateBackward)
-                queryStr.append(" ORDER BY `date` DESC");
-            else
-                queryStr.append(" ORDER BY `date` ASC");
-            queryStr.append(" LIMIT :start, :cnt;");
-            break;
-        case QueryRowCount:
-        case QueryRowCountBefore:
-            queryStr = "SELECT count(*) AS `count`"
-                " FROM `events`, `contacts`"
-                " WHERE `contacts`.`id` = `contact_id`";
-            if (!allContacts)
-                queryStr.append(" AND `jid` = :jid");
-            if (!allAccounts)
-                queryStr.append(" AND `acc_id` = :acc_id");
-            if (type == QueryRowCountBefore)
-                queryStr.append(" AND `date` < :date");
-            queryStr.append(";");
-            break;
-        case QueryJidRowId:
-            queryStr = "SELECT `id` FROM `contacts` WHERE `jid` = :jid AND acc_id = :acc_id;";
-            break;
-        case QueryFindText:
-            queryStr = "SELECT `acc_id`, `events`.`id`, `jid`, `date`, `events`.`type`, `direction`, `subject`, `m_text`, `lang`, `extra_data`"
-                " FROM `events`, `contacts`"
-                " WHERE `contacts`.`id` = `contact_id`";
-            if (!allContacts)
-                queryStr.append(" AND `jid` = :jid");
-            if (!allAccounts)
-                queryStr.append(" AND `acc_id` = :acc_id");
-            queryStr.append(" AND `m_text` IS NOT NULL");
-            queryStr.append(" ORDER BY `date`;");
-            break;
-        case QueryInsertEvent:
-            queryStr = "INSERT INTO `events` ("
-                "`contact_id`, `resource`, `date`, `type`, `direction`, `subject`, `m_text`, `lang`, `extra_data`"
-                ") VALUES ("
-                ":contact_id, :resource, :date, :type, :direction, :subject, :m_text, :lang, :extra_data"
-                ");";
-            break;
+    switch (type) {
+    case QueryContactsList:
+        queryStr = "SELECT `acc_id`, `jid` FROM `contacts` WHERE `type` = :type";
+        if (!allAccounts)
+            queryStr.append(" AND `acc_id` = :acc_id");
+        queryStr.append(" ORDER BY `jid`;");
+        break;
+    case QueryLatest:
+    case QueryOldest:
+    case QueryDateBackward:
+    case QueryDateForward:
+        queryStr = "SELECT `acc_id`, `events`.`id`, `jid`, `date`, `events`.`type`, `direction`, `subject`, `m_text`, "
+                   "`lang`, `extra_data`"
+                   " FROM `events`, `contacts`"
+                   " WHERE `contacts`.`id` = `contact_id`";
+        if (!allContacts)
+            queryStr.append(" AND `jid` = :jid");
+        if (!allAccounts)
+            queryStr.append(" AND `acc_id` = :acc_id");
+        if (type == QueryDateBackward)
+            queryStr.append(" AND `date` < :date");
+        else if (type == QueryDateForward)
+            queryStr.append(" AND `date` >= :date");
+        if (type == QueryLatest || type == QueryDateBackward)
+            queryStr.append(" ORDER BY `date` DESC");
+        else
+            queryStr.append(" ORDER BY `date` ASC");
+        queryStr.append(" LIMIT :start, :cnt;");
+        break;
+    case QueryRowCount:
+    case QueryRowCountBefore:
+        queryStr = "SELECT count(*) AS `count`"
+                   " FROM `events`, `contacts`"
+                   " WHERE `contacts`.`id` = `contact_id`";
+        if (!allContacts)
+            queryStr.append(" AND `jid` = :jid");
+        if (!allAccounts)
+            queryStr.append(" AND `acc_id` = :acc_id");
+        if (type == QueryRowCountBefore)
+            queryStr.append(" AND `date` < :date");
+        queryStr.append(";");
+        break;
+    case QueryJidRowId:
+        queryStr = "SELECT `id` FROM `contacts` WHERE `jid` = :jid AND acc_id = :acc_id;";
+        break;
+    case QueryFindText:
+        queryStr = "SELECT `acc_id`, `events`.`id`, `jid`, `date`, `events`.`type`, `direction`, `subject`, `m_text`, "
+                   "`lang`, `extra_data`"
+                   " FROM `events`, `contacts`"
+                   " WHERE `contacts`.`id` = `contact_id`";
+        if (!allContacts)
+            queryStr.append(" AND `jid` = :jid");
+        if (!allAccounts)
+            queryStr.append(" AND `acc_id` = :acc_id");
+        queryStr.append(" AND `m_text` IS NOT NULL");
+        queryStr.append(" ORDER BY `date`;");
+        break;
+    case QueryInsertEvent:
+        queryStr = "INSERT INTO `events` ("
+                   "`contact_id`, `resource`, `date`, `type`, `direction`, `subject`, `m_text`, `lang`, `extra_data`"
+                   ") VALUES ("
+                   ":contact_id, :resource, :date, :type, :direction, :subject, :m_text, :lang, :extra_data"
+                   ");";
+        break;
     }
     return queryStr;
 }
@@ -851,8 +836,8 @@ uint qHash(const QueryProperty &struc)
 {
     uint res = struc.type;
     res <<= 8;
-    res |=  struc.allAccounts ? 1 : 0;
+    res |= struc.allAccounts ? 1 : 0;
     res <<= 8;
-    res |=  struc.allContacts ? 1 : 0;
+    res |= struc.allContacts ? 1 : 0;
     return res;
 }
