@@ -1,6 +1,6 @@
 /*
  * eventdlg.h - dialog for sending / receiving messages and events
- * Copyright (C) 2001, 2002  Justin Karneges
+ * Copyright (C) 2001-2002  Justin Karneges
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -13,43 +13,41 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef EVENTDLG_H
 #define EVENTDLG_H
 
+#include "advwidget.h"
+#include "psievent.h"
+#include "ui_addurl.h"
+#include "userlist.h"
+#include "xmpp_rosterx.h"
+#include "xmpp_url.h"
+
 #include <QLineEdit>
 #include <QListWidget>
 
-#include "xmpp_url.h"
-#include "xmpp_rosterx.h"
-#include "ui_addurl.h"
-#include "advwidget.h"
-#include "userlist.h"
-#include "psievent.h"
-
+class EventDlg;
+class PsiAccount;
+class PsiCon;
+class PsiHttpAuthRequest;
+class PsiIcon;
 class QDateTime;
 class QStringList;
-class PsiCon;
-class PsiAccount;
-class PsiIcon;
-class EventDlg;
-namespace XMPP {
-    class Jid;
-    class XData;
-}
-class PsiHttpAuthRequest;
 
+namespace XMPP {
+class Jid;
+class XData;
+}
 using namespace XMPP;
 
-class ELineEdit : public QLineEdit
-{
+class ELineEdit : public QLineEdit {
     Q_OBJECT
 public:
-    ELineEdit(EventDlg *parent, const char *name=0);
+    ELineEdit(EventDlg *parent, const char *name = nullptr);
 
 signals:
     void changeResource(const QString &);
@@ -60,36 +58,35 @@ protected:
     void dragEnterEvent(QDragEnterEvent *);
     void dropEvent(QDropEvent *);
     void keyPressEvent(QKeyEvent *);
-    //QMenu *createPopupMenu();
+    // QMenu *createPopupMenu();
 
 private slots:
-    void resourceMenuActivated(QAction*);
+    void resourceMenuActivated(QAction *);
 
 private:
     UserResourceList url;
 };
 
-class AttachView : public QListWidget
-{
+class AttachView : public QListWidget {
     Q_OBJECT
 public:
-    AttachView(QWidget* parent);
+    AttachView(QWidget *parent);
     ~AttachView();
 
     void setReadOnly(bool);
     void urlAdd(const QString &, const QString &);
-    void gcAdd(const QString &, const QString& = QString(), const QString& = QString(), const QString& = QString());
+    void gcAdd(const QString &, const QString & = QString(), const QString & = QString(), const QString & = QString());
 
     UrlList urlList() const;
-    void addUrlList(const UrlList &);
+    void    addUrlList(const UrlList &);
 
 signals:
     void childCountChanged();
-    void actionGCJoin(const QString &, const QString&);
+    void actionGCJoin(const QString &, const QString &);
 
 protected:
     // reimplemented
-    void contextMenuEvent(QContextMenuEvent* e);
+    void contextMenuEvent(QContextMenuEvent *e);
 
 private slots:
     void qlv_doubleClicked(QListWidgetItem *);
@@ -100,16 +97,14 @@ private:
     void goURL(const QString &);
 };
 
-class AddUrlDlg : public QDialog, public Ui::AddUrl
-{
+class AddUrlDlg : public QDialog, public Ui::AddUrl {
     Q_OBJECT
 public:
-    AddUrlDlg(QWidget *parent=0);
+    AddUrlDlg(QWidget *parent = nullptr);
     ~AddUrlDlg();
 };
 
-class EventDlg : public AdvancedWidget<QWidget>
-{
+class EventDlg : public AdvancedWidget<QWidget> {
     Q_OBJECT
 public:
     // compose
@@ -121,16 +116,16 @@ public:
     static bool messagingEnabled();
 
     QString text() const;
-    bool isForAll() const;
-    void setHtml(const QString &);
-    void setSubject(const QString &);
-    void setThread(const QString &);
-    void setUrlOnShow();
+    bool    isForAll() const;
+    void    setHtml(const QString &);
+    void    setSubject(const QString &);
+    void    setThread(const QString &);
+    void    setUrlOnShow();
 
     PsiAccount *psiAccount();
 
 signals:
-    void aChat(const Jid& jid);
+    void aChat(const Jid &jid);
     void aReply(const Jid &jid, const QString &body, const QString &subject, const QString &thread);
     void aReadNext(const Jid &);
     void aDeny(const Jid &);
@@ -138,14 +133,13 @@ signals:
     void aHttpConfirm(const PsiHttpAuthRequest &);
     void aHttpDeny(const PsiHttpAuthRequest &);
     void aRosterExchange(const RosterExchangeItems &);
-    void aFormSubmit(const XData&, const QString&, const Jid&);
-    void aFormCancel(const XData&, const QString&, const Jid&);
+    void aFormSubmit(const XData &, const QString &, const Jid &);
+    void aFormCancel(const XData &, const QString &, const Jid &);
 
 protected:
     // reimplemented
     void showEvent(QShowEvent *);
     void keyPressEvent(QKeyEvent *);
-    void closeEvent(QCloseEvent *);
 
 public slots:
     void optionsUpdate();
@@ -153,7 +147,7 @@ public slots:
     void updateContact(const Jid &);
     void updateEvent(const PsiEvent::Ptr &);
     void updateReadNext(PsiIcon *, int);
-    void actionGCJoin(const QString &, const QString&);
+    void actionGCJoin(const QString &, const QString &);
 
 private slots:
     void to_textChanged(const QString &);
@@ -162,7 +156,7 @@ private slots:
     void updateIdentity(PsiAccount *);
     void updateIdentityVisibility();
     void accountUpdatedActivity();
-    void doWhois(bool force=false);
+    void doWhois(bool force = false);
     void doSend();
     void doReadNext();
     void doChat();
@@ -179,28 +173,25 @@ private slots:
     void doFormSubmit();
     void doFormCancel();
 
-    void updatePGP();
-    void encryptedMessageSent(int, bool, int, const QString &);
-    void trySendEncryptedNext();
-
 public:
     class Private;
+
 private:
     Private *d;
 
     void doneSend();
 
-    void init();
-    QStringList stringToList(const QString &, bool enc=true) const;
-    QString findJidInString(const QString &) const;
-    QString expandAddresses(const QString &, bool enc=true) const;
-    void buildCompletionList();
-    void setAccount(PsiAccount *);
-    void setTime(const QDateTime &, bool late=false);
+    void        init();
+    QStringList stringToList(const QString &, bool enc = true) const;
+    QString     findJidInString(const QString &) const;
+    QString     expandAddresses(const QString &, bool enc = true) const;
+    void        buildCompletionList();
+    void        setAccount(PsiAccount *);
+    void        setTime(const QDateTime &, bool late = false);
 
     friend class ELineEdit;
     UserResourceList getResources(const QString &) const;
-    QString jidToString(const Jid &, const QString &r="") const;
+    QString          jidToString(const Jid &, const QString &r = "") const;
 };
 
-#endif
+#endif // EVENTDLG_H
