@@ -13,33 +13,31 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef GLOBALEVENTQUEUE_H
 #define GLOBALEVENTQUEUE_H
 
-#include <QObject>
-
 #include "psievent.h"
 
-class GlobalEventQueue : public QObject
-{
+#include <QObject>
+
+class GlobalEventQueue : public QObject {
     Q_OBJECT
 
 public:
-    static GlobalEventQueue* instance();
+    static GlobalEventQueue *instance();
 
     int count() const;
 
-    const QList<int>& ids() const;
-    PsiEvent::Ptr peek(int id) const;
+    const QList<int> &ids() const;
+    PsiEvent::Ptr     peek(int id) const;
 
 protected:
-    void enqueue(EventItem* item);
-    void dequeue(EventItem* item);
+    void enqueue(EventItem *item);
+    void dequeue(EventItem *item);
 
 signals:
     void queueChanged();
@@ -47,10 +45,10 @@ signals:
 private:
     GlobalEventQueue();
 
-    static GlobalEventQueue* instance_;
-    QList<int> ids_;
-    QList<EventItem*> items_;
+    static GlobalEventQueue *instance_;
+    QList<int>               ids_;
+    QList<EventItem *>       items_;
     friend class EventQueue;
 };
 
-#endif
+#endif // GLOBALEVENTQUEUE_H
