@@ -3,30 +3,31 @@
 
 #include "languagemanager.h"
 
-#include <QPointer>
 #include <QDialog>
-
-namespace Ui {
-    class GroupchatTopicDlg;
-    class GroupChatTopicAddLangDlg;
-}
+#include <QPointer>
 
 class GCMainDlg;
 
+namespace Ui {
+class GroupChatTopicAddLangDlg;
+class GroupchatTopicDlg;
+}
+
 class GroupchatTopicDlg : public QDialog {
     Q_OBJECT
 public:
-    GroupchatTopicDlg(GCMainDlg *parent = 0);
+    GroupchatTopicDlg(GCMainDlg *parent = nullptr);
     ~GroupchatTopicDlg();
-    QMap<LanguageManager::LangId,QString> subjectMap() const;
-    void setSubjectMap(const QMap<LanguageManager::LangId,QString> &topics);
+    QMap<LanguageManager::LangId, QString> subjectMap() const;
+    void                                   setSubjectMap(const QMap<LanguageManager::LangId, QString> &topics);
 
 protected:
     void changeEvent(QEvent *e);
+
 private:
-    Ui::GroupchatTopicDlg *m_ui;
+    Ui::GroupchatTopicDlg *       m_ui;
     Ui::GroupChatTopicAddLangDlg *m_addLangUi;
-    QPointer<QDialog> addLangDlg;
+    QPointer<QDialog>             addLangDlg;
 
     void addLanguage(const LanguageManager::LangId &id, const QString &text = QString());
     void populateCountryAndScript();
