@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -25,19 +24,17 @@
 
 class PsiContact;
 
-class GroupMenu : public QMenu
-{
+class GroupMenu : public QMenu {
     Q_OBJECT
 public:
-    GroupMenu(QWidget* parent);
-    void updateMenu(PsiContact* contact);
+    GroupMenu(QWidget *parent);
+    void updateMenu(PsiContact *contact);
 
 signals:
     void groupActivated(QString groupName);
 
 private:
     QPointer<PsiContact> contact_;
-    QAction* createNewGroupAction_;
 
     /**
      * \param text will be shown on screen, and \param groupName is the
