@@ -13,20 +13,19 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 #include "htmltextcontroller.h"
-#include <QMenu>
-#include <QFontDialog>
-#include <QColorDialog>
 
-class HTMLTextMenu : public QMenu
-{
+#include <QColorDialog>
+#include <QFontDialog>
+#include <QMenu>
+
+class HTMLTextMenu : public QMenu {
     Q_OBJECT
 public:
-    HTMLTextMenu(QWidget* parent = 0): QMenu(parent)
+    HTMLTextMenu(QWidget *parent = nullptr) : QMenu(parent)
     {
         actBold = addAction(tr("Bold"));
         actBold->setCheckable(true);
@@ -62,68 +61,64 @@ public:
         actReset->setData(QVariant(HTMLTextController::StateNone));
     };
 
-    void setMenuState(QList<HTMLTextController::TextEditState> list)
-    {
-        foreach(HTMLTextController::TextEditState state, list) {
-            switch(state) {
-            case HTMLTextController::StateBold:
-                actBold->setChecked(true);
-                break;
-            case HTMLTextController::StateItalic:
-                actItalic->setChecked(true);
-                break;
-            case HTMLTextController::StateUnderline:
-                actUnderline->setChecked(true);
-                break;
-            case HTMLTextController::StateStrikeOut:
-                actStrikeOut->setChecked(true);
-                break;
-            case HTMLTextController::StateTextStyleChanged:
-                //actText->setChecked(true);
-                break;
-            case HTMLTextController::StateTextColorChanged:
-                actTextColor->setChecked(true);
-                break;
-            case HTMLTextController::StateBackgroundColorChanged:
-                actBackgroundColor->setChecked(true);
-                break;
-            default:
-                break;
-            }
-        }
-    };
+    void setMenuState(QList<HTMLTextController::TextEditState> list) {
+        foreach (HTMLTextController::TextEditState state,
+                 list) { switch (state) { case HTMLTextController::StateBold : actBold->setChecked(true);
+    break;
+case HTMLTextController::StateItalic:
+    actItalic->setChecked(true);
+    break;
+case HTMLTextController::StateUnderline:
+    actUnderline->setChecked(true);
+    break;
+case HTMLTextController::StateStrikeOut:
+    actStrikeOut->setChecked(true);
+    break;
+case HTMLTextController::StateTextStyleChanged:
+    // actText->setChecked(true);
+    break;
+case HTMLTextController::StateTextColorChanged:
+    actTextColor->setChecked(true);
+    break;
+case HTMLTextController::StateBackgroundColorChanged:
+    actBackgroundColor->setChecked(true);
+    break;
+default:
+    break;
+}
+}
+}
+;
 
 private:
-    QAction *actBold;
-    QAction *actUnderline;
-    QAction *actItalic;
-    QAction *actStrikeOut;
-    QAction *actText;
-    QAction *actTextColor;
-    QAction *actBackgroundColor;
-    QAction *actReset;
-
-};
+QAction *actBold;
+QAction *actUnderline;
+QAction *actItalic;
+QAction *actStrikeOut;
+QAction *actText;
+QAction *actTextColor;
+QAction *actBackgroundColor;
+QAction *actReset;
+}
+;
 
 //----------------------------------------------------------------------------
 // HTMLTextController
 //----------------------------------------------------------------------------
-HTMLTextController::HTMLTextController(QTextEdit *parent)
-    : QObject()
-    , te_(parent)
+HTMLTextController::HTMLTextController(QTextEdit *parent) : QObject(), te_(parent)
 {
-    font_ = te_->font();
-    currentFont_ = font_;
-    background_ = te_->currentCharFormat().background();
+    font_              = te_->font();
+    currentFont_       = font_;
+    background_        = te_->currentCharFormat().background();
     currentBackground_ = background_;
-    foreground_ = te_->currentCharFormat().foreground();
+    foreground_        = te_->currentCharFormat().foreground();
     currentForeground_ = foreground_;
 }
 
 void HTMLTextController::addState(TextEditState state)
 {
     QTextCharFormat tcf;
-    switch(state) {
+    switch (state) {
     case StateBold:
         tcf.setFontWeight(QFont::Bold);
         te_->mergeCurrentCharFormat(tcf);
@@ -171,7 +166,7 @@ void HTMLTextController::addState(TextEditState state)
 void HTMLTextController::removeState(TextEditState state)
 {
     QTextCharFormat tcf;
-    switch(state) {
+    switch (state) {
     case StateBold:
         tcf.setFontWeight(QFont::Normal);
         te_->mergeCurrentCharFormat(tcf);
@@ -205,23 +200,23 @@ void HTMLTextController::removeState(TextEditState state)
     }
 }
 
-QList<HTMLTextController::TextEditState>  HTMLTextController::state()
+QList<HTMLTextController::TextEditState> HTMLTextController::state()
 {
-    QList<TextEditState> list;
+    QList<TextEditState>  list;
     const QTextCharFormat tcf = te_->textCursor().charFormat();
-    if(tcf.fontWeight() == QFont::Bold)
+    if (tcf.fontWeight() == QFont::Bold)
         list.push_back(StateBold);
-    if(tcf.fontItalic())
+    if (tcf.fontItalic())
         list.push_back(StateItalic);
-    if(tcf.fontUnderline())
+    if (tcf.fontUnderline())
         list.push_back(StateUnderline);
-    if(tcf.fontStrikeOut())
+    if (tcf.fontStrikeOut())
         list.push_back(StateStrikeOut);
-    if(tcf.font() != font_)
+    if (tcf.font() != font_)
         list.push_back(StateTextStyleChanged);
-    if(tcf.background() != background_)
+    if (tcf.background() != background_)
         list.push_back(StateBackgroundColorChanged);
-    if(tcf.foreground() != foreground_)
+    if (tcf.foreground() != foreground_)
         list.push_back(StateTextColorChanged);
 
     return list;
@@ -231,90 +226,77 @@ void HTMLTextController::doMenu()
 {
     HTMLTextMenu *menu = new HTMLTextMenu();
     menu->setMenuState(state());
-    if(!cssString_.isEmpty())
+    if (!cssString_.isEmpty())
         menu->setStyleSheet(cssString_);
     QAction *act = menu->exec(QCursor::pos());
-    if(!act) {
+    if (!act) {
         delete menu;
         return;
     }
     int data = act->data().toInt();
-    if(data == StateBold) {
-        if(act->isChecked())
+    if (data == StateBold) {
+        if (act->isChecked())
             addState(StateBold);
         else
             removeState(StateBold);
     }
-    if(data == StateItalic) {
-        if(act->isChecked())
+    if (data == StateItalic) {
+        if (act->isChecked())
             addState(StateItalic);
         else
             removeState(StateItalic);
-    }
-    else if(data == StateUnderline) {
-        if(act->isChecked())
+    } else if (data == StateUnderline) {
+        if (act->isChecked())
             addState(StateUnderline);
         else
             removeState(StateUnderline);
-    }
-    else if(data == StateStrikeOut) {
-        if(act->isChecked())
+    } else if (data == StateStrikeOut) {
+        if (act->isChecked())
             addState(StateStrikeOut);
         else
             removeState(StateStrikeOut);
-    }
-    else if(data == StateTextStyleChanged) {
-        if(act->isChecked()) {
-            bool ok;
+    } else if (data == StateTextStyleChanged) {
+        if (act->isChecked()) {
+            bool  ok;
             QFont tmpFont = QFontDialog::getFont(&ok, font_);
-            if(ok) {
+            if (ok) {
                 currentFont_ = tmpFont;
                 addState(StateTextStyleChanged);
             }
-        }
-        else {
+        } else {
             currentFont_ = font_;
             removeState(StateTextStyleChanged);
         }
-    }
-    else if(data == StateTextColorChanged) {
-        if(act->isChecked()) {
+    } else if (data == StateTextColorChanged) {
+        if (act->isChecked()) {
             QColor color = QColorDialog::getColor(currentForeground_.color());
-            if(color.isValid()) {
+            if (color.isValid()) {
                 currentForeground_ = QBrush(color);
                 addState(StateTextColorChanged);
             }
-        }
-        else {
+        } else {
             currentForeground_ = foreground_;
             removeState(StateTextColorChanged);
         }
-    }
-    else if(data == StateBackgroundColorChanged) {
-        if(act->isChecked()) {
+    } else if (data == StateBackgroundColorChanged) {
+        if (act->isChecked()) {
             QColor color = QColorDialog::getColor(currentBackground_.color());
-            if(color.isValid()) {
+            if (color.isValid()) {
                 currentBackground_ = QBrush(color);
                 addState(StateBackgroundColorChanged);
             }
-        }
-        else {
+        } else {
             currentBackground_ = background_;
             removeState(StateBackgroundColorChanged);
         }
-    }
-    else if(data == StateNone)
+    } else if (data == StateNone)
         addState(StateNone);
 
     delete menu;
     te_->window()->activateWindow();
     te_->setFocus(Qt::MouseFocusReason);
-
 }
 
-void HTMLTextController::setFont(const QFont &f)
-{
-    font_ = f;
-}
+void HTMLTextController::setFont(const QFont &f) { font_ = f; }
 
 #include "htmltextcontroller.moc"
