@@ -13,46 +13,44 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 #ifndef HTMLTEXTCONTROLLER_H
 #define HTMLTEXTCONTROLLER_H
 
-#include  <QTextEdit>
+#include <QTextEdit>
 
-class HTMLTextController : public QObject
-{
+class HTMLTextController : public QObject {
     Q_OBJECT
 public:
     enum TextEditState {
-        StateNone = 0,
-        StateBold = 1,
-        StateItalic = 2,
-        StateUnderline = 4,
-        StateTextStyleChanged = 8,
-        StateTextColorChanged = 16,
+        StateNone                   = 0,
+        StateBold                   = 1,
+        StateItalic                 = 2,
+        StateUnderline              = 4,
+        StateTextStyleChanged       = 8,
+        StateTextColorChanged       = 16,
         StateBackgroundColorChanged = 32,
-        StateStrikeOut = 64
+        StateStrikeOut              = 64
     };
 
     HTMLTextController(QTextEdit *parent);
     void doMenu();
     void setFont(const QFont &);
-    void setCssString(const QString& css) { cssString_ = css; };
+    void setCssString(const QString &css) { cssString_ = css; };
 
 private:
-    void addState(TextEditState state);
-    void removeState(TextEditState state);
+    void                 addState(TextEditState state);
+    void                 removeState(TextEditState state);
     QList<TextEditState> state();
-    QString cssString_;
+    QString              cssString_;
 
 private:
     QTextEdit *te_;
-    QFont font_, currentFont_;
-    QBrush background_ ,currentBackground_;
-    QBrush foreground_, currentForeground_;
+    QFont      font_, currentFont_;
+    QBrush     background_, currentBackground_;
+    QBrush     foreground_, currentForeground_;
 };
 
 #endif // HTMLTEXTCONTROLLER_H
