@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -24,13 +23,13 @@
 #include <QObject>
 
 class HttpAuthListener;
-namespace XMPP {
-    class Task;
-}
 class PsiHttpAuthRequest;
 
-class HttpAuthManager : public QObject
-{
+namespace XMPP {
+class Task;
+}
+
+class HttpAuthManager : public QObject {
     Q_OBJECT
 
 public:
@@ -48,4 +47,4 @@ private:
     HttpAuthListener *listener_;
 };
 
-#endif
+#endif // HTTPAUTHMANAGER_H
