@@ -4,14 +4,11 @@
 using namespace XMPP;
 
 namespace IrisProtocol {
+DiscoInfoQuerier::DiscoInfoQuerier(XMPP::Client *client) : client_(client) { }
 
-DiscoInfoQuerier::DiscoInfoQuerier(XMPP::Client* client) : client_(client)
+void DiscoInfoQuerier::getDiscoInfo(const XMPP::Jid &jid, const QString &node)
 {
-}
-
-void DiscoInfoQuerier::getDiscoInfo(const XMPP::Jid& jid, const QString& node)
-{
-    JT_DiscoInfo* disco = new JT_DiscoInfo(client_->rootTask());
+    JT_DiscoInfo *disco = new JT_DiscoInfo(client_->rootTask());
     connect(disco, SIGNAL(finished()), SLOT(discoFinished()));
     disco->get(jid, node);
     disco->go(true);
@@ -19,15 +16,12 @@ void DiscoInfoQuerier::getDiscoInfo(const XMPP::Jid& jid, const QString& node)
 
 void DiscoInfoQuerier::discoFinished()
 {
-    JT_DiscoInfo *disco = (JT_DiscoInfo*)sender();
+    JT_DiscoInfo *disco = static_cast<JT_DiscoInfo *>(sender());
     Q_ASSERT(disco);
     if (disco->success()) {
         emit getDiscoInfo_success(disco->jid(), disco->node(), disco->item());
-    }
-    else {
+    } else {
         emit getDiscoInfo_error(disco->jid(), disco->node(), disco->statusCode(), disco->statusString());
     }
 }
-
-} // namespace
-
+}; // namespace IrisProtocol
