@@ -1,7 +1,7 @@
 /*
  * grepshortcutkeydialog.h - a dialog which greps a KeySequence and
  * emits a signal with this KeySequence as Parameter
- * Copyright (C) 2006 Cestonaro Thilo
+ * Copyright (C) 2006  Cestonaro Thilo
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -14,22 +14,20 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
+#ifndef GREPSHORTCUTKEYDIALOG_H
+#define GREPSHORTCUTKEYDIALOG_H
+
+#include "ui_grepshortcutkeydialog.h"
+
 #include <QDialog>
 #include <QKeyEvent>
 #include <QKeySequence>
 
-#include "ui_grepshortcutkeydialog.h"
-
-#ifndef GREPSHORTCUTKEYDIALOG_H
-#define GREPSHORTCUTKEYDIALOG_H
-
-class GrepShortcutKeyDialog : public QDialog
-{
+class GrepShortcutKeyDialog : public QDialog {
     Q_OBJECT
 public:
     GrepShortcutKeyDialog();
@@ -39,21 +37,21 @@ public:
 
 protected:
     // reimplemented
-    void keyPressEvent(QKeyEvent* event);
-    void keyReleaseEvent(QKeyEvent* event);
+    void keyPressEvent(QKeyEvent *event);
+    void keyReleaseEvent(QKeyEvent *event);
     void closeEvent(QCloseEvent *event);
 
 signals:
-    void newShortcutKey(const QKeySequence& key);
+    void newShortcutKey(const QKeySequence &key);
 
 private:
     Ui::GrepShortcutKeyDialog ui_;
-    bool gotKey;
+    bool                      gotKey;
 
-    void displayPressedKeys(const QKeySequence& keys);
-    QKeySequence getKeySequence(QKeyEvent* event) const;
-    bool isValid(int key) const;
-    bool isModifier(int key) const;
+    void         displayPressedKeys(const QKeySequence &keys);
+    QKeySequence getKeySequence(QKeyEvent *event) const;
+    bool         isValid(int key) const;
+    bool         isModifier(int key) const;
 };
 
-#endif
+#endif // GREPSHORTCUTKEYDIALOG_H
