@@ -13,38 +13,34 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef ATOMICXMLFILE_H
 #define ATOMICXMLFILE_H
 
+#include <QFile>
 #include <QString>
 #include <QStringList>
-#include <QFile>
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
 
-class AtomicXmlFileReader : public QXmlStreamReader
-{
-public:
-    virtual ~AtomicXmlFileReader() {}
-    virtual bool read(QIODevice* device) = 0;
-};
-
-class AtomicXmlFileWriter : public QXmlStreamWriter
-{
-public:
-    virtual ~AtomicXmlFileWriter() {}
-    virtual bool write(QIODevice* device) = 0;
-};
-
 class QDomDocument;
 
-class AtomicXmlFile
-{
+class AtomicXmlFileReader : public QXmlStreamReader {
+public:
+    virtual ~AtomicXmlFileReader() { }
+    virtual bool read(QIODevice *device) = 0;
+};
+
+class AtomicXmlFileWriter : public QXmlStreamWriter {
+public:
+    virtual ~AtomicXmlFileWriter() { }
+    virtual bool write(QIODevice *device) = 0;
+};
+
+class AtomicXmlFile {
 public:
     AtomicXmlFile(const QString &fileName);
 
@@ -52,8 +48,8 @@ public:
      * Atomically save \a writer to specified name. Prior to saving, back up
      * of old config data is created, and only then data is saved.
      */
-    template<typename T>
-    bool saveDocument(T writer) const {
+    template <typename T> bool saveDocument(T writer) const
+    {
         if (!saveDocument(writer, tempFileName())) {
             qWarning("AtomicXmlFile::saveDocument(): Unable to save '%s'. Possibly drive is full.",
                      qPrintable(tempFileName()));
@@ -64,15 +60,15 @@ public:
             if (QFile::exists(backupFileName()))
                 QFile::remove(backupFileName());
             if (!QFile::rename(fileName_, backupFileName())) {
-                qWarning("AtomicXmlFile::saveDocument(): Unable to rename '%s' to '%s'.",
-                         qPrintable(fileName_), qPrintable(backupFileName()));
+                qWarning("AtomicXmlFile::saveDocument(): Unable to rename '%s' to '%s'.", qPrintable(fileName_),
+                         qPrintable(backupFileName()));
                 return false;
             }
         }
 
         if (!QFile::rename(tempFileName(), fileName_)) {
-            qWarning("AtomicXmlFile::saveDocument(): Unable to rename '%s' to '%s'.",
-                     qPrintable(tempFileName()), qPrintable(fileName_));
+            qWarning("AtomicXmlFile::saveDocument(): Unable to rename '%s' to '%s'.", qPrintable(tempFileName()),
+                     qPrintable(fileName_));
             return false;
         }
 
@@ -82,11 +78,11 @@ public:
     /**
      * Tries to load \a reader from config file, or if that fails, from a back up.
      */
-    template<typename T>
-    bool loadDocument(T reader) const {
+    template <typename T> bool loadDocument(T reader) const
+    {
         Q_ASSERT(reader);
 
-        foreach(QString fileName, loadCandidateList()) {
+        for (const QString &fileName : loadCandidateList()) {
             if (loadDocument(reader, fileName)) {
                 return true;
             }
@@ -104,13 +100,13 @@ public:
 private:
     QString fileName_;
 
-    QString tempFileName() const;
-    QString backupFileName() const;
+    QString     tempFileName() const;
+    QString     backupFileName() const;
     QStringList loadCandidateList() const;
-    bool saveDocument(const QDomDocument& doc, QString fileName) const;
-    bool loadDocument(QDomDocument* doc, QString fileName) const;
-    bool saveDocument(AtomicXmlFileWriter* writer, QString fileName) const;
-    bool loadDocument(AtomicXmlFileReader* reader, QString fileName) const;
+    bool        saveDocument(const QDomDocument &doc, QString fileName) const;
+    bool        loadDocument(QDomDocument *doc, QString fileName) const;
+    bool        saveDocument(AtomicXmlFileWriter *writer, QString fileName) const;
+    bool        loadDocument(AtomicXmlFileReader *reader, QString fileName) const;
 };
 
-#endif
+#endif // ATOMICXMLFILE_H
