@@ -13,35 +13,33 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef GLOBALSHORTCUTMANAGER_H
 #define GLOBALSHORTCUTMANAGER_H
 
-#include <QObject>
 #include <QKeySequence>
 #include <QMap>
+#include <QObject>
 
-class QObject;
 class KeyTrigger;
+class QObject;
 
-class GlobalShortcutManager : public QObject
-{
+class GlobalShortcutManager : public QObject {
 public:
-    static GlobalShortcutManager* instance();
-    static void connect(const QKeySequence& key, QObject* receiver, const char* slot);
-    static void disconnect(const QKeySequence& key, QObject* receiver, const char* slot);
-    static void clear();
+    static GlobalShortcutManager *instance();
+    static void                   connect(const QKeySequence &key, QObject *receiver, const char *slot);
+    static void                   disconnect(const QKeySequence &key, QObject *receiver, const char *slot);
+    static void                   clear();
 
 private:
     GlobalShortcutManager();
     ~GlobalShortcutManager();
-    static GlobalShortcutManager* instance_;
+    static GlobalShortcutManager *instance_;
     class KeyTrigger;
-    QMap<QKeySequence, KeyTrigger*> triggers_;
+    QMap<QKeySequence, KeyTrigger *> triggers_;
 };
 
-#endif
+#endif // GLOBALSHORTCUTMANAGER_H
