@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -22,19 +21,16 @@
 #define GLOBALSHORTCUTTRIGGER_H
 
 #include "globalshortcutmanager.h"
+
 #include <QObject>
 
-class GlobalShortcutManager::KeyTrigger : public QObject
-{
+class GlobalShortcutManager::KeyTrigger : public QObject {
     Q_OBJECT
 public:
     /**
      * Is there any slot connected to this hotkey?
      */
-    bool isUsed() const
-    {
-        return QObject::receivers(SIGNAL(triggered())) > 0;
-    }
+    bool isUsed() const { return QObject::receivers(SIGNAL(triggered())) > 0; }
 
 signals:
     void triggered();
@@ -43,7 +39,7 @@ private:
     /**
      * Registers the \a key.
      */
-    KeyTrigger(const QKeySequence& key);
+    KeyTrigger(const QKeySequence &key);
     /**
      * Unregisters the key.
      */
@@ -55,7 +51,7 @@ private:
      * Platform-specific helper
      */
     class Impl;
-    Impl* d;
+    Impl *d;
 };
 
-#endif
+#endif // GLOBALSHORTCUTTRIGGER_H
