@@ -2,7 +2,7 @@
  * growlnotifier.h - A simple Qt interface to Growl
  *
  * Copyright (C) 2005  Remko Troncon
- *               2012  Evgeny Khryukin
+ * Copyright (C) 2012  Evgeny Khryukin
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,8 +20,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -36,26 +35,22 @@ class GrowlNotifierSignaler;
 /**
  * \brief A simple interface to Growl.
  */
-class GrowlNotifier
-{
+class GrowlNotifier {
 public:
-    GrowlNotifier(  const QStringList& notifications,
-            const QStringList& default_notifications,
-            const QString& app_name = "");
+    GrowlNotifier(const QStringList &notifications, const QStringList &default_notifications,
+                  const QString &app_name = "");
 
     virtual ~GrowlNotifier();
 
-    void notify(const QString& name, const QString& title,
-            const QString& description, const QPixmap& icon = QPixmap(),
-            bool sticky = false, const QObject* receiver = 0,
-            const char* clicked_slot = 0, const char* timeout_slot = 0,
-            void* context = 0);
+    void notify(const QString &name, const QString &title, const QString &description, const QPixmap &icon = QPixmap(),
+                bool sticky = false, const QObject *receiver = 0, const char *clicked_slot = 0,
+                const char *timeout_slot = 0, void *context = 0);
 
     static bool isRunning();
 
 private:
     class Private;
-    Private* d;
+    Private *d;
 };
 
-#endif
+#endif // GROWLNOTIFIER_H
