@@ -12,9 +12,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -25,8 +24,7 @@
 
 class IdlePlatform;
 
-class Idle : public QObject
-{
+class Idle : public QObject {
     Q_OBJECT
 public:
     Idle();
@@ -48,18 +46,17 @@ private:
     Private *d;
 };
 
-class IdlePlatform
-{
+class IdlePlatform {
 public:
     IdlePlatform();
     ~IdlePlatform();
 
     bool init();
-    int secondsIdle();
+    int  secondsIdle();
 
 private:
     class Private;
     Private *d;
 };
 
-#endif
+#endif // IDLE_H
