@@ -12,9 +12,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -23,9 +22,9 @@
 #ifndef HAVE_XSS
 
 IdlePlatform::IdlePlatform() { d = nullptr; }
-IdlePlatform::~IdlePlatform() {}
+IdlePlatform::~IdlePlatform() { }
 bool IdlePlatform::init() { return false; }
-int IdlePlatform::secondsIdle() { return 0; }
+int  IdlePlatform::secondsIdle() { return 0; }
 
 #else
 
@@ -34,43 +33,36 @@ int IdlePlatform::secondsIdle() { return 0; }
 //   in short qdbus org.kde.screensaver /ScreenSaver GetSessionIdleTime
 //   but on kde it returns in ms while gnome is in secs https://bugs.kde.org/show_bug.cgi?id=313571
 
-
 #include <QApplication>
 #include <QDesktopWidget>
-
+#include <QX11Info>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/extensions/scrnsaver.h>
 
-#include <QX11Info>
-
 static XErrorHandler old_handler = 0;
-extern "C" int xerrhandler(Display* dpy, XErrorEvent* err)
+extern "C" int       xerrhandler(Display *dpy, XErrorEvent *err)
 {
-    if(err->error_code == BadDrawable)
+    if (err->error_code == BadDrawable)
         return 0;
 
     return (*old_handler)(dpy, err);
 }
 
-class IdlePlatform::Private
-{
+class IdlePlatform::Private {
 public:
-    Private() {}
+    Private() { }
 
     XScreenSaverInfo *ss_info = nullptr;
 };
 
-IdlePlatform::IdlePlatform()
-{
-    d = new Private;
-}
+IdlePlatform::IdlePlatform() { d = new Private; }
 
 IdlePlatform::~IdlePlatform()
 {
-    if(d->ss_info)
+    if (d->ss_info)
         XFree(d->ss_info);
-    if(old_handler) {
+    if (old_handler) {
         XSetErrorHandler(old_handler);
         old_handler = 0;
     }
@@ -79,29 +71,31 @@ IdlePlatform::~IdlePlatform()
 
 bool IdlePlatform::init()
 {
-    if(!QX11Info::isPlatformX11())
+    if (!QX11Info::isPlatformX11())
         return false;
 
-    if(d->ss_info)
+    if (d->ss_info)
         return true;
 
     old_handler = XSetErrorHandler(xerrhandler);
 
     int event_base, error_base;
-    if(XScreenSaverQueryExtension(QX11Info::display(), &event_base, &error_base)) {
+#if !defined(LIMIT_X11_USAGE)
+    if (XScreenSaverQueryExtension(QX11Info::display(), &event_base, &error_base)) {
         d->ss_info = XScreenSaverAllocInfo();
         return true;
     }
+#endif
     return false;
 }
 
 int IdlePlatform::secondsIdle()
 {
-    if(!d->ss_info)
+    if (!d->ss_info)
         return 0;
-    if(!XScreenSaverQueryInfo(QX11Info::display(), QX11Info::appRootWindow(), d->ss_info))
+    if (!XScreenSaverQueryInfo(QX11Info::display(), QX11Info::appRootWindow(), d->ss_info))
         return 0;
     return d->ss_info->idle / 1000;
 }
 
-#endif
+#endif // HAVE_XSS
