@@ -12,15 +12,13 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "iodeviceopener.h"
 
-
-IODeviceOpener::IODeviceOpener(QIODevice* device, QIODevice::OpenModeFlag mode) : device_(device), close_(false)
+IODeviceOpener::IODeviceOpener(QIODevice *device, QIODevice::OpenModeFlag mode) : device_(device), close_(false)
 {
     if (!device_->isOpen()) {
         if (!device_->open(mode)) {
@@ -28,8 +26,7 @@ IODeviceOpener::IODeviceOpener(QIODevice* device, QIODevice::OpenModeFlag mode)
             return;
         }
         close_ = true;
-    }
-    else if (!(device_->openMode() & mode)) {
+    } else if (!(device_->openMode() & mode)) {
         isOpen_ = false;
         return;
     }
