@@ -18,28 +18,26 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
-#include <QApplication>
-#include <QMessageBox>
-#include <QPushButton>
-#include <QLayout>
-#include <QVBoxLayout>
-#include <QLineEdit>
-#include <QCheckBox>
-#include <QLabel>
-
 #include "mac_dock.h"
 
-class DockTestWidget : public QWidget
-{
+#include <QApplication>
+#include <QCheckBox>
+#include <QLabel>
+#include <QLayout>
+#include <QLineEdit>
+#include <QMessageBox>
+#include <QPushButton>
+#include <QVBoxLayout>
+
+class DockTestWidget : public QWidget {
     Q_OBJECT
 
 public:
-    DockTestWidget( QWidget *parent=0);
+    DockTestWidget(QWidget *parent = 0);
 
 public slots:
     void do_overlay();
@@ -48,33 +46,29 @@ private:
     QLineEdit *text;
 };
 
-
-DockTestWidget::DockTestWidget( QWidget *parent ) : QWidget(parent)
+DockTestWidget::DockTestWidget(QWidget *parent) : QWidget(parent)
 {
     // Initialize widgets
     QGridLayout *layout = new QGridLayout(this);
 
-    layout->addWidget(new QLabel("Text",this),0,0);
+    layout->addWidget(new QLabel("Text", this), 0, 0);
     text = new QLineEdit(this);
     text->setText("1");
-    layout->addWidget(text,0,1);
+    layout->addWidget(text, 0, 1);
 
-    QPushButton *overlay = new QPushButton( "Overlay", this );
+    QPushButton *overlay = new QPushButton("Overlay", this);
     connect(overlay, SIGNAL(clicked()), SLOT(do_overlay()));
-    layout->addWidget(overlay,1,0);
+    layout->addWidget(overlay, 1, 0);
 }
 
-int main( int argc, char **argv )
+int main(int argc, char **argv)
 {
-    QApplication a( argc, argv );
+    QApplication   a(argc, argv);
     DockTestWidget w;
     w.show();
     return a.exec();
 }
 
-void DockTestWidget::do_overlay()
-{
-    MacDock::overlay(text->text());
-}
+void DockTestWidget::do_overlay() { MacDock::overlay(text->text()); }
 
 #include "docktest.moc"
