@@ -1,18 +1,17 @@
-#ifndef MACDOCK_H
-#define MACDOCK_H
+#ifndef MAC_DOCK_H
+#define MAC_DOCK_H
 
 #include <QString>
 
-class MacDock
-{
+class MacDock {
 public:
     static void startBounce();
     static void stopBounce();
-    static void overlay(const QString& text = QString::null);
+    static void overlay(const QString &text = QString());
 
 private:
     static bool isBouncing;
     static bool overlayed;
 };
 
-#endif
+#endif // MAC_DOCK_H
