@@ -1,6 +1,6 @@
 /*
  * priorityvalidator.h - XMPP priority validator
- * Copyright (C) 2010 Dmitriy.trt
+ * Copyright (C) 2010  Dmitriy.trt
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -23,12 +22,11 @@
 
 #include <QValidator>
 
-class PriorityValidator : public QValidator
-{
-      Q_OBJECT
+class PriorityValidator : public QValidator {
+    Q_OBJECT
 public:
-      PriorityValidator(QObject* parent = 0) : QValidator(parent) { };
-      virtual State validate(QString &input, int &pos) const;
+    PriorityValidator(QObject *parent = nullptr) : QValidator(parent) {};
+    virtual State validate(QString &input, int &pos) const;
 };
 
 #endif // PRIORITYVALIDATOR_H
