@@ -19,48 +19,43 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef ENCHANTCHECKER_H
 #define ENCHANTCHECKER_H
 
-#include <QStringList>
-
 #include "spellchecker.h"
 
-namespace enchant
-{
-    class Dict;
+#include <QStringList>
+
+namespace enchant {
+class Dict;
 }
 
-class EnchantChecker : public SpellChecker
-{
+class EnchantChecker : public SpellChecker {
 public:
     EnchantChecker();
     ~EnchantChecker();
-    virtual QList<QString> suggestions(const QString&);
-    virtual bool isCorrect(const QString&);
-    virtual bool add(const QString&);
-    virtual bool available() const;
-    virtual bool writable() const;
+    virtual QList<QString> suggestions(const QString &);
+    virtual bool           isCorrect(const QString &);
+    virtual bool           add(const QString &);
+    virtual bool           available() const;
+    virtual bool           writable() const;
 
-    virtual void setActiveLanguages(const QSet<LanguageManager::LangId> &langs);
+    virtual void                          setActiveLanguages(const QSet<LanguageManager::LangId> &langs);
     virtual QSet<LanguageManager::LangId> getAllLanguages() const;
 
 private:
-    static void enchantDictDescribeFn(const char *const lang_tag,
-                                      const char *const provider_name,
-                                      const char *const provider_desc,
-                                      const char *const provider_file,
+    static void enchantDictDescribeFn(const char *const lang_tag, const char *const provider_name,
+                                      const char *const provider_desc, const char *const provider_file,
                                       void *user_data);
-    void clearSpellers();
+    void        clearSpellers();
 
-    typedef QList<enchant::Dict*> EnchantDictList;
-    EnchantDictList spellers_;
+    typedef QList<enchant::Dict *>          EnchantDictList;
+    EnchantDictList                         spellers_;
     QHash<LanguageManager::LangId, QString> allLanguages_;
 };
 
-#endif
+#endif // ENCHANTCHECKER_H
