@@ -1,7 +1,7 @@
 /*
  * hunspellchecker.cpp
  *
- * Copyright (C) 2015  Ilinykh Sergey, Vitaly Tonkacheyev
+ * Copyright (C) 2015  Sergey Ilinykh, Vitaly Tonkacheyev
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,35 +19,35 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "hunspellchecker.h"
 
-#include <QString>
-#include <QSet>
-#include <QDir>
-#include <QLibraryInfo>
-#include <QTextCodec>
-#include <QCoreApplication>
-#include <QLocale>
-#include <QMutableListIterator>
-//#include <QDebug>
-#include <hunspell.hxx>
 #ifdef Q_OS_WIN
 #include "applicationinfo.h"
 #endif
+#include "config.h"
 #include "languagemanager.h"
 
-#ifdef H_DEPRECATED
-# define NEW_HUNSPELL
-# define HS_STRING(text) li.codec->fromUnicode(text).toStdString()
-#else
-# define HS_STRING(text) li.codec->fromUnicode(text)
-#endif
+#include <QCoreApplication>
+//#include <QDebug>
+#include <QDir>
+#include <QLibraryInfo>
+#include <QLocale>
+#include <QMutableListIterator>
+#include <QSet>
+#include <QString>
+#include <QTextCodec>
+#include <hunspell.hxx>
 
+#ifdef H_DEPRECATED
+#define NEW_HUNSPELL
+#define HS_STRING(text) li.codec->fromUnicode(text).toStdString()
+#else
+#define HS_STRING(text) li.codec->fromUnicode(text)
+#endif
 
 HunspellChecker::HunspellChecker()
 {
@@ -55,38 +55,49 @@ HunspellChecker::HunspellChecker()
     getSupportedLanguages();
 }
 
-HunspellChecker::~HunspellChecker()
-{
-}
+HunspellChecker::~HunspellChecker() { }
 
 void HunspellChecker::getDictPaths()
 {
     if (dictPaths_.isEmpty()) {
         QSet<QString> dictPathSet;
-        QString pathFromEnv = QString::fromLocal8Bit(qgetenv("MYSPELL_DICT_DIR"));
+        QString       pathFromEnv = QString::fromLocal8Bit(qgetenv("MYSPELL_DICT_DIR"));
         if (!pathFromEnv.isEmpty())
             dictPathSet << pathFromEnv;
 #if defined(Q_OS_WIN)
         dictPathSet << QCoreApplication::applicationDirPath() + QLatin1String("/myspell/dicts")
-                << ApplicationInfo::homeDir(ApplicationInfo::DataLocation) + QLatin1String("/myspell/dicts");
+                    << ApplicationInfo::homeDir(ApplicationInfo::DataLocation) + QLatin1String("/myspell/dicts");
 
 #elif defined(Q_OS_MAC)
-        dictPathSet << QLatin1String("/opt/local/share/myspell"); // MacPorts standard paths
+        dictPathSet << QCoreApplication::applicationDirPath()
+                + QLatin1String("/../Resources/myspell/dicts")    // relative path to dictionaries inside app bundle
+                    << QLatin1String("/opt/local/share/myspell"); // MacPorts standard paths
+#elif defined(Q_OS_HAIKU)
+        dictPathSet << QLatin1String("/system/data/hunspell");
 #else
-        dictPathSet << QLatin1String("/usr/share/myspell")
-                << QLatin1String("/usr/share/hunspell")
-                << QLatin1String("/usr/local/share/myspell")
-                << QLatin1String("/usr/local/share/hunspell")
-                << QString("%1/.local/share/myspell").arg(QDir::home().absolutePath())
-                << QString("%1/.local/share/hunspell").arg(QDir::home().absolutePath());
+        dictPathSet << QLatin1String("/usr/share/myspell") << QLatin1String("/usr/share/hunspell")
+                    << QLatin1String("/usr/local/share/myspell") << QLatin1String("/usr/local/share/hunspell")
+                    << QString("%1/.local/share/myspell").arg(QDir::home().absolutePath())
+                    << QString("%1/.local/share/hunspell").arg(QDir::home().absolutePath());
 #endif
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+        dictPaths_ = dictPathSet.values();
+#else
         dictPaths_ = dictPathSet.toList();
+#endif
+#if defined(Q_OS_LINUX) && defined(SHARE_SUFF)
+    // Special hack for correct work of AppImage, snap and flatpak builds
+    static const QString &&additionalPath =
+            QDir().absoluteFilePath(qApp->applicationDirPath() + "/../share/" SHARE_SUFF);
+    dictPaths_.prepend(additionalPath + "/hunspell");
+    dictPaths_.prepend(additionalPath + "/myspell");
+#endif
     }
 }
 
-bool HunspellChecker::scanDictPaths(const QString &language, QFileInfo &aff , QFileInfo &dic)
+bool HunspellChecker::scanDictPaths(const QString &language, QFileInfo &aff, QFileInfo &dic)
 {
-    foreach (const QString &dictPath, dictPaths_) {
+    for (const QString &dictPath : dictPaths_) {
         QDir dir(dictPath);
         if (dir.exists()) {
             QFileInfo affInfo(dir.filePath(language + QLatin1String(".aff")));
@@ -104,12 +115,12 @@ bool HunspellChecker::scanDictPaths(const QString &language, QFileInfo &aff , QF
 void HunspellChecker::getSupportedLanguages()
 {
     QSet<LanguageManager::LangId> retHash;
-    foreach (const QString &dictPath, dictPaths_) {
+    for (const QString &dictPath : dictPaths_) {
         QDir dir(dictPath);
         if (!dir.exists()) {
             continue;
         }
-        foreach (const QFileInfo &fi, dir.entryInfoList(QStringList() << "*.dic", QDir::Files)) {
+        for (const QFileInfo &fi : dir.entryInfoList(QStringList() << "*.dic", QDir::Files)) {
             auto id = LanguageManager::fromString(fi.baseName());
             if (id.language) {
                 retHash.insert(id);
@@ -121,12 +132,12 @@ void HunspellChecker::getSupportedLanguages()
 
 void HunspellChecker::addLanguage(const LanguageManager::LangId &langId)
 {
-    QString language = LanguageManager::toString(langId).replace('-','_');
+    QString   language = LanguageManager::toString(langId).replace('-', '_');
     QFileInfo aff, dic;
     if (scanDictPaths(language, aff, dic)) {
         LangItem li;
-        li.hunspell_ = HunspellPtr(new Hunspell(aff.absoluteFilePath().toLocal8Bit(),
-                            dic.absoluteFilePath().toLocal8Bit()));
+        li.hunspell_
+            = HunspellPtr(new Hunspell(aff.absoluteFilePath().toLocal8Bit(), dic.absoluteFilePath().toLocal8Bit()));
         QByteArray codecName(li.hunspell_->get_dic_encoding());
         if (codecName.startsWith("microsoft-cp125")) {
             codecName.replace(0, sizeof("microsoft-cp") - 1, "Windows-");
@@ -135,7 +146,7 @@ void HunspellChecker::addLanguage(const LanguageManager::LangId &langId)
         }
         li.codec = QTextCodec::codecForName(codecName);
         if (li.codec) {
-            li.info.langId = langId;
+            li.info.langId   = langId;
             li.info.filename = dic.filePath();
             languages_.append(li);
         } else {
@@ -144,21 +155,21 @@ void HunspellChecker::addLanguage(const LanguageManager::LangId &langId)
     }
 }
 
-QList<QString> HunspellChecker::suggestions(const QString& word)
+QList<QString> HunspellChecker::suggestions(const QString &word)
 {
     QStringList qtResult;
-    foreach (const LangItem &li, languages_) {
+    for (const LangItem &li : languages_) {
 #ifdef NEW_HUNSPELL
         std::vector<std::string> result = li.hunspell_->suggest(HS_STRING(word));
-        if(!result.empty()){
-            foreach (const std::string &item, result) {
+        if (!result.empty()) {
+            for (const std::string &item : result) {
                 qtResult << QString(li.codec->toUnicode(item.c_str()));
             }
         }
 #else
         char **result;
-        int sugNum = li.hunspell_->suggest(&result, HS_STRING(word));
-        for (int i=0; i < sugNum; i++) {
+        int    sugNum = li.hunspell_->suggest(&result, HS_STRING(word));
+        for (int i = 0; i < sugNum; i++) {
             qtResult << li.codec->toUnicode(result[i]);
         }
         li.hunspell_->free_list(&result, sugNum);
@@ -169,18 +180,18 @@ QList<QString> HunspellChecker::suggestions(const QString& word)
 
 bool HunspellChecker::isCorrect(const QString &word)
 {
-    foreach (const LangItem &li, languages_) {
+    for (const LangItem &li : languages_) {
         if (li.hunspell_->spell(HS_STRING(word)) != 0) {
             return true;
         }
     }
     return false;
 }
-bool HunspellChecker::add(const QString& word)
+bool HunspellChecker::add(const QString &word)
 {
     if (!word.isEmpty()) {
         QString trimmed_word = word.trimmed();
-        foreach (const LangItem &li, languages_) {
+        for (const LangItem &li : languages_) {
             if (li.hunspell_->add(HS_STRING(trimmed_word)) != 0) {
                 return true;
             }
@@ -190,48 +201,42 @@ bool HunspellChecker::add(const QString& word)
 }
 bool HunspellChecker::available() const
 {
-    foreach (const LangItem &li, languages_) {
+    for (const LangItem &li : languages_) {
         if (li.hunspell_) {
             return true;
         }
     }
     return false;
 }
-bool HunspellChecker::writable() const
-{
-    return false;
-}
+bool HunspellChecker::writable() const { return false; }
 
 void HunspellChecker::unloadLanguage(const LanguageManager::LangId &langId)
 {
     QMutableListIterator<LangItem> it(languages_);
-    while(it.hasNext()) {
+    while (it.hasNext()) {
         LangItem item = it.next();
-        if(item.info.langId == langId) {
+        if (item.info.langId == langId) {
             it.remove();
         }
     }
 }
 
-QSet<LanguageManager::LangId> HunspellChecker::getAllLanguages() const
-{
-    return supportedLangs_;
-}
+QSet<LanguageManager::LangId> HunspellChecker::getAllLanguages() const { return supportedLangs_; }
 
 void HunspellChecker::setActiveLanguages(const QSet<LanguageManager::LangId> &newLangs)
 {
     QSet<LanguageManager::LangId> loadedLangs;
-    foreach (const LangItem &item, languages_) {
+    for (const LangItem &item : languages_) {
         loadedLangs << item.info.langId;
     }
-    QSet<LanguageManager::LangId> langsToUnload = loadedLangs - newLangs;
-    QSet<LanguageManager::LangId> langsToLoad = newLangs - loadedLangs;
+    QSet<LanguageManager::LangId>         langsToUnload = loadedLangs - newLangs;
+    QSet<LanguageManager::LangId>         langsToLoad   = newLangs - loadedLangs;
     QSetIterator<LanguageManager::LangId> it(langsToUnload);
-    while(it.hasNext()) {
+    while (it.hasNext()) {
         unloadLanguage(it.next());
     }
     it = langsToLoad;
-    while(it.hasNext()) {
+    while (it.hasNext()) {
         addLanguage(it.next());
     }
 }
