@@ -19,29 +19,27 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef MACSPELLCHECKER_H
 #define MACSPELLCHECKER_H
 
+#include "spellchecker.h"
+
 #include <QList>
 #include <QString>
 
-#include "spellchecker.h"
-
-class MacSpellChecker : public SpellChecker
-{
+class MacSpellChecker : public SpellChecker {
 public:
     MacSpellChecker();
     ~MacSpellChecker();
-    virtual QList<QString> suggestions(const QString&);
-    virtual bool isCorrect(const QString&);
-    virtual bool add(const QString&);
-    virtual bool available() const;
-    virtual bool writable() const;
+    virtual QList<QString> suggestions(const QString &);
+    virtual bool           isCorrect(const QString &);
+    virtual bool           add(const QString &);
+    virtual bool           available() const;
+    virtual bool           writable() const;
 };
 
-#endif
+#endif // MACSPELLCHECKER_H
