@@ -13,27 +13,25 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "systemwatch.h"
+
 #if defined(Q_OS_MAC)
-    #include "systemwatch_mac.h"
+#include "systemwatch_mac.h"
 #elif defined(Q_OS_WIN32)
-    #include "systemwatch_win.h"
+#include "systemwatch_win.h"
 #else
-    #include "systemwatch_unix.h"
+#include "systemwatch_unix.h"
 #endif
 
 #include <QApplication>
 
-SystemWatch::SystemWatch() : QObject(qApp)
-{
-}
+SystemWatch::SystemWatch() : QObject(qApp) { }
 
-SystemWatch* SystemWatch::instance()
+SystemWatch *SystemWatch::instance()
 {
     if (!instance_) {
 #if defined(Q_OS_MAC)
@@ -52,5 +50,4 @@ void SystemWatch::proceedWithSleep()
     // do nothing in base impl
 }
 
-
-SystemWatch* SystemWatch::instance_ = 0;
+SystemWatch *SystemWatch::instance_ = nullptr;
