@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -23,13 +22,12 @@
 
 #include <QObject>
 
-class SystemWatch : public QObject
-{
+class SystemWatch : public QObject {
     Q_OBJECT
 
 public:
-    static SystemWatch* instance();
-    virtual void proceedWithSleep();
+    static SystemWatch *instance();
+    virtual void        proceedWithSleep();
 
 signals:
     void sleep();
@@ -40,7 +38,7 @@ protected:
     SystemWatch();
 
 private:
-    static SystemWatch* instance_;
+    static SystemWatch *instance_;
 };
 
-#endif
+#endif // SYSTEMWATCH_H
