@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -23,8 +22,7 @@
 
 #include "systemwatch.h"
 
-class MacSystemWatch : public SystemWatch
-{
+class MacSystemWatch : public SystemWatch {
 public:
     MacSystemWatch();
 
@@ -34,4 +32,4 @@ public:
     void emitWakeup() { emit wakeup(); }
 };
 
-#endif
+#endif // SYSTEMWATCH_MAC_H
