@@ -13,21 +13,22 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
-#include <unistd.h>
 #include "systemwatch_unix.h"
-#ifdef USE_DBUS
-# include <QDBusConnection>
-# include <QDBusReply>
-# include <QDBusInterface>
-# include <QDBusUnixFileDescriptor>
-#endif
+
 #include "applicationinfo.h"
 
+#ifdef USE_DBUS
+#include <QDBusConnection>
+#include <QDBusInterface>
+#include <QDBusReply>
+#include <QDBusUnixFileDescriptor>
+#endif
+#include <unistd.h>
+
 UnixSystemWatch::UnixSystemWatch()
 {
 #ifdef USE_DBUS
@@ -35,10 +36,13 @@ UnixSystemWatch::UnixSystemWatch()
     QDBusConnection conn = QDBusConnection::systemBus();
     // listen to systemd's logind
     // TODO: use delaying Inhibitor locks
-    conn.connect("org.freedesktop.login1", "/org/freedesktop/login1", "org.freedesktop.login1.Manager", "PrepareForSleep", this, SLOT(prepareForSleep(bool)));
+    conn.connect("org.freedesktop.login1", "/org/freedesktop/login1", "org.freedesktop.login1.Manager",
+                 "PrepareForSleep", this, SLOT(prepareForSleep(bool)));
     // listen to UPower
-    conn.connect("org.freedesktop.UPower", "/org/freedesktop/UPower", "org.freedesktop.UPower", "Sleeping", this, SLOT(sleeping()));
-    conn.connect("org.freedesktop.UPower", "/org/freedesktop/UPower", "org.freedesktop.UPower", "Resuming", this, SLOT(resuming()));
+    conn.connect("org.freedesktop.UPower", "/org/freedesktop/UPower", "org.freedesktop.UPower", "Sleeping", this,
+                 SLOT(sleeping()));
+    conn.connect("org.freedesktop.UPower", "/org/freedesktop/UPower", "org.freedesktop.UPower", "Resuming", this,
+                 SLOT(resuming()));
 
     takeSleepLock();
 #endif
@@ -51,8 +55,10 @@ void UnixSystemWatch::takeSleepLock()
        "org.freedesktop.login1.Manager.Inhibit" string:"sleep" string:"Psi" \
                                                                string:"Closing connections..." string:"delay"
     */
-    QDBusInterface login1iface("org.freedesktop.login1", "/org/freedesktop/login1", "org.freedesktop.login1.Manager", QDBusConnection::systemBus());
-    QDBusReply<QDBusUnixFileDescriptor> repl = login1iface.call("Inhibit", "sleep", ApplicationInfo::name(), "Closing connections...", "delay");
+    QDBusInterface login1iface("org.freedesktop.login1", "/org/freedesktop/login1", "org.freedesktop.login1.Manager",
+                               QDBusConnection::systemBus());
+    QDBusReply<QDBusUnixFileDescriptor> repl
+        = login1iface.call("Inhibit", "sleep", ApplicationInfo::name(), "Closing connections...", "delay");
     // we could delay "shutdown" as well probably Qt session manager already can do this
     if (repl.isValid()) {
         lockFd = repl.value();
@@ -71,23 +77,14 @@ void UnixSystemWatch::proceedWithSleep()
 
 void UnixSystemWatch::prepareForSleep(bool beforeSleep)
 {
-    if (beforeSleep)
-    {
+    if (beforeSleep) {
         emit sleep();
-    }
-    else
-    {
+    } else {
         emit wakeup();
         takeSleepLock();
     }
 }
 
-void UnixSystemWatch::sleeping()
-{
-    emit sleep();
-}
+void UnixSystemWatch::sleeping() { emit sleep(); }
 
-void UnixSystemWatch::resuming()
-{
-    emit wakeup();
-}
+void UnixSystemWatch::resuming() { emit wakeup(); }
