@@ -13,26 +13,27 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef SYSTEMWATCH_UNIX_H
 #define SYSTEMWATCH_UNIX_H
+
+#include "systemwatch.h"
+
 #ifdef USE_DBUS
 #include <QDBusUnixFileDescriptor>
 #endif
-#include "systemwatch.h"
 
-class UnixSystemWatch : public SystemWatch
-{
+class UnixSystemWatch : public SystemWatch {
     Q_OBJECT
 
 #ifdef USE_DBUS
     QDBusUnixFileDescriptor lockFd; // systemd inhibitor for sleep. system goes to sleep as soon as lock is closed
 #endif
     void takeSleepLock();
+
 public:
     UnixSystemWatch();
     void proceedWithSleep();
@@ -43,5 +44,4 @@ private slots:
     void resuming();
 };
 
-
-#endif
+#endif // SYSTEMWATCH_UNIX_H
