@@ -12,46 +12,41 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
-#include <QString>
-#include <QStringList>
-#include <QFile>
+#include "zip.h"
 
 #ifdef PSIMINIZIP
 #include "minizip/unzip.h"
 #else
 #include <unzip.h>
 #endif
-#include "zip.h"
 
-class UnZipPrivate
-{
+#include <QFile>
+#include <QString>
+#include <QStringList>
+
+class UnZipPrivate {
 public:
-    UnZipPrivate() : caseSensitive(UnZip::CS_Default) {}
+    UnZipPrivate() : caseSensitive(UnZip::CS_Default) { }
 
-    QString name;
-    unzFile uf;
-    QStringList listing;
+    QString                name;
+    unzFile                uf;
+    QStringList            listing;
     UnZip::CaseSensitivity caseSensitive;
 };
 
 UnZip::UnZip(const QString &name)
 {
-    d = new UnZipPrivate;
-    d->uf = 0;
+    d       = new UnZipPrivate;
+    d->uf   = nullptr;
     d->name = name;
 }
 
-UnZip::UnZip(UnZip &&o) :
-    d(o.d)
-{
-    o.d = nullptr;
-}
+UnZip::UnZip(UnZip &&o) : d(o.d) { o.d = nullptr; }
 
 UnZip::~UnZip()
 {
@@ -61,27 +56,18 @@ UnZip::~UnZip()
     }
 }
 
-void UnZip::setCaseSensitivity(CaseSensitivity state)
-{
-    d->caseSensitive = state;
-}
+void UnZip::setCaseSensitivity(CaseSensitivity state) { d->caseSensitive = state; }
 
-void UnZip::setName(const QString &name)
-{
-    d->name = name;
-}
+void UnZip::setName(const QString &name) { d->name = name; }
 
-const QString & UnZip::name() const
-{
-    return d->name;
-}
+const QString &UnZip::name() const { return d->name; }
 
 bool UnZip::open()
 {
     close();
 
     d->uf = unzOpen(QFile::encodeName(d->name).data());
-    if(!d->uf)
+    if (!d->uf)
         return false;
 
     return getList();
@@ -89,39 +75,78 @@ bool UnZip::open()
 
 void UnZip::close()
 {
-    if(d->uf) {
+    if (d->uf) {
         unzClose(d->uf);
-        d->uf = 0;
+        d->uf = nullptr;
     }
 
     d->listing.clear();
 }
 
-const QStringList & UnZip::list() const
+QHash<QString, QByteArray> UnZip::unpackAll()
 {
-    return d->listing;
+    close();
+    QHash<QString, QByteArray> ret;
+    d->uf = unzOpen(QFile::encodeName(d->name).data());
+    if (!d->uf)
+        return ret;
+
+    unz_global_info gi;
+    int             err = unzGetGlobalInfo(d->uf, &gi);
+    if (err != UNZ_OK) {
+        close();
+        return ret;
+    }
+
+    for (int n = 0; n < (int)gi.number_entry; ++n) {
+        char          filename_inzip[256];
+        unz_file_info file_info;
+        int           err
+            = unzGetCurrentFileInfo(d->uf, &file_info, filename_inzip, sizeof(filename_inzip), nullptr, 0, nullptr, 0);
+        if (err != UNZ_OK)
+            break;
+
+        QString    filename = QString::fromUtf8(filename_inzip);
+        QByteArray data;
+        if (!readCurrentFile(&data))
+            break;
+
+        ret.insert(filename, data);
+
+        if ((n + 1) < (int)gi.number_entry) {
+            err = unzGoToNextFile(d->uf);
+            if (err != UNZ_OK)
+                break;
+        }
+    }
+
+    close();
+    return ret;
 }
 
+const QStringList &UnZip::list() const { return d->listing; }
+
 bool UnZip::getList()
 {
     unz_global_info gi;
-    int err = unzGetGlobalInfo(d->uf, &gi);
-    if(err != UNZ_OK)
+    int             err = unzGetGlobalInfo(d->uf, &gi);
+    if (err != UNZ_OK)
         return false;
 
     QStringList l;
-    for(int n = 0; n < (int)gi.number_entry; ++n) {
-        char filename_inzip[256];
+    for (int n = 0; n < (int)gi.number_entry; ++n) {
+        char          filename_inzip[256];
         unz_file_info file_info;
-        int err = unzGetCurrentFileInfo(d->uf, &file_info, filename_inzip, sizeof(filename_inzip), NULL, 0, NULL, 0);
-        if(err != UNZ_OK)
+        int           err
+            = unzGetCurrentFileInfo(d->uf, &file_info, filename_inzip, sizeof(filename_inzip), nullptr, 0, nullptr, 0);
+        if (err != UNZ_OK)
             return false;
 
         l += filename_inzip;
 
-        if((n+1) < (int)gi.number_entry) {
+        if ((n + 1) < (int)gi.number_entry) {
             err = unzGoToNextFile(d->uf);
-            if(err != UNZ_OK)
+            if (err != UNZ_OK)
                 return false;
         }
     }
@@ -131,52 +156,57 @@ bool UnZip::getList()
     return true;
 }
 
-bool UnZip::readFile(const QString &fname, QByteArray *buf, int max)
+bool UnZip::readCurrentFile(QByteArray *buf, int max)
 {
-    int err = unzLocateFile(d->uf, QFile::encodeName(fname).data(), d->caseSensitive);
-    if(err != UNZ_OK)
-        return false;
-
-    char filename_inzip[256];
-    unz_file_info file_info;
-    err = unzGetCurrentFileInfo(d->uf, &file_info, filename_inzip, sizeof(filename_inzip), NULL, 0, NULL, 0);
-    if(err != UNZ_OK)
-        return false;
-
-    err = unzOpenCurrentFile(d->uf);
-    if(err != UNZ_OK)
+    int err = unzOpenCurrentFile(d->uf);
+    if (err != UNZ_OK)
         return false;
 
     QByteArray a;
     QByteArray chunk;
     chunk.resize(16384);
-    while(1) {
+    while (1) {
         err = unzReadCurrentFile(d->uf, chunk.data(), chunk.size());
-        if(err < 0) {
+        if (err < 0) {
             unzCloseCurrentFile(d->uf);
             return false;
         }
-        if(err == 0)
+        if (err == 0)
             break;
 
         int oldsize = a.size();
-        if(max > 0 && oldsize + err > max)
+        if (max > 0 && oldsize + err > max)
             err = max - oldsize;
         a.resize(oldsize + err);
         memcpy(a.data() + oldsize, chunk.data(), err);
 
-        if(max > 0 && (int)a.size() >= max)
+        if (max > 0 && (int)a.size() >= max)
             break;
     }
 
     err = unzCloseCurrentFile(d->uf);
-    if(err != UNZ_OK)
+    if (err != UNZ_OK)
         return false;
 
     *buf = a;
     return true;
 }
 
+bool UnZip::readFile(const QString &fname, QByteArray *buf, int max)
+{
+    int err = unzLocateFile(d->uf, QFile::encodeName(fname).data(), d->caseSensitive);
+    if (err != UNZ_OK)
+        return false;
+
+    char          filename_inzip[256];
+    unz_file_info file_info;
+    err = unzGetCurrentFileInfo(d->uf, &file_info, filename_inzip, sizeof(filename_inzip), nullptr, 0, nullptr, 0);
+    if (err != UNZ_OK)
+        return false;
+
+    return readCurrentFile(buf, max);
+}
+
 bool UnZip::fileExists(const QString &fname)
 {
     int err = unzLocateFile(d->uf, QFile::encodeName(fname).data(), d->caseSensitive);
