@@ -12,47 +12,49 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef CS_ZIP_H
 #define CS_ZIP_H
 
-class QString;
+#include <QHash>
+#include <QString>
+
+class QByteArray;
 class QStringList;
 
-class UnZip
-{
+class UnZip {
 public:
-    enum CaseSensitivity
-    {
-        CS_Default = 0, // system default
-        CS_Sensitive = 1,
+    enum CaseSensitivity {
+        CS_Default     = 0, // system default
+        CS_Sensitive   = 1,
         CS_Insensitive = 2
     };
 
-    UnZip(const QString &fname="");
+    UnZip(const QString &fname = QString());
     UnZip(UnZip &&o);
     ~UnZip();
 
-    void setCaseSensitivity(CaseSensitivity state = CS_Default);
-    void setName(const QString &);
-    const QString & name() const;
+    void           setCaseSensitivity(CaseSensitivity state = CS_Default);
+    void           setName(const QString &);
+    const QString &name() const;
 
     bool open();
     void close();
 
-    const QStringList & list() const;
-    bool readFile(const QString &, QByteArray *, int max=0);
-    bool fileExists(const QString &);
+    QHash<QString, QByteArray> unpackAll();
+    const QStringList &        list() const;
+    bool                       readFile(const QString &, QByteArray *, int max = 0);
+    bool                       fileExists(const QString &);
 
 private:
     class UnZipPrivate *d;
 
     bool getList();
+    bool readCurrentFile(QByteArray *buf, int max = 0);
 };
 
-#endif
+#endif // CS_ZIP_H
