@@ -13,43 +13,41 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "mainwin_p.h"
 
+#include "alerticon.h"
+#include "icontoolbutton.h"
+#include "iconwidget.h"
+#include "psiaccount.h"
+#include "psicontactlist.h"
+#include "psitoolbar.h"
+#include "stretchwidget.h"
+
 #include <QApplication>
-#include <QStyle>
-#include <QTimer>
-#include <QSignalMapper>
-#include <QObject>
-#include <QPixmapCache>
-#include <QPixmap>
 #include <QFrame>
 #include <QLabel>
 #include <QMenu>
 #include <QMouseEvent>
+#include <QObject>
+#include <QPixmap>
+#include <QPixmapCache>
+#include <QSignalMapper>
+#include <QStyle>
+#include <QTimer>
 #include <QtAlgorithms>
 
-#include "psiaccount.h"
-#include "stretchwidget.h"
-#include "iconwidget.h"
-#include "icontoolbutton.h"
-#include "alerticon.h"
-#include "psicontactlist.h"
-#include "psitoolbar.h"
-
 //----------------------------------------------------------------------------
 // PopupActionButton
 //----------------------------------------------------------------------------
 
-class PopupActionButton : public QPushButton
-{
+class PopupActionButton : public QPushButton {
     Q_OBJECT
 public:
-    PopupActionButton(QWidget *parent = 0, const char *name = 0);
+    PopupActionButton(QWidget *parent = nullptr, const char *name = nullptr);
     ~PopupActionButton();
 
     void setIcon(PsiIcon *, bool showText);
@@ -68,12 +66,12 @@ private:
 
 private:
     PsiIcon *icon;
-    bool showText;
-    QString label;
+    bool     showText;
+    QString  label;
 };
 
-PopupActionButton::PopupActionButton(QWidget *parent, const char *name)
-: QPushButton(parent), icon(0), showText(true)
+PopupActionButton::PopupActionButton(QWidget *parent, const char *name) :
+    QPushButton(parent), icon(nullptr), showText(true)
 {
     setObjectName(name);
 }
@@ -93,17 +91,14 @@ QSize PopupActionButton::sizeHint() const
     return QPushButton::sizeHint();
 }
 
-QSize PopupActionButton::minimumSizeHint() const
-{
-    return QSize(16, 16);
-}
+QSize PopupActionButton::minimumSizeHint() const { return QSize(16, 16); }
 
 void PopupActionButton::setIcon(PsiIcon *i, bool st)
 {
-    if ( icon ) {
+    if (icon) {
         icon->stop();
-        disconnect (icon, 0, this, 0);
-        icon = 0;
+        disconnect(icon, nullptr, this, nullptr);
+        icon = nullptr;
     }
 
     icon = i;
@@ -112,7 +107,7 @@ void PopupActionButton::setIcon(PsiIcon *i, bool st)
         updateText();
     }
 
-    if ( icon ) {
+    if (icon) {
         pixmapUpdated();
 
         connect(icon, SIGNAL(pixmapChanged()), SLOT(pixmapUpdated()));
@@ -130,10 +125,9 @@ void PopupActionButton::setLabel(const QString &lbl)
 
 void PopupActionButton::updateText()
 {
-    if((showText && !label.isEmpty()) && styleSheet().isEmpty()) {
+    if ((showText && !label.isEmpty()) && styleSheet().isEmpty()) {
         setStyleSheet("text-align: center");
-    }
-    else if((!showText || label.isEmpty()) && styleSheet() == "text-align: center") {
+    } else if ((!showText || label.isEmpty()) && styleSheet() == "text-align: center") {
         setStyleSheet(QString());
     }
 
@@ -148,7 +142,14 @@ void PopupActionButton::updateText()
 
 void PopupActionButton::pixmapUpdated()
 {
-    QPixmap pix = icon ? icon->pixmap() : QPixmap();
+    QPixmap pix;
+    if (icon) {
+        auto fs = fontInfo().pixelSize();
+        pix     = icon->pixmap(QSize(int(fs * BiggerTextIconK + .5), int(fs * BiggerTextIconK + .5)));
+        if (pix.height() > fs * HugeIconButtonK) {
+            pix = pix.scaledToHeight(int(fs * BiggerTextIconK + .5), Qt::SmoothTransformation);
+        }
+    }
     QPushButton::setIcon(pix);
     QPushButton::setIconSize(pix.size());
 }
@@ -165,7 +166,7 @@ void PopupActionButton::paintEvent(QPaintEvent *p)
         style_option.init(this);
         QRect r = style()->subElementRect(QStyle::SE_PushButtonContents, &style_option, this);
 
-        if(menu())
+        if (menu())
             r.setWidth(r.width() - style()->pixelMetric(QStyle::PM_MenuButtonIndicator, &style_option, this));
         // if(!QPushButton::icon().isNull())
         //     r.setWidth(r.width() - (QPushButton::icon().pixmap(QIcon::Small, QIcon::Normal, QIcon::Off).width()));
@@ -174,26 +175,34 @@ void PopupActionButton::paintEvent(QPaintEvent *p)
         QFontMetrics fm(font());
 
         // w1 = width of button text, w2 = width of text area
+#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+        int w1 = fm.horizontalAdvance(label);
+#else
         int w1 = fm.width(label);
+#endif
         int w2 = r.width();
 
         // backup original text
         QString oldtext = label;
 
         // button text larger than what will fit?
-        if(w1 > w2) {
+        if (w1 > w2) {
 
             // make a string that fits
-            bool found = false;
+            bool    found = false;
             QString newtext;
-            int n;
-            for(n = oldtext.length(); n > 0; --n) {
-                if(fm.width(oldtext, n) < w2) {
+            int     n;
+            for (n = oldtext.length(); n > 0; --n) {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+                if (fm.horizontalAdvance(oldtext, n) < w2) {
+#else
+                if (fm.width(oldtext, n) < w2) {
+#endif
                     found = true;
                     break;
                 }
             }
-            if(found)
+            if (found)
                 newtext = oldtext.mid(0, n);
             else
                 newtext = "";
@@ -204,8 +213,7 @@ void PopupActionButton::paintEvent(QPaintEvent *p)
                 QPushButton::setText(newtext);
                 setUpdatesEnabled(true);
             }
-        }
-        else {
+        } else {
             if (oldtext != text()) {
                 setUpdatesEnabled(false);
                 QPushButton::setText(oldtext);
@@ -221,18 +229,16 @@ void PopupActionButton::paintEvent(QPaintEvent *p)
 // PopupAction -- the IconButton with popup or QPopupMenu
 //----------------------------------------------------------------------------
 
-class PopupAction::Private : public QObject
-{
+class PopupAction::Private : public QObject {
 public:
-    QSizePolicy size;
-    QList<PopupActionButton*> buttons;
-    PsiIcon *icon;
-    bool showText;
+    QSizePolicy                size;
+    QList<PopupActionButton *> buttons;
+    PsiIcon *                  icon;
+    bool                       showText;
 
-    Private (QObject *parent)
-    : QObject (parent)
+    Private(QObject *parent) : QObject(parent)
     {
-        icon = 0;
+        icon     = nullptr;
         showText = true;
     }
 
@@ -245,65 +251,58 @@ public:
     }
 };
 
-PopupAction::PopupAction (const QString &label, QMenu *_menu, QObject *parent, const char *name)
-: IconAction (label, label, 0, parent, name)
+PopupAction::PopupAction(const QString &label, QMenu *_menu, QObject *parent, const char *name) :
+    IconAction(label, label, 0, parent, name)
 {
-    d = new Private (this);
-    setMenu( _menu );
+    d = new Private(this);
+    setMenu(_menu);
 }
 
-void PopupAction::setSizePolicy (const QSizePolicy &p)
-{
-    d->size = p;
-}
+void PopupAction::setSizePolicy(const QSizePolicy &p) { d->size = p; }
 
-void PopupAction::setAlert (const PsiIcon *icon)
-{
-    setIcon(icon, d->showText, true);
-}
+void PopupAction::setAlert(const PsiIcon *icon) { setIcon(icon, d->showText, true); }
 
-void PopupAction::setIcon (const PsiIcon *icon, bool showText, bool alert)
+void PopupAction::setIcon(const PsiIcon *icon, bool showText, bool alert)
 {
-    PsiIcon *oldIcon = 0;
-    if ( d->icon ) {
+    PsiIcon *oldIcon = nullptr;
+    if (d->icon) {
         oldIcon = d->icon;
-        d->icon = 0;
+        d->icon = nullptr;
     }
 
     d->showText = showText;
 
-    if ( icon ) {
-        if ( !alert )
+    if (icon) {
+        if (!alert)
             d->icon = new PsiIcon(*icon);
         else
             d->icon = new AlertIcon(icon);
 
         IconAction::setIcon(icon->icon());
-    }
-    else {
-        d->icon = 0;
+    } else {
+        d->icon = nullptr;
         IconAction::setIcon(QIcon());
     }
 
-    foreach(PopupActionButton* btn, d->buttons) {
-        btn->setIcon (d->icon, showText);
+    for (PopupActionButton *btn : d->buttons) {
+        btn->setIcon(d->icon, showText);
     }
 
-    if ( oldIcon ) {
+    if (oldIcon) {
         delete oldIcon;
     }
 }
 
-void PopupAction::setText (const QString &text)
+void PopupAction::setText(const QString &text)
 {
-    foreach(PopupActionButton* btn, d->buttons) {
-        btn->setLabel (text);
+    for (PopupActionButton *btn : d->buttons) {
+        btn->setLabel(text);
     }
 }
 
 bool PopupAction::addTo(QWidget *w)
 {
-    QToolBar* toolbar = dynamic_cast<QToolBar*>(w);
+    QToolBar *toolbar = dynamic_cast<QToolBar *>(w);
     if (toolbar) {
         PopupActionButton *btn = new PopupActionButton(w);
         btn->setObjectName(objectName() + QString("_action_button"));
@@ -316,43 +315,38 @@ bool PopupAction::addTo(QWidget *w)
         toolbar->addWidget(btn);
 
         connect(btn, SIGNAL(destroyed()), SLOT(objectDestroyed()));
-    }
-    else {
+    } else {
         return IconAction::addTo(w);
     }
 
     return true;
 }
 
-void PopupAction::objectDestroyed ()
-{
-    const QObject *obj = sender();
-    d->buttons.removeAll( (PopupActionButton *) obj );
-}
+void PopupAction::objectDestroyed() { d->buttons.removeAll(static_cast<PopupActionButton *>(sender())); }
 
-void PopupAction::setEnabled (bool e)
+void PopupAction::setEnabled(bool e)
 {
-    IconAction::setEnabled (e);
-    foreach(PopupActionButton* btn, d->buttons) {
-        btn->setEnabled (e);
+    IconAction::setEnabled(e);
+    for (PopupActionButton *btn : d->buttons) {
+        btn->setEnabled(e);
     }
 }
 
 IconAction *PopupAction::copy() const
 {
-    PopupAction *act = new PopupAction(text(), menu(), 0, objectName().toLatin1());
+    PopupAction *act = new PopupAction(text(), menu(), nullptr, objectName().toLatin1());
 
     *act = *this;
 
     return act;
 }
 
-PopupAction &PopupAction::operator=( const PopupAction &from )
+PopupAction &PopupAction::operator=(const PopupAction &from)
 {
-    *( (IconAction *)this ) = from;
+    *(static_cast<IconAction *>(this)) = from;
 
     d->size = from.d->size;
-    setIcon( from.d->icon );
+    setIcon(from.d->icon);
     d->showText = from.d->showText;
 
     return *this;
@@ -362,8 +356,7 @@ PopupAction &PopupAction::operator=( const PopupAction &from )
 // MLabel -- a clickable label
 //----------------------------------------------------------------------------
 
-MLabel::MLabel(QWidget *parent, const char *name)
-:QLabel(parent)
+MLabel::MLabel(QWidget *parent, const char *name) : QLabel(parent)
 {
     setObjectName(name);
     setMinimumWidth(48);
@@ -373,38 +366,35 @@ MLabel::MLabel(QWidget *parent, const char *name)
 
 void MLabel::mouseReleaseEvent(QMouseEvent *e)
 {
-    emit clicked(e->button());
+    emit clicked(int(e->button()));
     e->ignore();
 }
 
 void MLabel::mouseDoubleClickEvent(QMouseEvent *e)
 {
-    if(e->button() == Qt::LeftButton)
+    if (e->button() == Qt::LeftButton)
         emit doubleClicked();
 
     e->ignore();
 }
 
-
 //----------------------------------------------------------------------------
 // MAction
 //----------------------------------------------------------------------------
 
-MAction::MAction(PsiIcon i, const QString& s, int id, PsiCon* psi, QObject* parent)
-    : IconActionGroup(parent)
+MAction::MAction(PsiIcon i, const QString &s, int id, PsiCon *psi, QObject *parent) : IconActionGroup(parent)
 {
     init(s, i, id, psi);
 }
 
-MAction::MAction(const QString& s, int id, PsiCon* psi, QObject* parent)
-    : IconActionGroup(parent)
+MAction::MAction(const QString &s, int id, PsiCon *psi, QObject *parent) : IconActionGroup(parent)
 {
     init(s, PsiIcon(), id, psi);
 }
 
-void MAction::init(const QString& name, PsiIcon i, int id, PsiCon* psi)
+void MAction::init(const QString &name, PsiIcon i, int id, PsiCon *psi)
 {
-    id_ = id;
+    id_         = id;
     controller_ = psi;
 
     setText(name);
@@ -416,16 +406,13 @@ void MAction::init(const QString& name, PsiIcon i, int id, PsiCon* psi)
     numAccountsChanged();
 }
 
-bool MAction::addTo(QWidget* widget)
+bool MAction::addTo(QWidget *widget)
 {
     widget->addAction(this);
     return true;
 }
 
-QList<PsiAccount*> MAction::accounts() const
-{
-    return controller_->contactList()->enabledAccounts();
-}
+QList<PsiAccount *> MAction::accounts() const { return controller_->contactList()->enabledAccounts(); }
 
 void MAction::slotActivated()
 {
@@ -436,8 +423,8 @@ void MAction::slotActivated()
 
 void MAction::actionActivated()
 {
-    QAction* action = static_cast<QAction*>(sender());
-    int num = action->property("id").toInt();
+    QAction *action = static_cast<QAction *>(sender());
+    int      num    = action->property("id").toInt();
     if (num >= 0 && num < accounts().count()) {
         emit activated(accounts().at(num), id_);
     }
@@ -447,10 +434,10 @@ void MAction::numAccountsChanged()
 {
     setEnabled(accounts().count() > 0);
 
-    qDeleteAll(findChildren<QAction*>());
+    qDeleteAll(findChildren<QAction *>());
 
-    foreach(PsiAccount* account, accounts()) {
-        QAction* act = new QAction(account->name(), this);
+    for (PsiAccount *account : accounts()) {
+        QAction *act = new QAction(account->name(), this);
         act->setProperty("id", accounts().indexOf(account));
         connect(act, SIGNAL(triggered()), SLOT(actionActivated()));
     }
@@ -458,47 +445,43 @@ void MAction::numAccountsChanged()
 
 IconAction *MAction::copy() const
 {
-    MAction *act = new MAction(text(), id_, controller_, 0);
+    MAction *act = new MAction(text(), id_, controller_, nullptr);
 
     *act = *this;
 
     return act;
 }
 
-MAction &MAction::operator=( const MAction &from )
+MAction &MAction::operator=(const MAction &from)
 {
-    *( (IconAction *)this ) = from;
+    *(static_cast<IconAction *>(this)) = from;
 
     return *this;
 }
 
-void MAction::doSetMenu(QMenu* menu)
+void MAction::doSetMenu(QMenu *menu)
 {
-    IconActionGroup::doSetMenu(findChildren<QAction*>().count() > 1 ? menu : 0);
+    IconActionGroup::doSetMenu(findChildren<QAction *>().count() > 1 ? menu : nullptr);
 }
 
 //----------------------------------------------------------------------------
 // SpacerAction
 //----------------------------------------------------------------------------
 
-SpacerAction::SpacerAction(QObject *parent, const char *name)
-: IconAction(parent)
+SpacerAction::SpacerAction(QObject *parent, const char *name) : IconAction(parent)
 {
     setObjectName(name);
     setText(tr("<Spacer>"));
-    setText(tr("<Spacer>"));
-    setWhatsThis(tr("Spacer provides spacing to separate actions"));
+    setToolTip(tr("Spacer provides spacing to separate actions"));
 }
 
-SpacerAction::~SpacerAction()
-{
-}
+SpacerAction::~SpacerAction() { }
 
 bool SpacerAction::addTo(QWidget *w)
 {
-    QToolBar* toolbar = dynamic_cast<QToolBar*>(w);
+    QToolBar *toolbar = dynamic_cast<QToolBar *>(w);
     if (toolbar) {
-        StretchWidget* stretch = new StretchWidget(w);
+        StretchWidget *stretch = new StretchWidget(w);
         toolbar->addWidget(stretch);
         return true;
     }
@@ -506,25 +489,20 @@ bool SpacerAction::addTo(QWidget *w)
     return false;
 }
 
-IconAction *SpacerAction::copy() const
-{
-    return new SpacerAction( 0 );
-}
+IconAction *SpacerAction::copy() const { return new SpacerAction(nullptr); }
 
 //----------------------------------------------------------------------------
 // SeparatorAction
 //----------------------------------------------------------------------------
 
-SeparatorAction::SeparatorAction( QObject *parent, const char *name )
-    : IconAction( tr("<Separator>"), tr("<Separator>"), 0, parent, name )
+SeparatorAction::SeparatorAction(QObject *parent, const char *name) :
+    IconAction(tr("<Separator>"), tr("<Separator>"), 0, parent, name)
 {
     setSeparator(true);
-    setWhatsThis (tr("Separator"));
+    setToolTip(tr("Separator"));
 }
 
-SeparatorAction::~SeparatorAction()
-{
-}
+SeparatorAction::~SeparatorAction() { }
 
 // we don't want QToolButtons when adding this action
 // on toolbar
@@ -534,37 +512,29 @@ bool SeparatorAction::addTo(QWidget *w)
     return true;
 }
 
-IconAction *SeparatorAction::copy() const
-{
-    return new SeparatorAction(0);
-}
+IconAction *SeparatorAction::copy() const { return new SeparatorAction(nullptr); }
 
 //----------------------------------------------------------------------------
 // EventNotifierAction
 //----------------------------------------------------------------------------
 
-class EventNotifierAction::Private
-{
+class EventNotifierAction::Private {
 public:
     Private() = default;
 
-    QList<MLabel*> labels;
-    bool hide = false;
-    QString message;
+    QList<MLabel *> labels;
+    bool            hide = false;
+    QString         message;
 };
 
-EventNotifierAction::EventNotifierAction(QObject *parent, const char *name)
-: IconAction(parent, name)
+EventNotifierAction::EventNotifierAction(QObject *parent, const char *name) : IconAction(parent, name)
 {
     d = new Private;
     setText(tr("<Event notifier>"));
     d->hide = true;
 }
 
-EventNotifierAction::~EventNotifierAction()
-{
-    delete d;
-}
+EventNotifierAction::~EventNotifierAction() { delete d; }
 
 bool EventNotifierAction::addTo(QWidget *w)
 {
@@ -576,13 +546,12 @@ bool EventNotifierAction::addTo(QWidget *w)
         connect(label, SIGNAL(doubleClicked()), SIGNAL(triggered()));
         connect(label, SIGNAL(clicked(int)), SIGNAL(clicked(int)));
 
-        QToolBar* toolbar = dynamic_cast<QToolBar*>(w);
+        QToolBar *toolbar = dynamic_cast<QToolBar *>(w);
         if (!toolbar) {
-            QLayout* layout = w->layout();
+            QLayout *layout = w->layout();
             if (layout)
                 layout->addWidget(label);
-        }
-        else {
+        } else {
             toolbar->addWidget(label);
         }
 
@@ -599,7 +568,7 @@ void EventNotifierAction::setMessage(const QString &m)
 {
     d->message = m;
 
-    foreach(MLabel* label, d->labels) {
+    for (MLabel *label : d->labels) {
         label->setText(d->message);
     }
 }
@@ -614,24 +583,24 @@ void EventNotifierAction::hide()
 {
     d->hide = true;
 
-    foreach(MLabel* label, d->labels) {
+    for (MLabel *label : d->labels) {
         label->hide();
-        PsiToolBar *toolBar = dynamic_cast<PsiToolBar*>(label->parent());
+        PsiToolBar *toolBar = dynamic_cast<PsiToolBar *>(label->parent());
         if (toolBar) {
             int found = 0;
-            foreach(QWidget* widget, toolBar->findChildren<QWidget*>()) {
-                if (!widget->objectName().startsWith("qt_") &&
-                    !QString(widget->metaObject()->className()).startsWith("QToolBar") &&
-                    !QString(widget->metaObject()->className()).startsWith("QMenu") &&
-                    QString(widget->metaObject()->className()) != "Oxygen::TransitionWidget") // dirty hack
+            for (QWidget *widget : toolBar->findChildren<QWidget *>()) {
+                if (!widget->objectName().startsWith("qt_")
+                    && !QString(widget->metaObject()->className()).startsWith("QToolBar")
+                    && !QString(widget->metaObject()->className()).startsWith("QMenu")
+                    && QString(widget->metaObject()->className()) != "Oxygen::TransitionWidget") // dirty hack
                 {
                     found++;
                 }
             }
 
-            if (found == 1)   // only MLabel is on ToolBar
-                //We should not hide toolbar, if it should be visible (user set `enabled` in options)
-                //toolBar->hide();
+            if (found == 1) // only MLabel is on ToolBar
+                // We should not hide toolbar, if it should be visible (user set `enabled` in options)
+                // toolBar->hide();
                 toolBar->updateVisibility();
         }
     }
@@ -641,9 +610,9 @@ void EventNotifierAction::show()
 {
     d->hide = false;
 
-    foreach(MLabel* label, d->labels) {
+    for (MLabel *label : d->labels) {
         label->show();
-        QToolBar *toolBar = dynamic_cast<QToolBar*>(label->parent());
+        QToolBar *toolBar = dynamic_cast<QToolBar *>(label->parent());
         if (toolBar)
             toolBar->show();
     }
@@ -659,16 +628,16 @@ void EventNotifierAction::updateVisibility()
 
 IconAction *EventNotifierAction::copy() const
 {
-    EventNotifierAction *act = new EventNotifierAction( 0 );
+    EventNotifierAction *act = new EventNotifierAction(nullptr);
 
     *act = *this;
 
     return act;
 }
 
-EventNotifierAction &EventNotifierAction::operator=( const EventNotifierAction &from )
+EventNotifierAction &EventNotifierAction::operator=(const EventNotifierAction &from)
 {
-    *( (IconAction *)this ) = from;
+    *(static_cast<IconAction *>(this)) = from;
 
     d->hide = from.d->hide;
 
