@@ -13,31 +13,29 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef MAINWIN_P_H
 
+#include "iconaction.h"
+#include "psicon.h"
+
+#include <QAction>
+#include <QLabel>
+#include <QLayout>
+#include <QMenu>
+#include <QMouseEvent>
 #include <QPushButton>
 #include <QToolButton>
-#include <QMenu>
-#include <QLayout>
-#include <QLabel>
-#include <QAction>
-#include <QMouseEvent>
-
-#include "psicon.h"
-#include "iconaction.h"
 
 class QMenu;
 
-class SeparatorAction : public IconAction
-{
+class SeparatorAction : public IconAction {
     Q_OBJECT
 public:
-    SeparatorAction(QObject *parent, const char *name = 0);
+    SeparatorAction(QObject *parent, const char *name = nullptr);
     ~SeparatorAction();
 
     virtual bool addTo(QWidget *w);
@@ -45,76 +43,72 @@ public:
     virtual IconAction *copy() const;
 };
 
-class SpacerAction : public IconAction
-{
+class SpacerAction : public IconAction {
     Q_OBJECT
 public:
-    SpacerAction(QObject *parent, const char *name = 0);
+    SpacerAction(QObject *parent, const char *name = nullptr);
     ~SpacerAction();
 
-    virtual bool addTo (QWidget *w);
+    virtual bool addTo(QWidget *w);
 
     virtual IconAction *copy() const;
 };
 
-class EventNotifierAction : public IconAction
-{
+class EventNotifierAction : public IconAction {
     Q_OBJECT
 public:
-    EventNotifierAction(QObject *parent, const char *name = 0);
+    EventNotifierAction(QObject *parent, const char *name = nullptr);
     ~EventNotifierAction();
 
     void setMessage(const QString &);
-    bool addTo (QWidget *w);
+    bool addTo(QWidget *w);
 
     void hide();
     void show();
     void updateVisibility();
 
-    virtual IconAction *copy() const;
-    virtual EventNotifierAction &operator=( const EventNotifierAction & );
+    virtual IconAction *         copy() const;
+    virtual EventNotifierAction &operator=(const EventNotifierAction &);
 
 signals:
     void clicked(int);
 
 private slots:
-    void objectDestroyed ();
+    void objectDestroyed();
 
 private:
     class Private;
     Private *d;
 };
 
-class PopupAction : public IconAction
-{
+class PopupAction : public IconAction {
     Q_OBJECT
 private:
     class Private;
     Private *d;
 
 private slots:
-    void objectDestroyed ();
+    void objectDestroyed();
 
 public slots:
-    void setEnabled (bool);
+    void setEnabled(bool);
 
 public:
-    PopupAction (const QString &label, QMenu *_menu, QObject *parent, const char *name);
-    void setSizePolicy (const QSizePolicy &p);
-    void setAlert (const PsiIcon *);
-    void setIcon (const PsiIcon *, bool showText = true, bool alert = false);
-    void setText (const QString &text);
-    bool addTo (QWidget *w);
+    PopupAction(const QString &label, QMenu *_menu, QObject *parent, const char *name);
+    void setSizePolicy(const QSizePolicy &p);
+    void setAlert(const PsiIcon *);
+    void setIcon(const PsiIcon *, bool showText = true, bool alert = false);
+    void setText(const QString &text);
+    bool addTo(QWidget *w);
 
-    virtual IconAction *copy() const;
-    virtual PopupAction &operator=( const PopupAction & );
+    virtual IconAction * copy() const;
+    virtual PopupAction &operator=(const PopupAction &);
 };
 
-class MLabel : public QLabel
-{
+class MLabel : public QLabel {
     Q_OBJECT
 public:
-    MLabel(QWidget *parent=0, const char *name=0);
+    MLabel(QWidget *parent = nullptr, const char *name = nullptr);
 
 protected:
     // reimplemented
@@ -126,8 +120,7 @@ signals:
     void doubleClicked();
 };
 
-class MAction : public IconActionGroup
-{
+class MAction : public IconActionGroup {
     Q_OBJECT
 
 public:
@@ -138,7 +131,7 @@ public:
     virtual bool addTo(QWidget *);
 
     virtual IconAction *copy() const;
-    virtual MAction &operator=( const MAction & );
+    virtual MAction &   operator=(const MAction &);
 
 signals:
     void activated(PsiAccount *, int);
@@ -150,15 +143,14 @@ private slots:
 
 protected:
     // reimplemented
-    virtual void doSetMenu(QMenu* menu);
+    virtual void doSetMenu(QMenu *menu);
 
 private:
-    int id_;
-    PsiCon* controller_;
+    int     id_;
+    PsiCon *controller_;
 
-    void init(const QString& name, PsiIcon, int id, PsiCon* psi);
-    QList<PsiAccount*> accounts() const;
+    void                init(const QString &name, PsiIcon, int id, PsiCon *psi);
+    QList<PsiAccount *> accounts() const;
 };
 
-#endif
-
+#endif // MAINWIN_P_H
