@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 Martin Hostettler
+ * Copyright (C) 2008  Martin Hostettler
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,9 +19,11 @@
 // tab completion helper for mini command system
 
 #include "mcmdcompletion.h"
+
 #include "minicmd.h"
 
-void MCmdTabCompletion::setup(QString str, int pos, int &start, int &end) {
+void MCmdTabCompletion::setup(QString str, int pos, int &start, int &end)
+{
     if (mgr_->isActive()) {
         mCmdList_ = mgr_->completeCommand(str, pos, start, end);
     } else {
@@ -29,14 +31,16 @@ void MCmdTabCompletion::setup(QString str, int pos, int &start, int &end) {
     }
 }
 
-QStringList MCmdTabCompletion::possibleCompletions() {
+QStringList MCmdTabCompletion::possibleCompletions()
+{
     if (mgr_->isActive()) {
         return mCmdList_;
     }
     return QStringList();
 }
 
-QStringList MCmdTabCompletion::allChoices(QString &guess) {
+QStringList MCmdTabCompletion::allChoices(QString &guess)
+{
     if (mgr_->isActive()) {
         guess = QString();
         return mCmdList_;
