@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 Martin Hostettler
+ * Copyright (C) 2008  Martin Hostettler
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,27 +26,25 @@
 #include <QPalette>
 
 class QLabel;
-class QTextEdit;
 class QString;
+class QTextEdit;
 
 class MCmdSimpleSite : public MCmdUiSiteIface {
 public:
-    MCmdSimpleSite(QLabel *p, QTextEdit *i) : promptWidget(p), inputWidget(i), open(false) {};
-    MCmdSimpleSite() : promptWidget(0), inputWidget(0), open(false) {};
-    ~MCmdSimpleSite() {};
+    MCmdSimpleSite(QLabel *p, QTextEdit *i);
+    MCmdSimpleSite();
+    ~MCmdSimpleSite() = default;
     virtual void mCmdReady(const QString prompt, const QString preset);
     virtual void mCmdClose();
-    bool isActive() { return open; };
-    void setPrompt(QLabel *p) {promptWidget = p;};
-    void setInput(QTextEdit *i);
+    bool         isActive() const;
+    void         setPrompt(QLabel *p);
+    void         setInput(QTextEdit *i);
+
 protected:
-    QLabel *promptWidget;
+    QLabel *   promptWidget;
     QTextEdit *inputWidget;
-    bool open;
-    QString mini_msg_swap;
-    int cursorPos;  // FIXME save cursor position...
-    QPalette palette, cmdPalette;
+    bool       open;
+    QString    mini_msg_swap;
 };
 
-
-#endif
+#endif // MINICMDSIMPLESITE_H
