@@ -13,60 +13,36 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
+#include "mood.h"
+
+#include "moodcatalog.h"
+
 #include <QDomDocument>
 #include <QDomElement>
 
-#include "mood.h"
-#include "moodcatalog.h"
+Mood::Mood() { type_ = Unknown; }
 
-Mood::Mood()
-{
-    type_ = Unknown;
-}
+Mood::Mood(Mood::Type type, const QString &text) : type_(type), text_(text) { }
 
-Mood::Mood(Mood::Type type, const QString& text) : type_(type), text_(text)
-{
-}
+Mood::Mood(const QDomElement &e) { fromXml(e); }
 
-Mood::Mood(const QDomElement& e)
-{
-    fromXml(e);
-}
+Mood::Type Mood::type() const { return type_; }
 
-Mood::Type Mood::type() const
-{
-    return type_;
-}
+QString Mood::typeText() const { return MoodCatalog::instance()->findEntryByType(type_).text(); }
 
-QString Mood::typeText() const
-{
-    return MoodCatalog::instance()->findEntryByType(type_).text();
-}
+QString Mood::typeValue() const { return MoodCatalog::instance()->findEntryByType(type_).value(); }
 
-QString Mood::typeValue() const
-{
-    return MoodCatalog::instance()->findEntryByType(type_).value();
-}
+const QString &Mood::text() const { return text_; }
 
-const QString& Mood::text() const
-{
-    return text_;
-}
+bool Mood::isNull() const { return type_ == Unknown && text().isEmpty(); }
 
-bool Mood::isNull() const
+QDomElement Mood::toXml(QDomDocument &doc)
 {
-    return type_ == Unknown && text().isEmpty();
-}
-
-QDomElement Mood::toXml(QDomDocument& doc)
-{
-    QDomElement mood = doc.createElement("mood");
-    mood.setAttribute("xmlns", PEP_MOOD_NS);
+    QDomElement mood = doc.createElementNS(PEP_MOOD_NS, "mood");
 
     if (type() != Unknown) {
         QDomElement el = doc.createElement(MoodCatalog::instance()->findEntryByType(type()).value());
@@ -75,7 +51,7 @@ QDomElement Mood::toXml(QDomDocument& doc)
 
     if (!text().isEmpty()) {
         QDomElement el = doc.createElement("text");
-        QDomText t = doc.createTextNode(text());
+        QDomText    t  = doc.createTextNode(text());
         el.appendChild(t);
         mood.appendChild(el);
     }
@@ -83,22 +59,21 @@ QDomElement Mood::toXml(QDomDocument& doc)
     return mood;
 }
 
-void Mood::fromXml(const QDomElement& e)
+void Mood::fromXml(const QDomElement &e)
 {
     text_.clear();
     type_ = Unknown;
     if (e.tagName() != "mood")
         return;
 
-    for(QDomNode n = e.firstChild(); !n.isNull(); n = n.nextSibling()) {
+    for (QDomNode n = e.firstChild(); !n.isNull(); n = n.nextSibling()) {
         QDomElement m = n.toElement();
-        if(m.isNull()) {
+        if (m.isNull()) {
             continue;
         }
         if (m.tagName() == "text") {
             text_ = m.text();
-        }
-        else {
+        } else {
             type_ = MoodCatalog::instance()->findEntryByValue(m.tagName()).type();
         }
     }
