@@ -13,25 +13,24 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
-#include "xmpp_pubsubitem.h"
-#include "xmpp_client.h"
-#include "xmpp_task.h"
 #include "mooddlg.h"
-#include "moodcatalog.h"
-#include "psiaccount.h"
-#include "pepmanager.h"
-#include "psiiconset.h"
 
-MoodDlg::MoodDlg(QList<PsiAccount*> list)
-    : QDialog(0), pa_(list)
+#include "moodcatalog.h"
+#include "pepmanager.h"
+#include "psiaccount.h"
+#include "psiiconset.h"
+#include "xmpp_client.h"
+#include "xmpp_pubsubitem.h"
+#include "xmpp_task.h"
+
+MoodDlg::MoodDlg(QList<PsiAccount *> list) : QDialog(nullptr), pa_(list)
 {
     setAttribute(Qt::WA_DeleteOnClose);
-    if(pa_.isEmpty())
+    if (pa_.isEmpty())
         close();
     ui_.setupUi(this);
     setWindowIcon(IconsetFactory::icon("mood/").icon());
@@ -42,10 +41,10 @@ MoodDlg::MoodDlg(QList<PsiAccount*> list)
 
     ui_.cb_type->addItem(tr("<unset>"));
     PsiAccount *pa = pa_.first();
-    Mood::Type mt = pa->mood().type();
-    int i=1;
-    foreach(MoodCatalog::Entry e, MoodCatalog::instance()->entries()) {
-            ui_.cb_type->addItem(IconsetFactory::icon("mood/"+e.value()).icon(), e.text());
+    Mood::Type  mt = pa->mood().type();
+    int         i  = 1;
+    for (MoodCatalog::Entry e : MoodCatalog::instance()->entries()) {
+        ui_.cb_type->addItem(IconsetFactory::icon("mood/" + e.value()).icon(), e.text());
         if (e.type() == mt) {
             ui_.cb_type->setCurrentIndex(i);
         }
@@ -54,17 +53,17 @@ MoodDlg::MoodDlg(QList<PsiAccount*> list)
     ui_.le_text->setText(pa->mood().text());
 }
 
-
 void MoodDlg::setMood()
 {
     QString moodstr = ui_.cb_type->currentText();
-    foreach(PsiAccount *pa, pa_) {
+    for (PsiAccount *pa : pa_) {
         if (moodstr == tr("<unset>")) {
             pa->pepManager()->disable("mood", PEP_MOOD_NS, "current");
-        }
-        else {
+        } else {
             Mood::Type type = MoodCatalog::instance()->findEntryByText(moodstr).type();
-            pa->pepManager()->publish(PEP_MOOD_NS, PubSubItem("current",Mood(type,ui_.le_text->text()).toXml(*pa->client()->rootTask()->doc())));
+            pa->pepManager()->publish(
+                PEP_MOOD_NS,
+                PubSubItem("current", Mood(type, ui_.le_text->text()).toXml(*pa->client()->rootTask()->doc())));
         }
     }
     close();
