@@ -13,72 +13,71 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "msgmle.h"
 
+#include "htmltextcontroller.h"
+#include "psiiconset.h"
+#include "psioptions.h"
+#include "qiteaudiorecorder.h"
+#include "shortcutmanager.h"
+#include "spellchecker/spellchecker.h"
+#include "spellchecker/spellhighlighter.h"
+#include "textutil.h"
+
 #include <QAbstractTextDocumentLayout>
 #include <QAction>
 #include <QApplication>
+#include <QAudioRecorder>
+#include <QClipboard>
 #include <QDesktopWidget>
 #include <QEvent>
 #include <QKeyEvent>
+#include <QLabel>
 #include <QLayout>
 #include <QMenu>
+#include <QMimeData>
+#include <QMimeDatabase>
 #include <QResizeEvent>
+#include <QStyle>
 #include <QTextCharFormat>
 #include <QTextDocument>
 #include <QTimer>
-#include <QMimeData>
-#include <QClipboard>
+#include <QToolButton>
 
-#include "shortcutmanager.h"
-#include "spellchecker/spellhighlighter.h"
-#include "spellchecker/spellchecker.h"
-#include "psioptions.h"
-#include "htmltextcontroller.h"
+static const int TIMEOUT        = 30000; // 30 secs maximum time interval
+static const int SECOND         = 1000;
+static const int maxOverlayTime = TIMEOUT / SECOND;
 
 //----------------------------------------------------------------------------
 // CapitalLettersController
 //----------------------------------------------------------------------------
 
-class CapitalLettersController : public QObject
-{
+class CapitalLettersController : public QObject {
     Q_OBJECT
 public:
-    CapitalLettersController(QTextEdit* parent)
-        : QObject()
-        , te_(parent)
-        , enabled_(true)
+    explicit CapitalLettersController(QTextEdit *parent) : QObject(), te_(parent), enabled_(true)
     {
-        connect(te_->document(), SIGNAL(contentsChange(int,int,int)), SLOT(textChanged(int,int,int)));
+        connect(te_->document(), SIGNAL(contentsChange(int, int, int)), SLOT(textChanged(int, int, int)));
     }
 
-    virtual ~CapitalLettersController() {}
+    ~CapitalLettersController() override = default;
 
-    void setAutoCapitalizeEnabled(bool enabled)
-    {
-        enabled_ = enabled;
-    }
+    void setEnabled(bool enabled) { enabled_ = enabled; }
+    bool isEnabled() const { return enabled_; }
 
 private:
-    void capitalizeChar(int pos, QChar c)
-    {
-        changeChar(pos, c.toUpper());
-    }
+    void capitalizeChar(int pos, QChar c) { changeChar(pos, c.toUpper()); }
 
-    void decapitalizeChar(int pos, QChar c)
-    {
-        changeChar(pos, c.toLower());
-    }
+    void decapitalizeChar(int pos, QChar c) { changeChar(pos, c.toLower()); }
 
     void changeChar(int pos, QChar c)
     {
         QTextCursor cur = te_->textCursor();
-        cur.setPosition(pos+1);
+        cur.setPosition(pos + 1);
         const QTextCharFormat cf = cur.charFormat();
         cur.deletePreviousChar();
         cur.setCharFormat(cf);
@@ -88,36 +87,33 @@ private:
 public slots:
     void textChanged(int pos, int /*charsRemoved*/, int charsAdded)
     {
-        if(enabled_) {
-            if(charsAdded == 0) {
+        if (enabled_) {
+            if (charsAdded == 0) {
                 return;
             }
-            if(!te_->textCursor().atEnd()) { //Editing the letter in the middle of the text
+            if (!te_->textCursor().atEnd()) { // Editing the letter in the middle of the text
                 return;
             }
             bool capitalizeNext_ = false;
 
-            if(pos == 0 && charsAdded < 3) { //the first letter after the previous message was sent
+            if (pos == 0 && charsAdded < 3) { // the first letter after the previous message was sent
                 capitalizeNext_ = true;
-            }
-            else if (charsAdded > 1) { //Insert a piece of text
+            } else if (charsAdded > 1) { // Insert a piece of text
                 return;
-            }
-            else {
+            } else {
                 QString txt = te_->toPlainText();
                 QRegExp capitalizeAfter("(?:^[^.][.]+\\s+)|(?:\\s*[^.]{2,}[.]+\\s+)|(?:[!?]\\s+)");
-                int index = txt.lastIndexOf(capitalizeAfter);
-                if(index != -1 && index == pos-capitalizeAfter.matchedLength()) {
+                int     index = txt.lastIndexOf(capitalizeAfter);
+                if (index != -1 && index == pos - capitalizeAfter.matchedLength()) {
                     capitalizeNext_ = true;
                 }
             }
 
-            if(capitalizeNext_) {
+            if (capitalizeNext_) {
                 QChar ch = te_->document()->characterAt(pos);
-                if(!ch.isLetter() || !ch.isLower()) {
+                if (!ch.isLetter() || !ch.isLower()) {
                     return;
-                }
-                else {
+                } else {
                     capitalizeChar(pos, ch);
                 }
             }
@@ -126,26 +122,25 @@ public slots:
 
     void changeCase()
     {
-        bool tmpEnabled = enabled_;
-        enabled_ = false;
+        bool tmpEnabled    = enabled_;
+        enabled_           = false;
         QTextCursor oldCur = te_->textCursor();
-        int pos = oldCur.position();
-        int begin = 0;
-        int end = te_->document()->characterCount();
-        if(oldCur.hasSelection()) {
+        int         pos    = oldCur.position();
+        int         begin  = 0;
+        int         end    = te_->document()->characterCount();
+        if (oldCur.hasSelection()) {
             begin = oldCur.selectionStart();
-            end = oldCur.selectionEnd();
+            end   = oldCur.selectionEnd();
         }
-        for(; begin < end; begin++) {
+        for (; begin < end; begin++) {
             QChar ch = te_->document()->characterAt(begin);
-            if(!ch.isLetter()) {
+            if (!ch.isLetter()) {
                 continue;
             }
 
-            if(ch.isLower()) {
+            if (ch.isLower()) {
                 capitalizeChar(begin, ch);
-            }
-            else {
+            } else {
                 decapitalizeChar(begin, ch);
             }
         }
@@ -155,20 +150,17 @@ public slots:
     }
 
 private:
-    QTextEdit* te_;
-    bool enabled_;
+    QTextEdit *te_;
+    bool       enabled_;
 };
 
-
 //----------------------------------------------------------------------------
 // ChatEdit
 //----------------------------------------------------------------------------
-ChatEdit::ChatEdit(QWidget *parent)
-    : QTextEdit(parent)
-    , palOriginal(palette())
-    , palCorrection(palOriginal)
+ChatEdit::ChatEdit(QWidget *parent) :
+    QTextEdit(parent), layout_(nullptr), recButton_(nullptr), overlay_(nullptr), timeout_(TIMEOUT)
 {
-    controller_ = new HTMLTextController(this);
+    controller_  = new HTMLTextController(this);
     capitalizer_ = new CapitalLettersController(this);
 
     setWordWrapMode(QTextOption::WordWrap);
@@ -181,9 +173,8 @@ ChatEdit::ChatEdit(QWidget *parent)
 
     previous_position_ = 0;
     setCheckSpelling(checkSpellingGloballyEnabled());
-    connect(PsiOptions::instance(),SIGNAL(optionChanged(const QString&)),SLOT(optionsChanged()));
+    connect(PsiOptions::instance(), SIGNAL(optionChanged(const QString &)), SLOT(optionsChanged()));
     typedMsgsIndex = 0;
-    palCorrection.setColor(QPalette::Base, QColor(160, 160, 0));
     initActions();
     setShortcuts();
     optionsChanged();
@@ -196,10 +187,7 @@ ChatEdit::~ChatEdit()
     delete capitalizer_;
 }
 
-CapitalLettersController * ChatEdit::capitalizer()
-{
-    return capitalizer_;
-}
+CapitalLettersController *ChatEdit::capitalizer() { return capitalizer_; }
 
 void ChatEdit::initActions()
 {
@@ -207,7 +195,7 @@ void ChatEdit::initActions()
     addAction(act_showMessagePrev);
     connect(act_showMessagePrev, SIGNAL(triggered()), SLOT(showHistoryMessagePrev()));
 
-    act_showMessageNext= new QAction(this);
+    act_showMessageNext = new QAction(this);
     addAction(act_showMessageNext);
     connect(act_showMessageNext, SIGNAL(triggered()), SLOT(showHistoryMessageNext()));
 
@@ -215,7 +203,7 @@ void ChatEdit::initActions()
     addAction(act_showMessageFirst);
     connect(act_showMessageFirst, SIGNAL(triggered()), SLOT(showHistoryMessageFirst()));
 
-    act_showMessageLast= new QAction(this);
+    act_showMessageLast = new QAction(this);
     addAction(act_showMessageLast);
     connect(act_showMessageLast, SIGNAL(triggered()), SLOT(showHistoryMessageLast()));
 
@@ -224,7 +212,7 @@ void ChatEdit::initActions()
     connect(act_changeCase, SIGNAL(triggered()), capitalizer_, SLOT(changeCase()));
 
     QClipboard *clipboard = QApplication::clipboard();
-    actPasteAsQuote_ = new QAction(tr("Paste as Quotation"), this);
+    actPasteAsQuote_      = new QAction(tr("Paste as Quotation"), this);
     actPasteAsQuote_->setEnabled(clipboard->mimeData()->hasText());
     addAction(actPasteAsQuote_);
     connect(actPasteAsQuote_, SIGNAL(triggered()), SLOT(pasteAsQuote()));
@@ -240,15 +228,9 @@ void ChatEdit::setShortcuts()
     act_changeCase->setShortcuts(ShortcutManager::instance()->shortcuts("chat.change-case"));
 }
 
-void ChatEdit::setDialog(QWidget* dialog)
-{
-    dialog_ = dialog;
-}
+void ChatEdit::setDialog(QWidget *dialog) { dialog_ = dialog; }
 
-QSize ChatEdit::sizeHint() const
-{
-    return minimumSizeHint();
-}
+QSize ChatEdit::sizeHint() const { return minimumSizeHint(); }
 
 void ChatEdit::setFont(const QFont &f)
 {
@@ -256,7 +238,7 @@ void ChatEdit::setFont(const QFont &f)
     controller_->setFont(f);
 }
 
-QMenu* ChatEdit::createStandardContextMenu(const QPoint &position)
+QMenu *ChatEdit::createStandardContextMenu(const QPoint &position)
 {
     QMenu *menu = QTextEdit::createStandardContextMenu(position);
     menu->addAction(actPasteAsQuote_);
@@ -265,7 +247,8 @@ QMenu* ChatEdit::createStandardContextMenu(const QPoint &position)
 
 bool ChatEdit::checkSpellingGloballyEnabled()
 {
-    return (SpellChecker::instance()->available() && PsiOptions::instance()->getOption("options.ui.spell-check.enabled").toBool());
+    return (SpellChecker::instance()->available()
+            && PsiOptions::instance()->getOption("options.ui.spell-check.enabled").toBool());
 }
 
 void ChatEdit::setCheckSpelling(bool b)
@@ -274,29 +257,29 @@ void ChatEdit::setCheckSpelling(bool b)
     if (check_spelling_) {
         if (!spellhighlighter_)
             spellhighlighter_.reset(new SpellHighlighter(document()));
-    }
-    else {
+    } else {
         spellhighlighter_.reset();
     }
 }
 
-bool ChatEdit::focusNextPrevChild(bool next)
-{
-    return QWidget::focusNextPrevChild(next);
-}
+bool ChatEdit::focusNextPrevChild(bool next) { return QWidget::focusNextPrevChild(next); }
 
 // Qt text controls are quite greedy to grab key events.
 // disable that.
-bool ChatEdit::event(QEvent * event) {
+bool ChatEdit::event(QEvent *event)
+{
     if (event->type() == QEvent::ShortcutOverride) {
         return false;
     }
+    if (event->type() == QEvent::PaletteChange && recButton_ && !correction) {
+        setRecButtonIcon();
+    }
     return QTextEdit::event(event);
 }
 
 void ChatEdit::keyPressEvent(QKeyEvent *e)
 {
-/*    if(e->key() == Qt::Key_Escape || (e->key() == Qt::Key_W && e->modifiers() & Qt::ControlModifier))
+    /*    if(e->key() == Qt::Key_Escape || (e->key() == Qt::Key_W && e->modifiers() & Qt::ControlModifier))
         e->ignore();
     else if(e->key() == Qt::Key_Return &&
            ((e->modifiers() & Qt::ControlModifier)
@@ -311,21 +294,19 @@ void ChatEdit::keyPressEvent(QKeyEvent *e)
         e->ignore();
     else  if(e->key() == Qt::Key_S && (e->modifiers() & Qt::AltModifier))
         e->ignore();
-    else*/ if(e->key() == Qt::Key_U && (e->modifiers() & Qt::ControlModifier))
+    else*/
+    if (e->key() == Qt::Key_U && (e->modifiers() & Qt::ControlModifier))
         setText("");
-/*    else if((e->key() == Qt::Key_Return || e->key() == Qt::Key_Enter) && !((e->modifiers() & Qt::ShiftModifier) || (e->modifiers() & Qt::AltModifier)) && LEGOPTS.chatSoftReturn)
-        e->ignore();
-    else if((e->key() == Qt::Key_PageUp || e->key() == Qt::Key_PageDown) && (e->modifiers() & Qt::ShiftModifier))
-        e->ignore();
-    else if((e->key() == Qt::Key_PageUp || e->key() == Qt::Key_PageDown) && (e->modifiers() & Qt::ControlModifier))
-        e->ignore(); */
+/*    else if((e->key() == Qt::Key_Return || e->key() == Qt::Key_Enter) && !((e->modifiers() & Qt::ShiftModifier) ||
+   (e->modifiers() & Qt::AltModifier)) && LEGOPTS.chatSoftReturn) e->ignore(); else if((e->key() == Qt::Key_PageUp ||
+   e->key() == Qt::Key_PageDown) && (e->modifiers() & Qt::ShiftModifier)) e->ignore(); else if((e->key() ==
+   Qt::Key_PageUp || e->key() == Qt::Key_PageDown) && (e->modifiers() & Qt::ControlModifier)) e->ignore(); */
 #ifdef Q_OS_MAC
     else if (e->key() == Qt::Key_QuoteLeft && e->modifiers() == Qt::ControlModifier) {
         e->ignore();
     }
 #endif
-    else
-    {
+    else {
         QTextEdit::keyPressEvent(e);
     }
 }
@@ -344,20 +325,21 @@ void ChatEdit::contextMenuEvent(QContextMenuEvent *e)
         tc.movePosition(QTextCursor::StartOfWord, QTextCursor::MoveAnchor);
         tc.movePosition(QTextCursor::EndOfWord, QTextCursor::KeepAnchor);
         QString selected_word = tc.selectedText();
-        if (!selected_word.isEmpty() && !QRegExp("\\d+").exactMatch(selected_word) && !SpellChecker::instance()->isCorrect(selected_word)) {
+        if (!selected_word.isEmpty() && !QRegExp("\\d+").exactMatch(selected_word)
+            && !SpellChecker::instance()->isCorrect(selected_word)) {
             QList<QString> suggestions = SpellChecker::instance()->suggestions(selected_word);
             if (!suggestions.isEmpty() || SpellChecker::instance()->writable()) {
                 QMenu spell_menu;
                 if (!suggestions.isEmpty()) {
-                    foreach(QString suggestion, suggestions) {
-                        QAction* act_suggestion = spell_menu.addAction(suggestion);
-                        connect(act_suggestion,SIGNAL(triggered()),SLOT(applySuggestion()));
+                    for (const QString &suggestion : suggestions) {
+                        QAction *act_suggestion = spell_menu.addAction(suggestion);
+                        connect(act_suggestion, SIGNAL(triggered()), SLOT(applySuggestion()));
                     }
                     spell_menu.addSeparator();
                 }
                 if (SpellChecker::instance()->writable()) {
-                    QAction* act_add = spell_menu.addAction(tr("Add to dictionary"));
-                    connect(act_add,SIGNAL(triggered()),SLOT(addToDictionary()));
+                    QAction *act_add = spell_menu.addAction(tr("Add to dictionary"));
+                    connect(act_add, SIGNAL(triggered()), SLOT(addToDictionary()));
                 }
                 spell_menu.exec(QCursor::pos());
                 e->accept();
@@ -383,11 +365,11 @@ void ChatEdit::contextMenuEvent(QContextMenuEvent *e)
  */
 void ChatEdit::applySuggestion()
 {
-    QAction* act_suggestion = (QAction*) sender();
-    int current_position = textCursor().position();
+    auto *act_suggestion   = qobject_cast<QAction *>(sender());
+    int   current_position = textCursor().position();
 
     // Replace the word
-    QTextCursor    tc = cursorForPosition(last_click_);
+    QTextCursor tc = cursorForPosition(last_click_);
     tc.movePosition(QTextCursor::StartOfWord, QTextCursor::MoveAnchor);
     tc.movePosition(QTextCursor::EndOfWord, QTextCursor::KeepAnchor);
     int old_length = tc.position() - tc.anchor();
@@ -409,8 +391,8 @@ void ChatEdit::applySuggestion()
  */
 void ChatEdit::addToDictionary()
 {
-    QTextCursor    tc = cursorForPosition(last_click_);
-    int current_position = textCursor().position();
+    QTextCursor tc               = cursorForPosition(last_click_);
+    int         current_position = textCursor().position();
 
     // Get the selected word
     tc.movePosition(QTextCursor::StartOfWord, QTextCursor::MoveAnchor);
@@ -426,7 +408,7 @@ void ChatEdit::addToDictionary()
 void ChatEdit::optionsChanged()
 {
     setCheckSpelling(checkSpellingGloballyEnabled());
-    capitalizer_->setAutoCapitalizeEnabled(PsiOptions::instance()->getOption("options.ui.chat.auto-capitalize").toBool());
+    capitalizer_->setEnabled(PsiOptions::instance()->getOption("options.ui.chat.auto-capitalize").toBool());
 }
 
 void ChatEdit::showHistoryMessageNext()
@@ -437,7 +419,7 @@ void ChatEdit::showHistoryMessageNext()
             ++typedMsgsIndex;
             showMessageHistory();
         } else {
-            if(typedMsgsIndex != typedMsgsHistory.size()) {
+            if (typedMsgsIndex != typedMsgsHistory.size()) {
                 typedMsgsIndex = typedMsgsHistory.size();
                 // Restore last typed text
                 setEditText(currentText);
@@ -465,9 +447,9 @@ void ChatEdit::showHistoryMessagePrev()
         // Save current typed text
         if (typedMsgsIndex == typedMsgsHistory.size()) {
             currentText = toPlainText();
-            correction = true;
+            correction  = true;
         }
-        if (typedMsgsIndex == typedMsgsHistory.size() -1 && correction) {
+        if (typedMsgsIndex == typedMsgsHistory.size() - 1 && correction) {
             correction = false;
             ++typedMsgsIndex;
         }
@@ -501,7 +483,7 @@ void ChatEdit::showHistoryMessageLast()
     }
 }
 
-void ChatEdit::setEditText(const QString& text)
+void ChatEdit::setEditText(const QString &text)
 {
     setPlainText(text);
     moveCursor(QTextCursor::End);
@@ -509,17 +491,51 @@ void ChatEdit::setEditText(const QString& text)
 
 void ChatEdit::insertFromMimeData(const QMimeData *source)
 {
-    if (source->hasImage()) {
-        auto img = qvariant_cast<QImage>(source->imageData());
-        if (!img.isNull()) {
-            emit imagePasted(img);
+    auto obtainSourceText = [source]() {
+        if (!source->text().isEmpty())
+            return source->text();
+        return QString::fromLocal8Bit(source->data("text/plain"));
+    };
+    if (source->hasImage() || source->hasUrls()) {
+        // Check that source doesn't contains a local files and paste data as a text
+        bool isLocalFile = false;
+        for (const QUrl &url : source->urls()) {
+            if (url.isLocalFile())
+                isLocalFile = true;
         }
+        if (source->hasText() && !isLocalFile) {
+            textCursor().insertText(obtainSourceText());
+            return;
+        }
+        emit fileSharingRequested(source);
+        return;
     }
+// dirty hacks to make text drag-n-drop work in OS Linux with Qt>=5.11
+#if defined(Q_OS_LINUX) && (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
+    if (source->hasText()) {
+        textCursor().insertText(obtainSourceText());
+        return;
+    }
+    if (source->hasHtml()) {
+        textCursor().insertText(TextUtil::rich2plain(source->html()));
+        return;
+    }
+#endif
     QTextEdit::insertFromMimeData(source);
 }
 
-void ChatEdit::updateBackground() {
-    setPalette(correction ? palCorrection : palOriginal);
+bool ChatEdit::canInsertFromMimeData(const QMimeData *source) const
+{
+    return (source->hasText() || source->hasHtml() || source->hasUrls() || source->hasImage()
+            || QTextEdit::canInsertFromMimeData(source));
+}
+
+void ChatEdit::updateBackground()
+{
+    setProperty("correction", correction);
+    style()->unpolish(this);
+    style()->polish(this);
+    update();
 }
 
 void ChatEdit::showMessageHistory()
@@ -528,14 +544,14 @@ void ChatEdit::showMessageHistory()
     updateBackground();
 }
 
-void ChatEdit::appendMessageHistory(const QString& text)
+void ChatEdit::appendMessageHistory(const QString &text)
 {
     if (!text.simplified().isEmpty()) {
         if (currentText == text)
             // Remove current typed text only if we want to add it to history
             currentText.clear();
-        long index = typedMsgsHistory.indexOf(text);
-        if (index >=0) {
+        int index = typedMsgsHistory.indexOf(text);
+        if (index >= 0) {
             typedMsgsHistory.removeAt(index);
         }
         if (typedMsgsHistory.size() >= MAX_MESSAGE_HISTORY) {
@@ -552,70 +568,191 @@ void ChatEdit::clearMessageHistory()
     typedMsgsIndex = 0;
 }
 
-XMPP::HTMLElement ChatEdit::toHTMLElement() {
+XMPP::HTMLElement ChatEdit::toHTMLElement()
+{
     XMPP::HTMLElement elem;
-    QString html = toHtml();
-    int index = html.indexOf("<body");
-    int lastIndex = html.lastIndexOf("</body>");
-    if(index == -1 || lastIndex == -1)
+    QString           html      = toHtml();
+    int               index     = html.indexOf("<body");
+    int               lastIndex = html.lastIndexOf("</body>");
+    if (index == -1 || lastIndex == -1)
         return elem;
     lastIndex += 7;
-    html = html.mid(index, lastIndex-index);
+    html = html.mid(index, lastIndex - index);
     QDomDocument doc;
-    if(!doc.setContent(html))
+    if (!doc.setContent(html))
         return elem;
     QDomElement htmlElem = doc.firstChildElement("body");
-    QDomElement p = htmlElem.firstChildElement("p");
-    QDomElement body = doc.createElementNS("http://www.w3.org/1999/xhtml", "body");
-    bool foundSpan = false;
-    int paraCnt = 0;
-    while(!p.isNull()) {
-        p.setAttribute("style", "margin:0;padding:0;"); //p.removeAttribute("style");
-        body.appendChild(p.cloneNode(true).toElement());
-        if(!p.firstChildElement("span").isNull())
-            foundSpan = true;
-        p = p.nextSiblingElement("p");
-        ++paraCnt;
+    QDomElement p        = htmlElem.firstChildElement("p");
+    if (p.isNull()) {
+        // try Qt 5.15 way
+        p = htmlElem.firstChildElement("table").firstChildElement("tr").firstChildElement("td").firstChildElement("p");
     }
-    if(foundSpan) {
-        if (paraCnt == 1)
-            body.firstChildElement("p").setTagName("span");
+    QDomElement body    = doc.createElementNS("http://www.w3.org/1999/xhtml", "body");
+    bool        htmlish = false;
+    while (!p.isNull()) {
+        for (auto pc = p.firstChild(); !pc.isNull(); pc = pc.nextSibling()) {
+            if (pc.isElement() && pc.toElement().tagName() != QStringLiteral("br"))
+                htmlish = true;
+            body.appendChild(pc.cloneNode(true));
+        }
+        p = p.nextSiblingElement("p");
+    }
+    if (htmlish && body.childNodes().size() > 0) {
         elem.setBody(body);
     }
     return elem;
 }
 
-void ChatEdit::doHTMLTextMenu() {
-    controller_->doMenu();
-}
+void ChatEdit::doHTMLTextMenu() { controller_->doMenu(); }
 
-void ChatEdit::setCssString(const QString &css) {
-    controller_->setCssString(css);
-}
+void ChatEdit::setCssString(const QString &css) { controller_->setCssString(css); }
 
 void ChatEdit::insertAsQuote(const QString &text)
 {
-    int pos =  textCursor().position();
+    int     pos      = textCursor().position();
     QString prevLine = toPlainText().left(pos - 1);
-    prevLine = prevLine.mid(prevLine.lastIndexOf("\n") + 1);
+    prevLine         = prevLine.mid(prevLine.lastIndexOf("\n") + 1);
 
     QString quote = QString::fromUtf8("» ") + text;
     quote.replace("\n", QString::fromUtf8("\n» "));
 
     // Check for previous quote and merge if true
-    if(!prevLine.startsWith(QString::fromUtf8("»"))) {
+    if (!prevLine.startsWith(QString::fromUtf8("»"))) {
         quote.prepend("\n");
     }
     quote.append("\n");
     insertPlainText(quote);
 }
 
+void ChatEdit::addSoundRecButton()
+{
+    if (!recButton_) {
+        layout_.reset(new QHBoxLayout(this));
+        recButton_.reset(new QToolButton(this));
+        overlay_.reset(new QLabel(this));
+
+        // Set text right margin for rec button
+        connect(document(), &QTextDocument::contentsChanged, this, &ChatEdit::setRigthMargin);
+
+        // Add text label and rec button to the right side of LineEdit
+        // Setting label color to grey with 70% opacity with red bold text
+        overlay_->setStyleSheet("background-color: rgba(169, 169, 169, 0.7); color: red; font-weight: bold;");
+        overlay_->setAlignment(Qt::AlignCenter);
+        setOverlayText(maxOverlayTime);
+        overlay_->setVisible(false);
+        layout_->addWidget(overlay_.get());
+        recButton_->setToolTip(tr("Record and share audio note while pressed"));
+        setRecButtonIcon();
+        auto iconSize = fontInfo().pixelSize() * 1.5;
+        recButton_->setMinimumSize(QSize(iconSize, iconSize));
+        layout_->addWidget(recButton_.get());
+        layout_->setAlignment(Qt::AlignRight | Qt::AlignBottom);
+
+        connect(recButton_.get(), &QToolButton::pressed, this, [this]() { // Rec button pressed
+            if (recorder_) {
+                recorder_->disconnect();
+                recorder_.reset();
+            }
+
+            recorder_.reset(new AudioRecorder);
+            recorder_->setMaxDuration(TIMEOUT);
+            connect(recorder_.get(), &AudioRecorder::recorded, this, [this]() {
+                if (recorder_->duration() < 1000)
+                    return;
+
+                QMimeData md;
+                auto      data = recorder_->data();
+                auto      mime = QMimeDatabase().mimeTypeForData(data).name();
+                md.setData(mime, data);
+                md.setData("application/x-psi-amplitudes", recorder_->amplitudes());
+                emit fileSharingRequested(&md);
+            });
+            connect(recorder_.get(), &AudioRecorder::recordingStarted, this, [this]() {
+                recButton_->setIcon(IconsetFactory::iconPixmap("psi/mic_rec", fontInfo().pixelSize() * 1.5));
+                overlay_->setVisible(true);
+                timeout_ = TIMEOUT;
+                timer_.reset(new QTimer); // countdown timer to stop recording while the button is pressed
+                connect(timer_.get(), &QTimer::timeout, this, [this]() {
+                    if (timeout_ > 0) {
+                        timeout_ -= SECOND;
+                        setOverlayText(timeout_ / SECOND);
+                    } else {
+                        timer_->stop();
+                        recorder_->stop();
+                    }
+                });
+                timer_->start(SECOND);
+            });
+            recorder_->record();
+        });
+        connect(recButton_.get(), &QToolButton::released, this, [this]() { // Rec button relesed
+            setRecButtonIcon();
+            if (timer_) {
+                timer_->stop();
+                timer_.reset();
+            }
+            setOverlayText(maxOverlayTime);
+            overlay_->setVisible(false);
+            if (recorder_) {
+                recorder_->stop();
+            }
+        });
+    }
+}
+
+void ChatEdit::removeSoundRecButton()
+{
+    disconnect(recButton_.get());
+    layout_.reset();
+    recButton_.reset();
+    overlay_.reset();
+    disconnect(recorder_.get());
+    recorder_.reset();
+}
+
+void ChatEdit::setOverlayText(int value) { overlay_->setText(tr("Recording (%1 sec left)").arg(value)); }
+
+void ChatEdit::setRecButtonIcon()
+{
+    auto isColorDark = [](int r, int g, int b) { return (r * 0.299 + g * 0.578 + b * 0.144) <= 186; };
+    if (recButton_) {
+        const QColor bcgColor(palette().color(backgroundRole()));
+        int          red, green, blue = 0;
+        bcgColor.getRgb(&red, &green, &blue);
+        auto mis = fontInfo().pixelSize() * 1.5;
+        if (isColorDark(red, green, blue)) {
+            // Invert icon pixmap if background color is dark
+            QImage recImage = IconsetFactory::icon("psi/mic").image(QSize(mis, mis));
+            recImage.invertPixels();
+            recButton_->setIcon(QPixmap::fromImage(recImage));
+        } else {
+            recButton_->setIcon(IconsetFactory::iconPixmap("psi/mic", mis));
+        }
+        const QColor toolTipBgColor(recButton_->palette().color(recButton_->backgroundRole()));
+        toolTipBgColor.getRgb(&red, &green, &blue);
+        const QString btnStyle
+            = QString("border: 0; color: %1;").arg(isColorDark(red, green, blue) ? "white" : "black");
+        recButton_->setStyleSheet(btnStyle);
+    }
+}
+
+int ChatEdit::recButtonHeigth() const { return recButton_ ? recButton_->minimumHeight() : 0; }
+
+void ChatEdit::setRigthMargin()
+{
+    // Set margin for text to avoid text placing under record button
+    const float      margin = recButtonHeigth() * 1.5;
+    QTextFrameFormat frmt   = document()->rootFrame()->frameFormat();
+    if (frmt.rightMargin() < margin) {
+        frmt.setRightMargin(margin);
+        document()->rootFrame()->setFrameFormat(frmt);
+    }
+}
 
 //----------------------------------------------------------------------------
 // LineEdit
 //----------------------------------------------------------------------------
-LineEdit::LineEdit( QWidget *parent)
-    : ChatEdit(parent)
+LineEdit::LineEdit(QWidget *parent) : ChatEdit(parent)
 {
     setWordWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere); // no need for horizontal scrollbar with this
     setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
@@ -623,31 +760,33 @@ LineEdit::LineEdit( QWidget *parent)
 
     setMinimumHeight(0);
 
-    connect(this, SIGNAL(textChanged()), SLOT(recalculateSize()));
+    connect(this, &QTextEdit::textChanged, this, &LineEdit::recalculateSize);
 }
 
-LineEdit::~LineEdit()
-{
-}
+LineEdit::~LineEdit() { }
 
 QSize LineEdit::minimumSizeHint() const
 {
-    QSize sh = QTextEdit::minimumSizeHint();
-    sh.setHeight(fontMetrics().height() + 1);
+    const int spacing = fontMetrics().lineSpacing() + 1;
+    const int sz      = hasSoundRecButton() ? qMax(recButtonHeigth() * 2 - 1, spacing) : spacing;
+    QSize     sh      = QTextEdit::minimumSizeHint();
+    sh.setHeight(sz);
     sh += QSize(0, QFrame::lineWidth() * 2);
     return sh;
 }
 
 QSize LineEdit::sizeHint() const
 {
-    QSize sh = QTextEdit::sizeHint();
-    sh.setHeight(int(document()->documentLayout()->documentSize().height()));
+    QSize     sh      = QTextEdit::sizeHint();
+    const int dHeight = int(document()->documentLayout()->documentSize().height());
+    const int sz      = hasSoundRecButton() ? qMax(recButtonHeigth() * 2 - 1, dHeight) : dHeight;
+    sh.setHeight(sz);
     sh += QSize(0, QFrame::lineWidth() * 2);
-    ((QTextEdit*)this)->setMaximumHeight(sh.height());
+    static_cast<QTextEdit *>(const_cast<LineEdit *>(this))->setMaximumHeight(sh.height());
     return sh;
 }
 
-void LineEdit::resizeEvent(QResizeEvent* e)
+void LineEdit::resizeEvent(QResizeEvent *e)
 {
     ChatEdit::resizeEvent(e);
     QTimer::singleShot(0, this, SLOT(updateScrollBar()));
