@@ -1,13 +1,12 @@
 #include "mucaffiliationsproxymodel.h"
 
-MUCAffiliationsProxyModel::MUCAffiliationsProxyModel(QObject* parent)
-    : QSortFilterProxyModel(parent)
+MUCAffiliationsProxyModel::MUCAffiliationsProxyModel(QObject *parent) : QSortFilterProxyModel(parent)
 {
     sort(0, Qt::AscendingOrder);
     setDynamicSortFilter(true);
 }
 
-bool MUCAffiliationsProxyModel::filterAcceptsRow(int sourceRow, const QModelIndex& sourceParent) const
+bool MUCAffiliationsProxyModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
 {
     QModelIndex idx = sourceModel()->index(sourceRow, 0, sourceParent);
     if (!idx.isValid())
@@ -16,8 +15,5 @@ bool MUCAffiliationsProxyModel::filterAcceptsRow(int sourceRow, const QModelInde
     if (!idx.parent().isValid())
         return true;
 
-    if (filterRegExp().indexIn(idx.data().toString()) >= 0)
-        return true;
-
-    return false;
+    return filterRegExp().indexIn(idx.data().toString()) >= 0;
 }
