@@ -13,37 +13,35 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef MUCCONFIG_H
 #define MUCCONFIG_H
 
-#include <QDialog>
-
 #include "ui_mucconfig.h"
 #include "xmpp_muc.h"
 
-class QScrollArea;
-class XDataWidget;
-class MUCManager;
+#include <QDialog>
+
+class InfoWidget;
 class MUCAffiliationsModel;
 class MUCAffiliationsProxyModel;
-class InfoWidget;
-namespace XMPP {
-    class XData;
-}
+class MUCManager;
+class QScrollArea;
+class XDataWidget;
 
+namespace XMPP {
+class XData;
+}
 using namespace XMPP;
 
-class MUCConfigDlg : public QDialog
-{
+class MUCConfigDlg : public QDialog {
     Q_OBJECT
 
 public:
-    MUCConfigDlg(MUCManager*, QWidget*);
+    MUCConfigDlg(MUCManager *, QWidget *);
     ~MUCConfigDlg();
 
     void setRoleAffiliation(MUCItem::Role, MUCItem::Affiliation);
@@ -61,30 +59,30 @@ protected slots:
     void apply();
     void destroy();
     void currentTabChanged(int);
-    void applyFilter(const QString&);
+    void applyFilter(const QString &);
 
-    void getConfiguration_success( const XData&);
-    void getConfiguration_error(int, const QString&);
+    void getConfiguration_success(const XData &);
+    void getConfiguration_error(int, const QString &);
     void setConfiguration_success();
-    void setConfiguration_error(int, const QString&);
+    void setConfiguration_error(int, const QString &);
     void setItems_success();
-    void setItems_error(int, const QString&);
-    void getItemsByAffiliation_success(MUCItem::Affiliation, const QList<MUCItem>&);
-    void getItemsByAffiliation_error(MUCItem::Affiliation, int, const QString&);
+    void setItems_error(int, const QString &);
+    void getItemsByAffiliation_success(MUCItem::Affiliation, const QList<MUCItem> &);
+    void getItemsByAffiliation_error(MUCItem::Affiliation, int, const QString &);
     void destroy_success();
-    void destroy_error(int, const QString&);
+    void destroy_error(int, const QString &);
 
 private:
-    Ui::MUCConfig ui_;
-    MUCItem::Role role_;
-    MUCItem::Affiliation affiliation_;
-    MUCManager* manager_;
-    QScrollArea* data_container_;
-    XDataWidget* data_;
-    InfoWidget* vcard_;
-    MUCAffiliationsModel* affiliations_model_;
-    MUCAffiliationsProxyModel* affiliations_proxy_model_;
+    Ui::MUCConfig               ui_;
+    MUCItem::Role               role_;
+    MUCItem::Affiliation        affiliation_;
+    MUCManager *                manager_;
+    QScrollArea *               data_container_;
+    XDataWidget *               data_;
+    InfoWidget *                vcard_;
+    MUCAffiliationsModel *      affiliations_model_;
+    MUCAffiliationsProxyModel * affiliations_proxy_model_;
     QList<MUCItem::Affiliation> pending_requests_;
 };
 
-#endif
+#endif // MUCCONFIG_H
