@@ -13,49 +13,48 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef MUCJOINDLG_H
 #define MUCJOINDLG_H
 
-#include <QDialog>
-
 #include "ui_mucjoin.h"
+#include "xmpp_jid.h"
+
+#include <QDialog>
+#include <QTimer>
 
 class PsiCon;
+class PsiAccount;
 class QString;
 
-#include "xmpp_jid.h"
-#include "psiaccount.h"
-
-class MUCJoinDlg : public QDialog
-{
+class MUCJoinDlg : public QDialog {
     Q_OBJECT
 
 public:
+    enum MucJoinReason { MucAutoJoin, MucCustomJoin };
 
     MUCJoinDlg(PsiCon *, PsiAccount *);
     ~MUCJoinDlg();
 
-    void setJid(const XMPP::Jid& jid);
-    void setNick(const QString& nick);
-    void setPassword(const QString& password);
+    void setJid(const XMPP::Jid &jid);
+    void setNick(const QString &nick);
+    void setPassword(const QString &password);
 
     void joined();
     void error(int, const QString &);
 
 public slots:
     void done(int);
-    void doJoin(PsiAccount::MucJoinReason reason = PsiAccount::MucCustomJoin);
+    void doJoin(MucJoinReason reason = MucCustomJoin);
 
     // reimplemented
     void accept();
 
 public:
-    PsiAccount::MucJoinReason getReason() const { return reason_; }
+    MucJoinReason getReason() const { return reason_; }
 
 private slots:
     void updateIdentity(PsiAccount *);
@@ -63,15 +62,17 @@ private slots:
     void pa_disconnected();
     void favoritesCurrentRowChanged(int);
     void favoritesItemDoubleClicked(QListWidgetItem *lwi);
+    void lwFavorites_customContextMenuRequested(const QPoint &pos);
 
 private:
-    Ui::MUCJoin ui_;
-    PsiCon* controller_;
-    PsiAccount* account_;
-    QPushButton* joinButton_;
-    XMPP::Jid jid_;
-    PsiAccount::MucJoinReason reason_;
-    bool nickAlreadyCompleted_;
+    Ui::MUCJoin   ui_;
+    PsiCon *      controller_;
+    PsiAccount *  account_;
+    QPushButton * joinButton_;
+    XMPP::Jid     jid_;
+    MucJoinReason reason_;
+    QTimer *      timer_;
+    bool          nickAlreadyCompleted_;
 
     void disableWidgets();
     void enableWidgets();
@@ -79,4 +80,4 @@ private:
     void updateFavorites();
 };
 
-#endif
+#endif // MUCJOINDLG_H
