@@ -1,7 +1,6 @@
 /*
  * mucreasonseditor.cpp
- * Copyright (C)
- * 2011 Evgeny Khryukin
+ * Copyright (C) 2011  Evgeny Khryukin
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -14,20 +13,17 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "mucreasonseditor.h"
+
 #include "common.h"
 #include "psioptions.h"
 #include "ui_mucreasonseditor.h"
 
-
-MUCReasonsEditor::MUCReasonsEditor(QWidget* parent)
-    : QDialog(parent)
-    , ui_(new Ui::MUCReasonsEditor)
+MUCReasonsEditor::MUCReasonsEditor(QWidget *parent) : QDialog(parent), ui_(new Ui::MUCReasonsEditor)
 {
     ui_->setupUi(this);
     ui_->lstReasons->addItems(PsiOptions::instance()->getOption("options.muc.reasons").toStringList());
@@ -37,10 +33,7 @@ MUCReasonsEditor::MUCReasonsEditor(QWidget* parent)
     connect(ui_->lstReasons, SIGNAL(currentTextChanged(QString)), SLOT(currentChanged(QString)));
 }
 
-MUCReasonsEditor::~MUCReasonsEditor()
-{
-    delete ui_;
-}
+MUCReasonsEditor::~MUCReasonsEditor() { delete ui_; }
 
 void MUCReasonsEditor::accept()
 {
@@ -49,10 +42,7 @@ void MUCReasonsEditor::accept()
     QDialog::accept();
 }
 
-void MUCReasonsEditor::currentChanged(const QString &r)
-{
-    ui_->txtReason->setText(r);
-}
+void MUCReasonsEditor::currentChanged(const QString &r) { ui_->txtReason->setText(r); }
 
 void MUCReasonsEditor::addButtonClicked()
 {
@@ -66,7 +56,7 @@ void MUCReasonsEditor::removeButtonClicked()
 {
     int idx = ui_->lstReasons->currentRow();
     if (idx >= 0) {
-        QListWidgetItem *item =ui_->lstReasons->takeItem(idx);
+        QListWidgetItem *item = ui_->lstReasons->takeItem(idx);
         if (item)
             delete item;
     }
@@ -75,7 +65,7 @@ void MUCReasonsEditor::removeButtonClicked()
 void MUCReasonsEditor::save()
 {
     QStringList reasons;
-    int cnt = ui_->lstReasons->count();
+    int         cnt = ui_->lstReasons->count();
     for (int i = 0; i < cnt; ++i)
         reasons.append(ui_->lstReasons->item(i)->text());
     PsiOptions::instance()->setOption("options.muc.reasons", reasons);
