@@ -3,11 +3,10 @@
 
 #include "optionstab.h"
 
-class QWidget;
 class QButtonGroup;
+class QWidget;
 
-class OptionsTabApplication : public OptionsTab
-{
+class OptionsTabApplication : public OptionsTab {
     Q_OBJECT
 public:
     OptionsTabApplication(QObject *parent);
@@ -16,19 +15,17 @@ public:
     void setHaveAutoUpdater(bool);
 
     QWidget *widget();
-    void applyOptions();
-    void restoreOptions();
-
-private slots:
-    void updatePortLabel();
+    void     applyOptions();
+    void     restoreOptions();
 
 private:
-    QWidget *w = nullptr;
-    bool haveAutoUpdater_ = false;
-    QString configPath_;
+    QWidget *w                = nullptr;
+    bool     haveAutoUpdater_ = false;
+    QString  configPath_;
+    bool     autostartOptChanged_ = false;
 
 private slots:
     void doEnableQuitOnClose(int);
 };
 
-#endif
+#endif // OPT_APPLICATION_H
