@@ -3,23 +3,22 @@
 
 #include "optionstab.h"
 
-class QWidget;
 class QButtonGroup;
+class QWidget;
 
-class OptionsTabChat : public OptionsTab
-{
+class OptionsTabChat : public OptionsTab {
     Q_OBJECT
 public:
     OptionsTabChat(QObject *parent);
     ~OptionsTabChat();
 
     QWidget *widget();
-    void applyOptions();
-    void restoreOptions();
+    void     applyOptions();
+    void     restoreOptions();
 
 private:
-    QWidget *w;
-    QButtonGroup *bg_defAct, *bg_delChats;
+    QWidget *     w;
+    QButtonGroup *bg_defAct;
 };
 
-#endif
+#endif // OPT_CHAT_H
