@@ -2,24 +2,24 @@
 #define OPT_ICONSET_H
 
 #include "optionstab.h"
+
 #include <QEvent>
 
-class QWidget;
-class QListWidgetItem;
 class IconsetLoadThread;
+class QListWidgetItem;
 class QTreeWidgetItem;
+class QWidget;
 
-class OptionsTabIconsetSystem : public OptionsTab
-{
+class OptionsTabIconsetSystem : public OptionsTab {
     Q_OBJECT
 public:
     OptionsTabIconsetSystem(QObject *parent);
     ~OptionsTabIconsetSystem();
 
     QWidget *widget();
-    void applyOptions();
-    void restoreOptions();
-    bool stretchable() const { return true; }
+    void     applyOptions();
+    void     restoreOptions();
+    bool     stretchable() const { return true; }
 
 private slots:
     void setData(PsiCon *, QWidget *);
@@ -31,23 +31,22 @@ protected:
 
 private:
     QWidget *w, *parentWidget;
-    PsiCon *psi;
+    PsiCon * psi;
 
-    int numIconsets, iconsetsLoaded;
+    int                numIconsets, iconsetsLoaded;
     IconsetLoadThread *thread;
 };
 
-class OptionsTabIconsetEmoticons : public OptionsTab
-{
+class OptionsTabIconsetEmoticons : public OptionsTab {
     Q_OBJECT
 public:
     OptionsTabIconsetEmoticons(QObject *parent);
     ~OptionsTabIconsetEmoticons();
 
     QWidget *widget();
-    void applyOptions();
-    void restoreOptions();
-    bool stretchable() const { return true; }
+    void     applyOptions();
+    void     restoreOptions();
+    bool     stretchable() const { return true; }
 
 private slots:
     void setData(PsiCon *, QWidget *);
@@ -59,23 +58,22 @@ protected:
 
 private:
     QWidget *w, *parentWidget;
-    PsiCon *psi;
+    PsiCon * psi;
 
-    int numIconsets, iconsetsLoaded;
+    int                numIconsets, iconsetsLoaded;
     IconsetLoadThread *thread;
 };
 
-class OptionsTabIconsetMoods : public OptionsTab
-{
+class OptionsTabIconsetMoods : public OptionsTab {
     Q_OBJECT
 public:
     OptionsTabIconsetMoods(QObject *parent);
     ~OptionsTabIconsetMoods();
 
     QWidget *widget();
-    void applyOptions();
-    void restoreOptions();
-    bool stretchable() const { return true; }
+    void     applyOptions();
+    void     restoreOptions();
+    bool     stretchable() const { return true; }
 
 private slots:
     void setData(PsiCon *, QWidget *);
@@ -87,23 +85,22 @@ protected:
 
 private:
     QWidget *w, *parentWidget;
-    PsiCon *psi;
+    PsiCon * psi;
 
-    int numIconsets, iconsetsLoaded;
+    int                numIconsets, iconsetsLoaded;
     IconsetLoadThread *thread;
 };
 
-class OptionsTabIconsetActivity : public OptionsTab
-{
+class OptionsTabIconsetActivity : public OptionsTab {
     Q_OBJECT
 public:
     OptionsTabIconsetActivity(QObject *parent);
     ~OptionsTabIconsetActivity();
 
     QWidget *widget();
-    void applyOptions();
-    void restoreOptions();
-    bool stretchable() const { return true; }
+    void     applyOptions();
+    void     restoreOptions();
+    bool     stretchable() const { return true; }
 
 private slots:
     void setData(PsiCon *, QWidget *);
@@ -115,23 +112,22 @@ protected:
 
 private:
     QWidget *w, *parentWidget;
-    PsiCon *psi;
+    PsiCon * psi;
 
-    int numIconsets, iconsetsLoaded;
+    int                numIconsets, iconsetsLoaded;
     IconsetLoadThread *thread;
 };
 
-class OptionsTabIconsetClients : public OptionsTab
-{
+class OptionsTabIconsetClients : public OptionsTab {
     Q_OBJECT
 public:
     OptionsTabIconsetClients(QObject *parent);
     ~OptionsTabIconsetClients();
 
     QWidget *widget();
-    void applyOptions();
-    void restoreOptions();
-    bool stretchable() const { return true; }
+    void     applyOptions();
+    void     restoreOptions();
+    bool     stretchable() const { return true; }
 
 private slots:
     void setData(PsiCon *, QWidget *);
@@ -143,23 +139,22 @@ protected:
 
 private:
     QWidget *w, *parentWidget;
-    PsiCon *psi;
+    PsiCon * psi;
 
-    int numIconsets, iconsetsLoaded;
+    int                numIconsets, iconsetsLoaded;
     IconsetLoadThread *thread;
 };
 
-class OptionsTabIconsetAffiliations : public OptionsTab
-{
+class OptionsTabIconsetAffiliations : public OptionsTab {
     Q_OBJECT
 public:
     OptionsTabIconsetAffiliations(QObject *parent);
     ~OptionsTabIconsetAffiliations();
 
     QWidget *widget();
-    void applyOptions();
-    void restoreOptions();
-    bool stretchable() const { return true; }
+    void     applyOptions();
+    void     restoreOptions();
+    bool     stretchable() const { return true; }
 
 private slots:
     void setData(PsiCon *, QWidget *);
@@ -171,23 +166,22 @@ protected:
 
 private:
     QWidget *w, *parentWidget;
-    PsiCon *psi;
+    PsiCon * psi;
 
-    int numIconsets, iconsetsLoaded;
+    int                numIconsets, iconsetsLoaded;
     IconsetLoadThread *thread;
 };
 
-class OptionsTabIconsetRoster : public OptionsTab
-{
+class OptionsTabIconsetRoster : public OptionsTab {
     Q_OBJECT
 public:
     OptionsTabIconsetRoster(QObject *parent);
     ~OptionsTabIconsetRoster();
 
     QWidget *widget();
-    void applyOptions();
-    void restoreOptions();
-    bool stretchable() const { return true; }
+    void     applyOptions();
+    void     restoreOptions();
+    bool     stretchable() const { return true; }
 
 private slots:
     void setData(PsiCon *, QWidget *);
@@ -199,11 +193,11 @@ private slots:
     void isServices_iconsetSelected(QListWidgetItem *current, QListWidgetItem *previous);
     void isServices_selectionChanged(QTreeWidgetItem *);
 
-    void isCustom_iconsetSelected(QListWidgetItem *current, QListWidgetItem *previous);
-    void isCustom_selectionChanged(QTreeWidgetItem *);
-    void isCustom_textChanged();
-    void isCustom_add();
-    void isCustom_delete();
+    void    isCustom_iconsetSelected(QListWidgetItem *current, QListWidgetItem *previous);
+    void    isCustom_selectionChanged(QTreeWidgetItem *);
+    void    isCustom_textChanged();
+    void    isCustom_add();
+    void    isCustom_delete();
     QString clipCustomText(QString);
 
 protected:
@@ -211,19 +205,15 @@ protected:
     void cancelThread();
 
 private:
-    QWidget* w;
-    QWidget* parentWidget;
-    PsiCon *psi;
-    int numIconsets, iconsetsLoaded;
+    QWidget *          w;
+    QWidget *          parentWidget;
+    PsiCon *           psi;
+    int                numIconsets, iconsetsLoaded;
     IconsetLoadThread *thread;
 
-    enum {
-        IconsetRole = Qt::UserRole + 0,
-        ServiceRole = Qt::UserRole + 1,
-        RegexpRole  = Qt::UserRole + 2
-    };
+    enum { IconsetRole = Qt::UserRole + 0, ServiceRole = Qt::UserRole + 1, RegexpRole = Qt::UserRole + 2 };
 
-    void addService(const QString& id, const QString& name);
+    void addService(const QString &id, const QString &name);
 };
 
-#endif
+#endif // OPT_ICONSET_H
