@@ -1,56 +1,55 @@
 #include "opt_input.h"
 
-#include <QWidget>
-#include <QTreeWidget>
-#include <QTreeWidgetItem>
-#include <QCheckBox>
-#include <QLocale>
-
 #include "psioptions.h"
 #include "spellchecker/spellchecker.h"
-
-
 #include "ui_opt_input.h"
 
-static const QString ENABLED_OPTION = QStringLiteral("options.ui.spell-check.enabled");
-static const QString DICTS_OPTION = QStringLiteral("options.ui.spell-check.langs");
+#include <QCheckBox>
+#include <QLocale>
+#include <QTreeWidget>
+#include <QWidget>
+
+static const QString ENABLED_OPTION    = QStringLiteral("options.ui.spell-check.enabled");
+static const QString DICTS_OPTION      = QStringLiteral("options.ui.spell-check.langs");
 static const QString AUTORESIZE_OPTION = QStringLiteral("options.ui.chat.use-expanding-line-edit");
-static const uint FullName = 0;
+static const uint    FullName          = 0;
 
-
-class OptInputUI : public QWidget, public Ui::OptInput
-{
+class OptInputUI : public QWidget, public Ui::OptInput {
 public:
     OptInputUI() : QWidget() { setupUi(this); }
 };
 
-OptionsTabInput::OptionsTabInput(QObject *parent)
-: OptionsTab(parent, "input", "", tr("Input"), tr("Input options"), "psi/action_templates_edit"),
-  w_(0),
-  psi_(0)
+OptionsTabInput::OptionsTabInput(QObject *parent) :
+    OptionsTab(parent, "input", "", tr("Input"), tr("Input options"), "psi/action_templates_edit"), w_(nullptr),
+    psi_(nullptr)
 {
 }
 
-OptionsTabInput::~OptionsTabInput()
-{}
+OptionsTabInput::~OptionsTabInput() { }
 
 QWidget *OptionsTabInput::widget()
 {
     if (w_) {
-        return 0;
+        return nullptr;
     }
 
-    w_ = new OptInputUI();
+    w_            = new OptInputUI();
     OptInputUI *d = static_cast<OptInputUI *>(w_);
 
-    availableDicts_ = SpellChecker::instance()->getAllLanguages();
-    defaultLangs_ = LanguageManager::bestUiMatch(availableDicts_).toSet();
+    w_->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 
-    d->isSpellCheck->setWhatsThis(tr("Check this option if you want your spelling to be checked"));
+    availableDicts_ = SpellChecker::instance()->getAllLanguages();
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+    auto list     = LanguageManager::bestUiMatch(availableDicts_);
+    defaultLangs_ = QSet<LanguageManager::LangId>(list.begin(), list.end());
+#else
+    defaultLangs_ = LanguageManager::bestUiMatch(availableDicts_).toSet();
+#endif
+    d->isSpellCheck->setToolTip(tr("Check this option if you want your spelling to be checked"));
 
     connect(d->isSpellCheck, &QCheckBox::toggled, this, &OptionsTabInput::itemToggled);
 
-    d->ck_autoCapitalize->setWhatsThis(
+    d->ck_autoCapitalize->setToolTip(
         tr("Enables automatic substitution of the first letter in a sentence to the same capital letter"));
 
     return w_;
@@ -62,22 +61,21 @@ void OptionsTabInput::applyOptions()
         return;
     }
 
-    OptInputUI *d = static_cast<OptInputUI *>(w_);
-    PsiOptions* o = PsiOptions::instance();
+    OptInputUI *  d = static_cast<OptInputUI *>(w_);
+    PsiOptions *  o = PsiOptions::instance();
     SpellChecker *s = SpellChecker::instance();
 
     bool isEnabled = d->isSpellCheck->isChecked();
     o->setOption(ENABLED_OPTION, isEnabled);
     o->setOption(AUTORESIZE_OPTION, d->isAutoResize->isChecked());
-    if(!isEnabled) {
+    if (!isEnabled) {
         loadedDicts_.clear();
         s->setActiveLanguages(loadedDicts_);
-    }
-    else {
+    } else {
         d->groupBoxDicts->setEnabled(isEnabled);
         s->setActiveLanguages(loadedDicts_);
         QStringList loaded;
-        for (auto const &id: loadedDicts_) {
+        for (auto const &id : loadedDicts_) {
             loaded.append(LanguageManager::toString(id));
         }
         o->setOption(DICTS_OPTION, QVariant(loaded.join(" ")));
@@ -92,41 +90,47 @@ void OptionsTabInput::restoreOptions()
     }
 
     OptInputUI *d = static_cast<OptInputUI *>(w_);
-    PsiOptions* o = PsiOptions::instance();
+    PsiOptions *o = PsiOptions::instance();
 
     updateDictLists();
 
-    d->isAutoResize->setChecked( o->getOption(AUTORESIZE_OPTION).toBool() );
+    d->isAutoResize->setChecked(o->getOption(AUTORESIZE_OPTION).toBool());
     bool isEnabled = o->getOption(ENABLED_OPTION).toBool();
-    isEnabled = (!SpellChecker::instance()->available()) ? false : isEnabled;
+    isEnabled      = (!SpellChecker::instance()->available()) ? false : isEnabled;
     d->groupBoxDicts->setEnabled(isEnabled);
     d->isSpellCheck->setChecked(isEnabled);
     if (!availableDicts_.isEmpty()) {
         d->dictsWarnLabel->setVisible(false);
-        if(isEnabled && isTreeViewEmpty()) {
+        if (isEnabled && isTreeViewEmpty()) {
             fillList();
         }
         if (isEnabled) {
             setChecked();
         }
-    }
-    else {
+    } else {
         d->dictsWarnLabel->setVisible(true);
     }
     d->ck_autoCapitalize->setChecked(o->getOption("options.ui.chat.auto-capitalize").toBool());
 }
 
-void OptionsTabInput::setData(PsiCon *psi, QWidget *)
-{
-    psi_ = psi;
-}
+void OptionsTabInput::setData(PsiCon *psi, QWidget *) { psi_ = psi; }
+
+bool OptionsTabInput::stretchable() const { return true; }
 
 void OptionsTabInput::updateDictLists()
 {
-    PsiOptions* o = PsiOptions::instance();
-    QStringList newLoadedList = o->getOption(DICTS_OPTION).toString().split(QRegExp("\\s+"), QString::SkipEmptyParts);
+    PsiOptions *o             = PsiOptions::instance();
+    QStringList newLoadedList = o->getOption(DICTS_OPTION)
+                                    .toString()
+                                    .split(QRegExp("\\s+"),
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+                                           Qt::SkipEmptyParts
+#else
+                                           QString::SkipEmptyParts
+#endif
+                                    );
     QSet<LanguageManager::LangId> newLoadedSet;
-    for (auto &l: newLoadedList) {
+    for (auto &l : newLoadedList) {
         auto id = LanguageManager::fromString(l);
         if (id.language) {
             newLoadedSet.insert(id);
@@ -134,33 +138,32 @@ void OptionsTabInput::updateDictLists()
     }
 
     newLoadedSet = (newLoadedSet.isEmpty()) ? defaultLangs_ : newLoadedSet;
-    if(newLoadedSet != loadedDicts_ || loadedDicts_.isEmpty()) {
+    if (newLoadedSet != loadedDicts_ || loadedDicts_.isEmpty()) {
         loadedDicts_ = newLoadedSet;
     }
 }
 
 void OptionsTabInput::fillList()
 {
-    if(!w_) {
+    if (!w_) {
         return;
     }
 
     OptInputUI *d = static_cast<OptInputUI *>(w_);
 
-    if(!availableDicts_.isEmpty()) {
+    if (!availableDicts_.isEmpty()) {
         d->availDicts->disconnect();
         d->availDicts->clear();
-        for (auto const &id: availableDicts_) {
+        for (auto const &id : availableDicts_) {
             QTreeWidgetItem *dic = new QTreeWidgetItem(d->availDicts, QTreeWidgetItem::Type);
             dic->setText(FullName, LanguageManager::languageName(id));
             dic->setData(FullName, Qt::UserRole, QVariant::fromValue<LanguageManager::LangId>(id));
-            if(!loadedDicts_.contains(id)) {
+            if (!loadedDicts_.contains(id)) {
                 dic->setCheckState(FullName, Qt::Unchecked);
-                //qDebug() << "item" << item << "unchecked";
-            }
-            else {
+                // qDebug() << "item" << item << "unchecked";
+            } else {
                 dic->setCheckState(FullName, Qt::Checked);
-                //qDebug() << "item" << item << "checked";
+                // qDebug() << "item" << item << "checked";
             }
         }
         connect(d->availDicts, &QTreeWidget::itemChanged, this, &OptionsTabInput::itemChanged);
@@ -169,17 +172,17 @@ void OptionsTabInput::fillList()
 
 void OptionsTabInput::setChecked()
 {
-    if(!w_) {
+    if (!w_) {
         return;
     }
 
-    OptInputUI *d = static_cast<OptInputUI *>(w_);
+    OptInputUI *            d = static_cast<OptInputUI *>(w_);
     QTreeWidgetItemIterator it(d->availDicts);
-    while(*it) {
-        QTreeWidgetItem *item = *it;
+    while (*it) {
+        QTreeWidgetItem *       item   = *it;
         LanguageManager::LangId langId = item->data(FullName, Qt::UserRole).value<LanguageManager::LangId>();
-        Qt::CheckState state = loadedDicts_.contains(langId) ? Qt::Checked : Qt::Unchecked;
-        if(state != item->checkState(FullName)) {
+        Qt::CheckState          state  = loadedDicts_.contains(langId) ? Qt::Checked : Qt::Unchecked;
+        if (state != item->checkState(FullName)) {
             item->setCheckState(FullName, state);
         }
         ++it;
@@ -188,13 +191,13 @@ void OptionsTabInput::setChecked()
 
 void OptionsTabInput::itemToggled(bool toggled)
 {
-    if(!w_) {
+    if (!w_) {
         return;
     }
 
     OptInputUI *d = static_cast<OptInputUI *>(w_);
 
-    if(toggled) {
+    if (toggled) {
         updateDictLists();
         fillList();
         setChecked();
@@ -204,15 +207,14 @@ void OptionsTabInput::itemToggled(bool toggled)
 
 void OptionsTabInput::itemChanged(QTreeWidgetItem *item, int column)
 {
-    if ( !w_ )
+    if (!w_)
         return;
 
-    bool enabled = bool(item->checkState(column) == Qt::Checked);
-    LanguageManager::LangId id = item->data(column, Qt::UserRole).value<LanguageManager::LangId>();
-    if(loadedDicts_.contains(id) && !enabled) {
+    bool                    enabled = bool(item->checkState(column) == Qt::Checked);
+    LanguageManager::LangId id      = item->data(column, Qt::UserRole).value<LanguageManager::LangId>();
+    if (loadedDicts_.contains(id) && !enabled) {
         loadedDicts_.remove(id);
-    }
-    else if (enabled){
+    } else if (enabled) {
         loadedDicts_ << id;
     }
     dataChanged();
@@ -220,9 +222,9 @@ void OptionsTabInput::itemChanged(QTreeWidgetItem *item, int column)
 
 bool OptionsTabInput::isTreeViewEmpty()
 {
-    if ( !w_ )
+    if (!w_)
         return true;
-    OptInputUI *d = static_cast<OptInputUI *>(w_);
+    OptInputUI *            d = static_cast<OptInputUI *>(w_);
     QTreeWidgetItemIterator it(d->availDicts);
     return !bool(*it);
 }
