@@ -3,22 +3,21 @@
 
 #include "optionstab.h"
 
-class QWidget;
 class QButtonGroup;
+class QWidget;
 
-class OptionsTabRosterMain : public OptionsTab
-{
+class OptionsTabRosterMain : public OptionsTab {
     Q_OBJECT
 public:
     OptionsTabRosterMain(QObject *parent);
     ~OptionsTabRosterMain();
 
     QWidget *widget();
-    void applyOptions();
-    void restoreOptions();
+    void     applyOptions();
+    void     restoreOptions();
 
 private:
     QWidget *w;
 };
 
-#endif
+#endif // OPT_ROSTER_MAIN_H
