@@ -3,19 +3,18 @@
 
 #include "optionstab.h"
 
-class QWidget;
 class QButtonGroup;
+class QWidget;
 
-class OptionsTabRosterMuc : public OptionsTab
-{
+class OptionsTabRosterMuc : public OptionsTab {
     Q_OBJECT
 public:
     OptionsTabRosterMuc(QObject *parent);
     ~OptionsTabRosterMuc();
 
     QWidget *widget();
-    void applyOptions();
-    void restoreOptions();
+    void     applyOptions();
+    void     restoreOptions();
 
 protected:
     virtual void changeEvent(QEvent *e);
@@ -24,4 +23,4 @@ private:
     QWidget *w;
 };
 
-#endif
+#endif // OPT_ROSTER_MUC_H
