@@ -1,6 +1,6 @@
 /*
  * opt_shortcuts.cpp - an OptionsTab for setting the Keyboard Shortcuts of Psi
- * Copyright (C) 2006 Cestonaro Thilo
+ * Copyright (C) 2006  Cestonaro Thilo
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -13,30 +13,27 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "opt_shortcuts.h"
 
-#include <QMessageBox>
-
 #include "common.h"
+#include "grepshortcutkeydialog.h"
 #include "psioptions.h"
 #include "shortcutmanager.h"
-#include "grepshortcutkeydialog.h"
-
 #include "ui_opt_shortcuts.h"
 
+#include <QMessageBox>
+
 #define ITEMKIND Qt::UserRole
 #define OPTIONSTREEPATH Qt::UserRole + 1
 
 /**
  * \class the Ui for the Options Tab Shortcuts
  */
-class OptShortcutsUI : public QWidget, public Ui::OptShortcuts
-{
+class OptShortcutsUI : public QWidget, public Ui::OptShortcuts {
 public:
     OptShortcutsUI() : QWidget() { setupUi(this); }
 };
@@ -48,18 +45,16 @@ public:
 /**
  * \brief Constructor of the Options Tab Shortcuts Class
  */
-OptionsTabShortcuts::OptionsTabShortcuts(QObject *parent)
-: OptionsTab(parent, "shortcuts", "", tr("Shortcuts"), tr("Options for Psi Shortcuts"), "psi/shortcuts")
+OptionsTabShortcuts::OptionsTabShortcuts(QObject *parent) :
+    OptionsTab(parent, "shortcuts", "", tr("Shortcuts"), tr("Options for Psi Shortcuts"), "psi/shortcuts")
 {
-    w = 0;
+    w = nullptr;
 }
 
 /**
  * \brief Destructor of the Options Tab Shortcuts Class
  */
-OptionsTabShortcuts::~OptionsTabShortcuts()
-{
-}
+OptionsTabShortcuts::~OptionsTabShortcuts() { }
 
 /**
  * \brief widget, creates the Options Tab Shortcuts Widget
@@ -67,10 +62,10 @@ OptionsTabShortcuts::~OptionsTabShortcuts()
  */
 QWidget *OptionsTabShortcuts::widget()
 {
-    if ( w )
-        return 0;
+    if (w)
+        return nullptr;
 
-    w = new OptShortcutsUI();
+    w                 = new OptShortcutsUI();
     OptShortcutsUI *d = static_cast<OptShortcutsUI *>(w);
 
     d->treeShortcuts->setColumnWidth(0, 320);
@@ -80,7 +75,8 @@ QWidget *OptionsTabShortcuts::widget()
     d->edit->setEnabled(false);
 
     connect(d->treeShortcuts, SIGNAL(itemSelectionChanged()), this, SLOT(onItemSelectionChanged()));
-    connect(d->treeShortcuts, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)), this, SLOT(onItemDoubleClicked(QTreeWidgetItem *, int)));
+    connect(d->treeShortcuts, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)), this,
+            SLOT(onItemDoubleClicked(QTreeWidgetItem *, int)));
     connect(d->add, SIGNAL(clicked()), this, SLOT(onAdd()));
     connect(d->remove, SIGNAL(clicked()), this, SLOT(onRemove()));
     connect(d->edit, SIGNAL(clicked()), this, SLOT(onEdit()));
@@ -92,54 +88,53 @@ QWidget *OptionsTabShortcuts::widget()
  * \brief    applyOptions, if options have changed, they will be applied by calling this function
  * \param    opt, unused, totally ignored
  */
-void OptionsTabShortcuts::applyOptions() {
-    if ( !w )
+void OptionsTabShortcuts::applyOptions()
+{
+    if (!w)
         return;
 
-    OptShortcutsUI *d = static_cast<OptShortcutsUI *>(w);
-    PsiOptions *options = PsiOptions::instance();
+    OptShortcutsUI *d       = static_cast<OptShortcutsUI *>(w);
+    PsiOptions *    options = PsiOptions::instance();
 
-    int toplevelItemsCount = d->treeShortcuts->topLevelItemCount();
-    int shortcutItemsCount;
-    int keyItemsCount;
-    QTreeWidgetItem *topLevelItem;
-    QTreeWidgetItem *shortcutItem;
-    QTreeWidgetItem *keyItem;
-    QString optionsPath;
-    QString comment;
-    QList<QString> children;
+    int                 toplevelItemsCount = d->treeShortcuts->topLevelItemCount();
+    int                 shortcutItemsCount;
+    int                 keyItemsCount;
+    QTreeWidgetItem *   topLevelItem;
+    QTreeWidgetItem *   shortcutItem;
+    QTreeWidgetItem *   keyItem;
+    QString             optionsPath;
+    QString             comment;
+    QList<QString>      children;
     QList<QKeySequence> keys;
 
     /* step through the Toplevel Items */
-    for(int topLevelIndex = 0 ; topLevelIndex < toplevelItemsCount; topLevelIndex++) {
-        topLevelItem = d->treeShortcuts->topLevelItem(topLevelIndex);
+    for (int topLevelIndex = 0; topLevelIndex < toplevelItemsCount; topLevelIndex++) {
+        topLevelItem       = d->treeShortcuts->topLevelItem(topLevelIndex);
         shortcutItemsCount = topLevelItem->childCount();
 
         /* step through the Shortcut Items */
-        for(int shortcutItemIndex = 0; shortcutItemIndex < shortcutItemsCount; shortcutItemIndex++) {
-            shortcutItem = topLevelItem->child(shortcutItemIndex);
+        for (int shortcutItemIndex = 0; shortcutItemIndex < shortcutItemsCount; shortcutItemIndex++) {
+            shortcutItem  = topLevelItem->child(shortcutItemIndex);
             keyItemsCount = shortcutItem->childCount();
 
             /* get the Options Path of the Shortcut Item */
             optionsPath = shortcutItem->data(0, OPTIONSTREEPATH).toString();
 
             /* just one Key Sequence */
-            if(keyItemsCount == 1) {
+            if (keyItemsCount == 1) {
                 /* so set the option to this keysequence directly */
                 keyItem = shortcutItem->child(0);
                 options->setOption(optionsPath, QVariant(keyItem->text(1)));
-            }
-            else if(keyItemsCount > 1){
+            } else if (keyItemsCount > 1) {
                 /* more than one, then collect them in a list */
                 QList<QVariant> keySequences;
-                for(int keyItemIndex = 0; keyItemIndex < keyItemsCount; keyItemIndex++) {
+                for (int keyItemIndex = 0; keyItemIndex < keyItemsCount; keyItemIndex++) {
                     keyItem = shortcutItem->child(keyItemIndex);
                     keySequences.append(QVariant(keyItem->text(1)));
                 }
 
                 options->setOption(optionsPath, QVariant(keySequences));
-            }
-            else {
+            } else {
                 /* zero key sequences, so set an empty string, so it will be written empty to the options.xml */
                 options->setOption(optionsPath, "");
             }
@@ -152,7 +147,7 @@ void OptionsTabShortcuts::applyOptions() {
  */
 void OptionsTabShortcuts::restoreOptions()
 {
-    if ( !w )
+    if (!w)
         return;
 
     readShortcuts(PsiOptions::instance());
@@ -166,69 +161,68 @@ void OptionsTabShortcuts::readShortcuts(const PsiOptions *options)
     OptShortcutsUI *d = static_cast<OptShortcutsUI *>(w);
 
     QTreeWidgetItem *topLevelItem;
-    QList<QString> shortcutGroups = options->getChildOptionNames("options.shortcuts", true, true);
+    QList<QString>   shortcutGroups = options->getChildOptionNames("options.shortcuts", true, true);
 
     /* step through the shortcut groups e.g. chatdlg */
-    foreach(QString shortcutGroup, shortcutGroups) {
+    for (const QString &shortcutGroup : shortcutGroups) {
         topLevelItem = new QTreeWidgetItem(d->treeShortcuts);
 
         QString comment = options->getComment(shortcutGroup);
         if (comment.isNull()) {
             comment = tr("Unnamed group");
-        }
-        else {
+        } else {
             comment = translateShortcut(comment);
         }
         topLevelItem->setText(0, comment);
         topLevelItem->setData(0, OPTIONSTREEPATH, QVariant(shortcutGroup));
-        topLevelItem->setData(0, ITEMKIND, QVariant((int)OptionsTabShortcuts::TopLevelItem));
+        topLevelItem->setData(0, ITEMKIND, QVariant(int(OptionsTabShortcuts::TopLevelItem)));
         topLevelItem->setExpanded(true);
         d->treeShortcuts->addTopLevelItem(topLevelItem);
     }
 
-    int toplevelItemsCount = d->treeShortcuts->topLevelItemCount();
-    QTreeWidgetItem *shortcutItem;
-    QTreeWidgetItem *keyItem;
-    QString optionsPath;
-    QString comment;
-    QList<QString> shortcuts;
+    int                 toplevelItemsCount = d->treeShortcuts->topLevelItemCount();
+    QTreeWidgetItem *   shortcutItem;
+    QTreeWidgetItem *   keyItem;
+    QString             optionsPath;
+    QString             comment;
+    QList<QString>      shortcuts;
     QList<QKeySequence> keys;
-    int keyItemsCount;
+    int                 keyItemsCount;
 
     /* step through the toplevel items */
-    for(int toplevelItemIndex = 0 ; toplevelItemIndex < toplevelItemsCount; toplevelItemIndex++) {
+    for (int toplevelItemIndex = 0; toplevelItemIndex < toplevelItemsCount; toplevelItemIndex++) {
         topLevelItem = d->treeShortcuts->topLevelItem(toplevelItemIndex);
-        optionsPath = topLevelItem->data(0, OPTIONSTREEPATH).toString();
+        optionsPath  = topLevelItem->data(0, OPTIONSTREEPATH).toString();
 
         /* if a optionsPath was saved in the toplevel item, we can get the shortcuts and the keys for the shortcuts */
-        if(!optionsPath.isEmpty()) {
+        if (!optionsPath.isEmpty()) {
 
             shortcuts = options->getChildOptionNames(optionsPath, true, true);
             /* step through the shortcuts */
-            foreach(QString shortcut, shortcuts) {
+            for (const QString &shortcut : shortcuts) {
 
-                keys = ShortcutManager::readShortcutsFromOptions(shortcut.mid(QString("options.shortcuts").length() + 1), options);
+                keys = ShortcutManager::readShortcutsFromOptions(
+                    shortcut.mid(QString("options.shortcuts").length() + 1), options);
                 comment = options->getComment(shortcut);
                 if (comment.isNull()) {
                     comment = tr("Unnamed group");
-                }
-                else {
+                } else {
                     comment = translateShortcut(comment);
                 }
 
                 /* create the TreeWidgetItem and set the Data the Kind and it's Optionspath and append it */
                 shortcutItem = new QTreeWidgetItem(topLevelItem);
                 shortcutItem->setText(0, comment);
-                shortcutItem->setData(0, ITEMKIND, QVariant((int)OptionsTabShortcuts::ShortcutItem));
+                shortcutItem->setData(0, ITEMKIND, QVariant(int(OptionsTabShortcuts::ShortcutItem)));
                 shortcutItem->setData(0, OPTIONSTREEPATH, QVariant(shortcut));
                 topLevelItem->addChild(shortcutItem);
 
                 /* step through this shortcut's keys and create 'Key XXXX' entries for them */
                 keyItemsCount = 1;
-                foreach(QKeySequence key, keys) {
+                for (QKeySequence key : keys) {
                     keyItem = new QTreeWidgetItem(shortcutItem);
                     keyItem->setText(0, QString(tr("Key %1")).arg(keyItemsCount++));
-                    keyItem->setData(0, ITEMKIND, QVariant((int)OptionsTabShortcuts::KeyItem));
+                    keyItem->setData(0, ITEMKIND, QVariant(int(OptionsTabShortcuts::KeyItem)));
                     keyItem->setText(1, key.toString(QKeySequence::NativeText));
                     shortcutItem->addChild(keyItem);
                 }
@@ -240,30 +234,31 @@ void OptionsTabShortcuts::readShortcuts(const PsiOptions *options)
 /**
  * \brief    Button Add pressed, creates a new Key entry
  */
-void OptionsTabShortcuts::onAdd() {
+void OptionsTabShortcuts::onAdd()
+{
     OptShortcutsUI *d = static_cast<OptShortcutsUI *>(w);
 
-    QTreeWidgetItem    *shortcutItem;
+    QTreeWidgetItem *shortcutItem;
 
     QList<QTreeWidgetItem *> selectedItems = d->treeShortcuts->selectedItems();
-    QString    optionsPath;
-    Kind itemKind;
+    QString                  optionsPath;
+    Kind                     itemKind;
 
-    if(selectedItems.count() == 0)
+    if (selectedItems.count() == 0)
         return;
 
     shortcutItem = selectedItems[0];
-    itemKind = (Kind)shortcutItem->data(0, ITEMKIND).toInt();
+    itemKind     = static_cast<Kind>(shortcutItem->data(0, ITEMKIND).toInt());
 
-    switch(itemKind) {
-        case OptionsTabShortcuts::KeyItem:
-            /* it was a keyItem, so get it's parent */
-            shortcutItem = shortcutItem->parent();
-            break;
-        case OptionsTabShortcuts::ShortcutItem:
-            break;
-        default:
-            return;
+    switch (itemKind) {
+    case OptionsTabShortcuts::KeyItem:
+        /* it was a keyItem, so get it's parent */
+        shortcutItem = shortcutItem->parent();
+        break;
+    case OptionsTabShortcuts::ShortcutItem:
+        break;
+    default:
+        return;
     }
 
     addTo(shortcutItem);
@@ -275,7 +270,7 @@ void OptionsTabShortcuts::onAdd() {
  */
 void OptionsTabShortcuts::addTo(QTreeWidgetItem *shortcutItem)
 {
-    OptShortcutsUI *d = static_cast<OptShortcutsUI *>(w);
+    OptShortcutsUI *         d             = static_cast<OptShortcutsUI *>(w);
     QList<QTreeWidgetItem *> selectedItems = d->treeShortcuts->selectedItems();
 
     QTreeWidgetItem *newKeyItem = new QTreeWidgetItem(shortcutItem);
@@ -293,28 +288,29 @@ void OptionsTabShortcuts::addTo(QTreeWidgetItem *shortcutItem)
 /**
  * \brief Button Remove pressed, removes the currently selected item, if it is a Keyitem
  */
-void OptionsTabShortcuts::onRemove() {
-    OptShortcutsUI *d = static_cast<OptShortcutsUI *>(w);
+void OptionsTabShortcuts::onRemove()
+{
+    OptShortcutsUI *         d             = static_cast<OptShortcutsUI *>(w);
     QList<QTreeWidgetItem *> selectedItems = d->treeShortcuts->selectedItems();
 
-    if(selectedItems.count() == 0)
+    if (selectedItems.count() == 0)
         return;
 
-    QTreeWidgetItem    *shortcutItem;
-    QTreeWidgetItem    *keyItem;
-    int keyItemsCount;
+    QTreeWidgetItem *shortcutItem;
+    QTreeWidgetItem *keyItem;
+    int              keyItemsCount;
 
     keyItem = selectedItems[0];
 
     /* we need a Item with the Kind "KeyItem", else we could / should not remove it */
-    if((Kind)keyItem->data(0, ITEMKIND).toInt() == OptionsTabShortcuts::KeyItem) {
+    if (static_cast<Kind>(keyItem->data(0, ITEMKIND).toInt()) == OptionsTabShortcuts::KeyItem) {
         shortcutItem = keyItem->parent();
         /* remove the key item from the shortcut item's children */
         shortcutItem->takeChild(shortcutItem->indexOfChild(keyItem));
 
         /* rename the children which are left over */
         keyItemsCount = shortcutItem->childCount();
-        for( int keyItemIndex = 0; keyItemIndex < keyItemsCount; keyItemIndex++)
+        for (int keyItemIndex = 0; keyItemIndex < keyItemsCount; keyItemIndex++)
             shortcutItem->child(keyItemIndex)->setText(0, QString(tr("Key %1")).arg(keyItemIndex + 1));
 
         /* notify the options dlg that data was changed */
@@ -325,27 +321,29 @@ void OptionsTabShortcuts::onRemove() {
 /**
  * \brief Button Edit pressed, edits the currently selected item if it is a key
  */
-void OptionsTabShortcuts::onEdit() {
-    OptShortcutsUI *d = static_cast<OptShortcutsUI *>(w);
+void OptionsTabShortcuts::onEdit()
+{
+    OptShortcutsUI *         d             = static_cast<OptShortcutsUI *>(w);
     QList<QTreeWidgetItem *> selectedItems = d->treeShortcuts->selectedItems();
 
-    if(selectedItems.count() == 0)
+    if (selectedItems.count() == 0)
         return;
 
-    QTreeWidgetItem    *keyItem = selectedItems[0];
+    QTreeWidgetItem *keyItem = selectedItems[0];
 
-    if((Kind)keyItem->data(0, ITEMKIND).toInt() == OptionsTabShortcuts::KeyItem)
+    if (static_cast<Kind>(keyItem->data(0, ITEMKIND).toInt()) == OptionsTabShortcuts::KeyItem)
         grep();
 }
 
 /**
  * \brief Button Restore Defaults pressed
  */
-void OptionsTabShortcuts::onRestoreDefaults() {
+void OptionsTabShortcuts::onRestoreDefaults()
+{
     if (QMessageBox::information(w, CAP(tr("Restore default shortcuts")),
-                   tr("Are you sure you would like to restore the default shortcuts?"),
-                   QMessageBox::Yes | QMessageBox::No,
-                   QMessageBox::No) == QMessageBox::Yes) {
+                                 tr("Are you sure you would like to restore the default shortcuts?"),
+                                 QMessageBox::Yes | QMessageBox::No, QMessageBox::No)
+        == QMessageBox::Yes) {
 
         OptShortcutsUI *d = static_cast<OptShortcutsUI *>(w);
         d->treeShortcuts->clear();
@@ -359,8 +357,8 @@ void OptionsTabShortcuts::onRestoreDefaults() {
  */
 void OptionsTabShortcuts::grep()
 {
-    GrepShortcutKeyDialog* grep = new GrepShortcutKeyDialog();
-    connect(grep, SIGNAL(newShortcutKey(const QKeySequence&)), this, SLOT(onNewShortcutKey(const QKeySequence&)));
+    GrepShortcutKeyDialog *grep = new GrepShortcutKeyDialog();
+    connect(grep, SIGNAL(newShortcutKey(const QKeySequence &)), this, SLOT(onNewShortcutKey(const QKeySequence &)));
     grep->show();
 }
 
@@ -368,39 +366,40 @@ void OptionsTabShortcuts::grep()
  * \brief    in the treeview, the selected item has changed, the add and remove buttons are
  *             enabled or disabled, depening on the selected item type
  */
-void OptionsTabShortcuts::onItemSelectionChanged() {
-    OptShortcutsUI *d = static_cast<OptShortcutsUI *>(w);
+void OptionsTabShortcuts::onItemSelectionChanged()
+{
+    OptShortcutsUI *         d             = static_cast<OptShortcutsUI *>(w);
     QList<QTreeWidgetItem *> selectedItems = d->treeShortcuts->selectedItems();
-    Kind itemKind;
+    Kind                     itemKind;
 
     /* zero selected Item(s), so we can't add or remove anything, disable the buttons */
-    if(selectedItems.count() == 0) {
+    if (selectedItems.count() == 0) {
         d->add->setEnabled(false);
         d->remove->setEnabled(false);
         d->edit->setEnabled(false);
         return;
     }
 
-    itemKind = (Kind)selectedItems[0]->data(0, ITEMKIND).toInt();
-    switch(itemKind) {
-        case OptionsTabShortcuts::TopLevelItem:
-            /* for a topLevel Item, we can't do anything neither add a key, nor remove one */
-            d->add->setEnabled(false);
-            d->remove->setEnabled(false);
-            d->edit->setEnabled(false);
-            break;
-        case OptionsTabShortcuts::ShortcutItem:
-            /* at a shortcut Item, we can add a key, but not remove it */
-            d->add->setEnabled(true);
-            d->remove->setEnabled(false);
-            d->edit->setEnabled(false);
-            break;
-        case OptionsTabShortcuts::KeyItem:
-            /* at a key item, we can add a key to it's parent shortcut item, or remove it */
-            d->add->setEnabled(true);
-            d->remove->setEnabled(true);
-            d->edit->setEnabled(true);
-            break;
+    itemKind = static_cast<Kind>(selectedItems[0]->data(0, ITEMKIND).toInt());
+    switch (itemKind) {
+    case OptionsTabShortcuts::TopLevelItem:
+        /* for a topLevel Item, we can't do anything neither add a key, nor remove one */
+        d->add->setEnabled(false);
+        d->remove->setEnabled(false);
+        d->edit->setEnabled(false);
+        break;
+    case OptionsTabShortcuts::ShortcutItem:
+        /* at a shortcut Item, we can add a key, but not remove it */
+        d->add->setEnabled(true);
+        d->remove->setEnabled(false);
+        d->edit->setEnabled(false);
+        break;
+    case OptionsTabShortcuts::KeyItem:
+        /* at a key item, we can add a key to it's parent shortcut item, or remove it */
+        d->add->setEnabled(true);
+        d->remove->setEnabled(true);
+        d->edit->setEnabled(true);
+        break;
     }
 }
 
@@ -414,7 +413,7 @@ void OptionsTabShortcuts::onItemDoubleClicked(QTreeWidgetItem *item, int column)
     if (!item)
         return;
 
-     Kind itemKind = (Kind)item->data(0, ITEMKIND).toInt();
+    Kind itemKind = static_cast<Kind>(item->data(0, ITEMKIND).toInt());
     if (itemKind == KeyItem)
         grep();
     else if (itemKind == ShortcutItem && item->childCount() == 0)
@@ -426,21 +425,22 @@ void OptionsTabShortcuts::onItemDoubleClicked(QTreeWidgetItem *item, int column)
  *            so the new KeySequence can be set to the KeyItem
  * \param    the new KeySequence for the keyitem
  */
-void OptionsTabShortcuts::onNewShortcutKey(const QKeySequence& key) {
-    OptShortcutsUI *d = static_cast<OptShortcutsUI *>(w);
-    QTreeWidgetItem    *keyItem;
+void OptionsTabShortcuts::onNewShortcutKey(const QKeySequence &key)
+{
+    OptShortcutsUI *         d = static_cast<OptShortcutsUI *>(w);
+    QTreeWidgetItem *        keyItem;
     QList<QTreeWidgetItem *> selectedItems = d->treeShortcuts->selectedItems();
-    QString    optionsPath;
-    Kind itemKind;
+    QString                  optionsPath;
+    Kind                     itemKind;
 
-    if(selectedItems.count() == 0)
+    if (selectedItems.count() == 0)
         return;
 
-    keyItem = selectedItems[0];
-    itemKind = (OptionsTabShortcuts::Kind)keyItem->data(0, ITEMKIND).toInt();
+    keyItem  = selectedItems[0];
+    itemKind = static_cast<OptionsTabShortcuts::Kind>(keyItem->data(0, ITEMKIND).toInt());
 
     /* if we got a key item, set the new key sequence and notify the options dialog that data has changed */
-    if(itemKind == OptionsTabShortcuts::KeyItem) {
+    if (itemKind == OptionsTabShortcuts::KeyItem) {
         keyItem->setText(1, key.toString(QKeySequence::NativeText));
         emit dataChanged();
     }
