@@ -1,21 +1,20 @@
 #ifndef OPT_STATUSAUTO_H
 #define OPT_STATUSAUTO_H
 
-#include "optionstab.h"
 #include "common.h"
+#include "optionstab.h"
 
 class QWidget;
 
-class OptionsTabStatusAuto : public OptionsTab
-{
+class OptionsTabStatusAuto : public OptionsTab {
     Q_OBJECT
 public:
     OptionsTabStatusAuto(QObject *parent);
     ~OptionsTabStatusAuto();
 
     QWidget *widget();
-    void applyOptions();
-    void restoreOptions();
+    void     applyOptions();
+    void     restoreOptions();
 
     void setData(PsiCon *, QWidget *parentDialog);
 
