@@ -1,15 +1,13 @@
 #ifndef OPTIONSDLGIFACE_H
 #define OPTIONSDLGIFACE_H
 
-class OptionsDlgIface : public QObject
-{
+class OptionsDlgIface : public QObject {
     Q_OBJECT
 public:
     OptionsDlgIface(QObject *parent, const char *name);
     ~OptionsDlgIface();
 
 public slots:
-
 };
 
-#endif
+#endif // OPTIONSDLGIFACE_H
