@@ -13,17 +13,20 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "pepmanager.h"
 
-#include <QtDebug>
-#include "xmpp_xmlcommon.h"
+#include "xmpp_client.h"
+#include "xmpp_pubsubitem.h"
+#include "xmpp_pubsubretraction.h"
+#include "xmpp_serverinfomanager.h"
 #include "xmpp_tasks.h"
-#include "serverinfomanager.h"
+#include "xmpp_xmlcommon.h"
+
+#include <QtDebug>
 
 using namespace XMPP;
 
@@ -33,14 +36,14 @@ using namespace XMPP;
 
 // -----------------------------------------------------------------------------
 
-class PEPGetTask : public Task
-{
+class PEPGetTask : public Task {
 public:
-    PEPGetTask(Task* parent, const QString& jid, const QString& node, const QString& itemID) : Task(parent), jid_(jid), node_(node) {
+    PEPGetTask(Task *parent, const QString &jid, const QString &node, const QString &itemID) :
+        Task(parent), jid_(jid), node_(node)
+    {
         iq_ = createIQ(doc(), "get", jid_, id());
 
-        QDomElement pubsub = doc()->createElement("pubsub");
-        pubsub.setAttribute("xmlns", "http://jabber.org/protocol/pubsub");
+        QDomElement pubsub = doc()->createElementNS("http://jabber.org/protocol/pubsub", "pubsub");
         iq_.appendChild(pubsub);
 
         QDomElement items = doc()->createElement("items");
@@ -52,57 +55,48 @@ public:
         items.appendChild(item);
     }
 
-    void onGo() {
-        send(iq_);
-    }
+    void onGo() { send(iq_); }
 
-    bool take(const QDomElement &x) {
-        if(!iqVerify(x, jid_, id()))
+    bool take(const QDomElement &x)
+    {
+        if (!iqVerify(x, jid_, id()))
             return false;
 
-        if(x.attribute("type") == "result") {
+        if (x.attribute("type") == "result") {
             // FIXME Check namespace...
             QDomElement e = x.firstChildElement("pubsub");
             if (!e.isNull()) {
                 QDomElement i = e.firstChildElement("items");
                 if (!i.isNull()) {
                     QString iname = "item";
-                    for(QDomElement e1 = i.firstChildElement(iname); !e1.isNull(); e1 = e1.nextSiblingElement(iname)) {
-                        for(QDomElement e2 = e1.firstChildElement(); !e2.isNull(); e2 = e2.nextSiblingElement()) {
-                            items_ += PubSubItem(e1.attribute("id"),e2);
+                    for (QDomElement e1 = i.firstChildElement(iname); !e1.isNull(); e1 = e1.nextSiblingElement(iname)) {
+                        for (QDomElement e2 = e1.firstChildElement(); !e2.isNull(); e2 = e2.nextSiblingElement()) {
+                            items_ += PubSubItem(e1.attribute("id"), e2);
                         }
                     }
                 }
             }
             setSuccess();
             return true;
-        }
-        else {
+        } else {
             setError(x);
             return true;
         }
     }
 
-    const QList<PubSubItem>& items() const {
-        return items_;
-    }
+    const QList<PubSubItem> &items() const { return items_; }
 
-    const QString& jid() const {
-        return jid_;
-    }
+    const QString &jid() const { return jid_; }
 
-    const QString& node() const {
-        return node_;
-    }
+    const QString &node() const { return node_; }
 
 private:
-    QDomElement iq_;
-    QString jid_;
-    QString node_;
+    QDomElement       iq_;
+    QString           jid_;
+    QString           node_;
     QList<PubSubItem> items_;
 };
 
-
 // -----------------------------------------------------------------------------
 
 /*
@@ -112,8 +106,7 @@ public:
     PEPUnsubscribeTask(Task* parent, const QString& jid, const QString& node) : Task(parent), jid_(jid) {
         iq_ = createIQ(doc(), "set", jid_, id());
 
-        QDomElement pubsub = doc()->createElement("pubsub");
-        pubsub.setAttribute("xmlns", "http://jabber.org/protocol/pubsub");
+        QDomElement pubsub = doc()->createElementNS("http://jabber.org/protocol/pubsub", "pubsub");
         iq_.appendChild(pubsub);
 
         QDomElement unsubscribe = doc()->createElement("unsubscribe");
@@ -152,8 +145,7 @@ public:
     PEPSubscribeTask(Task* parent, const QString& jid, const QString& node) : Task(parent), jid_(jid) {
         iq_ = createIQ(doc(), "set", jid_, id());
 
-        QDomElement pubsub = doc()->createElement("pubsub");
-        pubsub.setAttribute("xmlns", "http://jabber.org/protocol/pubsub");
+        QDomElement pubsub = doc()->createElementNS("http://jabber.org/protocol/pubsub", "pubsub");
         iq_.appendChild(pubsub);
 
         QDomElement subscribe = doc()->createElement("subscribe");
@@ -194,8 +186,7 @@ public:
         node_ = node;
         iq_ = createIQ(doc(), "set", "", id());
 
-        QDomElement pubsub = doc()->createElement("pubsub");
-        pubsub.setAttribute("xmlns", "http://jabber.org/protocol/pubsub");
+        QDomElement pubsub = doc()->createElementNS("http://jabber.org/protocol/pubsub", "pubsub");
         iq_.appendChild(pubsub);
 
         QDomElement subscribe = doc()->createElement("create");
@@ -234,14 +225,14 @@ private:
 
 // -----------------------------------------------------------------------------
 
-class PEPPublishTask : public Task
-{
+class PEPPublishTask : public Task {
 public:
-    PEPPublishTask(Task* parent, const QString& node, const PubSubItem& it, PEPManager::Access access) : Task(parent), node_(node), item_(it) {
+    PEPPublishTask(Task *parent, const QString &node, const PubSubItem &it, PEPManager::Access access) :
+        Task(parent), node_(node), item_(it)
+    {
         iq_ = createIQ(doc(), "set", "", id());
 
-        QDomElement pubsub = doc()->createElement("pubsub");
-        pubsub.setAttribute("xmlns", "http://jabber.org/protocol/pubsub");
+        QDomElement pubsub = doc()->createElementNS("http://jabber.org/protocol/pubsub", "pubsub");
         iq_.appendChild(pubsub);
 
         QDomElement publish = doc()->createElement("publish");
@@ -253,13 +244,13 @@ public:
         publish.appendChild(item);
 
         if (access != PEPManager::DefaultAccess) {
-            QDomElement conf = doc()->createElement("configure");
-            QDomElement conf_x = doc()->createElementNS("jabber:x:data","x");
+            QDomElement conf   = doc()->createElement("configure");
+            QDomElement conf_x = doc()->createElementNS("jabber:x:data", "x");
 
             // Form type
             QDomElement conf_x_field_type = doc()->createElement("field");
-            conf_x_field_type.setAttribute("var","FORM_TYPE");
-            conf_x_field_type.setAttribute("type","hidden");
+            conf_x_field_type.setAttribute("var", "FORM_TYPE");
+            conf_x_field_type.setAttribute("type", "hidden");
             QDomElement conf_x_field_type_value = doc()->createElement("value");
             conf_x_field_type_value.appendChild(doc()->createTextNode("http://jabber.org/protocol/pubsub#node_config"));
             conf_x_field_type.appendChild(conf_x_field_type_value);
@@ -267,18 +258,16 @@ public:
 
             // Access model
             QDomElement access_model = doc()->createElement("field");
-            access_model.setAttribute("var","pubsub#access_model");
+            access_model.setAttribute("var", "pubsub#access_model");
             QDomElement access_model_value = doc()->createElement("value");
             access_model.appendChild(access_model_value);
             if (access == PEPManager::PublicAccess) {
                 access_model_value.appendChild(doc()->createTextNode("open"));
-            }
-            else if (access == PEPManager::PresenceAccess) {
+            } else if (access == PEPManager::PresenceAccess) {
                 access_model_value.appendChild(doc()->createTextNode("presence"));
             }
             conf_x.appendChild(access_model);
 
-
             conf.appendChild(conf_x);
             pubsub.appendChild(conf);
         }
@@ -286,48 +275,41 @@ public:
         item.appendChild(it.payload());
     }
 
-    bool take(const QDomElement& x) {
-        if(!iqVerify(x, "", id()))
+    bool take(const QDomElement &x)
+    {
+        if (!iqVerify(x, "", id()))
             return false;
 
-        if(x.attribute("type") == "result") {
+        if (x.attribute("type") == "result") {
             setSuccess();
-        }
-        else {
+        } else {
             setError(x);
         }
         return true;
     }
 
-    void onGo() {
-        send(iq_);
-    }
+    void onGo() { send(iq_); }
 
-    const PubSubItem& item() const {
-        return item_;
-    }
+    const PubSubItem &item() const { return item_; }
 
-    const QString& node() const {
-        return node_;
-    }
+    const QString &node() const { return node_; }
 
 private:
     QDomElement iq_;
-    QString node_;
-    PubSubItem item_;
+    QString     node_;
+    PubSubItem  item_;
 };
 
-
 // -----------------------------------------------------------------------------
 
-class PEPRetractTask : public Task
-{
+class PEPRetractTask : public Task {
 public:
-    PEPRetractTask(Task* parent, const QString& node, const QString& itemId) : Task(parent), node_(node), itemId_(itemId) {
+    PEPRetractTask(Task *parent, const QString &node, const QString &itemId) :
+        Task(parent), node_(node), itemId_(itemId)
+    {
         iq_ = createIQ(doc(), "set", "", id());
 
-        QDomElement pubsub = doc()->createElement("pubsub");
-        pubsub.setAttribute("xmlns", "http://jabber.org/protocol/pubsub");
+        QDomElement pubsub = doc()->createElementNS("http://jabber.org/protocol/pubsub", "pubsub");
         iq_.appendChild(pubsub);
 
         QDomElement retract = doc()->createElement("retract");
@@ -340,34 +322,29 @@ public:
         retract.appendChild(item);
     }
 
-    bool take(const QDomElement& x) {
-        if(!iqVerify(x, "", id()))
+    bool take(const QDomElement &x)
+    {
+        if (!iqVerify(x, "", id()))
             return false;
 
-        if(x.attribute("type") == "result") {
+        if (x.attribute("type") == "result") {
             setSuccess();
-        }
-        else {
+        } else {
             setError(x);
         }
         return true;
     }
 
-    void onGo() {
-        send(iq_);
-    }
+    void onGo() { send(iq_); }
 
-    const QString& node() const {
-        return node_;
-    }
+    const QString &node() const { return node_; }
 
 private:
     QDomElement iq_;
-    QString node_;
-    QString itemId_;
+    QString     node_;
+    QString     itemId_;
 };
 
-
 // -----------------------------------------------------------------------------
 
 /*
@@ -438,7 +415,7 @@ private:
 
 // -----------------------------------------------------------------------------
 
-PEPManager::PEPManager(Client* client, ServerInfoManager* serverInfo) : client_(client), serverInfo_(serverInfo)
+PEPManager::PEPManager(Client *client, ServerInfoManager *serverInfo) : client_(client), serverInfo_(serverInfo)
 {
     connect(client_, SIGNAL(messageReceived(const Message &)), SLOT(messageReceived(const Message &)));
 }
@@ -486,7 +463,6 @@ void PEPManager::createNode(const QString& node)
     t->go(true);
 }
 
-
 void PEPManager::subscribe(const QString& jid, const QString& ns)
 {
     PEPSubscribeTask* t = new PEPSubscribeTask(client_->rootTask(),jid,ns);
@@ -510,7 +486,8 @@ void PEPManager::createFinished()
         emit ready(task->node());
     }
     else {
-        qWarning(QString("[%3] PEP Create failed: '%1' (%2)").arg(task->statusString()).arg(QString::number(task->statusCode())).arg(client_->jid().full()));
+        qWarning(QString("[%3] PEP Create failed: '%1'
+(%2)").arg(task->statusString()).arg(QString::number(task->statusCode())).arg(client_->jid().full()));
     }
 }
 
@@ -522,7 +499,8 @@ void PEPManager::subscribeFinished()
         saveSubscriptions();
     }
     else {
-        qWarning(QString("[%3] PEP Subscribe failed: '%1' (%2)").arg(task->statusString()).arg(QString::number(task->statusCode())).arg(client_->jid().full()));
+        qWarning(QString("[%3] PEP Subscribe failed: '%1'
+(%2)").arg(task->statusString()).arg(QString::number(task->statusCode())).arg(client_->jid().full()));
     }
 }
 
@@ -537,7 +515,8 @@ void PEPManager::unsubscribeFinished()
 {
     PEPUnsubscribeTask* task = (PEPUnsubscribeTask*) sender();
     if (!task->success()) {
-        qWarning(QString("[%3] PEP Unsubscribe failed: '%1' (%2)").arg(task->statusString()).arg(QString::number(task->statusCode())).arg(client_->jid().full()));
+        qWarning(QString("[%3] PEP Unsubscribe failed: '%1'
+(%2)").arg(task->statusString()).arg(QString::number(task->statusCode())).arg(client_->jid().full()));
     }
 
     // We're being conservative about unsubscribing. Remove subscription,
@@ -546,67 +525,65 @@ void PEPManager::unsubscribeFinished()
     saveSubscriptions();
 }*/
 
-void PEPManager::publish(const QString& node, const PubSubItem& it, Access access)
+void PEPManager::publish(const QString &node, const PubSubItem &it, Access access)
 {
-    //if (!canPublish(node))
+    // if (!canPublish(node))
     //    return;
     if (!serverInfo_->hasPEP())
         return;
 
-    PEPPublishTask* tp = new PEPPublishTask(client_->rootTask(),node,it,access);
+    PEPPublishTask *tp = new PEPPublishTask(client_->rootTask(), node, it, access);
     connect(tp, SIGNAL(finished()), SLOT(publishFinished()));
     tp->go(true);
 }
 
-
-void PEPManager::retract(const QString& node, const QString& id)
+void PEPManager::retract(const QString &node, const QString &id)
 {
     if (!serverInfo_->hasPEP())
         return;
 
-    PEPRetractTask* tp = new PEPRetractTask(client_->rootTask(),node,id);
+    PEPRetractTask *tp = new PEPRetractTask(client_->rootTask(), node, id);
     // FIXME: add notification of success/failure
     tp->go(true);
 }
 
-
-void PEPManager::disable(const QString& tagName, const QString& node, const QString& id)
+void PEPManager::disable(const QString &tagName, const QString &node, const QString &id)
 {
     // disable by publishing an empty element
-    QDomElement element = client_->rootTask()->doc()->createElement(tagName);
-    element.setAttribute("xmlns", node);
+    QDomElement element = client_->rootTask()->doc()->createElementNS(node, tagName);
 
-    publish(node, PubSubItem(id,element));
+    publish(node, PubSubItem(id, element));
 }
 
-
 void PEPManager::publishFinished()
 {
-    PEPPublishTask* task = (PEPPublishTask*) sender();
+    PEPPublishTask *task = static_cast<PEPPublishTask *>(sender());
     if (task->success()) {
-        emit publish_success(task->node(),task->item());
-    }
-    else {
-        qWarning() << QString("[%3] PEP Publish failed: '%1' (%2)").arg(task->statusString()).arg(QString::number(task->statusCode())).arg(client_->jid().full());
-        emit publish_error(task->node(),task->item());
+        emit publish_success(task->node(), task->item());
+    } else {
+        qWarning() << QString("[%3] PEP Publish failed: '%1' (%2)")
+                          .arg(task->statusString())
+                          .arg(QString::number(task->statusCode()))
+                          .arg(client_->jid().full());
+        emit publish_error(task->node(), task->item());
     }
 }
 
-void PEPManager::get(const Jid& jid, const QString& node, const QString& id)
+void PEPManager::get(const Jid &jid, const QString &node, const QString &id)
 {
-    PEPGetTask* g = new PEPGetTask(client_->rootTask(),jid.bare(),node,id);
+    PEPGetTask *g = new PEPGetTask(client_->rootTask(), jid.bare(), node, id);
     connect(g, SIGNAL(finished()), SLOT(getFinished()));
     g->go(true);
 }
 
-void PEPManager::messageReceived(const Message& m)
+void PEPManager::messageReceived(const Message &m)
 {
     if (m.type() != "error") {
-        foreach(PubSubRetraction i, m.pubsubRetractions()) {
-            emit itemRetracted(m.from(),m.pubsubNode(), i);
+        for (PubSubRetraction i : m.pubsubRetractions()) {
+            emit itemRetracted(m.from(), m.pubsubNode(), i);
         }
-        foreach(PubSubItem i, m.pubsubItems()) {
-            emit itemPublished(m.from(),m.pubsubNode(),i);
+        for (PubSubItem i : m.pubsubItems()) {
+            emit itemPublished(m.from(), m.pubsubNode(), i);
         }
     }
 }
@@ -626,16 +603,18 @@ void PEPManager::messageReceived(const Message& m)
 
 void PEPManager::getFinished()
 {
-    PEPGetTask* task = (PEPGetTask*) sender();
+    PEPGetTask *task = static_cast<PEPGetTask *>(sender());
     if (task->success()) {
         // Act as if the item was published. This is a convenience
         // implementation, probably should be changed later.
         if (!task->items().isEmpty()) {
-            emit itemPublished(task->jid(),task->node(),task->items().first());
+            emit itemPublished(task->jid(), task->node(), task->items().first());
         }
-    }
-    else {
-        qWarning() << QString("[%3] PEP Get failed: '%1' (%2)").arg(task->statusString()).arg(QString::number(task->statusCode())).arg(client_->jid().full());
+    } else {
+        qWarning() << QString("[%3] PEP Get failed: '%1' (%2)")
+                          .arg(task->statusString())
+                          .arg(QString::number(task->statusCode()))
+                          .arg(client_->jid().full());
     }
 }
 
@@ -671,7 +650,8 @@ void PEPManager::getSelfSubscriptionsTaskFinished()
         }
     }
     else {
-        qWarning(QString("[%3] Error getting own subscriptions: '%1' (%2)").arg(task->statusString()).arg(QString::number(task->statusCode())).arg(client_->jid().full()));
+        qWarning(QString("[%3] Error getting own subscriptions: '%1'
+(%2)").arg(task->statusString()).arg(QString::number(task->statusCode())).arg(client_->jid().full()));
     }
 }
 
