@@ -13,21 +13,19 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
-#include <QSortFilterProxyModel>
-
 #include "privacylistblockedmodel.h"
+
 #include "privacylistmodel.h"
 
-PrivacyListBlockedModel::PrivacyListBlockedModel(QObject* parent) : QSortFilterProxyModel(parent)
-{
-}
+#include <QSortFilterProxyModel>
 
-bool PrivacyListBlockedModel::lessThan(const QModelIndex & left, const QModelIndex & right ) const
+PrivacyListBlockedModel::PrivacyListBlockedModel(QObject *parent) : QSortFilterProxyModel(parent) { }
+
+bool PrivacyListBlockedModel::lessThan(const QModelIndex &left, const QModelIndex &right) const
 {
     return left.row() < right.row();
 }
@@ -37,7 +35,9 @@ bool PrivacyListBlockedModel::filterAcceptsColumn(int source_column, const QMode
     return source_column == PrivacyListModel::ValueColumn;
 }
 
-bool PrivacyListBlockedModel::filterAcceptsRow(int source_row, const QModelIndex & source_parent ) const
+bool PrivacyListBlockedModel::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
 {
-    return sourceModel()->data(sourceModel()->index(source_row,0,source_parent),PrivacyListModel::BlockedRole).toBool();
+    return sourceModel()
+        ->data(sourceModel()->index(source_row, 0, source_parent), PrivacyListModel::BlockedRole)
+        .toBool();
 }
