@@ -4,24 +4,22 @@
 #include <QObject>
 
 namespace XMPP {
-    class Jid;
-    class DiscoItem;
+class DiscoItem;
+class Jid;
 };
 
 namespace Protocol {
-
 /**
  * A DiscoInfoQuerier is an object used to query Service Discovery information.
  */
-class DiscoInfoQuerier : public QObject
-{
+class DiscoInfoQuerier : public QObject {
     Q_OBJECT
 
 public:
     /**
      * Retrieves Disco information of a jid on a specific node.
      */
-    virtual void getDiscoInfo(const XMPP::Jid& jid, const QString& node) = 0;
+    virtual void getDiscoInfo(const XMPP::Jid &jid, const QString &node) = 0;
 
 signals:
     /**
@@ -31,7 +29,7 @@ signals:
      * @param node the node on which the request was done
      * @param item the resulting disco item.
      */
-    void getDiscoInfo_success(const XMPP::Jid& jid, const QString& node, const XMPP::DiscoItem& item);
+    void getDiscoInfo_success(const XMPP::Jid &jid, const QString &node, const XMPP::DiscoItem &item);
 
     /**
      * Signals that a disco information request returned an error.
@@ -41,8 +39,8 @@ signals:
      * @param error_code the error code of the error
      * @param error_string the error text of the error
      */
-    void getDiscoInfo_error(const XMPP::Jid& jid, const QString& node, int error_code, const QString& error_string);
-};
+    void getDiscoInfo_error(const XMPP::Jid &jid, const QString &node, int error_code, const QString &error_string);
 };
+}; // namespace Protocol
 
-#endif
+#endif // DISCOINFOQUERIER_H
