@@ -13,108 +13,101 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "profiles.h"
-#include "common.h"
-#include "applicationinfo.h"
-#include <QDir>
-#include <QFileInfo>
-#include <QDomElement>
 
-#include <QApplication>
-#include <QTextStream>
-#include <QtCrypto>
-#include <QList>
-#include <QUuid>
-#include <QDesktopWidget>
-
-#include "eventdlg.h"
-#include "chatdlg.h"
-#include "xmpp_xmlcommon.h"
-#include "fancylabel.h"
 #include "advwidget.h"
-#include "psioptions.h"
-#include "varlist.h"
+#include "applicationinfo.h"
 #include "atomicxmlfile/atomicxmlfile.h"
-#include "psitoolbar.h"
+#include "chatdlg.h"
+#include "common.h"
+#include "fancylabel.h"
 #include "optionstree.h"
-#include "shortcutmanager.h"
 #ifdef HAVE_PGPUTIL
 #include "pgputil.h"
 #endif
 #ifdef PSI_PLUGINS
 #include "pluginmanager.h"
 #endif
+#include "psioptions.h"
+#include "psitoolbar.h"
+#include "shortcutmanager.h"
+#include "varlist.h"
+#include "xmpp_xmlcommon.h"
+
+#include <QApplication>
+#include <QDesktopWidget>
+#include <QDir>
+#include <QDomElement>
+#include <QFileInfo>
+#include <QList>
+#include <QTextStream>
+#include <QUuid>
+#include <QtCrypto>
+
+#define PROXY_NONE 0
+#define PROXY_HTTPS 1
+#define PROXY_SOCKS4 2
+#define PROXY_SOCKS5 3
 
-using namespace XMPP;
 using namespace XMLHelper;
+using namespace XMPP;
 
-#define PROXY_NONE       0
-#define PROXY_HTTPS      1
-#define PROXY_SOCKS4     2
-#define PROXY_SOCKS5     3
-
-UserAccount::UserAccount()
-    : lastStatus(XMPP::Status::Online)
-{
-    reset();
-}
+UserAccount::UserAccount() : lastStatus(XMPP::Status::Online) { reset(); }
 
 void UserAccount::reset()
 {
-    id = QUuid::createUuid().toString();
-    name = "Default";
-    opt_enabled = true;
-    opt_auto = false;
-    tog_offline = true;
-    tog_away = true;
-    tog_hidden = false;
-    tog_agents = true;
-    tog_self = false;
-    customAuth = false;
+    id                        = QUuid::createUuid().toString();
+    name                      = "Default";
+    opt_enabled               = true;
+    opt_auto                  = false;
+    tog_offline               = true;
+    tog_away                  = true;
+    tog_hidden                = false;
+    tog_agents                = true;
+    tog_self                  = false;
+    customAuth                = false;
     storeSaltedHashedPassword = false;
-    req_mutual_auth = false;
-    legacy_ssl_probe = false;
-    security_level = QCA::SL_None;
-    ssl = SSL_Auto;
-    jid = "";
-    pass = "";
-    scramSaltedHashPassword = "";
-    opt_pass = false;
-    port = 5222;
-    opt_host = false;
-    host = "";
-    opt_automatic_resource = false;
-    priority_dep_on_status = true;
-    ignore_global_actions = false;
-    resource = ApplicationInfo::name();
-    priority = 55;
-    ibbOnly = false;
-    opt_keepAlive = true;
-    opt_sm = true;
-    allow_plain = XMPP::ClientStream::AllowPlainOverTLS;
-    opt_compress = true;
-    opt_log = true;
-    opt_reconn = true;
-    opt_connectAfterSleep = false;
-    opt_autoSameStatus = true;
-    lastStatusWithPriority = false;
-    opt_ignoreSSLWarnings = false;
+    req_mutual_auth           = false;
+    legacy_ssl_probe          = false;
+    security_level            = QCA::SL_None;
+    ssl                       = SSL_Auto;
+    jid                       = "";
+    pass                      = "";
+    scramSaltedHashPassword   = "";
+    opt_pass                  = false;
+    port                      = 5222;
+    opt_host                  = false;
+    host                      = "";
+    opt_automatic_resource    = true;
+    priority_dep_on_status    = true;
+    ignore_global_actions     = false;
+    resource                  = ApplicationInfo::name();
+    priority                  = 55;
+    ibbOnly                   = false;
+    opt_keepAlive             = true;
+    opt_sm                    = true;
+    allow_plain               = XMPP::ClientStream::AllowPlainOverTLS;
+    opt_compress              = true;
+    opt_log                   = true;
+    opt_reconn                = true;
+    opt_connectAfterSleep     = false;
+    opt_autoSameStatus        = true;
+    lastStatusWithPriority    = false;
+    opt_ignoreSSLWarnings     = false;
 
     proxy_index = 0;
-    proxy_type = PROXY_NONE;
-    proxy_host = "";
-    proxy_port = 8080;
-    proxy_user = "";
-    proxy_pass = "";
+    proxy_type  = PROXY_NONE;
+    proxy_host  = "";
+    proxy_port  = 8080;
+    proxy_user  = "";
+    proxy_pass  = "";
 
     stunHosts.clear();
-    stunHosts << "stun.jabber.ru:5249"
-              << "stun.habahaba.im"
+    stunHosts << "stun.l.google.com:19302"
               << "stun.ekiga.net"
               << "provserver.televolution.net"
               << "stun1.voiceeclipse.net"
@@ -136,14 +129,14 @@ void UserAccount::reset()
 
     stunHost = stunHosts[0];
 
-    keybind.clear();
+    pgpKnownKeys.clear();
+    pgpEnabledChats.clear();
+    pgpDisabledChats.clear();
 
     roster.clear();
 }
 
-UserAccount::~UserAccount()
-{
-}
+UserAccount::~UserAccount() { }
 
 void UserAccount::fromOptions(OptionsTree *o, QString base)
 {
@@ -157,25 +150,24 @@ void UserAccount::fromOptions(OptionsTree *o, QString base)
 
     QStringList allSetOptions = o->getChildOptionNames(base, true, true);
 
-    opt_enabled = o->getOption(base + ".enabled").toBool();
-    opt_auto = o->getOption(base + ".auto").toBool();
-    opt_keepAlive = o->getOption(base + ".keep-alive").toBool();
-    opt_sm = o->getOption(base + ".enable-sm", true).toBool();
-    opt_compress = o->getOption(base + ".compress").toBool();
-    req_mutual_auth = o->getOption(base + ".require-mutual-auth").toBool();
-    legacy_ssl_probe = o->getOption(base + ".legacy-ssl-probe").toBool();
+    opt_enabled            = o->getOption(base + ".enabled").toBool();
+    opt_auto               = o->getOption(base + ".auto").toBool();
+    opt_keepAlive          = o->getOption(base + ".keep-alive").toBool();
+    opt_sm                 = o->getOption(base + ".enable-sm", true).toBool();
+    opt_compress           = o->getOption(base + ".compress").toBool();
+    req_mutual_auth        = o->getOption(base + ".require-mutual-auth").toBool();
+    legacy_ssl_probe       = o->getOption(base + ".legacy-ssl-probe").toBool();
     opt_automatic_resource = o->getOption(base + ".automatic-resource").toBool();
     priority_dep_on_status = o->getOption(base + ".priority-depends-on-status", false).toBool();
-    ignore_global_actions = o->getOption(base + ".ignore-global-actions").toBool();
-    opt_log = o->getOption(base + ".log").toBool();
-    opt_reconn = o->getOption(base + ".reconn").toBool();
-    opt_ignoreSSLWarnings = o->getOption(base + ".ignore-SSL-warnings").toBool();
+    ignore_global_actions  = o->getOption(base + ".ignore-global-actions").toBool();
+    opt_log                = o->getOption(base + ".log").toBool();
+    opt_reconn             = o->getOption(base + ".reconn").toBool();
+    opt_ignoreSSLWarnings  = o->getOption(base + ".ignore-SSL-warnings").toBool();
 
     // FIX-ME: See FS#771
     if (o->getChildOptionNames().contains(base + ".connect-after-sleep")) {
         opt_connectAfterSleep = o->getOption(base + ".connect-after-sleep").toBool();
-    }
-    else {
+    } else {
         o->setOption(base + ".connect-after-sleep", opt_connectAfterSleep);
     }
 
@@ -184,32 +176,24 @@ void UserAccount::fromOptions(OptionsTree *o, QString base)
         id = tmpId;
     }
     name = o->getOption(base + ".name").toString();
-    jid = o->getOption(base + ".jid").toString();
+    jid  = o->getOption(base + ".jid").toString();
 
     customAuth = o->getOption(base + ".custom-auth.use").toBool();
-    authid = o->getOption(base + ".custom-auth.authid").toString();
-    realm = o->getOption(base + ".custom-auth.realm").toString();
+    authid     = o->getOption(base + ".custom-auth.authid").toString();
+    realm      = o->getOption(base + ".custom-auth.realm").toString();
 
     // read scram salted password options
     storeSaltedHashedPassword = o->getOption(base + ".scram.store-salted-password").toBool();
-    scramSaltedHashPassword = o->getOption(base + ".scram.salted-password").toString();
+    scramSaltedHashPassword   = o->getOption(base + ".scram.salted-password").toString();
 
     // read password (we must do this after reading the jid, to decode properly)
     QString tmp = o->getOption(base + ".password", QString()).toString();
-    if(!tmp.isEmpty()) {
+    if (!tmp.isEmpty()) {
         opt_pass = true;
-        pass = decodePassword(tmp, jid);
-#ifdef HAVE_KEYCHAIN
-        if (isKeychainEnabled()) {
-            // Erase password from options, since we are going to keep it in keychain only
-            // TODO move this to the migration code. Added in Psi 2.0 2018-01-05
-            o->removeOption(base + ".password");
-            saveXMPPPasswordToKeyring(jid, pass, qApp);
-        }
-#endif
+        pass     = decodePassword(tmp, jid);
     }
 
-    opt_host = o->getOption(base + ".use-host").toBool();
+    opt_host       = o->getOption(base + ".use-host").toBool();
     security_level = o->getOption(base + ".security-level").toInt();
 
     tmp = o->getOption(base + ".ssl").toString();
@@ -238,24 +222,13 @@ void UserAccount::fromOptions(OptionsTree *o, QString base)
         lastStatusWithPriority = o->getOption(base + ".last-with-priority").toBool();
         if (lastStatusWithPriority) {
             lastStatus.setPriority(o->getOption(base + ".last-priority").toInt());
-        }
-        else {
+        } else {
             lastStatus.setPriority(defaultPriority(lastStatus));
         }
     }
 
 #ifdef HAVE_PGPUTIL
-    QString pgpSecretKeyID = o->getOption(base + ".pgp-secret-key-id").toString();
-    if (!pgpSecretKeyID.isEmpty()) {
-        QCA::KeyStoreEntry e = PGPUtil::instance().getSecretKeyStoreEntry(pgpSecretKeyID);
-        if (!e.isNull())
-            pgpSecretKey = e.pgpSecretKey();
-
-        pgpPassPhrase = o->getOption(base + ".pgp-pass-phrase").toString();
-        if(!pgpPassPhrase.isEmpty()) {
-            pgpPassPhrase = decodePassword(pgpPassPhrase, pgpSecretKeyID);
-        }
-    }
+    pgpSecretKey = o->getOption(base + ".pgp-secret-key-id").toString();
 #endif
 
     tmp = o->getOption(base + ".allow-plain").toString();
@@ -270,7 +243,7 @@ void UserAccount::fromOptions(OptionsTree *o, QString base)
     }
 
     QStringList rosterCache = o->getChildOptionNames(base + ".roster-cache", true, true);
-    foreach(QString rbase, rosterCache) {
+    for (const QString &rbase : rosterCache) {
         RosterItem ri;
         ri.setJid(Jid(o->getOption(rbase + ".jid").toString()));
         ri.setName(o->getOption(rbase + ".name").toString());
@@ -284,29 +257,29 @@ void UserAccount::fromOptions(OptionsTree *o, QString base)
 
     groupState.clear();
     QVariantList states = o->mapKeyList(base + ".group-state");
-    foreach(QVariant k, states) {
+    for (QVariant k : states) {
         GroupData gd;
-        QString sbase = o->mapLookup(base + ".group-state", k);
-        gd.open = o->getOption(sbase + ".open").toBool();
-        gd.rank = o->getOption(sbase + ".rank").toInt();
+        QString   sbase = o->mapLookup(base + ".group-state", k);
+        gd.open         = o->getOption(sbase + ".open").toBool();
+        gd.rank         = o->getOption(sbase + ".rank").toInt();
         groupState.insert(k.toString(), gd);
     }
 
     proxyID = o->getOption(base + ".proxy-id").toString();
 
-    keybind.fromOptions(o, base + ".pgp-key-bindings");
+    pgpKnownKeys.fromOptions(o, base + ".pgp-key-bindings");
+    pgpEnabledChats  = o->getOption(base + ".pgp-enabled-chats").toStringList();
+    pgpDisabledChats = o->getOption(base + ".pgp-disabled-chats").toStringList();
 
     dtProxy = o->getOption(base + ".bytestreams-proxy").toString();
     ibbOnly = o->getOption(base + ".ibb-only").toBool();
 
-
     if (allSetOptions.contains(base + ".stun-hosts")) {
         stunHosts = o->getOption(base + ".stun-hosts").toStringList();
         if (allSetOptions.contains(base + ".stun-host")) {
             stunHost = o->getOption(base + ".stun-host").toString();
         }
-    }
-    else if (!o->getOption(base + ".stun-host").toString().isEmpty()) {
+    } else if (!o->getOption(base + ".stun-host").toString().isEmpty()) {
         stunHost = o->getOption(base + ".stun-host").toString();
     }
     if (allSetOptions.contains(base + ".stun-username")) {
@@ -315,15 +288,16 @@ void UserAccount::fromOptions(OptionsTree *o, QString base)
     if (allSetOptions.contains(base + ".stun-password")) {
         stunPass = o->getOption(base + ".stun-password").toString();
     }
+    onlyMyTurn = o->getOption(base + ".stun-onlymyturn", false).toBool();
 
     if (allSetOptions.contains(base + ".tls")) {
-        tlsOverrideCert = o->getOption(base + ".tls.override-certificate").toByteArray();
+        tlsOverrideCert   = o->getOption(base + ".tls.override-certificate").toByteArray();
         tlsOverrideDomain = o->getOption(base + ".tls.override-domain").toString();
     }
 
     alwaysVisibleContacts = o->getOption(base + ".always-visible-contacts").toStringList();
-    localMucBookmarks = o->getOption(base + ".muc-bookmarks").toStringList();
-    ignoreMucBookmarks = o->getOption(base + ".muc-bookmarks-ignore").toStringList();
+    localMucBookmarks     = o->getOption(base + ".muc-bookmarks").toStringList();
+    ignoreMucBookmarks    = o->getOption(base + ".muc-bookmarks-ignore").toStringList();
 }
 
 void UserAccount::toOptions(OptionsTree *o, QString base)
@@ -364,7 +338,7 @@ void UserAccount::toOptions(OptionsTree *o, QString base)
 #ifdef HAVE_KEYCHAIN
     if (!isKeychainEnabled()) {
 #endif
-        if(opt_pass) {
+        if (opt_pass) {
             o->setOption(base + ".password", encodePassword(pass, jid));
         } else {
             o->setOption(base + ".password", "");
@@ -375,48 +349,46 @@ void UserAccount::toOptions(OptionsTree *o, QString base)
     o->setOption(base + ".use-host", opt_host);
     o->setOption(base + ".security-level", security_level);
     switch (ssl) {
-        case SSL_No:
-            o->setOption(base + ".ssl", "no");
-            break;
-        case SSL_Yes:
-            o->setOption(base + ".ssl", "yes");
-            break;
-        case SSL_Auto:
-            o->setOption(base + ".ssl", "auto");
-            break;
-        case SSL_Legacy:
-            o->setOption(base + ".ssl", "legacy");
-            break;
-        default:
-            qFatal("unknown ssl enum value in UserAccount::toOptions");
+    case SSL_No:
+        o->setOption(base + ".ssl", "no");
+        break;
+    case SSL_Yes:
+        o->setOption(base + ".ssl", "yes");
+        break;
+    case SSL_Auto:
+        o->setOption(base + ".ssl", "auto");
+        break;
+    case SSL_Legacy:
+        o->setOption(base + ".ssl", "legacy");
+        break;
+    default:
+        qFatal("unknown ssl enum value in UserAccount::toOptions");
     }
     o->setOption(base + ".host", host);
     o->setOption(base + ".port", port);
     o->setOption(base + ".resource", resource);
     o->setOption(base + ".priority", priority);
     if (!pgpSecretKey.isNull()) {
-        o->setOption(base + ".pgp-secret-key-id", pgpSecretKey.keyId());
-        o->setOption(base + ".pgp-pass-phrase", encodePassword(pgpPassPhrase, pgpSecretKey.keyId()));
+        o->setOption(base + ".pgp-secret-key-id", pgpSecretKey);
     } else {
         o->setOption(base + ".pgp-secret-key-id", "");
-        o->setOption(base + ".pgp-pass-phrase", "");
     }
     switch (allow_plain) {
-        case XMPP::ClientStream::NoAllowPlain:
-            o->setOption(base + ".allow-plain", "never");
-            break;
-        case XMPP::ClientStream::AllowPlain:
-            o->setOption(base + ".allow-plain", "always");
-            break;
-        case XMPP::ClientStream::AllowPlainOverTLS:
-            o->setOption(base + ".allow-plain", "over encryped");
-            break;
-        default:
-            qFatal("unknown allow_plain enum value in UserAccount::toOptions");
+    case XMPP::ClientStream::NoAllowPlain:
+        o->setOption(base + ".allow-plain", "never");
+        break;
+    case XMPP::ClientStream::AllowPlain:
+        o->setOption(base + ".allow-plain", "always");
+        break;
+    case XMPP::ClientStream::AllowPlainOverTLS:
+        o->setOption(base + ".allow-plain", "over encryped");
+        break;
+    default:
+        qFatal("unknown allow_plain enum value in UserAccount::toOptions");
     }
 
     int idx = 0;
-    foreach(RosterItem ri, roster) {
+    for (RosterItem ri : roster) {
         QString rbase = base + ".roster-cache.a" + QString::number(idx++);
         o->setOption(rbase + ".jid", ri.jid().full());
         o->setOption(rbase + ".name", ri.name());
@@ -426,7 +398,7 @@ void UserAccount::toOptions(OptionsTree *o, QString base)
     }
 
     // now we check for redundant entries
-    QStringList groupList;
+    QStringList   groupList;
     QSet<QString> removeList;
     groupList << "/\\/" + name + "\\/\\"; // account name is a very 'special' group
 
@@ -435,24 +407,24 @@ void UserAccount::toOptions(OptionsTree *o, QString base)
     groupList << qApp->translate("ContactProfile", "Agents/Transports");
 
     // first, add all groups' names to groupList
-    foreach(RosterItem i, roster) {
+    for (RosterItem i : roster) {
         groupList += i.groups();
     }
 
     // now, check if there's groupState name entry in groupList
-    foreach(QString group, groupState.keys()) {
+    for (const QString &group : groupState.keys()) {
         if (!groupList.contains(group)) {
             removeList << group;
         }
     }
 
     // remove redundant groups
-    foreach(QString group, removeList) {
-        groupState.remove( group );
+    for (const QString &group : removeList) {
+        groupState.remove(group);
     }
 
     // and finally, save the data
-    foreach(QString group, groupState.keys()) {
+    for (const QString &group : groupState.keys()) {
         QString groupBase = o->mapPut(base + ".group-state", group);
         o->setOption(groupBase + ".open", groupState[group].open);
         o->setOption(groupBase + ".rank", groupState[group].rank);
@@ -460,7 +432,10 @@ void UserAccount::toOptions(OptionsTree *o, QString base)
 
     o->setOption(base + ".proxy-id", proxyID);
 
-    keybind.toOptions(o, base + ".pgp-key-bindings");
+    pgpKnownKeys.toOptions(o, base + ".pgp-key-bindings");
+    o->setOption(base + ".pgp-enabled-chats", pgpEnabledChats);
+    o->setOption(base + ".pgp-disabled-chats", pgpDisabledChats);
+
     o->setOption(base + ".bytestreams-proxy", dtProxy.full());
     o->setOption(base + ".ibb-only", ibbOnly);
 
@@ -468,6 +443,7 @@ void UserAccount::toOptions(OptionsTree *o, QString base)
     o->setOption(base + ".stun-host", stunHost);
     o->setOption(base + ".stun-username", stunUser);
     o->setOption(base + ".stun-password", stunPass);
+    o->setOption(base + ".stun-onlymyturn", onlyMyTurn);
 
     o->setOption(base + ".tls.override-certificate", tlsOverrideCert);
     o->setOption(base + ".tls.override-domain", tlsOverrideDomain);
@@ -483,17 +459,15 @@ int UserAccount::defaultPriority(const XMPP::Status &s)
     if (priority_dep_on_status) {
         if (s.isAvailable()) {
             return PsiOptions::instance()->getOption("options.status.default-priority." + s.typeString()).toInt();
+        } else {
+            return 0; // Priority for Offline status, it is not used
         }
-        else {
-            return 0; //Priority for Offline status, it is not used
-        }
-    }
-    else {
+    } else {
         return priority;
     }
 }
 
-void UserAccount::saveLastStatus(OptionsTree *o, QString base=QString())
+void UserAccount::saveLastStatus(OptionsTree *o, QString base = QString())
 {
     if (base.isEmpty()) {
         base = optionsBase;
@@ -504,8 +478,7 @@ void UserAccount::saveLastStatus(OptionsTree *o, QString base=QString())
     o->setOption(base + ".last-with-priority", lastStatusWithPriority);
     if (lastStatusWithPriority) {
         o->setOption(base + ".last-priority", lastStatus.priority());
-    }
-    else {
+    } else {
         o->removeOption(base + ".last-priority");
     }
 }
@@ -516,21 +489,31 @@ void OptionsMigration::lateMigration()
     if (PsiOptions::instance()->getOption("options.ui.contactlist.toolbars.m0.name").toString() != "Chat") {
         QStringList pluginsKeys;
 #ifdef PSI_PLUGINS
-        PluginManager *pm = PluginManager::instance();
-        QStringList plugins = pm->availablePlugins();
-        foreach (const QString &plugin, plugins) {
-            pluginsKeys << pm->shortName(plugin) + "-plugin";
+        PluginManager *pm      = PluginManager::instance();
+        QStringList    plugins = pm->availablePlugins();
+        for (const QString &plugin : plugins) {
+            pluginsKeys << plugin + "-plugin";
         }
 #endif
         ToolbarPrefs chatToolbar;
         chatToolbar.on = PsiOptions::instance()->getOption("options.ui.chat.central-toolbar").toBool();
         PsiOptions::instance()->removeOption("options.ui.chat.central-toolbar");
         chatToolbar.name = "Chat";
-        chatToolbar.keys << "chat_clear"  << "chat_find" << "chat_html_text" << "chat_add_contact";
+        chatToolbar.keys << "chat_clear"
+                         << "chat_find"
+                         << "chat_html_text"
+                         << "chat_add_contact"
+                         << "chat_share_files";
         chatToolbar.keys += pluginsKeys;
-        chatToolbar.keys << "spacer" << "chat_icon" << "chat_file"
-                         << "chat_pgp" << "chat_info" << "chat_history" << "chat_voice"
-                         << "chat_active_contacts" << "chat_templates";
+        chatToolbar.keys << "spacer"
+                         << "chat_icon"
+                         << "chat_file"
+                         << "chat_pgp"
+                         << "chat_info"
+                         << "chat_history"
+                         << "chat_voice"
+                         << "chat_active_contacts"
+                         << "chat_templates";
 
         if (PsiOptions::instance()->getOption("options.ui.chat.disable-paste-send").toBool()) {
             chatToolbar.keys.removeAt(chatToolbar.keys.indexOf("chat_ps"));
@@ -540,10 +523,16 @@ void OptionsMigration::lateMigration()
         groupchatToolbar.on = chatToolbar.on;
 
         groupchatToolbar.name = "Groupchat";
-        groupchatToolbar.keys << "gchat_clear"  << "gchat_find" << "gchat_html_text" <<
-                                 "gchat_configure" << "gchat_templates";
+        groupchatToolbar.keys << "gchat_info"
+                              << "gchat_clear"
+                              << "gchat_find"
+                              << "gchat_html_text"
+                              << "gchat_configure"
+                              << "gchat_share_files"
+                              << "gchat_templates";
         groupchatToolbar.keys += pluginsKeys;
-        groupchatToolbar.keys << "spacer" << "gchat_icon" ;
+        groupchatToolbar.keys << "spacer"
+                              << "gchat_icon";
 
         if (PsiOptions::instance()->getOption("options.ui.chat.disable-paste-send").toBool()) {
             groupchatToolbar.keys.removeAt(groupchatToolbar.keys.indexOf("gchat_ps"));
@@ -551,31 +540,31 @@ void OptionsMigration::lateMigration()
         PsiOptions::instance()->removeOption("options.ui.chat.disable-paste-send");
 
         QList<ToolbarPrefs> toolbars;
-        toolbars << chatToolbar
-                 << groupchatToolbar;
+        toolbars << chatToolbar << groupchatToolbar;
 
-        QStringList toolbarBases = PsiOptions::instance()->getChildOptionNames("options.ui.contactlist.toolbars", true, true);
-        foreach(QString base, toolbarBases) {
+        QStringList toolbarBases
+            = PsiOptions::instance()->getChildOptionNames("options.ui.contactlist.toolbars", true, true);
+        for (const QString &base : toolbarBases) {
             ToolbarPrefs tb;
-            tb.id = PsiOptions::instance()->getOption(base + ".key").toString();
+            tb.id   = PsiOptions::instance()->getOption(base + ".key").toString();
             tb.name = PsiOptions::instance()->getOption(base + ".name").toString();
             if (tb.id.isEmpty() || tb.name.isEmpty()) {
                 qDebug("Does not look like a toolbar");
                 continue;
             }
 
-            tb.on = PsiOptions::instance()->getOption(base + ".visible").toBool();
+            tb.on     = PsiOptions::instance()->getOption(base + ".visible").toBool();
             tb.locked = PsiOptions::instance()->getOption(base + ".locked").toBool();
-            tb.dock = Qt3Dock(PsiOptions::instance()->getOption(base + ".dock.position").toInt()); //FIXME
-            tb.nl = PsiOptions::instance()->getOption(base + ".dock.nl").toBool();
-            tb.keys = PsiOptions::instance()->getOption(base + ".actions").toStringList();
+            tb.dock   = Qt3Dock(PsiOptions::instance()->getOption(base + ".dock.position").toInt()); // FIXME
+            tb.nl     = PsiOptions::instance()->getOption(base + ".dock.nl").toBool();
+            tb.keys   = PsiOptions::instance()->getOption(base + ".actions").toStringList();
 
             toolbars << tb;
         }
 
         PsiOptions::instance()->removeOption("options.ui.contactlist.toolbars", true);
 
-        foreach(ToolbarPrefs tb, toolbars) {
+        for (ToolbarPrefs tb : toolbars) {
             tb.locked = true;
             PsiToolBar::structToOptions(PsiOptions::instance(), tb);
         }
@@ -588,13 +577,13 @@ void OptionsMigration::lateMigration()
     }
 
     // avoid duplicating Esc for hide and close
-    auto hideKS = ShortcutManager::readShortcutsFromOptions("common.hide", PsiOptions::instance());
-    auto closeKS = ShortcutManager::readShortcutsFromOptions("common.close", PsiOptions::instance());
+    auto         hideKS  = ShortcutManager::readShortcutsFromOptions("common.hide", PsiOptions::instance());
+    auto         closeKS = ShortcutManager::readShortcutsFromOptions("common.close", PsiOptions::instance());
     QKeySequence escKS(Qt::Key_Escape);
     if (hideKS.contains(escKS) && closeKS.contains(escKS)) {
         closeKS.removeAll(escKS);
         QVariantList vl;
-        foreach (auto &ks, closeKS) {
+        for (auto &ks : closeKS) {
             vl.append(QVariant::fromValue(ks));
         }
 
@@ -602,7 +591,6 @@ void OptionsMigration::lateMigration()
     }
 }
 
-
 QString pathToProfile(const QString &name, ApplicationInfo::HomedirType type)
 {
     return ApplicationInfo::profilesDir(type) + "/" + name;
@@ -618,15 +606,15 @@ QStringList getProfilesList()
     QStringList list;
 
     QDir d(ApplicationInfo::profilesDir(ApplicationInfo::ConfigLocation));
-    if(!d.exists())
+    if (!d.exists())
         return list;
 
     QStringList entries = d.entryList();
-    for(QStringList::Iterator it = entries.begin(); it != entries.end(); ++it) {
-        if(*it == "." || *it == "..")
+    for (QStringList::Iterator it = entries.begin(); it != entries.end(); ++it) {
+        if (*it == "." || *it == "..")
             continue;
         QFileInfo info(d, *it);
-        if(!info.isDir())
+        if (!info.isDir())
             continue;
 
         list.append(*it);
@@ -642,8 +630,8 @@ bool profileExists(const QString &_name)
     QString name = _name.toLower();
 
     QStringList list = getProfilesList();
-    for(QStringList::ConstIterator it = list.begin(); it != list.end(); ++it) {
-        if((*it).toLower() == name)
+    for (QStringList::ConstIterator it = list.begin(); it != list.end(); ++it) {
+        if ((*it).toLower() == name)
             return true;
     }
     return false;
@@ -651,42 +639,42 @@ bool profileExists(const QString &_name)
 
 bool profileNew(const QString &name)
 {
-    if(name.isEmpty())
+    if (name.isEmpty())
         return false;
 
     // verify the string is sane
-    for(int n = 0; n < int(name.length()); ++n) {
-        if(!name.at(n).isLetterOrNumber())
+    for (int n = 0; n < int(name.length()); ++n) {
+        if (!name.at(n).isLetterOrNumber())
             return false;
     }
 
     // make it
     QDir configProfilesDir(ApplicationInfo::profilesDir(ApplicationInfo::ConfigLocation));
-    if(!configProfilesDir.exists())
+    if (!configProfilesDir.exists())
         return false;
     QDir configCurrentProfileDir(configProfilesDir.path() + "/" + name);
-    if(!configCurrentProfileDir.exists()) {
+    if (!configCurrentProfileDir.exists()) {
         if (!configProfilesDir.mkdir(name))
-        return false;
+            return false;
     }
 
     QDir dataProfilesDir(ApplicationInfo::profilesDir(ApplicationInfo::DataLocation));
-    if(!dataProfilesDir.exists())
+    if (!dataProfilesDir.exists())
         return false;
     QDir dataCurrentProfileDir(dataProfilesDir.path() + "/" + name);
-    if(!dataCurrentProfileDir.exists()) {
+    if (!dataCurrentProfileDir.exists()) {
         if (!dataProfilesDir.mkdir(name))
-        return false;
+            return false;
     }
     dataCurrentProfileDir.mkdir("history");
 
     QDir cacheProfilesDir(ApplicationInfo::profilesDir(ApplicationInfo::CacheLocation));
-    if(!cacheProfilesDir.exists())
+    if (!cacheProfilesDir.exists())
         return false;
     QDir cacheCurrentProfileDir(cacheProfilesDir.path() + "/" + name);
-    if(!cacheCurrentProfileDir.exists()) {
+    if (!cacheCurrentProfileDir.exists()) {
         if (!cacheProfilesDir.mkdir(name))
-        return false;
+            return false;
     }
     cacheCurrentProfileDir.mkdir("vcard");
 
@@ -696,34 +684,33 @@ bool profileNew(const QString &name)
 bool profileRename(const QString &oldname, const QString &name)
 {
     // verify the string is sane
-    for(int n = 0; n < int(name.length()); ++n) {
-        if(!name.at(n).isLetterOrNumber())
+    for (int n = 0; n < int(name.length()); ++n) {
+        if (!name.at(n).isLetterOrNumber())
             return false;
     }
 
     // locate the folders
     QStringList paths;
     paths << ApplicationInfo::profilesDir(ApplicationInfo::ConfigLocation);
-    if(!paths.contains(ApplicationInfo::profilesDir(ApplicationInfo::DataLocation))) {
+    if (!paths.contains(ApplicationInfo::profilesDir(ApplicationInfo::DataLocation))) {
         paths << ApplicationInfo::profilesDir(ApplicationInfo::DataLocation);
     }
-    if(!paths.contains(ApplicationInfo::profilesDir(ApplicationInfo::CacheLocation))) {
+    if (!paths.contains(ApplicationInfo::profilesDir(ApplicationInfo::CacheLocation))) {
         paths << ApplicationInfo::profilesDir(ApplicationInfo::CacheLocation);
     }
 
-
     // First we need to check configDir for existing
     QDir configDir(paths[0]);
-    if(!configDir.exists())
+    if (!configDir.exists())
         return false;
 
     // and if all ok we may rename it.
-    foreach(QString path, paths) {
+    for (const QString &path : paths) {
         QDir d(path);
-        if(!d.exists() || !d.exists(oldname))
+        if (!d.exists() || !d.exists(oldname))
             continue;
 
-        if(!d.rename(oldname, name))
+        if (!d.rename(oldname, name))
             return false;
     }
     return true;
@@ -734,23 +721,22 @@ static bool folderRemove(const QDir &_d)
     QDir d = _d;
 
     QStringList entries = d.entryList();
-    for(QStringList::Iterator it = entries.begin(); it != entries.end(); ++it) {
-        if(*it == "." || *it == "..")
+    for (QStringList::Iterator it = entries.begin(); it != entries.end(); ++it) {
+        if (*it == "." || *it == "..")
             continue;
         QFileInfo info(d, *it);
-        if(info.isDir()) {
-            if(!folderRemove(QDir(info.filePath())))
+        if (info.isDir()) {
+            if (!folderRemove(QDir(info.filePath())))
                 return false;
-        }
-        else {
-            //printf("deleting [%s]\n", info.filePath().latin1());
+        } else {
+            // printf("deleting [%s]\n", info.filePath().latin1());
             d.remove(info.fileName());
         }
     }
     QString name = d.dirName();
-    if(!d.cdUp())
+    if (!d.cdUp())
         return false;
-    //printf("removing folder [%s]\n", d.filePath(name).latin1());
+    // printf("removing folder [%s]\n", d.filePath(name).latin1());
     d.rmdir(name);
 
     return true;
@@ -759,13 +745,13 @@ static bool folderRemove(const QDir &_d)
 bool profileDelete(const QStringList &paths)
 {
     bool ret = true;
-    foreach(QString path, paths) {
+    for (const QString &path : paths) {
         QDir d(path);
-        if(!d.exists())
+        if (!d.exists())
             continue;
 
         ret = folderRemove(QDir(path));
-        if(!ret) {
+        if (!ret) {
             break;
         }
     }
