@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -25,15 +24,14 @@
 
 class PsiCon;
 
-class PsiActionList : public MetaActionList
-{
+class PsiActionList : public MetaActionList {
 public:
     PsiActionList(PsiCon *psi);
     ~PsiActionList();
 
     enum ActionsType {
-        Actions_Common    = (1 << 0),
-        Actions_MainWin   = (1 << 1),
+        Actions_Common  = (1 << 0),
+        Actions_MainWin = (1 << 1),
         // Actions_Message   = (1 << 2),
         Actions_Chat      = (1 << 3),
         Actions_Groupchat = (1 << 4)
@@ -41,8 +39,9 @@ public:
 
 public:
     class Private;
+
 private:
     Private *d;
 };
 
-#endif
+#endif // PSIACTIONLIST_H
