@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -28,8 +27,7 @@
 
 class QEvent;
 
-class PsiApplication : public QApplication
-{
+class PsiApplication : public QApplication {
     Q_OBJECT
 public:
     PsiApplication(int &argc, char **argv, bool GUIenabled = true);
@@ -46,4 +44,4 @@ private:
     void init(bool GUIenabled);
 };
 
-#endif
+#endif // PSIAPPLICATION_H
