@@ -3,14 +3,13 @@
 
 #include "xmpp_caps.h"
 
-class PsiCapsRegistry : public XMPP::CapsRegistry
-{
+class PsiCapsRegistry : public XMPP::CapsRegistry {
     Q_OBJECT
 
 public:
-    PsiCapsRegistry(QObject *parent = 0);
+    PsiCapsRegistry(QObject *parent = nullptr);
 
-    void saveData(const QByteArray &data);
+    void       saveData(const QByteArray &data);
     QByteArray loadData();
 };
 
