@@ -13,52 +13,40 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "psicontact.h"
 
-#include <QFileDialog>
-#include <QTimer>
-
+#include "alertable.h"
 #include "avatars.h"
 #include "common.h"
+#include "desktoputil.h"
 #include "iconset.h"
 #include "jidutil.h"
 #include "profiles.h"
 #include "psiaccount.h"
+#include "psicon.h"
+#include "psicontactlist.h"
 #include "psicontactmenu.h"
 #include "psiiconset.h"
 #include "psioptions.h"
-#include "userlist.h"
-#include "userlist.h"
-#include "alertable.h"
-#include "avatars.h"
 #include "psiprivacymanager.h"
-#include "desktoputil.h"
+#include "userlist.h"
 #include "vcardfactory.h"
-#include "psicon.h"
-#include "psicontactlist.h"
+
+#include <QFileDialog>
+#include <QTimer>
 
 #define STATUS_TIMER_INTERVAL 5000
 #define ANIM_TIMER_INTERVAL 5000
 
-class PsiContact::Private : public Alertable
-{
+class PsiContact::Private : public Alertable {
 public:
-    Private(PsiContact* contact)
-        : Alertable()
-        , q(contact)
-        , account_(0)
-        , statusTimer_(nullptr)
-        , animTimer_(nullptr)
-        , oldStatus_(XMPP::Status::Offline)
-        , isValid_(true)
-        , isAnimated_(false)
-        , isAlwaysVisible_(false)
-        , isSelf(false)
+    Private(PsiContact *contact) :
+        Alertable(), q(contact), account_(nullptr), statusTimer_(nullptr), animTimer_(nullptr),
+        oldStatus_(XMPP::Status::Offline), isValid_(true), isAnimated_(false), isAlwaysVisible_(false), isSelf(false)
     {
     }
 
@@ -68,20 +56,20 @@ public:
         delete animTimer_;
     }
 
-    PsiContact* q;
-    PsiAccount* account_;
-    QTimer* statusTimer_;
-    QTimer* animTimer_;
+    PsiContact * q;
+    PsiAccount * account_;
+    QTimer *     statusTimer_;
+    QTimer *     animTimer_;
     UserListItem u_;
-    QString name_;
-    Status status_;
-    Status oldStatus_;
-    bool isValid_;
-    bool isAnimated_;
-    bool isAlwaysVisible_;
-    bool isSelf;
+    QString      name_;
+    Status       status_;
+    Status       oldStatus_;
+    bool         isValid_;
+    bool         isAnimated_;
+    bool         isAlwaysVisible_;
+    bool         isSelf;
 
-    XMPP::Status status(const UserListItem& u) const
+    XMPP::Status status(const UserListItem &u) const
     {
         XMPP::Status status = XMPP::Status(XMPP::Status::Offline);
         if (u.priority() != u.userResourceList().end())
@@ -92,10 +80,7 @@ public:
     /**
      * Returns userHost of the base jid combined with \param resource.
      */
-    Jid jidForResource(const QString& resource)
-    {
-        return u_.jid().withResource(resource);
-    }
+    Jid jidForResource(const QString &resource) { return u_.jid().withResource(resource); }
 
     void setStatus(XMPP::Status status)
     {
@@ -118,7 +103,7 @@ public:
     {
         delete statusTimer_;
         statusTimer_ = nullptr;
-        oldStatus_ = status_;
+        oldStatus_   = status_;
         emit q->updated();
     }
 };
@@ -126,26 +111,24 @@ public:
 /**
  * Creates new PsiContact.
  */
-PsiContact::PsiContact(const UserListItem& u, PsiAccount* account, bool isSelf)
-    : QObject(account)
+PsiContact::PsiContact(const UserListItem &u, PsiAccount *account, bool isSelf) : QObject(account)
 {
-    d = new Private(this);
-    d->isSelf = isSelf;
+    d           = new Private(this);
+    d->isSelf   = isSelf;
     d->account_ = account;
     if (d->account_) {
-        connect(d->account_->avatarFactory(), SIGNAL(avatarChanged(const Jid&)), SLOT(avatarChanged(const Jid&)));
+        connect(d->account_->avatarFactory(), &AvatarFactory::avatarChanged, this, &PsiContact::avatarChanged);
     }
-    connect(VCardFactory::instance(), SIGNAL(vcardChanged(const Jid&)), SLOT(vcardChanged(const Jid&)));
+    connect(VCardFactory::instance(), &VCardFactory::vcardChanged, this, &PsiContact::vcardChanged);
     update(u);
 
     // updateParent();
 }
 
-PsiContact::PsiContact()
-    : QObject(0)
+PsiContact::PsiContact() : QObject(nullptr)
 {
-    d = new Private(this);
-    d->account_ = 0;
+    d           = new Private(this);
+    d->account_ = nullptr;
 }
 
 /**
@@ -161,28 +144,22 @@ PsiContact::~PsiContact()
 /**
  * Returns account to which a contact belongs.
  */
-PsiAccount* PsiContact::account() const
-{
-    return d->account_;
-}
+PsiAccount *PsiContact::account() const { return d->account_; }
 
 /**
  * TODO: Think of ways to remove this function.
  */
-const UserListItem& PsiContact::userListItem() const
-{
-    return d->u_;
-}
+const UserListItem &PsiContact::userListItem() const { return d->u_; }
 
 /**
  * This function should be called only by PsiAccount to update
  * PsiContact's current state.
  */
-void PsiContact::update(const UserListItem& u)
+void PsiContact::update(const UserListItem &u)
 {
     bool isGroupsChanged = u.groups() != d->u_.groups();
-    d->u_ = u;
-    Status status = d->status(d->u_);
+    d->u_                = u;
+    Status status        = d->status(d->u_);
 
     d->setStatus(status);
 
@@ -204,32 +181,30 @@ void PsiContact::activate()
 /**
  * Returns contact's display name.
  */
-const QString& PsiContact::name() const
+const QString &PsiContact::name() const
 {
     d->name_ = JIDUtil::nickOrJid(d->u_.name(), jid().full());
     return d->name_;
 }
 
-QString PsiContact::comparisonName() const
-{
-    return name() + jid().full() + account()->name();
-}
+QString PsiContact::comparisonName() const { return name() + jid().full() + account()->name(); }
 
 /**
  * Returns contact's XMPP address.
  */
-XMPP::Jid PsiContact::jid() const
+XMPP::Jid PsiContact::jid() const { return d->u_.jid(); }
+
+const Jid &PsiContact::realJid() const
 {
+    if (isPrivate() && d->status_.hasMUCItem() && d->status_.mucItem().jid().isValid())
+        return d->status_.mucItem().jid();
     return d->u_.jid();
 }
 
 /**
  * Returns contact's status.
  */
-Status PsiContact::status() const
-{
-    return d->status_;
-}
+Status PsiContact::status() const { return d->status_; }
 
 QString PsiContact::statusText() const
 {
@@ -242,10 +217,7 @@ QString PsiContact::statusText() const
 /**
  * Returns tool tip text for contact in HTML format.
  */
-QString PsiContact::toolTip() const
-{
-    return d->u_.makeTip(true, false);
-}
+QString PsiContact::toolTip() const { return d->u_.makeTip(true, false); }
 
 /**
  * Returns contact's avatar picture.
@@ -260,17 +232,14 @@ QIcon PsiContact::picture() const
 /**
  * Creates a menu with actions for this contact.
  */
-ContactListItemMenu* PsiContact::contextMenu(ContactListModel* model)
+ContactListItemMenu *PsiContact::contextMenu(ContactListModel *model)
 {
     if (!account())
-        return 0;
+        return nullptr;
     return new PsiContactMenu(this, model);
 }
 
-bool PsiContact::isFake() const
-{
-    return false;
-}
+bool PsiContact::isFake() const { return false; }
 
 /**
  * Returns true if user could modify (i.e. rename/change group/remove from
@@ -284,41 +253,26 @@ bool PsiContact::isEditable() const
     return account()->isAvailable() && inList();
 }
 
-bool PsiContact::isDragEnabled() const
-{
-    return isEditable()
-           && !isPrivate()
-           && !isAgent()
-           && !isConference();
-}
+bool PsiContact::isDragEnabled() const { return isEditable() && !isPrivate() && !isAgent() && !isConference(); }
 
 /**
  * This function should be invoked when contact is being renamed by
  * user. \param name specifies new name. PsiContact is responsible
  * for the actual roster update.
  */
-void PsiContact::setName(const QString& name)
+void PsiContact::setName(const QString &name)
 {
     if (account())
         account()->actionRename(jid(), name);
 }
 
-QString PsiContact::generalGroupName()
-{
-    return tr("General");
-}
+QString PsiContact::generalGroupName() { return tr("General"); }
 
-QString PsiContact::notInListGroupName()
-{
-    return tr("Not in list");
-}
+QString PsiContact::notInListGroupName() { return tr("Not in list"); }
 
-QString PsiContact::hiddenGroupName()
-{
-    return tr("Hidden");
-}
+QString PsiContact::hiddenGroupName() { return tr("Hidden"); }
 
-static const QString globalGroupDelimiter = "::";
+static const QString globalGroupDelimiter  = "::";
 static const QString accountGroupDelimiter = "::";
 
 /**
@@ -334,24 +288,22 @@ QStringList PsiContact::groups() const
 
     if (!inList()) {
         result << QString();
-    }
-    else if (d->u_.groups().isEmpty()) {
+    } else if (d->u_.groups().isEmpty()) {
         // empty group name means that the contact should be added
         // to the 'General' group or no group at all
-// #ifdef USE_GENERAL_CONTACT_GROUP
-//         result << generalGroupName();
-// #else
+        // #ifdef USE_GENERAL_CONTACT_GROUP
+        //         result << generalGroupName();
+        // #else
         result << QString();
-// #endif
-    }
-    else {
-        foreach(QString group, d->u_.groups()) {
+        // #endif
+    } else {
+        for (const QString &group : d->u_.groups()) {
             QString groupName = group.split(accountGroupDelimiter).join(globalGroupDelimiter);
-// #ifdef USE_GENERAL_CONTACT_GROUP
-//             if (groupName.isEmpty()) {
-//                 groupName = generalGroupName();
-//             }
-// #endif
+            // #ifdef USE_GENERAL_CONTACT_GROUP
+            //             if (groupName.isEmpty()) {
+            //                 groupName = generalGroupName();
+            //             }
+            // #endif
             if (!result.contains(groupName)) {
                 result << groupName;
             }
@@ -372,13 +324,13 @@ void PsiContact::setGroups(QStringList newGroups)
     if (!account())
         return;
     QStringList newAccountGroups;
-    foreach(QString group, newGroups) {
+    for (const QString &group : newGroups) {
         QString groupName = group.split(globalGroupDelimiter).join(accountGroupDelimiter);
-// #ifdef USE_GENERAL_CONTACT_GROUP
-//         if (groupName == generalGroupName()) {
-//             groupName = QString();
-//         }
-// #endif
+        // #ifdef USE_GENERAL_CONTACT_GROUP
+        //         if (groupName == generalGroupName()) {
+        //             groupName = QString();
+        //         }
+        // #endif
         newAccountGroups << groupName;
     }
 
@@ -388,7 +340,7 @@ void PsiContact::setGroups(QStringList newGroups)
     account()->actionGroupsSet(jid(), newAccountGroups);
 }
 
-bool PsiContact::groupOperationPermitted(const QString& oldGroupName, const QString& newGroupName) const
+bool PsiContact::groupOperationPermitted(const QString &oldGroupName, const QString &newGroupName) const
 {
     Q_UNUSED(oldGroupName);
     Q_UNUSED(newGroupName);
@@ -397,7 +349,7 @@ bool PsiContact::groupOperationPermitted(const QString& oldGroupName, const QStr
 
 bool PsiContact::isRemovable() const
 {
-    foreach(QString group, groups()) {
+    for (const QString &group : groups()) {
         if (!groupOperationPermitted(group, QString()))
             return false;
     }
@@ -407,13 +359,24 @@ bool PsiContact::isRemovable() const
     return account()->isAvailable();
 }
 
+bool PsiContact::canAddToRsoter() const
+{
+    if (isSelf() || inList() || PsiOptions::instance()->getOption("options.ui.contactlist.lockdown-roster").toBool()
+        || (isPrivate() && !(d->status_.hasMUCItem() && d->status_.mucItem().jid().isValid())))
+        return false;
+
+    if (!isPrivate()) // then what?
+        return true;
+
+    auto realContact = account()->findContact(d->status_.mucItem().jid().withResource(QString()));
+    Q_ASSERT(realContact != this);
+    return !realContact || realContact->canAddToRsoter();
+}
+
 /**
  * Returns true if contact currently have an alert set.
  */
-bool PsiContact::alerting() const
-{
-    return d->alerting();
-}
+bool PsiContact::alerting() const { return d->alerting(); }
 
 QIcon PsiContact::alertPicture() const
 {
@@ -426,7 +389,7 @@ QIcon PsiContact::alertPicture() const
 /**
  * Sets alert icon for contact. Pass null pointer in order to clear alert.
  */
-void PsiContact::setAlert(const PsiIcon* icon)
+void PsiContact::setAlert(const PsiIcon *icon)
 {
     d->setAlert(icon);
     // updateParent();
@@ -450,25 +413,22 @@ void PsiContact::startAnim()
 void PsiContact::stopAnim()
 {
     delete d->animTimer_;
-    d->animTimer_ = nullptr;
+    d->animTimer_  = nullptr;
     d->isAnimated_ = false;
     emit anim();
 }
 
-bool PsiContact::isAnimated() const
-{
-    return d->isAnimated_;
-}
+bool PsiContact::isAnimated() const { return d->isAnimated_; }
 
 /**
  * Returns true if there is opened chat with this contact
  */
 bool PsiContact::isActiveContact() const
 {
-    if(isConference()) {
+    if (isConference()) {
         return false;
     }
-    return account()->findChatDialog(jid(), isPrivate() ? true : false);
+    return bool(account()->findChatDialog(jid(), isPrivate()));
 }
 
 /**
@@ -484,10 +444,7 @@ bool PsiContact::shouldBeVisible() const
     return res;
 }
 
-bool PsiContact::isAlwaysVisible() const
-{
-    return d->isAlwaysVisible_;
-}
+bool PsiContact::isAlwaysVisible() const { return d->isAlwaysVisible_; }
 
 void PsiContact::setAlwaysVisible(bool visible)
 {
@@ -509,10 +466,7 @@ void PsiContact::setAlwaysVisible(bool visible)
  * if reimplemented in metacontact-enabled subclass, it could match
  * several different jids.
  */
-bool PsiContact::find(const Jid& jid) const
-{
-    return this->jid().compare(jid);
-}
+bool PsiContact::find(const Jid &jid) const { return this->jid().compare(jid); }
 
 /**
  * This behaves just like ContactListContact::contactList(), but statically
@@ -523,10 +477,7 @@ bool PsiContact::find(const Jid& jid) const
 //     return static_cast<PsiContactList*>(ContactListContact::contactList());
 // }
 
-const UserResourceList& PsiContact::userResourceList() const
-{
-    return d->u_.userResourceList();
-}
+const UserResourceList &PsiContact::userResourceList() const { return d->u_.userResourceList(); }
 
 void PsiContact::receiveIncomingEvent()
 {
@@ -587,7 +538,7 @@ void PsiContact::openActiveChat(QString resource)
 void PsiContact::sendFile()
 {
     if (account())
-        account()->actionSendFile(jid());
+        account()->sendFiles(jid());
 }
 
 void PsiContact::inviteToGroupchat(QString groupChat)
@@ -607,8 +558,8 @@ void PsiContact::toggleBlockedStateConfirmation()
     if (!account())
         return;
 
-    PsiPrivacyManager* privacyManager = dynamic_cast<PsiPrivacyManager*>(account()->privacyManager());
-    bool blocked = privacyManager->isContactBlocked(jid());
+    PsiPrivacyManager *privacyManager = dynamic_cast<PsiPrivacyManager *>(account()->privacyManager());
+    bool               blocked        = privacyManager->isContactBlocked(jid());
     blockContactConfirmationHelper(!blocked);
 }
 
@@ -617,16 +568,13 @@ void PsiContact::blockContactConfirmationHelper(bool block)
     if (!account())
         return;
 
-    PsiPrivacyManager* privacyManager = dynamic_cast<PsiPrivacyManager*>(account()->privacyManager());
+    PsiPrivacyManager *privacyManager = dynamic_cast<PsiPrivacyManager *>(account()->privacyManager());
     privacyManager->setContactBlocked(jid(), block);
 }
 
-void PsiContact::updateStatus()
-{
-    d->updateStatus();
-}
+void PsiContact::updateStatus() { d->updateStatus(); }
 
-void PsiContact::blockContactConfirmation(const QString& id, bool confirmed)
+void PsiContact::blockContactConfirmation(const QString &id, bool confirmed)
 {
     Q_ASSERT(id == "blockContact");
     Q_UNUSED(id);
@@ -646,10 +594,7 @@ void PsiContact::rerequestAuthorizationFrom()
         account()->dj_authReq(jid());
 }
 
-void PsiContact::removeAuthorizationFrom()
-{
-    qWarning("PsiContact::removeAuthorizationFrom()");
-}
+void PsiContact::removeAuthorizationFrom() { qWarning("PsiContact::removeAuthorizationFrom()"); }
 
 void PsiContact::remove()
 {
@@ -675,7 +620,8 @@ void PsiContact::history()
         account()->actionHistory(jid());
 }
 
-void PsiContact::addRemoveAuthBlockAvailable(bool* addButton, bool* deleteButton, bool* authButton, bool* blockButton) const
+void PsiContact::addRemoveAuthBlockAvailable(bool *addButton, bool *deleteButton, bool *authButton,
+                                             bool *blockButton) const
 {
     Q_ASSERT(addButton && deleteButton && authButton && blockButton);
     *addButton    = false;
@@ -686,21 +632,20 @@ void PsiContact::addRemoveAuthBlockAvailable(bool* addButton, bool* deleteButton
     *deleteButton = isRemovable();
 
     if (account() && account()->isAvailable() && !userListItem().isSelf()) {
-        UserListItem* u = account()->findFirstRelevant(jid());
+        UserListItem *u = account()->findFirstRelevant(jid());
 
         *blockButton = isEditable();
 
         if (!u || !u->inList()) {
-            *addButton   = isEditable();
-        }
-        else {
+            *addButton = isEditable();
+        } else {
             if (!authorizesToSeeStatus()) {
                 *authButton = isEditable();
             }
         }
 
-        PsiPrivacyManager* privacyManager = dynamic_cast<PsiPrivacyManager*>(account()->privacyManager());
-        if(privacyManager)
+        PsiPrivacyManager *privacyManager = dynamic_cast<PsiPrivacyManager *>(account()->privacyManager());
+        if (privacyManager)
             *blockButton = *blockButton && privacyManager->isAvailable();
     }
 }
@@ -733,19 +678,16 @@ bool PsiContact::blockAvailable() const
     return blockButton;
 }
 
-void PsiContact::avatarChanged(const Jid& j)
+void PsiContact::avatarChanged(const Jid &j)
 {
     if (!j.compare(jid(), false))
         return;
     emit updated();
 }
 
-void PsiContact::rereadVCard()
-{
-    vcardChanged(jid());
-}
+void PsiContact::rereadVCard() { vcardChanged(jid()); }
 
-void PsiContact::vcardChanged(const Jid& j)
+void PsiContact::vcardChanged(const Jid &j)
 {
     if (!j.compare(jid(), false))
         return;
@@ -753,7 +695,7 @@ void PsiContact::vcardChanged(const Jid& j)
     emit updated();
 }
 
-//bool PsiContact::compare(const ContactListItem* other) const
+// bool PsiContact::compare(const ContactListItem* other) const
 //{
 //    const ContactListGroup* group = dynamic_cast<const ContactListGroup*>(other);
 //    if (group) {
@@ -773,55 +715,34 @@ void PsiContact::vcardChanged(const Jid& j)
 
 bool PsiContact::isBlocked() const
 {
-    if(account()) {
-        PsiPrivacyManager* privacyManager = dynamic_cast<PsiPrivacyManager*>(account()->privacyManager());
+    if (account()) {
+        PsiPrivacyManager *privacyManager = dynamic_cast<PsiPrivacyManager *>(account()->privacyManager());
         return privacyManager->isContactBlocked(jid());
     }
     return false;
 }
 
-bool PsiContact::isSelf() const
-{
-    return d->isSelf;
-}
+bool PsiContact::isSelf() const { return d->isSelf; }
 
-bool PsiContact::isAgent() const
-{
-    return userListItem().isTransport();
-}
+bool PsiContact::isAgent() const { return userListItem().isTransport(); }
 
-bool PsiContact::isConference() const
-{
-    return userListItem().isConference();
-}
+bool PsiContact::isConference() const { return userListItem().isConference(); }
 
-bool PsiContact::inList() const
-{
-    return userListItem().inList();
-}
+bool PsiContact::inList() const { return userListItem().inList(); }
 
-bool PsiContact::isValid() const
-{
-    return d->isValid_;
-}
+bool PsiContact::isValid() const { return d->isValid_; }
 
-bool PsiContact::isPrivate() const
-{
-    return userListItem().isPrivate();
-}
+bool PsiContact::isPrivate() const { return userListItem().isPrivate(); }
 
-bool PsiContact::noGroups() const
-{
-    return userListItem().groups().isEmpty();
-}
+bool PsiContact::noGroups() const { return userListItem().groups().isEmpty(); }
 
 /*!
  * Returns true if contact could see our status.
  */
 bool PsiContact::authorized() const
 {
-    return userListItem().subscription().type() == Subscription::Both ||
-           userListItem().subscription().type() == Subscription::From;
+    return userListItem().subscription().type() == Subscription::Both
+        || userListItem().subscription().type() == Subscription::From;
 }
 
 /*!
@@ -829,28 +750,19 @@ bool PsiContact::authorized() const
  */
 bool PsiContact::authorizesToSeeStatus() const
 {
-    return userListItem().subscription().type() == Subscription::Both ||
-           userListItem().subscription().type() == Subscription::To;
+    return userListItem().subscription().type() == Subscription::Both
+        || userListItem().subscription().type() == Subscription::To;
 }
 
-bool PsiContact::askingForAuth() const
-{
-    return userListItem().ask() == "subscribe";
-}
+bool PsiContact::askingForAuth() const { return userListItem().ask() == "subscribe"; }
 
 bool PsiContact::isOnline() const
 {
-    if (!inList() ||
-        isPrivate())
-    {
+    if (!inList() || isPrivate()) {
         return true;
     }
 
-    return d->status_.type()    != XMPP::Status::Offline ||
-           d->oldStatus_.type() != XMPP::Status::Offline;
+    return d->status_.type() != XMPP::Status::Offline || d->oldStatus_.type() != XMPP::Status::Offline;
 }
 
-bool PsiContact::isHidden() const
-{
-    return userListItem().isHidden();
-}
+bool PsiContact::isHidden() const { return userListItem().isHidden(); }
