@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -25,15 +24,14 @@
 
 class PsiContact;
 
-class PsiContactMenu : public ContactListItemMenu
-{
+class PsiContactMenu : public ContactListItemMenu {
     Q_OBJECT
 public:
-    PsiContactMenu(PsiContact* contact, ContactListModel* model);
+    PsiContactMenu(PsiContact *contact, ContactListModel *model);
     ~PsiContactMenu();
 
     // reimplemented
-    virtual QList<QAction*> availableActions() const;
+    virtual QList<QAction *> availableActions() const;
 
 signals:
     void removeSelection();
@@ -42,7 +40,7 @@ signals:
 private:
     class Private;
     friend class Private;
-    Private* d;
+    Private *d;
 };
 
-#endif
+#endif // PSICONTACTMENU_H
