@@ -22,42 +22,35 @@
 #define PSIMEDIA_H
 
 #include <QMetaType>
+#include <QSharedDataPointer>
 #include <QSize>
 #include <QStringList>
-#include <QSharedDataPointer>
-
 #ifdef QT_GUI_LIB
 #include <QWidget>
 #endif
+#include <functional>
 
 class QMetaMethod;
 
 namespace PsiMedia {
-
+class RtpChannelPrivate;
 class RtpSession;
 class RtpSessionPrivate;
 class VideoWidgetPrivate;
-class RtpChannelPrivate;
+class Provider;
 
-enum PluginResult
-{
-    PluginSuccess,
-    ErrorLoad,
-    ErrorVersion,
-    ErrorInit
-};
+enum PluginResult { PluginSuccess, ErrorLoad, ErrorVersion, ErrorInit };
 
 bool isSupported();
-PluginResult loadPlugin(const QString &fname, const QString &resourcePath);
-void unloadPlugin();
+
 QString creditName();
 QString creditText();
 
-class Device
-{
+void setProvider(Provider *provider);
+
+class Device {
 public:
-    enum Type
-    {
+    enum Type {
         AudioOut, // speaker
         AudioIn,  // microphone
         VideoIn   // camera
@@ -66,13 +59,13 @@ public:
     Device();
     Device(const Device &other);
     ~Device();
-    Device & operator=(const Device &other);
+    Device &operator=(const Device &other);
 
-    bool isNull() const;
-    Type type() const;
+    bool    isNull() const;
+    Type    type() const;
     QString name() const;
     QString id() const;
-    bool isDefault() const;
+    bool    isDefault() const;
 
 private:
     class Private;
@@ -81,19 +74,18 @@ private:
 };
 
 #ifdef QT_GUI_LIB
-class VideoWidget : public QWidget
-{
+class VideoWidget : public QWidget {
     Q_OBJECT
 
 public:
-    VideoWidget(QWidget *parent = 0);
-    ~VideoWidget();
+    explicit VideoWidget(QWidget *parent = nullptr);
+    ~VideoWidget() override;
 
-    virtual QSize sizeHint() const;
+    QSize sizeHint() const override;
 
 protected:
-    virtual void paintEvent(QPaintEvent *event);
-    virtual void resizeEvent(QResizeEvent *event);
+    void paintEvent(QPaintEvent *event) override;
+    void resizeEvent(QResizeEvent *event) override;
 
 signals:
     // check the size hint after receiving this signal
@@ -108,18 +100,17 @@ private:
 };
 #endif
 
-class AudioParams
-{
+class AudioParams {
 public:
     AudioParams();
     AudioParams(const AudioParams &other);
     ~AudioParams();
-    AudioParams & operator=(const AudioParams &other);
+    AudioParams &operator=(const AudioParams &other);
 
     QString codec() const;
-    int sampleRate() const;
-    int sampleSize() const;
-    int channels() const;
+    int     sampleRate() const;
+    int     sampleSize() const;
+    int     channels() const;
     QString toString() const;
 
     void setCodec(const QString &s);
@@ -129,27 +120,23 @@ public:
 
     bool operator==(const AudioParams &other) const;
 
-    inline bool operator!=(const AudioParams &other) const
-    {
-        return !(*this == other);
-    }
+    inline bool operator!=(const AudioParams &other) const { return !(*this == other); }
 
 private:
     class Private;
     Private *d;
 };
 
-class VideoParams
-{
+class VideoParams {
 public:
     VideoParams();
     VideoParams(const VideoParams &other);
     ~VideoParams();
-    VideoParams & operator=(const VideoParams &other);
+    VideoParams &operator=(const VideoParams &other);
 
     QString codec() const;
-    QSize size() const;
-    int fps() const;
+    QSize   size() const;
+    int     fps() const;
     QString toString() const;
 
     void setCodec(const QString &s);
@@ -158,33 +145,23 @@ public:
 
     bool operator==(const VideoParams &other) const;
 
-    inline bool operator!=(const VideoParams &other) const
-    {
-        return !(*this == other);
-    }
+    inline bool operator!=(const VideoParams &other) const { return !(*this == other); }
 
 private:
     class Private;
     Private *d;
 };
 
-class Features : public QObject
-{
+class Features : public QObject {
     Q_OBJECT
 
 public:
-    enum Type
-    {
-        AudioOut   = 0x01,
-        AudioIn    = 0x02,
-        VideoIn    = 0x04,
-        AudioModes = 0x08,
-        VideoModes = 0x10,
-        All        = 0xff
-    };
+    enum Type { AudioOut = 0x01, AudioIn = 0x02, VideoIn = 0x04, AudioModes = 0x08, VideoModes = 0x10, All = 0xff };
 
-    Features(QObject *parent = 0);
-    ~Features();
+    explicit Features(QObject *parent = nullptr);
+    ~Features() override;
+
+    void setup();
 
     QList<Device> audioOutputDevices();
     QList<Device> audioInputDevices();
@@ -195,6 +172,7 @@ public:
 
 signals:
     void updated();
+    void availibityChanged();
 
 private:
     class Private;
@@ -202,19 +180,18 @@ private:
     Private *d;
 };
 
-class RtpPacket
-{
+class RtpPacket {
 public:
     RtpPacket();
     RtpPacket(const QByteArray &rawValue, int portOffset);
     RtpPacket(const RtpPacket &other);
     ~RtpPacket();
-    RtpPacket & operator=(const RtpPacket &other);
+    RtpPacket &operator=(const RtpPacket &other);
 
     bool isNull() const;
 
     QByteArray rawValue() const;
-    int portOffset() const;
+    int        portOffset() const;
 
 private:
     class Private;
@@ -223,26 +200,25 @@ private:
 
 // may drop packets if not read fast enough.
 // may queue no packets at all, if nobody is listening to readyRead.
-class RtpChannel : public QObject
-{
+class RtpChannel : public QObject {
     Q_OBJECT
 
 public:
-    int packetsAvailable() const;
+    int       packetsAvailable() const;
     RtpPacket read();
-    void write(const RtpPacket &rtp);
+    void      write(const RtpPacket &rtp);
 
 signals:
     void readyRead();
     void packetsWritten(int count);
 
 protected:
-    virtual void connectNotify(const QMetaMethod &signal) Q_DECL_OVERRIDE;
-    virtual void disconnectNotify(const QMetaMethod &signal) Q_DECL_OVERRIDE;
+    void connectNotify(const QMetaMethod &signal) Q_DECL_OVERRIDE;
+    void disconnectNotify(const QMetaMethod &signal) Q_DECL_OVERRIDE;
 
 private:
     RtpChannel();
-    ~RtpChannel();
+    ~RtpChannel() override;
     Q_DISABLE_COPY(RtpChannel)
 
     friend class RtpSession;
@@ -254,37 +230,32 @@ private:
 // this class essentially follows jingle's notion of payload information,
 //   though it's not really jingle-specific and should be usable for any RTP
 //   purpose
-class PayloadInfo
-{
+class PayloadInfo {
 public:
-    class Parameter
-    {
+    class Parameter {
     public:
         QString name;
         QString value;
 
         bool operator==(const Parameter &other) const;
 
-        inline bool operator!=(const Parameter &other) const
-        {
-            return !(*this == other);
-        }
+        inline bool operator!=(const Parameter &other) const { return !(*this == other); }
     };
 
     PayloadInfo();
     PayloadInfo(const PayloadInfo &other);
     ~PayloadInfo();
-    PayloadInfo & operator=(const PayloadInfo &other);
+    PayloadInfo &operator=(const PayloadInfo &other);
 
     bool isNull() const;
 
-    int id() const;
-    QString name() const;
-    int clockrate() const;
-    int channels() const;
-    int ptime() const;
-    int maxptime() const;
-    QList<Parameter> parameters() const;
+    int                     id() const;
+    QString                 name() const;
+    int                     clockrate() const;
+    int                     channels() const;
+    int                     ptime() const;
+    int                     maxptime() const;
+    const QList<Parameter> &parameters() const;
 
     void setId(int i);
     void setName(const QString &str);
@@ -296,30 +267,21 @@ public:
 
     bool operator==(const PayloadInfo &other) const;
 
-    inline bool operator!=(const PayloadInfo &other) const
-    {
-        return !(*this == other);
-    }
+    inline bool operator!=(const PayloadInfo &other) const { return !(*this == other); }
 
 private:
     class Private;
     Private *d;
 };
 
-class RtpSession : public QObject
-{
+class RtpSession : public QObject {
     Q_OBJECT
 
 public:
-    enum Error
-    {
-        ErrorGeneric,
-        ErrorSystem,
-        ErrorCodec
-    };
+    enum Error { ErrorGeneric, ErrorSystem, ErrorCodec };
 
-    RtpSession(QObject *parent = 0);
-    ~RtpSession();
+    explicit RtpSession(QObject *parent = nullptr);
+    ~RtpSession() override;
 
     void reset();
 
@@ -474,11 +436,11 @@ public:
     bool canTransmitVideo() const;
 
     // speaker
-    int outputVolume() const; // 0 (mute) to 100
+    int  outputVolume() const; // 0 (mute) to 100
     void setOutputVolume(int level);
 
     // microphone
-    int inputVolume() const; // 0 (mute) to 100
+    int  inputVolume() const; // 0 (mute) to 100
     void setInputVolume(int level);
 
     Error errorCode() const;
@@ -490,7 +452,7 @@ signals:
     void started();
     void preferencesUpdated();
     void audioOutputIntensityChanged(int intensity); // 0-100, -1 for no signal
-    void audioInputIntensityChanged(int intensity); // 0-100
+    void audioInputIntensityChanged(int intensity);  // 0-100
     void stoppedRecording();
     void stopped();
     void finished(); // for file playback only
@@ -502,10 +464,9 @@ private:
     friend class RtpSessionPrivate;
     RtpSessionPrivate *d;
 };
-
-}
+}; // namespace PsiMedia
 
 Q_DECLARE_METATYPE(PsiMedia::AudioParams)
 Q_DECLARE_METATYPE(PsiMedia::VideoParams)
 
-#endif
+#endif // PSIMEDIA_H
