@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -23,21 +22,20 @@
 
 #include "psicontact.h"
 
-class PsiSelfContact : public PsiContact
-{
+class PsiSelfContact : public PsiContact {
 public:
-    PsiSelfContact(const UserListItem& u, PsiAccount* parent);
+    PsiSelfContact(const UserListItem &u, PsiAccount *parent);
 
-    void update(const UserListItem& u);
+    void update(const UserListItem &u);
 
     // reimplemented
-    virtual ContactListItemMenu* contextMenu();
-    virtual bool isEditable() const;
-    virtual bool isSelf() const;
+    virtual ContactListItemMenu *contextMenu();
+    virtual bool                 isEditable() const;
+    virtual bool                 isSelf() const;
 
 protected:
     // reimplemented
     virtual bool shouldBeVisible() const;
 };
 
-#endif
+#endif // PSISELFCONTACT_H
