@@ -1,6 +1,6 @@
 /*
  * psithememanager.h - manages all themes in psi
- * Copyright (C) 2010 Rion (Sergey Ilinyh)
+ * Copyright (C) 2010  Sergey Ilinykh
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -13,39 +13,33 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef PSITHEMEMANAGER_H
 #define PSITHEMEMANAGER_H
 
-#include <QObject>
-
 #include "psithemeprovider.h"
 
-//class ChatViewTheme;
+#include <QObject>
+
+// class ChatViewTheme;
 
 class PsiThemeManager : public QObject {
     Q_OBJECT
 public:
-    static PsiThemeManager* instance();
-
-    void registerProvider(PsiThemeProvider *provider, bool required = false);
-    PsiThemeProvider *provider(const QString &type);
-    QList<PsiThemeProvider *> registeredProviders() const;
-    bool loadAll();
-
-private:
-    PsiThemeManager();
+    PsiThemeManager(QObject *parent);
     ~PsiThemeManager();
 
-    static PsiThemeManager* instance_;
+    void                      registerProvider(PsiThemeProvider *provider, bool required = false);
+    PsiThemeProvider *        unregisterProvider(const QString &type);
+    PsiThemeProvider *        provider(const QString &type);
+    QList<PsiThemeProvider *> registeredProviders() const;
+    bool                      loadAll();
 
     class Private;
     Private *d;
 };
 
-
-#endif
+#endif // PSITHEMEMANAGER_H
