@@ -1,6 +1,6 @@
 /*
  * psithememodel.h - just a model for theme views
- * Copyright (C) 2010-2017 Sergey Ilinykh
+ * Copyright (C) 2010-2017  Sergey Ilinykh
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -25,56 +24,52 @@
 #include <QFutureWatcher>
 #include <QStringList>
 
+class PsiThemeProvider;
 class Theme;
 
-struct ThemeItemInfo
-{
-    QString id;
-    QString title;
-    QString version;
-    QString description;
+struct ThemeItemInfo {
+    QString     id;
+    QString     title;
+    QString     version;
+    QString     description;
     QStringList authors;
-    QString creation;
-    QString homeUrl;
+    QString     creation;
+    QString     homeUrl;
 
     bool hasPreview;
-    bool isValid = false;
+    bool isValid   = false;
     bool isCurrent = false;
 };
 
-
-class PsiThemeModel : public QAbstractListModel
-{
+class PsiThemeModel : public QAbstractListModel {
     Q_OBJECT
 
 public:
-    enum ThemeRoles {
-        IdRole = Qt::UserRole + 1,
-        HasPreviewRole,
-        TitleRole,
-        IsCurrent
-    };
+    enum ThemeRoles { IdRole = Qt::UserRole + 1, HasPreviewRole, TitleRole, IsCurrent };
 
-    PsiThemeModel(QObject *parent);
+    PsiThemeModel(PsiThemeProvider *provider, QObject *parent);
     ~PsiThemeModel();
-    void setType(const QString &type);
 
-    int rowCount ( const QModelIndex & parent = QModelIndex() ) const ;
-    QVariant data ( const QModelIndex & index, int role = Qt::DisplayRole ) const;
-    int themeRow(const QString &id);
+    int      rowCount(const QModelIndex &parent = QModelIndex()) const;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    int      themeRow(const QString &id);
 
     bool setData(const QModelIndex &index, const QVariant &value, int role);
+
+public slots:
+    void load();
+
 private slots:
     void onThreadedResultReadyAt(int index);
     void loadComplete();
 
 private:
     struct Loader;
-    Loader *loader = nullptr;
+    Loader *                      loader   = nullptr;
+    PsiThemeProvider *            provider = nullptr;
     QFutureWatcher<ThemeItemInfo> themeWatcher;
-    QFuture<ThemeItemInfo> themesFuture;
-    QList<ThemeItemInfo> themesInfo;
-    QString providerType;
+    QFuture<ThemeItemInfo>        themesFuture;
+    QList<ThemeItemInfo>          themesInfo;
 };
 
-#endif
+#endif // PSITHEMEMODEL_H
