@@ -13,47 +13,44 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef PSITOOLBAR_H
 #define PSITOOLBAR_H
 
-#include <QToolBar>
-
-class QContextMenuEvent;
-
-class ToolbarPrefs;
-class PsiOptions;
-
 #include "psiactionlist.h"
 
-class PsiToolBar : public QToolBar
-{
+#include <QToolBar>
+
+class PsiOptions;
+class QContextMenuEvent;
+class ToolbarPrefs;
+
+class PsiToolBar : public QToolBar {
     Q_OBJECT
 
 public:
-    PsiToolBar(const QString& base, QWidget* mainWindow, MetaActionList* actionList);
+    PsiToolBar(const QString &base, QWidget *mainWindow, MetaActionList *actionList);
     ~PsiToolBar();
 
-    void initialize();
-    void updateVisibility();
+    void    initialize();
+    void    updateVisibility();
     QString base() const;
 
-    static void structToOptions(PsiOptions* options, const ToolbarPrefs& s);
+    static void structToOptions(PsiOptions *options, const ToolbarPrefs &s);
 
 signals:
     void customize();
 
 protected:
-    void contextMenuEvent(QContextMenuEvent* e);
+    void contextMenuEvent(QContextMenuEvent *e);
 
 private:
-    MetaActionList* actionList_;
-    QAction* customizeAction_;
-    QString base_;
+    MetaActionList *actionList_;
+    QAction *       customizeAction_;
+    QString         base_;
 };
 
-#endif
+#endif // PSITOOLBAR_H
