@@ -13,28 +13,26 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef RESOURCEMENU_H
 #define RESOURCEMENU_H
 
+#include "xmpp_jid.h"
+
 #include <QMenu>
 #include <QPointer>
 
-class UserResource;
 class PsiContact;
+class UserResource;
 
-#include "xmpp_jid.h"
-
-class ResourceMenu : public QMenu
-{
+class ResourceMenu : public QMenu {
     Q_OBJECT
 public:
     ResourceMenu(QWidget *parent);
-    ResourceMenu(const QString& title, PsiContact* contact, QWidget* parent);
+    ResourceMenu(const QString &title, PsiContact *contact, QWidget *parent);
 
     bool activeChatsMode() const;
     void setActiveChatsMode(bool activeChatsMode);
@@ -43,7 +41,7 @@ public:
     void addResource(int status, QString name);
 
 signals:
-    void resourceActivated(PsiContact* contact, const XMPP::Jid& jid);
+    void resourceActivated(PsiContact *contact, const XMPP::Jid &jid);
     void resourceActivated(QString resource);
 
 private slots:
@@ -52,7 +50,7 @@ private slots:
 
 private:
     QPointer<PsiContact> contact_;
-    bool activeChatsMode_;
+    bool                 activeChatsMode_;
 };
 
-#endif
+#endif // RESOURCEMENU_H
