@@ -13,36 +13,34 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef ROSTERITEMEXCHANGETASK_H
 #define ROSTERITEMEXCHANGETASK_H
 
-#include <QDomElement>
-
-#include "xmpp_task.h"
 #include "xmpp_rosterx.h"
+#include "xmpp_task.h"
+
+#include <QDomElement>
 
 using namespace XMPP;
 
-class RosterItemExchangeTask : public Task
-{
+class RosterItemExchangeTask : public Task {
     Q_OBJECT
 
 public:
-    RosterItemExchangeTask(Task*);
+    RosterItemExchangeTask(Task *);
 
-    bool take(const QDomElement&);
+    bool take(const QDomElement &);
     void setIgnoreNonRoster(bool);
 
 signals:
-    void rosterItemExchange(const Jid&, const RosterExchangeItems&);
+    void rosterItemExchange(const Jid &, const RosterExchangeItems &);
 
 private:
     bool ignoreNonRoster_;
 };
 
-#endif
+#endif // ROSTERITEMEXCHANGETASK_H
