@@ -4,27 +4,25 @@
 #include <QDialog>
 #include <QMenu>
 #include <QPointer>
-#include <QSignalMapper>
 
 #include "ui_sendbuttontemplateseditor.h"
 
-class SendButtonTemplatesEditor : public QDialog
-{
+class SendButtonTemplatesEditor : public QDialog {
     Q_OBJECT
 public:
-    SendButtonTemplatesEditor(QWidget* parent = 0);
+    SendButtonTemplatesEditor(QWidget *parent = nullptr);
 
 private:
     Ui::SendButtonTemplatesEditor ui_;
-    //QString t;
-    QAction *addChildTemplAction;
-    QAction *addChildSeparatorAction;
-    QAction *editAction;
-    QAction *removeAction;
-    QAction *upAction;
-    QAction *downAction;
-    void swapItem(int);
-    QStringList genTemplatesList(QTreeWidgetItem* item, QString base_path = "");
+    // QString t;
+    QAction *   addChildTemplAction;
+    QAction *   addChildSeparatorAction;
+    QAction *   editAction;
+    QAction *   removeAction;
+    QAction *   upAction;
+    QAction *   downAction;
+    void        swapItem(int);
+    QStringList genTemplatesList(QTreeWidgetItem *item, QString base_path = "");
 
 private slots:
     void addRootTemplate();
@@ -41,37 +39,33 @@ private slots:
 protected slots:
     void accept();
     void reject();
-
 };
 
-class SendButtonTemplatesMenu : public QMenu
-{
+class SendButtonTemplatesMenu : public QMenu {
     Q_OBJECT
 public:
-    SendButtonTemplatesMenu(QWidget* parent);
-    void setParams(bool ps);
+    SendButtonTemplatesMenu(QWidget *parent);
+    void               setParams(bool ps);
     static QStringList getMenuItems(const QString);
-    static QString addSlashes(QString);
-    static QString stripSlashes(QString);
+    static QString     addSlashes(QString);
+    static QString     stripSlashes(QString);
 
 private:
-    QSignalMapper *mapper;
-    bool ps_;
+    bool     ps_;
     QAction *pasteSendAct;
     QAction *onlyPaste;
-    void updatePsAction();
+    void     updatePsAction();
     QAction *makeAction(const QString);
 
 private slots:
     void update();
     void clickOnlyPaste();
-    void optionChanged(const QString& option);
+    void optionChanged(const QString &option);
 
 signals:
     void doPasteAndSend();
     void doEditTemplates();
     void doTemplateText(const QString &);
-
 };
 
 #endif
