@@ -13,25 +13,23 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef STATUSCOMBOBOX_H
 #define STATUSCOMBOBOX_H
 
-#include <QComboBox>
-
 #include "xmpp_status.h"
 
-class StatusComboBox : public QComboBox
-{
+#include <QComboBox>
+
+class StatusComboBox : public QComboBox {
     Q_OBJECT
 public:
-    StatusComboBox(QWidget* parent, XMPP::Status::Type type = XMPP::Status::Offline);
+    StatusComboBox(QWidget *parent, XMPP::Status::Type type = XMPP::Status::Offline);
 
-    void setStatus(XMPP::Status::Type type);
+    void               setStatus(XMPP::Status::Type type);
     XMPP::Status::Type status() const;
 
 signals:
@@ -44,4 +42,4 @@ private slots:
     void onCurrentIndexChanged(int);
 };
 
-#endif
+#endif // STATUSCOMBOBOX_H
