@@ -1,6 +1,6 @@
 /*
  * statusdlg.h - dialogs for setting and reading status messages
- * Copyright (C) 2001, 2002  Justin Karneges
+ * Copyright (C) 2001-2002  Justin Karneges
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -13,40 +13,37 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef STATUSDLG_H
 #define STATUSDLG_H
 
-#include <QDialog>
-
-#include <QList>
 #include "xmpp_jid.h"
 
-class PsiCon;
-class PsiAccount;
-class UserListItem;
-class QKeyEvent;
-namespace XMPP {
-    class Status;
-}
+#include <QDialog>
+#include <QList>
 
+class PsiAccount;
+class PsiCon;
+class QKeyEvent;
+class UserListItem;
+
+namespace XMPP {
+class Status;
+}
 using namespace XMPP;
 
-enum setStatusEnum {setStatusForAccount = 0, setStatusForJid, setStatusForJidList};
+enum setStatusEnum { setStatusForAccount = 0, setStatusForJid, setStatusForJidList };
 
-class StatusShowDlg : public QDialog
-{
+class StatusShowDlg : public QDialog {
     Q_OBJECT
 public:
     StatusShowDlg(const UserListItem &);
 };
 
-class StatusSetDlg : public QDialog
-{
+class StatusSetDlg : public QDialog {
     Q_OBJECT
 public:
     StatusSetDlg(PsiCon *, const Status &, bool withPriority = true);
@@ -75,4 +72,4 @@ private:
     void init();
 };
 
-#endif
+#endif // STATUSDLG_H
