@@ -13,46 +13,45 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef THEME_P_H
 #define THEME_P_H
 
-#include <QSharedData>
 #include "theme.h"
 
+#include <QSharedData>
+
 class QWidget;
 
-class ThemePrivate : public QSharedData
-{
+class ThemePrivate : public QSharedData {
 public:
     PsiThemeProvider *provider;
-    Theme::State state = Theme::State::NotLoaded;
+    Theme::State      state = Theme::State::NotLoaded;
 
     // metadata
-    QString id, name, version, description, creation, homeUrl;
-    QStringList authors;
+    QString                 id, name, version, description, creation, homeUrl;
+    QStringList             authors;
     QHash<QString, QString> info;
 
     // runtime info
     QString filepath;
-    bool caseInsensitiveFS;
+    bool    caseInsensitiveFS;
 
 public:
     ThemePrivate(PsiThemeProvider *provider);
     virtual ~ThemePrivate();
 
     virtual bool exists() = 0;
-    virtual bool load(); // synchronous load
-    virtual bool load(std::function<void(bool)> loadCallback);  // asynchronous load
+    virtual bool load();                                       // synchronous load
+    virtual bool load(std::function<void(bool)> loadCallback); // asynchronous load
 
-    virtual bool hasPreview() const;
-    virtual QWidget* previewWidget(); // this hack must be replaced with something widget based
+    virtual bool     hasPreview() const;
+    virtual QWidget *previewWidget(); // this hack must be replaced with something widget based
 
-    QByteArray loadData(const QString &fileName, bool *loaded = NULL) const;
+    QByteArray             loadData(const QString &fileName, bool *loaded = nullptr) const;
     Theme::ResourceLoader *resourceLoader() const;
 };
 
