@@ -1,7 +1,7 @@
 /*
  * crash.c - handle psi's crashes
  *
- * Copyright (C) 2004 by Juan F. Codagnone <juam@users.sourceforge.net>
+ * Copyright (C) 2004  Juan F. Codagnone <juam@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,19 +14,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
-#include <signal.h>
 #include "crash.h"
+
 #include "crash_sigsegv.h"
 
+#include <signal.h>
+
 namespace Crash {
-
-void registerSigsegvHandler(QString)
-{
-    signal(SIGSEGV, sigsegv_handler_bt_full_fnc);
-}
-
+void registerSigsegvHandler(QString) { signal(SIGSEGV, sigsegv_handler_bt_full_fnc); }
 }; // namespace Crash
