@@ -13,47 +13,39 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "optionstree.h"
 
-#include <QDomElement>
-#include <QDomDocument>
-#include <QStringList>
-
 #include "atomicxmlfile/atomicxmlfile.h"
 #include "optionstreereader.h"
 #include "optionstreewriter.h"
 
+#include <QDomDocument>
+#include <QDomElement>
+#include <QStringList>
+
 /**
  * Default constructor
  */
-OptionsTree::OptionsTree(QObject *parent)
-    : QObject(parent)
-{
-
-}
+OptionsTree::OptionsTree(QObject *parent) : QObject(parent) { }
 
 /**
  * Destructor
  */
-OptionsTree::~OptionsTree()
-{
-
-}
+OptionsTree::~OptionsTree() { }
 
 /**
  * Returns the value of the specified option
  * \param name 'Path' to the option ("appearance.emoticons.useSmilies")
  * \return value of the option. Will be invalid if non-existent.
  */
-QVariant OptionsTree::getOption(const QString& name, const QVariant &defaultValue) const
+QVariant OptionsTree::getOption(const QString &name, const QVariant &defaultValue) const
 {
-    QVariant value=tree_.getValue(name);
-    if (value==VariantTree::missingValue) {
+    QVariant value = tree_.getValue(name);
+    if (value == VariantTree::missingValue) {
         value = defaultValue;
         if (!value.isValid()) {
             qWarning("Accessing missing option %s", qPrintable(name));
@@ -72,10 +64,10 @@ QVariant OptionsTree::getOption(const QString& name, const QVariant &defaultValu
  * \param name "Path" to the option
  * \param value Value of the option
  */
-void OptionsTree::setOption(const QString& name, const QVariant& value)
+void OptionsTree::setOption(const QString &name, const QVariant &value)
 {
     const QVariant &prev = tree_.getValue(name);
-    if ( prev == value ) {
+    if (prev == value) {
         return;
     }
     if (!prev.isValid()) {
@@ -88,33 +80,23 @@ void OptionsTree::setOption(const QString& name, const QVariant& value)
     emit optionChanged(name);
 }
 
-
 /**
  * @brief returns true if the node @a node is an internal node.
  */
-bool OptionsTree::isInternalNode(const QString &node) const
-{
-    return tree_.isInternalNode(node);
-}
+bool OptionsTree::isInternalNode(const QString &node) const { return tree_.isInternalNode(node); }
 
 /**
  * \brief Sets the comment of the named option.
  * \param name "Path" to the option
  * \param comment the comment to store
  */
-void OptionsTree::setComment(const QString& name, const QString& comment)
-{
-    tree_.setComment(name,comment);
-}
+void OptionsTree::setComment(const QString &name, const QString &comment) { tree_.setComment(name, comment); }
 
 /**
  * \brief Returns the comment of the specified option.
  * \param name "Path" to the option
  */
-QString OptionsTree::getComment(const QString& name) const
-{
-    return tree_.getComment(name);
-}
+QString OptionsTree::getComment(const QString &name) const { return tree_.getComment(name); }
 
 bool OptionsTree::removeOption(const QString &name, bool internal_nodes)
 {
@@ -124,15 +106,11 @@ bool OptionsTree::removeOption(const QString &name, bool internal_nodes)
     return ok;
 }
 
-
 /**
  * Names of every stored option
  * \return Names of options
  */
-QStringList OptionsTree::allOptionNames() const
-{
-    return tree_.nodeChildren();
-}
+QStringList OptionsTree::allOptionNames() const { return tree_.nodeChildren(); }
 
 /**
  * Names of all child options of the given option.
@@ -140,25 +118,25 @@ QStringList OptionsTree::allOptionNames() const
  * \param internal_nodes include internal (non-final) nodes
  * \return Full names of options
  */
-QStringList OptionsTree::getChildOptionNames(const QString& parent, bool direct, bool internal_nodes) const
+QStringList OptionsTree::getChildOptionNames(const QString &parent, bool direct, bool internal_nodes) const
 {
-    return tree_.nodeChildren(parent,direct,internal_nodes);
+    return tree_.nodeChildren(parent, direct, internal_nodes);
 }
 
 bool OptionsTree::isValidName(const QString &name)
 {
-    foreach(QString part, name.split('.')) {
-        if (!VariantTree::isValidNodeName(part)) return false;
+    for (const QString &part : name.split('.')) {
+        if (!VariantTree::isValidNodeName(part))
+            return false;
     }
     return true;
 }
 
-
 QString OptionsTree::mapLookup(const QString &basename, const QVariant &key) const
 {
-    QStringList children = getChildOptionNames( basename, true, true);
-    foreach (QString path, children) {
-        if (getOption(path+".key") == key) {
+    QStringList children = getChildOptionNames(basename, true, true);
+    for (const QString &path : children) {
+        if (getOption(path + ".key") == key) {
             return path;
         }
     }
@@ -166,11 +144,14 @@ QString OptionsTree::mapLookup(const QString &basename, const QVariant &key) con
     return basename + "XXX";
 }
 
-QVariant OptionsTree::mapGet(const QString &basename, const QVariant &key, const QString &node) const {
+QVariant OptionsTree::mapGet(const QString &basename, const QVariant &key, const QString &node) const
+{
     return getOption(mapLookup(basename, key) + '.' + node);
 }
 
-QVariant OptionsTree::mapGet(const QString &basename, const QVariant &key, const QString &node, const QVariant &def) const {
+QVariant OptionsTree::mapGet(const QString &basename, const QVariant &key, const QString &node,
+                             const QVariant &def) const
+{
     QVariantList keys = mapKeyList(basename);
     if (keys.contains(key)) {
         return getOption(mapLookup(basename, key) + '.' + node);
@@ -179,12 +160,11 @@ QVariant OptionsTree::mapGet(const QString &basename, const QVariant &key, const
     }
 }
 
-
 QString OptionsTree::mapPut(const QString &basename, const QVariant &key)
 {
-    QStringList children = getChildOptionNames( basename, true, true);
-    foreach (QString path, children) {
-        if (getOption(path+".key") == key) {
+    QStringList children = getChildOptionNames(basename, true, true);
+    for (const QString &path : children) {
+        if (getOption(path + ".key") == key) {
             return path;
         }
     }
@@ -192,55 +172,50 @@ QString OptionsTree::mapPut(const QString &basename, const QVariant &key)
 
     // allocate first unused index
     QString path;
-    int i = 0;
+    int     i = 0;
     do {
-        path = basename+".m"+QString::number(i);
+        path = basename + ".m" + QString::number(i);
         ++i;
     } while (children.contains(path));
     setOption(path + ".key", key);
     return path;
 }
 
-void OptionsTree::mapPut(const QString &basename, const QVariant &key, const QString &node, const QVariant &value) {
+void OptionsTree::mapPut(const QString &basename, const QVariant &key, const QString &node, const QVariant &value)
+{
     setOption(mapPut(basename, key) + '.' + node, value);
 }
 
 bool mapKeyListLessThanByNumber(const QString &s1, const QString &s2)
 {
     int dotpos = s1.lastIndexOf('.');
-    if (s1.leftRef(dotpos+1).compare(s2.leftRef(dotpos+1)) == 0)
-    {
-        QString name1 = s1.mid(dotpos+1), name2 = s2.mid(dotpos+1);
-        if (name1[0] == 'm' && name2[0] == 'm')
-        {
-            bool ok1 = false, ok2 = false;
+    if (s1.leftRef(dotpos + 1).compare(s2.leftRef(dotpos + 1)) == 0) {
+        QString name1 = s1.mid(dotpos + 1), name2 = s2.mid(dotpos + 1);
+        if (name1[0] == 'm' && name2[0] == 'm') {
+            bool         ok1 = false, ok2 = false;
             unsigned int n1 = name1.mid(1).toUInt(&ok1), n2 = name2.mid(1).toUInt(&ok2);
-            if (ok1 && ok2)
-            {
+            if (ok1 && ok2) {
                 return n1 < n2;
             }
         }
     }
-    //fallback to string comparison
+    // fallback to string comparison
     return s1 < s2;
 }
 
 QVariantList OptionsTree::mapKeyList(const QString &basename, bool sortedByNumbers) const
 {
     QVariantList ret;
-    QStringList children = getChildOptionNames( basename, true, true);
-    if (sortedByNumbers)
-    {
-        qSort(children.begin(), children.end(), mapKeyListLessThanByNumber);
+    QStringList  children = getChildOptionNames(basename, true, true);
+    if (sortedByNumbers) {
+        std::sort(children.begin(), children.end(), mapKeyListLessThanByNumber);
     }
-    foreach (QString path, children) {
-        ret << getOption(path+".key");
+    for (const QString &path : children) {
+        ret << getOption(path + ".key");
     }
     return ret;
 }
 
-
-
 /**
  * Saves all options to the specified file
  * \param fileName Name of the file to which to save options
@@ -249,7 +224,8 @@ QVariantList OptionsTree::mapKeyList(const QString &basename, bool sortedByNumbe
  * \param configNS Namespace of the config format
  * \return 'true' if the file saves, 'false' if it fails
  */
-bool OptionsTree::saveOptions(const QString& fileName, const QString& configName, const QString& configNS, const QString& configVersion, bool streamWriter) const
+bool OptionsTree::saveOptions(const QString &fileName, const QString &configName, const QString &configNS,
+                              const QString &configVersion, bool streamWriter) const
 {
     AtomicXmlFile f(fileName);
     if (streamWriter) {
@@ -268,10 +244,7 @@ bool OptionsTree::saveOptions(const QString& fileName, const QString& configName
     doc.appendChild(base);
 
     tree_.toXml(doc, base);
-    if (!f.saveDocument(doc))
-        return false;
-
-    return true;
+    return f.saveDocument(doc);
 }
 
 /**
@@ -282,7 +255,8 @@ bool OptionsTree::saveOptions(const QString& fileName, const QString& configName
  * \param configNS Namespace of the config format
  * \return 'true' if the file loads, 'false' if it fails
  */
-bool OptionsTree::loadOptions(const QString& fileName, const QString& configName, const QString& configNS,  const QString& configVersion, bool streamReader)
+bool OptionsTree::loadOptions(const QString &fileName, const QString &configName, const QString &configNS,
+                              const QString &configVersion, bool streamReader)
 {
     AtomicXmlFile f(fileName);
     if (streamReader) {
@@ -297,14 +271,11 @@ bool OptionsTree::loadOptions(const QString& fileName, const QString& configName
     return loadOptions(doc.documentElement(), configName, configVersion, configNS);
 }
 
-
 /**
  * Checks for existing saved Options.
  * Does not guarantee that load succeeds if the config file was corrupted.
  */
-bool OptionsTree::exists(QString fileName) {
-    return AtomicXmlFile::exists(fileName);
-}
+bool OptionsTree::exists(QString fileName) { return AtomicXmlFile::exists(fileName); }
 
 /**
  * Loads all options from an XML element
@@ -313,18 +284,19 @@ bool OptionsTree::exists(QString fileName) {
  * \param configNS Namespace of the config format
  * \param configVersion If specified, the function will fail if the file version doesn't match
  */
-bool OptionsTree::loadOptions(const QDomElement& base, const QString& configName, const QString& configNS, const QString& configVersion)
+bool OptionsTree::loadOptions(const QDomElement &base, const QString &configName, const QString &configNS,
+                              const QString &configVersion)
 {
     Q_UNUSED(configName);
     Q_UNUSED(configNS);
     Q_UNUSED(configVersion);
 
     // Version check
-    //if(base.tagName() != configName)
+    // if(base.tagName() != configName)
     //    return false;
-    //if(configVersion!="" && base.attribute("version") != configVersion)
+    // if(configVersion!="" && base.attribute("version") != configVersion)
     //    return false;
-    //if(configNS!="" && base.attribute("xmlns")  != configNS)
+    // if(configNS!="" && base.namespaceURI()  != configNS)
     //    return false;
 
     // Convert
