@@ -1,6 +1,6 @@
 /*
  * mprisplugin.cpp
- * Copyright (C) 2010 Vitaly Tonkacheyev
+ * Copyright (C) 2010  Vitaly Tonkacheyev
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -22,33 +21,26 @@
 #define QT_STATICPLUGIN
 #endif
 
-#include <QtCore>
-#include <QObject>
-#include <QString>
-
 #include "mpristunecontroller.h"
 #include "tunecontrollerplugin.h"
 
-class MPRISPlugin : public QObject, public TuneControllerPlugin
-{
+#include <QObject>
+#include <QString>
+#include <QtCore>
+
+class MPRISPlugin : public QObject, public TuneControllerPlugin {
 
     Q_OBJECT
 
     Q_INTERFACES(TuneControllerPlugin)
     Q_PLUGIN_METADATA(IID "org.psi-im.Psi.TuneControllerPlugin")
 public:
-    virtual QString name();
-    virtual TuneController* createController();
+    virtual QString         name();
+    virtual TuneController *createController();
 };
 
-QString MPRISPlugin::name()
-{
-    return "MPRIS";
-}
+QString MPRISPlugin::name() { return "MPRIS"; }
 
-TuneController* MPRISPlugin::createController()
-{
-    return new MPRISTuneController();
-}
+TuneController *MPRISPlugin::createController() { return new MPRISTuneController(); }
 
 #include "mprisplugin.moc"
