@@ -13,21 +13,17 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
-#include "applicationinfo.h"
 #include "psifileplugin.h"
 
+#include "applicationinfo.h"
 
-QString PsiFilePlugin::name()
-{
-    return "Psi File";
-}
+QString PsiFilePlugin::name() { return "Psi File"; }
 
-TuneController* PsiFilePlugin::createController()
+TuneController *PsiFilePlugin::createController()
 {
     return new FileTuneController(ApplicationInfo::homeDir(ApplicationInfo::CacheLocation) + "/tune");
 }
