@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -25,28 +24,24 @@
 #define QT_STATICPLUGIN
 #endif
 
-#include <QtCore>
+#include "filetunecontroller.h"
+#include "tunecontrollerplugin.h"
+
 #include <QObject>
 #include <QString>
-
-#include "tunecontrollerplugin.h"
-#include "filetunecontroller.h"
-
-
-
+#include <QtCore>
 
 /**
  * \brief A TuneController plugin for the Psi file controller.
  */
-class PsiFilePlugin : public QObject, public TuneControllerPlugin
-{
+class PsiFilePlugin : public QObject, public TuneControllerPlugin {
     Q_OBJECT
     Q_PLUGIN_METADATA(IID "org.psi-im.Psi.TuneControllerPlugin")
     Q_INTERFACES(TuneControllerPlugin)
 
 public:
-    virtual QString name();
-    virtual TuneController* createController();
+    virtual QString         name();
+    virtual TuneController *createController();
 };
 
-#endif
+#endif // PSIFILEPLUGIN_H
