@@ -13,20 +13,14 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "winampplugin.h"
 
+#include "moc_winampplugin.cpp"
 
-QString WinAmpPlugin::name()
-{
-    return "WinAmp";
-}
+QString WinAmpPlugin::name() { return "WinAmp"; }
 
-TuneController* WinAmpPlugin::createController()
-{
-    return new WinAmpTuneController();
-}
+TuneController *WinAmpPlugin::createController() { return new WinAmpTuneController(); }
