@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -25,23 +24,21 @@
 #define QT_STATICPLUGIN
 #endif
 
-#include <QtCore>
+#include "tunecontrollerplugin.h"
+#include "winamptunecontroller.h"
+
 #include <QObject>
 #include <QString>
+#include <QtCore>
 
-#include "winamptunecontroller.h"
-#include "tunecontrollerplugin.h"
-
-class WinAmpPlugin : public QObject, public TuneControllerPlugin
-{
+class WinAmpPlugin : public QObject, public TuneControllerPlugin {
     Q_OBJECT
     Q_INTERFACES(TuneControllerPlugin)
     Q_PLUGIN_METADATA(IID "org.psi-im.Psi.TuneControllerPlugin")
 
 public:
-    virtual QString name();
-    virtual TuneController* createController();
+    virtual QString         name();
+    virtual TuneController *createController();
 };
 
-#endif
-
+#endif // WINAMPPLUGIN_H
