@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -23,18 +22,17 @@
 
 #include "pollingtunecontroller.h"
 
-#include <windows.h>
 #include <QPair>
+#include <windows.h>
 
-class WinAmpTuneController : public PollingTuneController
-{
+class WinAmpTuneController : public PollingTuneController {
     Q_OBJECT
 public:
     WinAmpTuneController();
     virtual Tune currentTune() const;
 
 private:
-    Tune getTune(const HWND &hWnd);
+    Tune                 getTune(const HWND &hWnd);
     QPair<bool, QString> getTrackTitle(const HWND &waWnd) const;
 
 protected slots:
@@ -42,7 +40,7 @@ protected slots:
 
 private:
     Tune prevTune_;
-    int antiscrollCounter_;
+    int  antiscrollCounter_;
 };
 
-#endif
+#endif // WINAMPTUNECONTROLLER_H
