@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -24,17 +23,16 @@
 #include <QObject>
 
 class PsiAccount;
-namespace XMPP {
-    class Jid;
-}
 
+namespace XMPP {
+class Jid;
+}
 using namespace XMPP;
 
 /**
  * \brief An abstract class for a voice call implementation.
  */
-class VoiceCaller : public QObject
-{
+class VoiceCaller : public QObject {
     Q_OBJECT
 
 public:
@@ -43,12 +41,12 @@ public:
      *
      * \param account the account to which this voice caller belongs
      */
-    VoiceCaller(PsiAccount* account) : account_(account) { };
+    VoiceCaller(PsiAccount *account) : account_(account) {};
 
     /**
      * \brief Retrieves the account to which this voice caller belongs.
      */
-    PsiAccount* account() { return account_; }
+    PsiAccount *account() { return account_; }
 
     /**
      * \brief Initializes the voice caller.
@@ -65,51 +63,51 @@ public:
     /**
      * \brief Call the given JID.
      */
-    virtual void call(const Jid&) = 0;
+    virtual void call(const Jid &) = 0;
 
     /**
      * \brief Accept a call from the given JID.
      */
-    virtual void accept(const Jid&) = 0;
+    virtual void accept(const Jid &) = 0;
 
     /**
      * \brief Reject the call from the given JID.
      */
-    virtual void reject(const Jid&) = 0;
+    virtual void reject(const Jid &) = 0;
 
     /**
      * \brief Terminate the call from the given JID.
      */
-    virtual void terminate(const Jid&) = 0;
+    virtual void terminate(const Jid &) = 0;
 
 signals:
     /**
      * \brief Incoming call from the given JID.
      */
-    void incoming(const Jid&);
+    void incoming(const Jid &);
 
     /**
      * \brief Contact accepted an incoming call.
      */
-    void accepted(const Jid&);
+    void accepted(const Jid &);
 
     /**
      * \brief Contact rejected an incoming call.
      */
-    void rejected(const Jid&);
+    void rejected(const Jid &);
 
     /**
      * \brief Call with given JID is in progress.
      */
-    void in_progress(const Jid&);
+    void in_progress(const Jid &);
 
     /**
      * \brief Call with given JID is terminated.
      */
-    void terminated(const Jid&);
+    void terminated(const Jid &);
 
 private:
-    PsiAccount* account_;
+    PsiAccount *account_;
 };
 
-#endif
+#endif // VOICECALLER_H
