@@ -17,30 +17,29 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef WBMANAGER_H
 #define WBMANAGER_H
 
-#include <QInputDialog>
-
 #include "../sxe/sxemanager.h"
 #include "wbdlg.h"
 
+#include <QInputDialog>
+
 #define WBNS "http://www.w3.org/2000/svg"
 
-namespace XMPP {
-    class Client;
-    class Jid;
-    class Message;
-}
-
-using namespace XMPP;
 class WbRequest;
 
+namespace XMPP {
+class Client;
+class Jid;
+class Message;
+}
+using namespace XMPP;
+
 /*! \brief The manager for whiteboard dialogs.
  *  The manager listen to SxeManager to pick up any new sessions negotiated by
  *  it and creates a dialog for each session.
@@ -50,18 +49,17 @@ class WbRequest;
  *
  *  \sa WbDlg
  */
-class WbManager : public QObject
-{
+class WbManager : public QObject {
     Q_OBJECT
 
 public:
     /*! \brief Constructor.
      *  Creates a new manager for the specified Client and PsiAccount
      */
-    WbManager(XMPP::Client* client, PsiAccount* pa, SxeManager* sxemanager);
+    WbManager(XMPP::Client *client, PsiAccount *pa, SxeManager *sxemanager);
     ~WbManager();
     /*! \brief Returns true if features contains WBNS and the user wishes to accept the invitation. */
-    //static bool checkInvitation(const Jid &peer, const QList<QString> &features);
+    // static bool checkInvitation(const Jid &peer, const QList<QString> &features);
     void requestActivated(int id);
 
 public slots:
@@ -72,27 +70,27 @@ private:
     /*! \brief Return a pointer to a dialog to the specified contact.
      *  If such dialog doesn't exits, returns 0.
      */
-    WbDlg* findWbDlg(const Jid &target);
+    WbDlg *findWbDlg(const Jid &target);
 
     /*! \brief A pointer to the PsiAccount to pass to new dialogs.*/
-    PsiAccount* pa_;
+    PsiAccount *pa_;
     /*! \brief A list of dialogs of established sessions.*/
-    QList<WbDlg*> dialogs_;
+    QList<WbDlg *> dialogs_;
     /*! \brief A pointer to the SxeManager used for negotiating sessions.*/
-    SxeManager* sxemanager_;
+    SxeManager *sxemanager_;
 
-    QList<WbRequest*> requests_;
+    QList<WbRequest *> requests_;
 
 signals:
     void wbRequest(const Jid &peer, int id);
 
 private slots:
     /*! \brief Removes and deletes the dialog for the given session.*/
-    void removeDialog(WbDlg* dialog);
+    void removeDialog(WbDlg *dialog);
     /*! \brief Returns a pointer to a new dialog to with given contact and session set.*/
-    void createWbDlg(SxeSession* session);
+    void createWbDlg(SxeSession *session);
 
-    void  checkInvitation(const Jid &peer, const QList<QString> &features, bool* result);
+    void checkInvitation(const Jid &peer, const QList<QString> &features, bool *result);
 };
 
-#endif
+#endif // WBMANAGER_H
