@@ -1,6 +1,6 @@
 /*
  * busywidget.h - cool animating widget
- * Copyright (C) 2001, 2002  Justin Karneges
+ * Copyright (C) 2001-2002  Justin Karneges
  *                           Hideaki Omuro
  *
  * This program is free software; you can redistribute it and/or
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -27,16 +26,15 @@
 class CColor;
 class CPanel;
 
-class BusyWidget : public QWidget
-{
+class BusyWidget : public QWidget {
     Q_OBJECT
-    Q_PROPERTY( bool active READ isActive WRITE setActive )
+    Q_PROPERTY(bool active READ isActive WRITE setActive)
 
-    Q_OVERRIDE( QSize minimumSize DESIGNABLE false SCRIPTABLE false )
-    Q_OVERRIDE( QSize maximumSize DESIGNABLE false SCRIPTABLE false )
+    Q_OVERRIDE(QSize minimumSize DESIGNABLE false SCRIPTABLE false)
+    Q_OVERRIDE(QSize maximumSize DESIGNABLE false SCRIPTABLE false)
 
 public:
-    BusyWidget(QWidget *parent=0);
+    BusyWidget(QWidget *parent = nullptr);
     ~BusyWidget();
 
     bool isActive() const;
@@ -58,9 +56,10 @@ private slots:
 
 public:
     class Private;
+
 private:
     Private *d;
     friend class Private;
 };
 
-#endif
+#endif // BUSYWIDGET_H
