@@ -12,9 +12,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -24,39 +23,42 @@
 #include <QAction>
 #include <QList>
 
-class QToolButton;
-class QPixmap;
-class QIcon;
-class PsiIcon;
 class IconToolButton;
+class PsiIcon;
 class QChildEvent;
+class QIcon;
+class QPixmap;
+class QToolButton;
 
-class IconAction : public QAction
-{
+class IconAction : public QAction {
     Q_OBJECT
 public:
     IconAction(QObject *parent, const QString &name = QString());
-    IconAction(const QString &statusTip, const QString &icon, const QString &text, QKeySequence accel, QObject *parent, const QString &name = QString(), bool checkable = false);
-    IconAction(const QString &statusTip, const QString &icon, const QString &text, QList<QKeySequence> accel, QObject *parent, const QString &name = QString(), bool checkable = false);
-    IconAction(const QString &statusTip, const QString &text, QKeySequence accel, QObject *parent, const QString &name = QString(), bool checkable = false);
-    IconAction(const QString &statusTip, const QString &text, QList<QKeySequence> accel, QObject *parent, const QString &name = QString(), bool checkable = false);
+    IconAction(const QString &statusTip, const QString &icon, const QString &text, QKeySequence accel, QObject *parent,
+               const QString &name = QString(), bool checkable = false);
+    IconAction(const QString &statusTip, const QString &icon, const QString &text, QList<QKeySequence> accel,
+               QObject *parent, const QString &name = QString(), bool checkable = false);
+    IconAction(const QString &statusTip, const QString &text, QKeySequence accel, QObject *parent,
+               const QString &name = QString(), bool checkable = false);
+    IconAction(const QString &statusTip, const QString &text, QList<QKeySequence> accel, QObject *parent,
+               const QString &name = QString(), bool checkable = false);
     IconAction(const QString &text, QObject *parent, const QString &icon);
     ~IconAction();
 
     virtual bool addTo(QWidget *);
 
     const PsiIcon *psiIcon() const;
-    void setPsiIcon(const PsiIcon *);
-    void setPsiIcon(const QString &);
-    QString psiIconName() const;
+    void           setPsiIcon(const PsiIcon *);
+    void           setPsiIcon(const QString &);
+    QString        psiIconName() const;
 
-    void setMenu( QMenu * );
+    void setMenu(QMenu *);
 
-    void setIcon( const QIcon & );
-    void setVisible( bool );
+    void setIcon(const QIcon &);
+    void setVisible(bool);
 
     virtual IconAction *copy() const;
-    virtual IconAction &operator=( const IconAction & );
+    virtual IconAction &operator=(const IconAction &);
 
     void setParent(QObject *newParent);
 
@@ -66,41 +68,40 @@ public slots:
     void setText(const QString &);
 
 protected:
-    virtual void doSetMenu(QMenu* menu);
+    virtual void doSetMenu(QMenu *menu);
     virtual void addingToolButton(IconToolButton *) { }
-    //virtual void addingMenuItem(QPopupMenu *, int id) { Q_UNUSED(id); }
+    // virtual void addingMenuItem(QPopupMenu *, int id) { Q_UNUSED(id); }
     QList<IconToolButton *> buttonList();
 
     QString toolTipFromMenuText() const;
 
 private slots:
     void objectDestroyed();
-    void iconUpdated();
     void toolButtonToggled(bool);
 
 public:
     class Private;
+
 private:
     Private *d;
     friend class Private;
 };
 
-class IconActionGroup : public IconAction
-{
+class IconActionGroup : public IconAction {
     Q_OBJECT
 public:
     IconActionGroup(QObject *parent, const char *name = nullptr, bool exclusive = false);
     ~IconActionGroup();
 
-    void setExclusive( bool );
+    void setExclusive(bool);
     bool isExclusive() const;
 
-    void add( QAction * );
+    void add(QAction *);
     void addSeparator();
 
-    bool addTo( QWidget * );
+    bool addTo(QWidget *);
 
-    void setUsesDropDown( bool );
+    void setUsesDropDown(bool);
     bool usesDropDown() const;
 
     void childEvent(QChildEvent *);
@@ -109,13 +110,14 @@ public:
 
     IconAction *copy() const;
 
-    QMenu* popup();
+    QMenu *popup();
 
 public:
     class Private;
+
 private:
     Private *d;
     friend class Private;
 };
 
-#endif
+#endif // ICONACTION_H
