@@ -13,37 +13,35 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #include "typeaheadfind.h"
 
+#include "iconaction.h"
+#include "psioptions.h"
+#include "shortcutmanager.h"
+#include "stretchwidget.h"
+
 #include <QAction>
-#include <QLineEdit>
 #include <QCheckBox>
 #include <QLabel>
+#include <QLineEdit>
 #include <QTextEdit>
 
-#include "iconaction.h"
-#include "stretchwidget.h"
-#include "shortcutmanager.h"
-#include "psioptions.h"
-
 /**
  * \class TypeAheadFindBar
  * \brief The TypeAheadFindBar class provides a toolbar for typeahead finding.
  */
 
-class TypeAheadFindBar::Private
-{
+class TypeAheadFindBar::Private {
 private:
-    void updateFoundStyle(bool state) {
+    void updateFoundStyle(bool state)
+    {
         if (state) {
             le_find->setStyleSheet("");
-        }
-        else {
+        } else {
             le_find->setStyleSheet("QLineEdit { background: #ff6666; color: #ffffff }");
         }
     }
@@ -60,8 +58,8 @@ public:
         if (backward) {
             options |= QTextDocument::FindBackward;
 
-            if (widgetType == TypeAheadFindBar::WebViewType) {
-                //FIXME make it work with web
+            if (widgetType == TypeAheadFindBar::Type::WebView) {
+                // FIXME make it work with web
             } else {
                 // move cursor before currect selection
                 // to prevent finding the same occurence again
@@ -71,37 +69,38 @@ public:
                 te->setTextCursor(cursor);
             }
         }
-#ifdef WEBENGINE
         find(text, options);
-#else
-        updateFoundStyle(find(text, options));
-#endif
     }
 
     // real search code
 
-    bool find(const QString &str, QTextDocument::FindFlags options, QTextCursor::MoveOperation start = QTextCursor::NoMove)
+    void find(const QString &str, QTextDocument::FindFlags options,
+              QTextCursor::MoveOperation start = QTextCursor::NoMove)
     {
-        if (widgetType == TypeAheadFindBar::WebViewType) {
+        if (widgetType == TypeAheadFindBar::Type::WebView) {
 #ifdef WEBKIT
 #ifdef WEBENGINE
             QWebEnginePage::FindFlags wkOptions;
-            wkOptions |= options & QTextDocument::FindBackward? QWebEnginePage::FindBackward : (QWebEnginePage::FindFlags)0;
-            wkOptions |= options & QTextDocument::FindCaseSensitively? QWebEnginePage::FindCaseSensitively : (QWebEnginePage::FindFlags)0;
-            wv->findText(str, wkOptions, [this](bool found) {
-                updateFoundStyle(found);
-            });
-            return true; // means nothing
+            wkOptions
+                |= options & QTextDocument::FindBackward ? QWebEnginePage::FindBackward : QWebEnginePage::FindFlags();
+            wkOptions |= options & QTextDocument::FindCaseSensitively ? QWebEnginePage::FindCaseSensitively
+                                                                      : QWebEnginePage::FindFlags();
+            wv->findText(str, wkOptions, [this](bool found) { updateFoundStyle(found); });
 #else
             QWebPage::FindFlags wkOptions;
-            wkOptions |= options & QTextDocument::FindBackward? QWebPage::FindBackward : (QWebPage::FindFlags)0;
-            wkOptions |= options & QTextDocument::FindCaseSensitively? QWebPage::FindCaseSensitively : (QWebPage::FindFlags)0;
-            return wv->findText(str, wkOptions);
+            wkOptions |= options & QTextDocument::FindBackward ? QWebPage::FindBackward : (QWebPage::FindFlags)0;
+            wkOptions |= options & QTextDocument::FindCaseSensitively ? QWebPage::FindCaseSensitively
+                                                                      : (QWebPage::FindFlags)0;
+            updateFoundStyle(wv->findText(str, wkOptions));
 #endif
 #else
             Q_UNUSED(str);
 #endif
+            return;
         }
+
+        // If we are here then it's not webkit/engine.
+
         if (start != QTextCursor::NoMove) {
             QTextCursor cursor = te->textCursor();
             cursor.movePosition(start);
@@ -109,18 +108,16 @@ public:
         }
 
         bool found = te->find(text, options);
-        if (!found) {
-            if (start == QTextCursor::NoMove)
-                return find(text, options, options & QTextDocument::FindBackward ? QTextCursor::End : QTextCursor::Start);
-
-            return false;
+        if (!found && start == QTextCursor::NoMove) {
+            find(text, options, options & QTextDocument::FindBackward ? QTextCursor::End : QTextCursor::Start);
+            return;
         }
 
-        return true;
+        updateFoundStyle(found);
     }
 
-    QString text;
-    bool caseSensitive;
+    QString                text;
+    bool                   caseSensitive;
     TypeAheadFindBar::Type widgetType;
 
     QTextEdit *te;
@@ -128,8 +125,8 @@ public:
     WebView *wv;
 #endif
     QLineEdit *le_find;
-    QAction *act_next;
-    QAction *act_prev;
+    QAction *  act_prev;
+    QAction *  act_next;
     QCheckBox *cb_case;
 };
 
@@ -139,32 +136,31 @@ public:
  * \param title, toolbar's title
  * \param parent, toolbar's parent
  */
-TypeAheadFindBar::TypeAheadFindBar(QTextEdit *textedit, const QString &title, QWidget *parent)
-: QToolBar(title, parent)
+TypeAheadFindBar::TypeAheadFindBar(QTextEdit *textedit, const QString &title, QWidget *parent) : QToolBar(title, parent)
 {
-    d = new Private();
-    d->widgetType = TextEditType;
-    d->te = textedit;
+    d             = new Private();
+    d->widgetType = Type::TextEdit;
+    d->te         = textedit;
     init();
 }
 
 #ifdef WEBKIT
-TypeAheadFindBar::TypeAheadFindBar(WebView *webView, const QString &/*title*/, QWidget */*parent*/)
+TypeAheadFindBar::TypeAheadFindBar(WebView *webView, const QString & /*title*/, QWidget * /*parent*/)
 {
-    d = new Private();
-    d->widgetType = WebViewType;
-    d->wv = webView;
+    d             = new Private();
+    d->widgetType = Type::WebView;
+    d->wv         = webView;
     init();
 }
 #endif
 
 void TypeAheadFindBar::init()
 {
-    setIconSize(QSize(16,16));
+    setIconSize(QSize(16, 16));
     setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Maximum);
 
     d->caseSensitive = false;
-    d->text = "";
+    d->text          = "";
 
     d->le_find = new QLineEdit(this);
     d->le_find->setMaximumWidth(200);
@@ -172,18 +168,18 @@ void TypeAheadFindBar::init()
     connect(d->le_find, SIGNAL(textEdited(const QString &)), SLOT(textChanged(const QString &)));
     addWidget(d->le_find);
 
-    d->act_next = new IconAction(tr("Find next"), "psi/arrowDown", "", 0, this);
-    d->act_next->setEnabled(false);
-    d->act_next->setToolTip(tr("Find next"));
-    connect(d->act_next, SIGNAL(triggered()), SLOT(findNext()));
-    addAction(d->act_next);
-
     d->act_prev = new IconAction(tr("Find previous"), "psi/arrowUp", "", 0, this);
     d->act_prev->setEnabled(false);
     d->act_prev->setToolTip(tr("Find previous"));
     connect(d->act_prev, SIGNAL(triggered()), SLOT(findPrevious()));
     addAction(d->act_prev);
 
+    d->act_next = new IconAction(tr("Find next"), "psi/arrowDown", "", 0, this);
+    d->act_next->setEnabled(false);
+    d->act_next->setToolTip(tr("Find next"));
+    connect(d->act_next, SIGNAL(triggered()), SLOT(findNext()));
+    addAction(d->act_next);
+
     d->cb_case = new QCheckBox(tr("&Case sensitive"), this);
     connect(d->cb_case, SIGNAL(stateChanged(int)), SLOT(caseToggled(int)));
     addWidget(d->cb_case);
@@ -201,7 +197,7 @@ void TypeAheadFindBar::init()
 TypeAheadFindBar::~TypeAheadFindBar()
 {
     delete d;
-    d = 0;
+    d = nullptr;
 }
 
 /**
@@ -210,8 +206,8 @@ TypeAheadFindBar::~TypeAheadFindBar()
  */
 void TypeAheadFindBar::optionsUpdate()
 {
-    d->act_next->setShortcuts(ShortcutManager::instance()->shortcuts("chat.find-next"));
     d->act_prev->setShortcuts(ShortcutManager::instance()->shortcuts("chat.find-prev"));
+    d->act_next->setShortcuts(ShortcutManager::instance()->shortcuts("chat.find-next"));
 }
 
 /**
@@ -242,7 +238,7 @@ void TypeAheadFindBar::toggleVisibility()
     if (isVisible())
         hide();
     else
-        //show();
+        // show();
         open();
 }
 
@@ -252,29 +248,28 @@ void TypeAheadFindBar::toggleVisibility()
 void TypeAheadFindBar::textChanged(const QString &str)
 {
     QTextCursor cursor;
-    if (d->widgetType == TextEditType) {
+    if (d->widgetType == Type::TextEdit) {
         cursor = d->te->textCursor();
     }
 
     if (str.isEmpty()) {
-        d->act_next->setEnabled(false);
         d->act_prev->setEnabled(false);
+        d->act_next->setEnabled(false);
         d->le_find->setStyleSheet("");
-        if (d->widgetType == WebViewType) {
+        if (d->widgetType == Type::WebView) {
 #ifdef WEBKIT
-            d->wv->page()->findText(""); //its buggy in qt-4.6.0
+            d->wv->page()->findText(""); // its buggy in qt-4.6.0
 #endif
-        } else { //TextEditType
+        } else { // TextEditType
             cursor.clearSelection();
             d->te->setTextCursor(cursor);
         }
         d->le_find->setStyleSheet("");
-    }
-    else {
-        d->act_next->setEnabled(true);
+    } else {
         d->act_prev->setEnabled(true);
+        d->act_next->setEnabled(true);
 
-        if (d->widgetType == TextEditType) {
+        if (d->widgetType == Type::TextEdit) {
             // don't jump to next word occurence after appending new charater
             cursor.setPosition(cursor.selectionStart());
             d->te->setTextCursor(cursor);
@@ -288,23 +283,14 @@ void TypeAheadFindBar::textChanged(const QString &str)
 /**
  * \brief Private slot activated when find-next is requested.
  */
-void TypeAheadFindBar::findNext()
-{
-    d->doFind();
-}
+void TypeAheadFindBar::findNext() { d->doFind(); }
 
 /**
  * \brief Private slot activated when find-prev is requested.
  */
-void TypeAheadFindBar::findPrevious()
-{
-    d->doFind(true);
-}
+void TypeAheadFindBar::findPrevious() { d->doFind(true); }
 
 /**
  * \brief Private slot activated when case-sensitive box is toggled.
  */
-void TypeAheadFindBar::caseToggled(int state)
-{
-    d->caseSensitive = (state == Qt::Checked);
-}
+void TypeAheadFindBar::caseToggled(int state) { d->caseSensitive = (state == Qt::Checked); }
