@@ -1,19 +1,20 @@
 #include "../../psirichtext.cpp"
-#include <QTextDocument>
-#include <QTextCursor>
 
+#include <QTextCursor>
+#include <QTextDocument>
 #include <QtTest/QtTest>
 
-class TestRichText : public QObject
-{
+class TestRichText : public QObject {
     Q_OBJECT
 private:
-    int countText(QTextDocument *doc, QString text) {
-        int result = 0;
+    int countText(QTextDocument *doc, QString text)
+    {
+        int         result = 0;
         QTextCursor cursor(doc);
         cursor.movePosition(QTextCursor::Start, QTextCursor::MoveAnchor);
 
-        forever {
+        forever
+        {
             cursor = doc->find(text, cursor);
             if (cursor.isNull())
                 break;
@@ -25,7 +26,8 @@ private:
     }
 
 private slots:
-    void testSetText() {
+    void testSetText()
+    {
         QTextDocument doc;
         PsiRichText::setText(&doc, "Test <icon name=\"foo\" text=\"bar\">");
         QCOMPARE(countText(&doc, QString(QChar::ObjectReplacementCharacter)), 1);
@@ -34,4 +36,3 @@ private slots:
 
 QTEST_MAIN(TestRichText)
 #include "main.moc"
-
