@@ -1,6 +1,6 @@
 /*
  * xmlconsole.h - dialog for interacting manually with XMPP
- * Copyright (C) 2001, 2002  Justin Karneges, Remko Troncon
+ * Copyright (C) 2001-2002  Justin Karneges, Remko Troncon
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -13,27 +13,25 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef XMLCONSOLE_H
 #define XMLCONSOLE_H
 
-#include <QWidget>
-#include <QDialog>
-#include <QPointer>
-
 #include "ui_xmlconsole.h"
 
-class QTextEdit;
-class QCheckBox;
+#include <QDialog>
+#include <QPointer>
+#include <QWidget>
+
 class PsiAccount;
+class QCheckBox;
+class QTextEdit;
 class XmlPrompt;
 
-class XmlConsole : public QWidget
-{
+class XmlConsole : public QWidget {
     Q_OBJECT
 public:
     XmlConsole(PsiAccount *);
@@ -50,20 +48,19 @@ private slots:
     void xml_textReady(const QString &);
 
 protected:
-    bool filtered(const QString&) const;
+    bool filtered(const QString &) const;
     void addRecord(bool incoming, const QString &str);
 
 private:
-    Ui::XMLConsole ui_;
-    PsiAccount *pa;
+    Ui::XMLConsole      ui_;
+    PsiAccount *        pa;
     QPointer<XmlPrompt> prompt;
 };
 
-class XmlPrompt : public QDialog
-{
+class XmlPrompt : public QDialog {
     Q_OBJECT
 public:
-    XmlPrompt(QWidget *parent=0);
+    XmlPrompt(QWidget *parent = nullptr);
     ~XmlPrompt();
 
 signals:
@@ -76,4 +73,4 @@ private:
     QTextEdit *te;
 };
 
-#endif
+#endif // XMLCONSOLE_H
