@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -300,10 +299,10 @@ chat.util.updateObject(adapter, function(chat){
                 var footerHtml = new Template(cache["Footer.html"] || "").toString({});
                 var initScripts;
                 if (chat.async) {
-                    initScripts = "<script src=\"/psithemes/chatview/moment-with-locales.js\"></script>\n \
-<script src=\"/psithemes/chatview/util.js\"></script>\n \
-<script src=\"/psithemes/chatview/adium/adapter.js\"></script>\n \
-<script src=\"/psiglobal/qwebchannel.js\"></script>\n \
+                    initScripts = "<script src=\"/psi/themes/chatview/moment-with-locales.js\"></script>\n \
+<script src=\"/psi/themes/chatview/util.js\"></script>\n \
+<script src=\"/psi/themes/chatview/adium/adapter.js\"></script>\n \
+<script src=\"/psi/static/qwebchannel.js\"></script>\n \
 <script type=\"text/javascript\">\n \
     new QWebChannel(qt.webChannelTransport, function (channel) {\n \
         window.srvSession = channel.objects.srvSession;\n \
@@ -316,7 +315,7 @@ chat.util.updateObject(adapter, function(chat){
     });\n \
 </script>";
                 } else {
-                    initScripts = "<script src=\"/psithemes/chatview/moment-with-locales.js\"></script>\n \
+                    initScripts = "<script src=\"/psi/themes/chatview/moment-with-locales.js\"></script>\n \
                         <script type=\"text/javascript\"> \
                             window.addEventListener(\"load\", \
                                                       function() { \
@@ -450,7 +449,7 @@ chat.util.updateObject(adapter, function(chat){
                                         template = data.local?templates.outgoingContent:templates.incomingContent;
                                     }
                                     prevGrouppingData = data;
-                                    data.senderStatusIcon="/psiicon/status/online"; //FIXME temporary hack
+                                    data.senderStatusIcon="/psi/icon/status/online"; //FIXME temporary hack
                                     break;
                                 case "join":
                                 case "part":
@@ -548,6 +547,7 @@ chat.util.updateObject(adapter, function(chat){
                 session.localUserAvatarChanged.connect(printAvatar);
 
                 session.newMessage.connect(chat.receiveObject);
+                session.scrollRequested.connect((value) => { window.scrollBy(0, value); });
                 chat.util.rereadOptions();
                 session.signalInited();
             }
